@@ -22,10 +22,9 @@
 
 #include <stdio.h>
 #include <assert.h>
-#ifdef MAME_DEBUG
 #include "driver.h"
-#include "mamedbg.h"
-#include "snprintf.h"
+#include "debugger.h"
+#include "debug/eainfo.h"
 
 #include "saturn.h"
 #include "sat.h"
@@ -1486,7 +1485,3 @@ unsigned saturn_dasm(char *dst, unsigned oldpc)
 
 	return pc-oldpc;
 }
-
-#endif	/* MAME_DEBUG */
-
-
