@@ -32,7 +32,7 @@
 #include <stdlib.h>
 #include "cpuintrf.h"
 #include "state.h"
-#include "mamedbg.h"
+#include "debugger.h"
 #include "tms7000.h"
 
 #define VERBOSE 0
@@ -48,7 +48,6 @@
 static void tms7000_set_irq_line(int irqline, int state);
 static void tms7000_get_context(void *dst);
 static void tms7000_set_context(void *src);
-static unsigned tms7000_dasm(char *buffer, unsigned pc);
 static void tms7000_check_IRQ_lines( void );
 static void tms7000_do_interrupt( UINT16 address, UINT8 line );
 static int tms7000_execute(int cycles);
@@ -192,34 +191,36 @@ static void tms7000_set_context(void *src)
         tms7000_check_IRQ_lines();
 }
 
-static void tms7000_init(void)
+static void tms7000_init(int index, int clock, const void *config, int (*irqcallback)(int))
 {
 	int cpu = cpu_getactivecpu();
 
 	memset(tms7000.pf, 0, 0x100);
 	memset(tms7000.rf, 0, 0x80);
 	
-        /* Save register state */
-	state_save_register_UINT16("tms7000", cpu, "PC", &pPC, 1);
-	state_save_register_UINT8("tms7000", cpu, "SP", &pSP, 1);
-	state_save_register_UINT8("tms7000", cpu, "SR", &pSR, 1);
+	/* Save register state */
+	state_save_register_item("tms7000", cpu, pPC);
+	state_save_register_item("tms7000", cpu, pSP);
+	state_save_register_item("tms7000", cpu, pSR);
         
-        /* Save Interrupt state */
-	state_save_register_UINT8("tms7000", cpu, "interrupts", tms7000.irq_state, 3);
-        
-        /* Save register and perpherial file state */
-	state_save_register_UINT8("tms7000", cpu, "register file", tms7000.rf, 0x80);
-	state_save_register_UINT8("tms7000", cpu, "Perpherial file", tms7000.pf, 0x100);
+	/* Save Interrupt state */
+	state_save_register_item_array("tms7000", cpu, tms7000.irq_state);
 
-        /* Save timer state */
-	state_save_register_INT8("tms7000", cpu, "t1_pre_scaler", &(tms7000.t1_prescaler), 1);
-	state_save_register_UINT8("tms7000", cpu, "t1_capture_latch", &(tms7000.t1_capture_latch), 1);
-	state_save_register_INT16("tms7000", cpu, "t1_decrementer", &(tms7000.t1_decrementer), 1);
+	/* Save register and perpherial file state */
+	state_save_register_item_array("tms7000", cpu, tms7000.rf);
+	state_save_register_item_array("tms7000", cpu, tms7000.pf);
 
-	state_save_register_UINT8("tms7000", cpu, "tms7000_idle_state", &(tms7000.idle_state), 1);
+	/* Save timer state */
+	state_save_register_item("tms7000", cpu, tms7000.t1_prescaler);
+	state_save_register_item("tms7000", cpu, tms7000.t1_capture_latch);
+	state_save_register_item("tms7000", cpu, tms7000.t1_decrementer);
+
+	state_save_register_item("tms7000", cpu, tms7000.idle_state);
+
+	tms7000.irq_callback = irqcallback;
 }
 
-static void tms7000_reset(void *param)
+static void tms7000_reset(void)
 {
 /*	tms7000.architecture = (int)param; */
         
@@ -262,10 +263,6 @@ static void tms7000_reset(void *param)
 	tms7000_div_by_16_trigger = -16;
 }
 
-static void tms7000_exit(void)
-{
-}
-
 
 /**************************************************************************
  * Generic set_info
@@ -289,9 +286,6 @@ static void tms7000_set_info(UINT32 state, union cpuinfo *info)
 		case CPUINFO_INT_REGISTER + TMS7000_T1_CL: tms7000.t1_capture_latch = info->i;	break;
 		case CPUINFO_INT_REGISTER + TMS7000_T1_PS: tms7000.t1_prescaler = info->i;	break;
 		case CPUINFO_INT_REGISTER + TMS7000_T1_DEC: tms7000.t1_decrementer = info->i;	break;
-        
-        /* --- the following bits of info are set as pointers to data or functions --- */
-        case CPUINFO_PTR_IRQ_CALLBACK:	tms7000.irq_callback = info->irqcallback;	break;
     }
 }
 
@@ -347,11 +341,11 @@ void tms7000_get_info(UINT32 state, union cpuinfo *info)
         case CPUINFO_PTR_SET_CONTEXT:	info->setcontext = tms7000_set_context;	break;
         case CPUINFO_PTR_INIT:	info->init = tms7000_init;	break;
         case CPUINFO_PTR_RESET:	info->reset = tms7000_reset;	break;
-        case CPUINFO_PTR_EXIT:	info->exit = tms7000_exit;	break;
         case CPUINFO_PTR_EXECUTE:	info->execute = tms7000_execute;	break;
         case CPUINFO_PTR_BURN:	info->burn = NULL;	/* Not supported */break;
-        case CPUINFO_PTR_DISASSEMBLE:	info->disassemble = tms7000_dasm;	break;
-        case CPUINFO_PTR_IRQ_CALLBACK:	info->irqcallback = tms7000.irq_callback; break;
+#ifdef MAME_DEBUG
+        case CPUINFO_PTR_DISASSEMBLE_NEW:	info->disassemble_new = tms7000_dasm;	break;
+#endif
         case CPUINFO_PTR_INSTRUCTION_COUNTER:	info->icount = &tms7000_icount;	break;
         case CPUINFO_PTR_REGISTER_LAYOUT:	info->p = tms7000_reg_layout;	break;
         case CPUINFO_PTR_WINDOW_LAYOUT:	info->p = tms7000_win_layout;	break;
@@ -399,16 +393,6 @@ void tms7000_exl_get_info(UINT32 state, union cpuinfo *info)
 	}
 }
 
-static unsigned tms7000_dasm(char *buffer, unsigned pc)
-{
-#ifdef MAME_DEBUG
-	return Dasm7000(buffer,pc);
-#else
-	sprintf( buffer, "$%02X", cpu_readop(pc) );
-	return 1;
-#endif
-}
-
 void tms7000_set_irq_line(int irqline, int state)
 {
 	if (tms7000.irq_state[irqline] != state)
@@ -608,7 +592,7 @@ static void tms7000_service_timer1( void )
 
 WRITE8_HANDLER( tms70x0_pf_w )	/* Perpherial file write */
 {
-	data8_t	temp1, temp2, temp3;
+	UINT8	temp1, temp2, temp3;
 	
 	switch( offset )
 	{
@@ -676,8 +660,8 @@ WRITE8_HANDLER( tms70x0_pf_w )	/* Perpherial file write */
 
  READ8_HANDLER( tms70x0_pf_r )	/* Perpherial file read */
 {
-	data8_t result;
-	data8_t	temp1, temp2, temp3;
+	UINT8 result;
+	UINT8	temp1, temp2, temp3;
 	
 	switch( offset )
 	{
