@@ -98,7 +98,7 @@ static int dsk_floppy_verify(UINT8 *diskimage_data)
 
 
 
-static DEVICE_INIT(dsk_floppy)
+static int device_init_dsk_floppy(mess_image *image)
 {
 	return floppy_drive_init(image, NULL);
 }
@@ -106,7 +106,7 @@ static DEVICE_INIT(dsk_floppy)
 
 
 /* load floppy */
-static DEVICE_LOAD(dsk_floppy)
+static int device_load_dsk_floppy(mess_image *image, mame_file *file)
 {
 	int id = image_index_in_device(image);
 	dsk_drive *thedrive = &drives[id];
@@ -158,7 +158,7 @@ static int dsk_save(mess_image *img, unsigned char **ptr)
 }
 
 
-static DEVICE_UNLOAD(dsk_floppy)
+static void device_unload_dsk_floppy(mess_image *image)
 {
 	int id = image_index_in_device(image);
 	dsk_drive *thedrive = &drives[id];
@@ -569,16 +569,25 @@ static int dsk_get_sectors_per_track(mess_image *img, int side)
 
 
 
-void legacydsk_device_getinfo(struct IODevice *dev)
+void legacydsk_device_getinfo(const device_class *devclass, UINT32 state, union devinfo *info)
 {
-	dev->type = IO_FLOPPY;
-	dev->file_extensions = "dsk\0";
-	dev->readable = 1;
-	dev->writeable = 1;
-	dev->creatable = 0;
-	dev->init = device_init_dsk_floppy;
-	dev->load = device_load_dsk_floppy;
-	dev->unload = device_unload_dsk_floppy;
-	/*dev->status = floppy_status;*/
+	switch(state)
+	{
+		/* --- the following bits of info are returned as 64-bit signed integers --- */
+		case DEVINFO_INT_TYPE:							info->i = IO_FLOPPY; break;
+		case DEVINFO_INT_READABLE:						info->i = 1; break;
+		case DEVINFO_INT_WRITEABLE:						info->i = 1; break;
+		case DEVINFO_INT_CREATABLE:						info->i = 0; break;
+
+		/* --- the following bits of info are returned as pointers to data or functions --- */
+		case DEVINFO_PTR_INIT:							info->init = device_init_dsk_floppy; break;
+		case DEVINFO_PTR_LOAD:							info->load = device_load_dsk_floppy; break;
+		case DEVINFO_PTR_UNLOAD:						info->unload = device_unload_dsk_floppy; break;
+		case DEVINFO_PTR_STATUS:						/* info->status = floppy_status; */ break;
+
+		/* --- the following bits of info are returned as NULL-terminated strings --- */
+		case DEVINFO_STR_DEV_FILE:						strcpy(info->s = device_temp_str(), __FILE__); break;
+		case DEVINFO_STR_FILE_EXTENSIONS:				strcpy(info->s = device_temp_str(), "dsk"); break;
+	}
 }
 
