@@ -12,7 +12,14 @@
 #include "devices/flopdrv.h"
 #include "formats/flopimg.h"
 
-void floppy_device_getinfo(struct IODevice *dev, const struct FloppyFormat *floppy_options);
+enum
+{
+	DEVINFO_PTR_FLOPPY_OPTIONS = DEVINFO_PTR_DEV_SPECIFIC
+};
+
+floppy_image *flopimg_get_image(mess_image *image);
+
+void floppy_device_getinfo(const device_class *devclass, UINT32 state, union devinfo *info);
 
 /* hack for apple II; replace this when we think of something better */
 void floppy_install_unload_proc(mess_image *image, void (*proc)(mess_image *image));
@@ -21,6 +28,3 @@ void floppy_install_unload_proc(mess_image *image, void (*proc)(mess_image *imag
 void floppy_install_tracktranslate_proc(mess_image *image, int (*proc)(mess_image *image, floppy_image *floppy, int physical_track));
 
 #endif /* MFLOPIMG_H */
-
-
-
