@@ -10,22 +10,11 @@
 #include <assert.h>
 #include <time.h>
 
+#include "osdepend.h"
 #include "formats/coco_dsk.h"
 #include "formats/basicdsk.h"
 #include "utils.h"
 
-#ifndef MIN
-#define MIN(a,b)		(((a) < (b)) ? (a) : (b))
-#endif
-
-#ifndef TRUE
-#define TRUE	1
-#endif
-
-#ifndef FALSE
-#define FALSE	1
-#endif
-
 /* ----------------------------------------------------------------------- 
  * JVC (Jeff Vavasour CoCo) format                                         
  *                                                                         
@@ -320,6 +309,10 @@ static floperr_t coco_os9_readheader(floppy_image *floppy, struct basicdsk_geome
 	geometry->sector_length = 256;
 	geometry->sectors = (header[0x11] << 8) + header[0x12];
 	geometry->heads = (header[0x10] & 0x01) ? 2 : 1;
+
+	if (!geometry->sectors)
+		return FLOPPY_ERROR_INVALIDIMAGE;
+
 	geometry->tracks = total_sectors / geometry->sectors / geometry->heads;
 
 	if (total_sectors != geometry->tracks * geometry->sectors * geometry->heads)
@@ -725,6 +718,7 @@ static floperr_t coco_dmk_format_track(floppy_image *floppy, int head, int track
 	UINT16 idam_offset;
 	UINT16 crc;
 	UINT8 *track_data;
+	void *track_data_v;
 	UINT32 max_track_size;
 	int *sector_map = NULL;
             
@@ -747,9 +741,10 @@ static floperr_t coco_dmk_format_track(floppy_image *floppy, int head, int track
 		goto done;
 	}
 		
-	err = floppy_load_track(floppy, head, track, TRUE, (void **) &track_data, NULL);
+	err = floppy_load_track(floppy, head, track, TRUE, &track_data_v, NULL);
 	if (err)
 		goto done;
+	track_data = (UINT8 *) track_data_v;
 
 	/* set up sector map */
 	sector_map = malloc(sectors * sizeof(*sector_map));
@@ -769,7 +764,7 @@ static floperr_t coco_dmk_format_track(floppy_image *floppy, int head, int track
 			physical_sector %= sectors;
 		}
 
-		sector_map[physical_sector] = logical_sector;
+		sector_map[physical_sector] = logical_sector + first_sector_id;
 		physical_sector += interleave + 1;
 		physical_sector %= sectors;
 	}
@@ -871,22 +866,24 @@ static UINT32 coco_dmk_get_track_size(floppy_image *floppy, int head, int track)
 	
 	
 
-static floperr_t coco_dmk_seek_sector_in_track(floppy_image *floppy, int head, int track, int sector, int dirtify, UINT8 **sector_data, UINT32 *sector_length)
+static floperr_t coco_dmk_seek_sector_in_track(floppy_image *floppy, int head, int track, int sector, int sector_is_index, int dirtify, UINT8 **sector_data, UINT32 *sector_length)
 {
 	struct dmk_tag *tag = get_dmk_tag(floppy);
 	floperr_t err;
-	UINT32 idam_offset;
+	UINT32 idam_offset = 0;
 	UINT16 calculated_crc;
 	size_t i;
 	size_t offs;
 	int state;
 	UINT8 *track_data;
+	void *track_data_v;
 	size_t track_length;
 	size_t sec_len;
 
-	err = floppy_load_track(floppy, head, track, dirtify, (void **) &track_data, &track_length);
+	err = floppy_load_track(floppy, head, track, dirtify, &track_data_v, &track_length);
 	if (err)
 		return err;
+	track_data = (UINT8 *) track_data_v;
 		
 	/* search for matching IDAM */
 	for (i = 0; i < DMK_TOC_LEN; i++)
@@ -908,12 +905,24 @@ static floperr_t coco_dmk_seek_sector_in_track(floppy_image *floppy, int head, i
 
 		calculated_crc = ccitt_crc16(0xCDB4, &track_data[idam_offset], DMK_IDAM_LENGTH - 2);
 
-		/* check IDAM integrity and check for matching sector */
-		if ((calculated_crc == dmk_idam_crc(&track_data[idam_offset]))
-				&& (track == dmk_idam_track(&track_data[idam_offset]))
-				&& (head == dmk_idam_side(&track_data[idam_offset]))
-				&& (sector == dmk_idam_sector(&track_data[idam_offset])))
-			break;
+		if (calculated_crc == dmk_idam_crc(&track_data[idam_offset]))
+		{
+			if (sector_is_index)
+			{
+				/* the sector is indexed; decrement the index and go */
+				if (sector-- == 0)
+					break;
+			}
+			else
+			{
+				/* check IDAM integrity and check for matching sector */
+				if ((sector == dmk_idam_sector(&track_data[idam_offset]))
+/*					&& (track == dmk_idam_track(&track_data[idam_offset]))	*/
+/*					&& (head == dmk_idam_side(&track_data[idam_offset]))	*/
+					)
+					break;
+			}
+		}
 	}
 
 	if (i >= DMK_TOC_LEN)
@@ -957,23 +966,25 @@ static floperr_t coco_dmk_seek_sector_in_track(floppy_image *floppy, int head, i
 
 static floperr_t coco_dmk_get_sector_length(floppy_image *floppy, int head, int track, int sector, UINT32 *sector_length)
 {
-	return coco_dmk_seek_sector_in_track(floppy, head, track, sector, FALSE, NULL, sector_length);
+	return coco_dmk_seek_sector_in_track(floppy, head, track, sector, FALSE, FALSE, NULL, sector_length);
 }
 
 
 
-static floperr_t coco_dmk_get_indexed_sector_info(floppy_image *floppy, int head, int track, int sector_index, int *sector, UINT32 *sector_length)
+static floperr_t coco_dmk_get_indexed_sector_info(floppy_image *floppy, int head, int track, int sector_index, int *cylinder, int *side, int *sector, UINT32 *sector_length)
 {
 	floperr_t err;
 	UINT32 idam_offset;
 	const UINT8 *track_data;
+	void *track_data_v;
 
 	if (sector_index*2 >= DMK_TOC_LEN)
 		return FLOPPY_ERROR_SEEKERROR;
 
-	err = floppy_load_track(floppy, head, track, FALSE, (void **) &track_data, NULL);
+	err = floppy_load_track(floppy, head, track, FALSE, &track_data_v, NULL);
 	if (err)
 		return err;
+	track_data = (UINT8 *) track_data_v;
 
 	idam_offset = track_data[sector_index * 2 + 1];
 	idam_offset <<= 8;
@@ -983,6 +994,10 @@ static floperr_t coco_dmk_get_indexed_sector_info(floppy_image *floppy, int head
 	if (idam_offset == 0)
 		return FLOPPY_ERROR_SEEKERROR;
 
+	if (cylinder)
+		*cylinder = dmk_idam_track(&track_data[idam_offset]);
+	if (side)
+		*side = dmk_idam_side(&track_data[idam_offset]);
 	if (sector)
 		*sector = dmk_idam_sector(&track_data[idam_offset]);
 	if (sector_length)
@@ -992,7 +1007,7 @@ static floperr_t coco_dmk_get_indexed_sector_info(floppy_image *floppy, int head
 
 
 
-static floperr_t coco_dmk_read_sector(floppy_image *floppy, int head, int track, int sector, void *buffer, size_t buflen)
+static floperr_t internal_coco_dmk_read_sector(floppy_image *floppy, int head, int track, int sector, int sector_is_index, void *buffer, size_t buflen)
 {
 	floperr_t err;
 	UINT32 sector_length;
@@ -1000,7 +1015,7 @@ static floperr_t coco_dmk_read_sector(floppy_image *floppy, int head, int track,
 	UINT16 calculated_crc;
 	UINT8 *sector_data;
 				
-	err = coco_dmk_seek_sector_in_track(floppy, head, track, sector, FALSE, &sector_data, &sector_length);
+	err = coco_dmk_seek_sector_in_track(floppy, head, track, sector, sector_is_index, FALSE, &sector_data, &sector_length);
 	if (err)
 		return err;
 
@@ -1016,17 +1031,17 @@ static floperr_t coco_dmk_read_sector(floppy_image *floppy, int head, int track,
 
 	return FLOPPY_ERROR_SUCCESS;
 }
-	
-	
-	
-static floperr_t coco_dmk_write_sector(floppy_image *floppy, int head, int track, int sector, const void *buffer, size_t buflen)
+
+
+
+static floperr_t internal_coco_dmk_write_sector(floppy_image *floppy, int head, int track, int sector, int sector_is_index, const void *buffer, size_t buflen)
 {
 	floperr_t err;
 	UINT32 sector_length;
 	UINT8 *sector_data;
 	UINT16 crc;
 		
-	err = coco_dmk_seek_sector_in_track(floppy, head, track, sector, TRUE, &sector_data, &sector_length);
+	err = coco_dmk_seek_sector_in_track(floppy, head, track, sector, sector_is_index, TRUE, &sector_data, &sector_length);
 	if (err)
 		return err;
 		
@@ -1043,6 +1058,28 @@ static floperr_t coco_dmk_write_sector(floppy_image *floppy, int head, int track
 
 		
 
+static floperr_t coco_dmk_read_sector(floppy_image *floppy, int head, int track, int sector, void *buffer, size_t buflen)
+{
+	return internal_coco_dmk_read_sector(floppy, head, track, sector, FALSE, buffer, buflen);
+}
+
+static floperr_t coco_dmk_write_sector(floppy_image *floppy, int head, int track, int sector, const void *buffer, size_t buflen)
+{
+	return internal_coco_dmk_write_sector(floppy, head, track, sector, FALSE, buffer, buflen);
+}
+
+static floperr_t coco_dmk_read_indexed_sector(floppy_image *floppy, int head, int track, int sector, void *buffer, size_t buflen)
+{
+	return internal_coco_dmk_read_sector(floppy, head, track, sector, TRUE, buffer, buflen);
+}
+
+static floperr_t coco_dmk_write_indexed_sector(floppy_image *floppy, int head, int track, int sector, const void *buffer, size_t buflen)
+{
+	return internal_coco_dmk_write_sector(floppy, head, track, sector, TRUE, buffer, buflen);
+}
+
+
+
 static void coco_dmk_interpret_header(floppy_image *floppy, int *heads, int *tracks, int *track_size)
 {
 	UINT8 header[DMK_HEADER_LEN];
@@ -1107,6 +1144,8 @@ FLOPPY_CONSTRUCT(coco_dmk_construct)
 	callbacks->get_indexed_sector_info = coco_dmk_get_indexed_sector_info;
 	callbacks->read_sector = coco_dmk_read_sector;
 	callbacks->write_sector = coco_dmk_write_sector;
+	callbacks->read_indexed_sector = coco_dmk_read_indexed_sector;
+	callbacks->write_indexed_sector = coco_dmk_write_indexed_sector;
 
 	return FLOPPY_ERROR_SUCCESS;
 }
