@@ -3,12 +3,11 @@
 /* machine/apple1.c */
 
 DRIVER_INIT( apple1 );
-void apple1_interrupt (void);
+MACHINE_RESET( apple1 );
 SNAPSHOT_LOAD( apple1 );
- READ8_HANDLER( apple1_pia0_kbdin );
- READ8_HANDLER( apple1_pia0_dsprdy );
- READ8_HANDLER( apple1_pia0_kbdrdy );
-WRITE8_HANDLER( apple1_pia0_dspout );
+
+READ8_HANDLER( apple1_cassette_r );
+WRITE8_HANDLER( apple1_cassette_w );
 
 /* vidhrdw/apple1.c */
 
@@ -17,7 +16,10 @@ VIDEO_UPDATE( apple1 );
 
 void apple1_vh_dsp_w (int data);
 void apple1_vh_dsp_clr (void);
+double apple1_vh_dsp_time_to_ready (void);
+
+extern int apple1_vh_clrscrn_pressed;
 
 /* systems/apple1.c */
 
-extern struct GfxLayout apple1_charlayout;
+extern gfx_layout apple1_charlayout;
