@@ -15,10 +15,10 @@ WRITE8_HANDLER( genesis_z80_bank_sel_w );
 
 VIDEO_START(genesis);
 VIDEO_UPDATE(genesis);
-MACHINE_INIT ( genesis );
+MACHINE_RESET ( genesis );
 INTERRUPT_GEN( genesis_interrupt );
 DRIVER_INIT ( genesis );
 
-extern data16_t *genesis_cartridge;
+extern UINT16 *genesis_cartridge;
 extern int genesis_is_ntsc;
 extern int genesis_region;
