@@ -4,10 +4,10 @@
 /* from machine/laser350.c */
 extern int laser_latch;
 
-void init_laser(void);
-MACHINE_INIT( laser350 );
-MACHINE_INIT( laser500 );
-MACHINE_INIT( laser700 );
+DRIVER_INIT(laser);
+MACHINE_RESET( laser350 );
+MACHINE_RESET( laser500 );
+MACHINE_RESET( laser700 );
 
 DEVICE_LOAD( laser_cart );
 DEVICE_UNLOAD( laser_cart );
