@@ -23,7 +23,7 @@
 	Raphael Nabet, 1999-2004.
 */
 
-#include "includes/wd179x.h"
+#include "machine/wd17xx.h"
 #include "smc92x4.h"
 #include "ti99_4x.h"
 #include "99_peb.h"
@@ -288,8 +288,7 @@ static FLOPPY_CONSTRUCT(ti99_floppy_construct)
 }
 
 FLOPPY_OPTIONS_START( ti99 )
-	FLOPPY_OPTION( ti99, "dsk\0",	"TI99 disk image",	ti99_floppy_identify,	ti99_floppy_construct,
-		)
+	FLOPPY_OPTION( ti99, "dsk\0",	"TI99 disk image",	ti99_floppy_identify,	ti99_floppy_construct, NULL)
 FLOPPY_OPTIONS_END
 
 static void ti99_install_tracktranslate_procs(void)
@@ -1140,8 +1139,8 @@ static int hfdc_irq_state;
 
 
 static int hfdc_select_callback(int which, select_mode_t select_mode, int select_line, int gpos);
-static data8_t hfdc_dma_read_callback(int which, offs_t offset);
-static void hfdc_dma_write_callback(int which, offs_t offset, data8_t data);
+static UINT8 hfdc_dma_read_callback(int which, offs_t offset);
+static void hfdc_dma_write_callback(int which, offs_t offset, UINT8 data);
 static void hfdc_int_callback(int which, int state);
 
 static const smc92x4_intf hfdc_intf =
@@ -1206,7 +1205,7 @@ static int hfdc_select_callback(int which, select_mode_t select_mode, int select
 /*
 	Read a byte from buffer in DMA mode
 */
-static data8_t hfdc_dma_read_callback(int which, offs_t offset)
+static UINT8 hfdc_dma_read_callback(int which, offs_t offset)
 {
 	(void) which;
 	return hfdc_ram[offset & 0x7fff];
@@ -1215,7 +1214,7 @@ static data8_t hfdc_dma_read_callback(int which, offs_t offset)
 /*
 	Write a byte to buffer in DMA mode
 */
-static void hfdc_dma_write_callback(int which, offs_t offset, data8_t data)
+static void hfdc_dma_write_callback(int which, offs_t offset, UINT8 data)
 {
 	(void) which;
 	hfdc_ram[offset & 0x7fff] = data;
