@@ -11,28 +11,34 @@
 #include "includes/advision.h"
 #include "devices/cartslot.h"
 #include "image.h"
+#include "cpuintrf.h"
+#include "sound/dac.h"
+#include "cpuint.h"
 
 unsigned char *advision_ram;
 int advision_rambank;
 int advision_framestart;
 int advision_videoenable;
 int advision_videobank;
+static int Lvalue[3];
+static int wLpointer;
+static int rLpointer;
+static int Dvalue;
+static int Gvalue;
 
-MACHINE_INIT( advision )
+MACHINE_RESET( advision )
 {
 	advision_ram = memory_region(REGION_CPU1) + 0x2000;
     advision_rambank = 0x300;
-    cpu_setbank(1,memory_region(REGION_CPU1) + 0x1000);
+    memory_set_bankptr(1,memory_region(REGION_CPU1) + 0x1000);
     advision_framestart = 0;
     advision_videoenable = 0;
-}
+    wLpointer = 0;
+	rLpointer = 0;
+	cpunum_set_input_line(1, INPUT_LINE_RESET, ASSERT_LINE);
 
-DEVICE_LOAD( advision_cart )
-{
-	return cartslot_load_generic(file, REGION_CPU1, 0, 4096, 4096, 0);
 }
 
-
 /****** External RAM ******************************/
 
  READ8_HANDLER ( advision_MAINRAM_r )
@@ -43,6 +49,21 @@ DEVICE_LOAD( advision_cart )
 
 	/* the video hardware interprets reads as writes */
     if (!advision_videoenable) advision_vh_write(d);
+
+     if (advision_videobank == 0x06) {
+		    if (d & 0x01) {
+	   			cpunum_set_input_line(1, INPUT_LINE_RESET, CLEAR_LINE);
+	   		/*	printf("RELEASE RESET\n"); */
+				wLpointer=0;
+				rLpointer=0;
+			}
+			else {
+				cpunum_set_input_line(1, INPUT_LINE_RESET, ASSERT_LINE);
+			/*	printf("SET RESET\n");*/
+			}
+
+		}
+
     return d;
 }
 
@@ -51,6 +72,56 @@ WRITE8_HANDLER ( advision_MAINRAM_w )
     advision_ram[advision_rambank + offset] = data;
 }
 
+
+READ8_HANDLER ( advision_getL )
+{
+	int d = 0;
+
+	d = Lvalue[rLpointer];
+	if (rLpointer < 3 ) rLpointer++;
+
+/*	if (rLpointer == 0) {d = 0x0f; }
+	if (rLpointer == 1) {d = 0x01; }
+	rLpointer++;
+
+	if (rLpointer > 1) rLpointer = 0; */
+
+	/* printf("READ L: %x\n",d); */
+
+	return d;
+}
+
+static void update_dac(void) {
+/*	printf("Clock: %x D: %x  G:%x \n",activecpu_get_icount(),Dvalue, Gvalue); */
+
+  	if (Gvalue == 0 && Dvalue == 0)
+		DAC_data_w(0, 0xff);
+   	else if (Gvalue == 1 && Dvalue == 1)
+   		DAC_data_w(0, 0x80);
+   	else
+		DAC_data_w(0, 0x00);
+}
+
+WRITE8_HANDLER ( advision_putG )
+{
+	Gvalue = data & 0x01;
+	update_dac();
+}
+
+WRITE8_HANDLER ( advision_putD )
+{
+	Dvalue = data & 0x01;
+	update_dac();
+}
+
+
+static void sound_write(int data)
+{
+	Lvalue[wLpointer] = ((data & 0xF0) >> 4);
+	if (wLpointer < 3) wLpointer++;
+	/* printf("WRITE L: %x\n",data); */
+}
+
 /***** 8048 Ports ************************/
 
 WRITE8_HANDLER ( advision_putp1 )
@@ -59,18 +130,16 @@ WRITE8_HANDLER ( advision_putp1 )
 
 	ROM = memory_region(REGION_CPU1);
 	if (data & 0x04)
-		cpu_setbank(1,&ROM[0x0000]);
+		memory_set_bankptr(1,&ROM[0x0000]);
 	else
-		cpu_setbank(1,&ROM[0x1000]);
+		memory_set_bankptr(1,&ROM[0x1000]);
 	advision_rambank = (data & 0x03) << 8;
 }
 
 WRITE8_HANDLER ( advision_putp2 )
 {
-	/*Use to log sound chip writes */
-	/*if (data != 0x20 && data != 0x40 && data != 0x60 && data != 0x80 && data != 0xA0 && data != 0x10) { */
-	/*	logerror("P2 WRITE PC=%x,%x\n",activecpu_get_icount(),data); */
-	/*} */
+
+	sound_write(data);
 
 	if ((advision_videoenable == 0x00) && (data & 0x10))
 	{
