@@ -12,11 +12,11 @@
 #include "driver.h"
 #include "cpu/m6502/m6502.h"
 #include "machine/6522via.h"
-#include "includes/wd179x.h"
+#include "machine/wd17xx.h"
 #include "includes/bbc.h"
 #include "includes/upd7002.h"
 #include "includes/i8271.h"
-#include "includes/mc146818.h"
+#include "machine/mc146818.h"
 #include "machine/mc6850.h"
 #include "devices/basicdsk.h"
 #include "devices/cassette.h"
@@ -73,7 +73,7 @@ Model A memory handling functions
 /* for the model A just address the 4 on board ROM sockets */
 WRITE8_HANDLER ( page_selecta_w )
 {
-	cpu_setbank(4,memory_region(REGION_USER1)+((data&0x03)<<14));
+	memory_set_bankptr(4,memory_region(REGION_USER1)+((data&0x03)<<14));
 }
 
 
@@ -96,9 +96,9 @@ WRITE8_HANDLER ( page_selectb_w )
 	bbc_rombank=data&0x0f;
 	if (bbc_rombank!=1)
 	{
-		cpu_setbank(4,memory_region(REGION_USER1)+(bbc_rombank<<14));
+		memory_set_bankptr(4,memory_region(REGION_USER1)+(bbc_rombank<<14));
 	} else {
-		cpu_setbank(4,memory_region(REGION_USER2)+((bbc_DFSType)<<14));
+		memory_set_bankptr(4,memory_region(REGION_USER2)+((bbc_DFSType)<<14));
 	}
 }
 
@@ -175,14 +175,14 @@ WRITE8_HANDLER ( page_selectbp_w )
 		if (pagedRAM)
 		{
 			/* if paged ram then set 8000 to afff to read from the ram 8000 to afff */
-			cpu_setbank(4,memory_region(REGION_CPU1)+0x8000);
+			memory_set_bankptr(4,memory_region(REGION_CPU1)+0x8000);
 		} else {
 			/* if paged rom then set the rom to be read from 8000 to afff */
-			cpu_setbank(4,memory_region(REGION_USER1)+(bbc_rombank<<14));
+			memory_set_bankptr(4,memory_region(REGION_USER1)+(bbc_rombank<<14));
 		};
 
 		/* set the rom to be read from b000 to bfff */
-		cpu_setbank(6,memory_region(REGION_USER1)+(bbc_rombank<<14)+0x03000);
+		memory_set_bank(6, bbc_rombank);
 	}
 	else
 	{
@@ -190,7 +190,7 @@ WRITE8_HANDLER ( page_selectbp_w )
 		vdusel=(data>>7)&0x01;
 		bbcbp_setvideoshadow(vdusel);
 		/*need to make the video display do a full screen refresh for the new memory area */
-		cpu_setbank(2, memory_region(REGION_CPU1)+0x3000);
+		memory_set_bankptr(2, memory_region(REGION_CPU1)+0x3000);
 	}
 }
 
@@ -226,15 +226,15 @@ static OPBASE_HANDLER( bbcbp_opbase_handler )
 	if (vdusel==0)
 	{
 		/* not in shadow ram mode so just read normal ram */
-		cpu_setbank(2, memory_region(REGION_CPU1)+0x3000);
+		memory_set_bankptr(2, memory_region(REGION_CPU1)+0x3000);
 	} else {
 		if (vdudriverset())
 		{
 			/* if VDUDriver set then read from shadow ram */
-			cpu_setbank(2, memory_region(REGION_CPU1)+0xb000);
+			memory_set_bankptr(2, memory_region(REGION_CPU1)+0xb000);
 		} else {
 			/* else read from normal ram */
-			cpu_setbank(2, memory_region(REGION_CPU1)+0x3000);
+			memory_set_bankptr(2, memory_region(REGION_CPU1)+0x3000);
 		}
 	}
 	return address;
@@ -402,9 +402,9 @@ WRITE8_HANDLER ( bbcm_ACCCON_write )
 
 	if (ACCCON_Y)
 	{
-		cpu_setbank(7,memory_region(REGION_CPU1)+0x9000);
+		memory_set_bankptr(7,memory_region(REGION_CPU1)+0x9000);
 	} else {
-		cpu_setbank(7,memory_region(REGION_USER1)+0x40000);
+		memory_set_bankptr(7,memory_region(REGION_USER1)+0x40000);
 	}
 
 	bbcbp_setvideoshadow(ACCCON_D);
@@ -412,9 +412,9 @@ WRITE8_HANDLER ( bbcm_ACCCON_write )
 
 	if (ACCCON_X)
 	{
-		cpu_setbank( 2, memory_region( REGION_CPU1 ) + 0xb000 );
+		memory_set_bankptr( 2, memory_region( REGION_CPU1 ) + 0xb000 );
 	} else {
-		cpu_setbank( 2, memory_region( REGION_CPU1 ) + 0x3000 );
+		memory_set_bankptr( 2, memory_region( REGION_CPU1 ) + 0x3000 );
 	}
 
 }
@@ -435,13 +435,12 @@ WRITE8_HANDLER ( page_selectbm_w )
 
 	if (pagedRAM)
 	{
-		cpu_setbank(4,memory_region(REGION_CPU1)+0x8000);
-		cpu_setbank(5,memory_region(REGION_USER1)+((bbc_rombank)<<14)+0x1000);
+		memory_set_bankptr(4,memory_region(REGION_CPU1)+0x8000);
+		memory_set_bank(5, bbc_rombank);
 	} else {
-		cpu_setbank(4,memory_region(REGION_USER1)+((bbc_rombank)<<14));
-		cpu_setbank(5,memory_region(REGION_USER1)+((bbc_rombank)<<14)+0x1000);
+		memory_set_bankptr(4,memory_region(REGION_USER1)+((bbc_rombank)<<14));
+		memory_set_bank(5, bbc_rombank);
 	}
-
 }
 
 
@@ -457,13 +456,13 @@ static OPBASE_HANDLER( bbcm_opbase_handler )
 {
 	if (ACCCON_X)
 	{
-		cpu_setbank( 2, memory_region( REGION_CPU1 ) + 0xb000 );
+		memory_set_bankptr( 2, memory_region( REGION_CPU1 ) + 0xb000 );
 	} else {
 		if (ACCCON_E && bbcm_vdudriverset())
 		{
-			cpu_setbank( 2, memory_region( REGION_CPU1 ) + 0xb000 );
+			memory_set_bankptr( 2, memory_region( REGION_CPU1 ) + 0xb000 );
 		} else {
-			cpu_setbank( 2, memory_region( REGION_CPU1 ) + 0x3000 );
+			memory_set_bankptr( 2, memory_region( REGION_CPU1 ) + 0x3000 );
 		}
 	}
 
@@ -1183,6 +1182,7 @@ bbcb_system_via= {
   bbcb_via_system_read_cb2,
   bbcb_via_system_write_porta,
   bbcb_via_system_write_portb,
+  NULL, NULL,
   bbcb_via_system_write_ca2,
   bbcb_via_system_write_cb2,
   bbc_via_system_irq
@@ -1271,6 +1271,8 @@ static struct via6522_interface bbcb_user_via =
 	0,/*via_user_read_cb2, */
 	bbcb_via_user_write_porta,/*via_user_write_porta, */
 	bbcb_via_user_write_portb,/*via_user_write_portb, */
+	0, /*via_user_write_ca1 */
+	0, /*via_user_write_cb1 */
 	bbcb_via_user_write_ca2,/*via_user_write_ca2, */
 	0,/*via_user_write_cb2, */
 	bbc_via_user_irq /*via_user_irq */
@@ -2060,17 +2062,20 @@ DRIVER_INIT( bbcm )
     mc146818_init(MC146818_STANDARD);
 }
 
-MACHINE_INIT( bbca )
+MACHINE_START( bbca )
 {
-	cpu_setbank(1,memory_region(REGION_CPU1));
-	cpu_setbank(3,memory_region(REGION_CPU1));
-
-	cpu_setbank(4,memory_region(REGION_USER1));          /* bank 4 is the paged ROMs     from 8000 to bfff */
-	cpu_setbank(7,memory_region(REGION_USER1)+0x10000);  /* bank 7 points at the OS rom  from c000 to ffff */
-	cpu_setbank(9,memory_region(REGION_USER1)+0x13f00);  /* bank 9 points at the OS rom  from c000 to ffff */
-
 	via_config(0, &bbcb_system_via);
 	via_set_clock(0,1000000);
+	return 0;
+}
+
+MACHINE_RESET( bbca )
+{
+	memory_set_bankptr(1,memory_region(REGION_CPU1));
+	memory_set_bankptr(3,memory_region(REGION_CPU1));
+
+	memory_set_bankptr(4,memory_region(REGION_USER1));          /* bank 4 is the paged ROMs     from 8000 to bfff */
+	memory_set_bankptr(7,memory_region(REGION_USER1)+0x10000);  /* bank 7 points at the OS rom  from c000 to ffff */
 
 	via_reset();
 
@@ -2079,27 +2084,17 @@ MACHINE_INIT( bbca )
 	MC6850_config(&BBC_MC6850_calls);
 }
 
-MACHINE_INIT( bbcb )
+MACHINE_START( bbcb )
 {
-	bbc_DFSType=  (readinputport(21)>>0)&0x07;
-	bbc_SWRAMtype=(readinputport(21)>>3)&0x03;
-	bbc_RAMSize=  (readinputport(21)>>5)&0x01;
+	/*bbc_DFSType=  (readinputport(21)>>0)&0x07; */
+	/*bbc_SWRAMtype=(readinputport(21)>>3)&0x03; */
+	/*bbc_RAMSize=  (readinputport(21)>>5)&0x01; */
+	
+	bbc_DFSType=  (0x03>>0)&0x07;
+	bbc_SWRAMtype=(0x18>>3)&0x03;
+	bbc_RAMSize=  (0x20>>5)&0x01;
+	
 
-	cpu_setbank(1,memory_region(REGION_CPU1));
-	if (bbc_RAMSize)
-	{
-		/* 32K Model B */
-		cpu_setbank(3,memory_region(REGION_CPU1)+0x4000);
-		set_video_memory_lookups(32);
-	} else {
-		/* 16K just repeat the lower 16K*/
-		cpu_setbank(3,memory_region(REGION_CPU1));
-		set_video_memory_lookups(16);
-	}
-
-	cpu_setbank(4,memory_region(REGION_USER1));          /* bank 4 is the paged ROMs     from 8000 to bfff */
-	cpu_setbank(7,memory_region(REGION_USER1)+0x40000);  /* bank 7 points at the OS rom  from c000 to ffff */
-	cpu_setbank(9,memory_region(REGION_USER1)+0x43f00);  /* bank 9 points at the OS rom  from c000 to ffff */
 
 	via_config(0, &bbcb_system_via);
 	via_set_clock(0,1000000);
@@ -2107,6 +2102,37 @@ MACHINE_INIT( bbcb )
 	via_config(1, &bbcb_user_via);
 	via_set_clock(1,1000000);
 
+	/*set up the required disc controller*/
+	switch (bbc_DFSType) {
+	case 0:	case 1: case 2: case 3:
+		previous_i8271_int_state=0;
+		i8271_init(&bbc_i8271_interface);
+		break;
+	case 4: case 5: case 6:
+		previous_wd177x_int_state=1;
+	    wd179x_init(WD_TYPE_177X,bbc_wd177x_callback);
+		break;
+	}
+	return 0;
+}
+
+MACHINE_RESET( bbcb )
+{
+	memory_set_bankptr(1,memory_region(REGION_CPU1));
+	if (bbc_RAMSize)
+	{
+		/* 32K Model B */
+		memory_set_bankptr(3,memory_region(REGION_CPU1)+0x4000);
+		set_video_memory_lookups(32);
+	} else {
+		/* 16K just repeat the lower 16K*/
+		memory_set_bankptr(3,memory_region(REGION_CPU1));
+		set_video_memory_lookups(16);
+	}
+
+	memory_set_bankptr(4,memory_region(REGION_USER1));          /* bank 4 is the paged ROMs     from 8000 to bfff */
+	memory_set_bankptr(7,memory_region(REGION_USER1)+0x40000);  /* bank 7 points at the OS rom  from c000 to ffff */
+
 	via_reset();
 
 	bbcb_IC32_initialise();
@@ -2118,39 +2144,40 @@ MACHINE_INIT( bbcb )
 	/*set up the required disc controller*/
 	switch (bbc_DFSType) {
 	case 0:	case 1: case 2: case 3:
-		previous_i8271_int_state=0;
-		i8271_init(&bbc_i8271_interface);
 		i8271_reset();
 		break;
 	case 4: case 5: case 6:
-		previous_wd177x_int_state=1;
-	    wd179x_init(WD_TYPE_177X,bbc_wd177x_callback);
 	    wd179x_reset();
 		break;
 	}
-
-	tms5220_reset_chip(sndti_token(SOUND_TMS5220, 0));
 }
 
 
-
-MACHINE_INIT( bbcbp )
+MACHINE_START( bbcbp )
 {
-	cpu_setbank(1,memory_region(REGION_CPU1));
-	cpu_setbank(2,memory_region(REGION_CPU1)+0x03000);  /* bank 2 screen/shadow ram     from 3000 to 7fff */
-	cpu_setbank(4,memory_region(REGION_USER1));         /* bank 4 is paged ROM or RAM   from 8000 to afff */
-	cpu_setbank(6,memory_region(REGION_USER1)+0x03000); /* bank 6 is the paged ROMs     from b000 to bfff */
-	cpu_setbank(7,memory_region(REGION_USER1)+0x40000); /* bank 7 points at the OS rom  from c000 to ffff */
-	cpu_setbank(9,memory_region(REGION_USER1)+0x43f00); /* bank 9 points at the OS rom  from c000 to ffff */
-
 	memory_set_opbase_handler(0, bbcbp_opbase_handler);
 
+	/* bank 6 is the paged ROMs     from b000 to bfff */
+	memory_configure_bank(6, 0, 16, memory_region(REGION_USER1) + 0x3000, 1<<14);
+
 	via_config(0, &bbcb_system_via);
 	via_set_clock(0,1000000);
 
 	via_config(1, &bbcb_user_via);
 	via_set_clock(1,1000000);
 
+	wd179x_init(WD_TYPE_177X,bbc_wd177x_callback);
+	return 0;
+}
+
+MACHINE_RESET( bbcbp )
+{
+	memory_set_bankptr(1,memory_region(REGION_CPU1));
+	memory_set_bankptr(2,memory_region(REGION_CPU1)+0x03000);  /* bank 2 screen/shadow ram     from 3000 to 7fff */
+	memory_set_bankptr(4,memory_region(REGION_USER1));         /* bank 4 is paged ROM or RAM   from 8000 to afff */
+	memory_set_bank(6, 0);
+	memory_set_bankptr(7,memory_region(REGION_USER1)+0x40000); /* bank 7 points at the OS rom  from c000 to ffff */
+
 	via_reset();
 
 	bbcb_IC32_initialise();
@@ -2159,30 +2186,36 @@ MACHINE_INIT( bbcbp )
 	MC6850_config(&BBC_MC6850_calls);
 
 	previous_wd177x_int_state=1;
-    wd179x_init(WD_TYPE_177X,bbc_wd177x_callback);
     wd179x_reset();
 }
 
 
 
-MACHINE_INIT( bbcm )
+MACHINE_START( bbcm )
 {
-	cpu_setbank(1,memory_region(REGION_CPU1));			/* bank 1 regular lower ram		from 0000 to 2fff */
-	cpu_setbank(2,memory_region(REGION_CPU1)+0x3000);	/* bank 2 screen/shadow ram		from 3000 to 7fff */
-	cpu_setbank(4,memory_region(REGION_USER1));         /* bank 4 is paged ROM or RAM   from 8000 to 8fff */
-	cpu_setbank(5,memory_region(REGION_USER1)+0x01000); /* bank 5 is the paged ROMs     from 9000 to bfff */
-	cpu_setbank(7,memory_region(REGION_USER1)+0x40000); /* bank 6 OS rom of RAM			from c000 to dfff */
-	cpu_setbank(8,memory_region(REGION_USER1)+0x42000); /* bank 8 OS rom  				from e000 to ffff */
-	cpu_setbank(9,memory_region(REGION_USER1)+0x43f00); /* bank 9 is the top of the OS  from ff00 to ffff */
-
 	memory_set_opbase_handler(0, bbcm_opbase_handler);
 
+	/* bank 5 is the paged ROMs     from 9000 to bfff */
+	memory_configure_bank(5, 0, 16, memory_region(REGION_USER1)+0x01000, 1<<14);
+
 	via_config(0, &bbcb_system_via);
 	via_set_clock(0,1000000);
 
 	via_config(1, &bbcb_user_via);
 	via_set_clock(1,1000000);
 
+	wd179x_init(WD_TYPE_177X,bbc_wd177x_callback);
+	return 0;
+}
+
+MACHINE_RESET( bbcm )
+{
+	memory_set_bankptr(1,memory_region(REGION_CPU1));			/* bank 1 regular lower ram		from 0000 to 2fff */
+	memory_set_bankptr(2,memory_region(REGION_CPU1)+0x3000);	/* bank 2 screen/shadow ram		from 3000 to 7fff */
+	memory_set_bankptr(4,memory_region(REGION_USER1));         /* bank 4 is paged ROM or RAM   from 8000 to 8fff */
+	memory_set_bank(5, 0);
+	memory_set_bankptr(7,memory_region(REGION_USER1)+0x40000); /* bank 6 OS rom of RAM			from c000 to dfff */
+
 	via_reset();
 
 	bbcb_IC32_initialise();
@@ -2191,7 +2224,5 @@ MACHINE_INIT( bbcm )
 	MC6850_config(&BBC_MC6850_calls);
 
 	previous_wd177x_int_state=1;
-    wd179x_init(WD_TYPE_177X,bbc_wd177x_callback);
     wd179x_reset();
-
 }
