@@ -13,10 +13,10 @@
 #include "cpu/m6502/m6502.h"
 #include "sound/sid6581.h"
 #include "mscommon.h"
+#include "machine/6526cia.h"
 
 #define VERBOSE_DBG 1
 #include "includes/cbm.h"
-#include "includes/cia6526.h"
 #include "includes/cbmserb.h"
 #include "includes/vc1541.h"
 #include "includes/vc20tape.h"
@@ -83,16 +83,23 @@ static  READ8_HANDLER(c128_dma8726_port_r)
 }
 
 WRITE8_HANDLER( c128_mmu8722_port_w );
- READ8_HANDLER( c128_mmu8722_port_r );
+READ8_HANDLER( c128_mmu8722_port_r );
+
 WRITE8_HANDLER( c128_write_d000 )
 {
-	if (!c128_write_io) {
+	UINT8 c64_port6510 = (UINT8) cpunum_get_info_int(0, CPUINFO_INT_M6510_PORT);
+
+	if (!c128_write_io)
+	{
 		if (offset + 0xd000 >= c128_ram_top)
 			c64_memory[0xd000 + offset] = data;
 		else
 			c128_ram[0xd000 + offset] = data;
-	} else {
-		switch ((offset&0xf00)>>8) {
+	}
+	else
+	{
+		switch ((offset&0xf00)>>8)
+		{
 		case 0:case 1: case 2: case 3:
 			vic2_port_w (offset & 0x3ff, data);
 			break;
@@ -107,15 +114,15 @@ WRITE8_HANDLER( c128_write_d000 )
 			break;
 		case 8: case 9: case 0xa: case 0xb:
 		    if (c64mode)
-			c64_colorram[(offset & 0x3ff)] = data | 0xf0;
+				c64_colorram[(offset & 0x3ff)] = data | 0xf0;
 		    else
-			c64_colorram[(offset & 0x3ff)|((c64_port6510&3)<<10)] = data | 0xf0; /* maybe all 8 bit connected! */
+				c64_colorram[(offset & 0x3ff)|((c64_port6510&3)<<10)] = data | 0xf0; /* maybe all 8 bit connected! */
 		    break;
 		case 0xc:
-			cia6526_0_port_w (offset & 0xff, data);
+			cia_0_w(offset, data);
 			break;
 		case 0xd:
-			cia6526_1_port_w (offset & 0xff, data);
+			cia_1_w(offset, data);
 			break;
 		case 0xf:
 			c128_dma8726_port_w(offset&0xff,data);
@@ -143,9 +150,9 @@ static  READ8_HANDLER( c128_read_io )
 	case 8: case 9: case 0xa: case 0xb:
 		return c64_colorram[offset & 0x3ff];
 	case 0xc:
-		return cia6526_0_port_r (offset & 0xff);
+		return cia_0_r(offset);
 	case 0xd:
-		return cia6526_1_port_r (offset & 0xff);
+		return cia_1_r(offset);
 	case 0xf:
 		return c128_dma8726_port_r(offset&0xff);
 	case 0xe:default:
@@ -163,7 +170,7 @@ void c128_bankswitch_64 (int reset)
 	if (!c64mode)
 		return;
 
-	data = ((c64_port6510 & c64_ddr6510) | (c64_ddr6510 ^ 0xff)) & 7;
+	data = (UINT8) cpunum_get_info_int(0, CPUINFO_INT_M6510_PORT) & 7;
 	if ((data == old)&&(exrom==c64_exrom)&&(game==c64_game)&&!reset)
 		return;
 
@@ -175,25 +182,25 @@ void c128_bankswitch_64 (int reset)
 	if ((!c64_game && c64_exrom)
 		|| (loram && hiram && !c64_exrom))
 	{
-		memory_set_bankptr (8, c64_roml);
+		memory_set_bankptr(8, c64_roml);
 	}
 	else
 	{
-		memory_set_bankptr (8, c64_memory + 0x8000);
+		memory_set_bankptr(8, c64_memory + 0x8000);
 	}
 
 	if ((!c64_game && c64_exrom && hiram)
 		|| (!c64_exrom))
 	{
-		memory_set_bankptr (9, c64_romh);
+		memory_set_bankptr(9, c64_romh);
 	}
 	else if (loram && hiram)
 	{
-		memory_set_bankptr (9, c64_basic);
+		memory_set_bankptr(9, c64_basic);
 	}
 	else
 	{
-		memory_set_bankptr (9, c64_memory + 0xa000);
+		memory_set_bankptr(9, c64_memory + 0xa000);
 	}
 
 	if ((!c64_game && c64_exrom)
@@ -207,31 +214,31 @@ void c128_bankswitch_64 (int reset)
 		rh = MRA8_BANK5;
 		c128_write_io = 0;
 		if ((!charen && (loram || hiram)))
-			memory_set_bankptr (13, c64_chargen);
+			memory_set_bankptr(13, c64_chargen);
 		else
-			memory_set_bankptr (13, c64_memory + 0xd000);
+			memory_set_bankptr(13, c64_memory + 0xd000);
 	}
 	c128_set_m8502_read_handler(0xd000, 0xdfff, rh);
 
 	if (!c64_game && c64_exrom)
 	{
-		memory_set_bankptr (14, c64_romh);
-		memory_set_bankptr (15, c64_romh+0x1f00);
-		memory_set_bankptr (16, c64_romh+0x1f05);
+		memory_set_bankptr(14, c64_romh);
+		memory_set_bankptr(15, c64_romh+0x1f00);
+		memory_set_bankptr(16, c64_romh+0x1f05);
 	}
 	else
 	{
 		if (hiram)
 		{
-			memory_set_bankptr (14, c64_kernal);
-			memory_set_bankptr (15, c64_kernal+0x1f00);
-			memory_set_bankptr (16, c64_kernal+0x1f05);
+			memory_set_bankptr(14, c64_kernal);
+			memory_set_bankptr(15, c64_kernal+0x1f00);
+			memory_set_bankptr(16, c64_kernal+0x1f05);
 		}
 		else
 		{
-			memory_set_bankptr (14, c64_memory + 0xe000);
-			memory_set_bankptr (15, c64_memory + 0xff00);
-			memory_set_bankptr (16, c64_memory + 0xff05);
+			memory_set_bankptr(14, c64_memory + 0xe000);
+			memory_set_bankptr(15, c64_memory + 0xff00);
+			memory_set_bankptr(16, c64_memory + 0xff05);
 		}
 	}
 	old = data;
@@ -281,8 +288,8 @@ static int mmu_page0, mmu_page1;
 	 c128_ram = c64_memory + MMU_RAM_ADDR;
 	 c128_va1617 = MMU_VIC_ADDR;
 #if 1
-	 memory_set_bankptr (10, c128_z80);
-	 memory_set_bankptr (11, c128_ram+0x1000);
+	 memory_set_bankptr(10, c128_z80);
+	 memory_set_bankptr(11, c128_ram+0x1000);
 	 if ( ((C128_MAIN_MEMORY==RAM256KB)&&(MMU_RAM_ADDR>=0x40000))
 		  ||((C128_MAIN_MEMORY==RAM128KB)&&(MMU_RAM_ADDR>=0x20000)) )
 		 c128_ram=NULL;
@@ -293,32 +300,32 @@ static int mmu_page0, mmu_page1;
 		 c128_ram_bottom = 0;
 
 	 if (MMU_RAM_ADDR==0) { /* this is used in z80 mode for rom on/off switching !*/
-		 memory_set_bankptr (10, c128_z80);
-		 memory_set_bankptr (11, c128_z80+0x400);
+		 memory_set_bankptr(10, c128_z80);
+		 memory_set_bankptr(11, c128_z80+0x400);
 	 } else {
-		 memory_set_bankptr (10, (c128_ram_bottom > 0 ? c64_memory : c128_ram));
-		 memory_set_bankptr (11, (c128_ram_bottom > 0x400 ? c64_memory : c128_ram) + 0x400);
+		 memory_set_bankptr(10, (c128_ram_bottom > 0 ? c64_memory : c128_ram));
+		 memory_set_bankptr(11, (c128_ram_bottom > 0x400 ? c64_memory : c128_ram) + 0x400);
 	 }
-	 memory_set_bankptr (1, (c128_ram_bottom > 0 ? c64_memory : c128_ram));
-	 memory_set_bankptr (2, (c128_ram_bottom > 0x400 ? c64_memory : c128_ram) + 0x400);
+	 memory_set_bankptr(1, (c128_ram_bottom > 0 ? c64_memory : c128_ram));
+	 memory_set_bankptr(2, (c128_ram_bottom > 0x400 ? c64_memory : c128_ram) + 0x400);
 
-	 memory_set_bankptr (3, (c128_ram_bottom > 0x1000 ? c64_memory : c128_ram) + 0x1000);
-	 memory_set_bankptr (4, (c128_ram_bottom > 0x2000 ? c64_memory : c128_ram) + 0x2000);
-	 memory_set_bankptr (5, c128_ram + 0x4000);
+	 memory_set_bankptr(3, (c128_ram_bottom > 0x1000 ? c64_memory : c128_ram) + 0x1000);
+	 memory_set_bankptr(4, (c128_ram_bottom > 0x2000 ? c64_memory : c128_ram) + 0x2000);
+	 memory_set_bankptr(5, c128_ram + 0x4000);
 
 	 if (MMU_TOP)
 		 c128_ram_top = 0x10000 - MMU_SIZE;
 	 else
 		 c128_ram_top = 0x10000;
 
-	 if (c128_ram_top > 0xc000) { memory_set_bankptr (6, c128_ram + 0xc000); }
-	 else { memory_set_bankptr (6, c64_memory + 0xc000); }
-	 if (c128_ram_top > 0xe000) { memory_set_bankptr (7, c128_ram + 0xe000); }
-	 else { memory_set_bankptr (7, c64_memory + 0xd000); }
-	 if (c128_ram_top > 0xf000) { memory_set_bankptr (8, c128_ram + 0xf000); }
-	 else { memory_set_bankptr (8, c64_memory + 0xe000); }
-	 if (c128_ram_top > 0xff05) { memory_set_bankptr (9, c128_ram + 0xff05); }
-	 else { memory_set_bankptr (9, c64_memory + 0xff05); }
+	 if (c128_ram_top > 0xc000) { memory_set_bankptr(6, c128_ram + 0xc000); }
+	 else { memory_set_bankptr(6, c64_memory + 0xc000); }
+	 if (c128_ram_top > 0xe000) { memory_set_bankptr(7, c128_ram + 0xe000); }
+	 else { memory_set_bankptr(7, c64_memory + 0xd000); }
+	 if (c128_ram_top > 0xf000) { memory_set_bankptr(8, c128_ram + 0xf000); }
+	 else { memory_set_bankptr(8, c64_memory + 0xe000); }
+	 if (c128_ram_top > 0xff05) { memory_set_bankptr(9, c128_ram + 0xff05); }
+	 else { memory_set_bankptr(9, c64_memory + 0xff05); }
 
 	 if ( ((C128_MAIN_MEMORY==RAM256KB)&&(MMU_RAM_ADDR>=0x40000))
 		  ||((C128_MAIN_MEMORY==RAM128KB)&&(MMU_RAM_ADDR>=0x20000)) )
@@ -339,17 +346,17 @@ static void c128_bankswitch_128 (int reset)
 		c128_ram_bottom = 0;
 		c128_ram_top = 0x10000;
 
-		memory_set_bankptr (1, c64_memory);
-		memory_set_bankptr (2, c64_memory + 0x100);
+		memory_set_bankptr(1, c64_memory);
+		memory_set_bankptr(2, c64_memory + 0x100);
 
-		memory_set_bankptr (3, c64_memory + 0x200);
-		memory_set_bankptr (4, c64_memory + 0x400);
-		memory_set_bankptr (5, c64_memory + 0x1000);
-		memory_set_bankptr (6, c64_memory + 0x2000);
+		memory_set_bankptr(3, c64_memory + 0x200);
+		memory_set_bankptr(4, c64_memory + 0x400);
+		memory_set_bankptr(5, c64_memory + 0x1000);
+		memory_set_bankptr(6, c64_memory + 0x2000);
 
-		memory_set_bankptr (7, c64_memory + 0x4000);
+		memory_set_bankptr(7, c64_memory + 0x4000);
 
-		memory_set_bankptr (12, c64_memory + 0xc000);
+		memory_set_bankptr(12, c64_memory + 0xc000);
 
 		c128_bankswitch_64 (reset);
 	}
@@ -357,48 +364,48 @@ static void c128_bankswitch_128 (int reset)
 	{
 		c128_ram = c64_memory + MMU_RAM_ADDR;
 		c128_va1617 = MMU_VIC_ADDR;
-		memory_set_bankptr (1, c64_memory + mmu_page0);
-		memory_set_bankptr (2, c64_memory + mmu_page1);
+		memory_set_bankptr(1, c64_memory + mmu_page0);
+		memory_set_bankptr(2, c64_memory + mmu_page1);
 		if (MMU_BOTTOM)
 			{
 				c128_ram_bottom = MMU_SIZE;
 			}
 		else
 			c128_ram_bottom = 0;
-		memory_set_bankptr (3, (c128_ram_bottom > 0x200 ? c64_memory : c128_ram) + 0x200);
-		memory_set_bankptr (4, (c128_ram_bottom > 0x400 ? c64_memory : c128_ram) + 0x400);
-		memory_set_bankptr (5, (c128_ram_bottom > 0x1000 ? c64_memory : c128_ram) + 0x1000);
-		memory_set_bankptr (6, (c128_ram_bottom > 0x2000 ? c64_memory : c128_ram) + 0x2000);
+		memory_set_bankptr(3, (c128_ram_bottom > 0x200 ? c64_memory : c128_ram) + 0x200);
+		memory_set_bankptr(4, (c128_ram_bottom > 0x400 ? c64_memory : c128_ram) + 0x400);
+		memory_set_bankptr(5, (c128_ram_bottom > 0x1000 ? c64_memory : c128_ram) + 0x1000);
+		memory_set_bankptr(6, (c128_ram_bottom > 0x2000 ? c64_memory : c128_ram) + 0x2000);
 
 		if (MMU_RAM_LO)
-			{
-				memory_set_bankptr (7, c128_ram + 0x4000);
-			}
+		{
+			memory_set_bankptr(7, c128_ram + 0x4000);
+		}
 		else
-			{
-				memory_set_bankptr (7, c128_basic);
-			}
+		{
+			memory_set_bankptr(7, c128_basic);
+		}
 
 		if (MMU_RAM_MID)
-			{
-				memory_set_bankptr (8, c128_ram + 0x8000);
-				memory_set_bankptr (9, c128_ram + 0xa000);
-			}
+		{
+			memory_set_bankptr(8, c128_ram + 0x8000);
+			memory_set_bankptr(9, c128_ram + 0xa000);
+		}
 		else if (MMU_ROM_MID)
-			{
-				memory_set_bankptr (8, c128_basic + 0x4000);
-				memory_set_bankptr (9, c128_basic + 0x6000);
-			}
+		{
+			memory_set_bankptr(8, c128_basic + 0x4000);
+			memory_set_bankptr(9, c128_basic + 0x6000);
+		}
 		else if (MMU_INTERNAL_ROM_MID)
-			{
-				memory_set_bankptr (8, c128_internal_function);
-				memory_set_bankptr (9, c128_internal_function + 0x2000);
-			}
+		{
+			memory_set_bankptr(8, c128_internal_function);
+			memory_set_bankptr(9, c128_internal_function + 0x2000);
+		}
 		else
-			{
-				memory_set_bankptr (8, c128_external_function);
-				memory_set_bankptr (9, c128_external_function + 0x2000);
-			}
+		{
+			memory_set_bankptr(8, c128_external_function);
+			memory_set_bankptr(9, c128_external_function + 0x2000);
+		}
 
 		if (MMU_TOP)
 		{
@@ -425,66 +432,66 @@ static void c128_bankswitch_128 (int reset)
 		{
 			if (c128_ram_top > 0xc000)
 			{
-				memory_set_bankptr (12, c128_ram + 0xc000);
+				memory_set_bankptr(12, c128_ram + 0xc000);
 			}
 			else
 			{
-				memory_set_bankptr (12, c64_memory + 0xc000);
+				memory_set_bankptr(12, c64_memory + 0xc000);
 			}
 			if (!MMU_IO_ON)
 			{
 				if (c128_ram_top > 0xd000)
 				{
-					memory_set_bankptr (13, c128_ram + 0xd000);
+					memory_set_bankptr(13, c128_ram + 0xd000);
 				}
 				else
 				{
-					memory_set_bankptr (13, c64_memory + 0xd000);
+					memory_set_bankptr(13, c64_memory + 0xd000);
 				}
 			}
 			if (c128_ram_top > 0xe000)
 			{
-				memory_set_bankptr (14, c128_ram + 0xe000);
+				memory_set_bankptr(14, c128_ram + 0xe000);
 			}
 			else
 			{
-				memory_set_bankptr (14, c64_memory + 0xe000);
+				memory_set_bankptr(14, c64_memory + 0xe000);
 			}
 			if (c128_ram_top > 0xff05)
 			{
-				memory_set_bankptr (16, c128_ram + 0xff05);
+				memory_set_bankptr(16, c128_ram + 0xff05);
 			}
 			else
 			{
-				memory_set_bankptr (16, c64_memory + 0xff05);
+				memory_set_bankptr(16, c64_memory + 0xff05);
 			}
 		}
 		else if (MMU_ROM_HI)
 		{
-			memory_set_bankptr (12, c128_editor);
+			memory_set_bankptr(12, c128_editor);
 			if (!MMU_IO_ON) {
-				memory_set_bankptr (13, c128_chargen);
+				memory_set_bankptr(13, c128_chargen);
 			}
-			memory_set_bankptr (14, c128_kernal);
-			memory_set_bankptr (16, c128_kernal + 0x1f05);
+			memory_set_bankptr(14, c128_kernal);
+			memory_set_bankptr(16, c128_kernal + 0x1f05);
 		}
 		else if (MMU_INTERNAL_ROM_HI)
 		{
-			memory_set_bankptr (12, c128_internal_function);
+			memory_set_bankptr(12, c128_internal_function);
 			if (!MMU_IO_ON) {
-				memory_set_bankptr (13, c128_internal_function + 0x1000);
+				memory_set_bankptr(13, c128_internal_function + 0x1000);
 			}
-			memory_set_bankptr (14, c128_internal_function + 0x2000);
-			memory_set_bankptr (16, c128_internal_function + 0x3f05);
+			memory_set_bankptr(14, c128_internal_function + 0x2000);
+			memory_set_bankptr(16, c128_internal_function + 0x3f05);
 		}
 		else					   /*if (MMU_EXTERNAL_ROM_HI) */
 		{
-			memory_set_bankptr (12, c128_external_function);
+			memory_set_bankptr(12, c128_external_function);
 			if (!MMU_IO_ON) {
-				memory_set_bankptr (13, c128_external_function + 0x1000);
+				memory_set_bankptr(13, c128_external_function + 0x1000);
 			}
-			memory_set_bankptr (14, c128_external_function + 0x2000);
-			memory_set_bankptr (16, c128_external_function + 0x3f05);
+			memory_set_bankptr(14, c128_external_function + 0x2000);
+			memory_set_bankptr(16, c128_external_function + 0x3f05);
 		}
 		if ( ((C128_MAIN_MEMORY==RAM256KB)&&(MMU_RAM_ADDR>=0x40000))
 			 ||((C128_MAIN_MEMORY==RAM128KB)&&(MMU_RAM_ADDR>=0x20000)) ) c128_ram=NULL;
@@ -494,47 +501,60 @@ static void c128_bankswitch_128 (int reset)
 
 static void c128_bankswitch (int reset)
 {
-	if (mmu_cpu != MMU_CPU8502) {
+	if (mmu_cpu != MMU_CPU8502)
+	{
 		if (!MMU_CPU8502)
-			{
-				{
-					DBG_LOG (1, "switching to z80",
-							 ("active %d\n",cpu_getactivecpu()) );
-					memory_set_context(0);
-					c128_bankswitch_z80();
-					memory_set_context(1);
-					cpunum_set_input_line(0, INPUT_LINE_HALT, 0);
-					cpunum_set_input_line(1, INPUT_LINE_HALT, 1);
-				}
-			}
+		{
+			DBG_LOG (1, "switching to z80",
+						("active %d\n",cpu_getactivecpu()) );
+			memory_set_context(0);
+			c128_bankswitch_z80();
+			memory_set_context(1);
+			cpunum_set_input_line(0, INPUT_LINE_HALT, CLEAR_LINE);
+			cpunum_set_input_line(1, INPUT_LINE_HALT, ASSERT_LINE);
+		}
 		else
-			{
-				DBG_LOG (1, "switching to m6502",
-						 ("active %d\n",cpu_getactivecpu()) );
-				memory_set_context(1);
-				c128_bankswitch_128(reset);
-				memory_set_context(0);
-				cpunum_set_input_line(1, INPUT_LINE_HALT, 0);
-				cpunum_set_input_line(0, INPUT_LINE_HALT, 1);
-			}
+		{
+			DBG_LOG (1, "switching to m6502",
+						("active %d\n",cpu_getactivecpu()) );
+			memory_set_context(1);
+			c128_bankswitch_128(reset);
+			memory_set_context(0);
+			cpunum_set_input_line(0, INPUT_LINE_HALT, ASSERT_LINE);
+			cpunum_set_input_line(1, INPUT_LINE_HALT, CLEAR_LINE);
+
+			/* NPW 19-Nov-2005 - In the C128, CPU #0 starts out and hands over
+			 * control to CPU #1.  CPU #1 seems to execute garbage from 0x0000
+			 * up to 0x1100, at which point it finally hits some code
+			 * (presumably set up by CPU #1.) This always worked, but when I
+			 * changed the m8502 CPU core to use an internal memory map, it
+			 * started BRK-ing forever when trying to execute 0x0000.
+			 * 
+			 * I am not sure whether the C128 actually executes this invalid
+			 * memory or if this is a bug in the C128 driver.  In any case, the
+			 * driver used to work with this behavior, so I am doing this hack
+			 * where I set CPU #1's PC to 0x1100 on reset.
+			 */
+			if (cpunum_get_reg(1, REG_PC) == 0x0000)
+				cpunum_set_reg(1, REG_PC, 0x1100);
+		}
 		mmu_cpu = MMU_CPU8502;
 		return;
 	}
-	if (!MMU_CPU8502) {
+	if (!MMU_CPU8502)
 		c128_bankswitch_z80();
-	} else {
+	else
 		c128_bankswitch_128(reset);
-	}
 }
 
 static void c128_mmu8722_reset (void)
 {
-	memset (c128_mmu, 0, sizeof (c128_mmu));
+	memset(c128_mmu, 0, sizeof (c128_mmu));
 	c128_mmu[5] |= 0x38;
 	c128_mmu[10] = 1;
-	mmu_cpu=0;
-    mmu_page0=0;
-    mmu_page1=0x0100;
+	mmu_cpu = 0;
+    mmu_page0 = 0;
+    mmu_page1 = 0x0100;
 	c128_bankswitch (1);
 }
 
@@ -669,6 +689,12 @@ WRITE8_HANDLER( c128_write_a000 )
 		c128_ram[0xa000 + offset] = data;
 }
 
+WRITE8_HANDLER( c128_write_c000 )
+{
+	if (c128_ram!=NULL)
+		c128_ram[0xc000 + offset] = data;
+}
+
 WRITE8_HANDLER( c128_write_e000 )
 {
 	if (offset + 0xe000 >= c128_ram_top)
@@ -700,6 +726,8 @@ WRITE8_HANDLER( c128_write_ff05 )
  */
 static int c128_dma_read(int offset)
 {
+	UINT8 c64_port6510 = (UINT8) cpunum_get_info_int(0, CPUINFO_INT_M6510_PORT);
+
 	/* main memory configuration to include */
 	if (c64mode)
 	{
@@ -721,8 +749,12 @@ static int c128_dma_read(int offset)
 
 static int c128_dma_read_color (int offset)
 {
-    if (c64mode) return c64_colorram[offset & 0x3ff] & 0xf;
-    return c64_colorram[(offset & 0x3ff)|((c64_port6510&0x3)<<10)] & 0xf;
+	UINT8 c64_port6510 = (UINT8) cpunum_get_info_int(0, CPUINFO_INT_M6510_PORT);
+
+	if (c64mode)
+		return c64_colorram[offset & 0x3ff] & 0xf;
+	else
+		return c64_colorram[(offset & 0x3ff)|((c64_port6510&0x3)<<10)] & 0xf;
 }
 
 static void c128_common_driver_init (void)
@@ -730,6 +762,12 @@ static void c128_common_driver_init (void)
 	UINT8 *gfx=memory_region(REGION_GFX1);
 	int i;
 
+	/* configure the M6510 port */
+	cpunum_set_info_fct(1, CPUINFO_PTR_M6510_PORTREAD, (genf *) c64_m6510_port_read);
+	cpunum_set_info_fct(1, CPUINFO_PTR_M6510_PORTWRITE, (genf *) c64_m6510_port_write);
+
+	c64_memory = memory_region(REGION_CPU1);
+
 	c128_basic = memory_region(REGION_CPU1)+0x100000;
 	c64_basic = memory_region(REGION_CPU1)+0x108000;
 	c64_kernal = memory_region(REGION_CPU1)+0x10a000;
@@ -746,19 +784,21 @@ static void c128_common_driver_init (void)
 	for (i=0; i<0x100; i++)
 		gfx[i]=i;
 
-	memset(c64_memory, 0xff, 0x100000);
-	c128 = 1;
 	vc20_tape_open (c64_tape_read);
 
-	cia6526_init();
+	{
+		cia6526_interface cia_intf[2];
+		cia_intf[0] = c64_cia0;
+		cia_intf[1] = c64_cia1;
+		cia_intf[0].tod_clock = c64_pal ? 50 : 60;
+		cia_intf[1].tod_clock = c64_pal ? 50 : 60;
 
-	c64_cia0.todin50hz = c64_pal;
-	cia6526_config (0, &c64_cia0);
-	c64_cia1.todin50hz = c64_pal;
-	cia6526_config (1, &c64_cia1);
+		cia_config(0, &cia_intf[0]);
+		cia_config(1, &cia_intf[1]);
+	}
 }
 
-void c128_driver_init (void)
+DRIVER_INIT( c128 )
 {
 	c128_common_driver_init ();
 	vic6567_init (1, c64_pal,
@@ -768,7 +808,7 @@ void c128_driver_init (void)
 	vdc8563_set_rastering(1);
 }
 
-void c128pal_driver_init (void)
+DRIVER_INIT( c128pal )
 {
 	c64_pal = 1;
 	c128_common_driver_init ();
@@ -779,14 +819,8 @@ void c128pal_driver_init (void)
 	vdc8563_set_rastering(0);
 }
 
-void c128_driver_shutdown (void)
+MACHINE_RESET( c128 )
 {
-	vc20_tape_close ();
-}
-
-MACHINE_INIT( c128 )
-{
-	logerror("reset\n");
 	c64_common_init_machine ();
 	c128_vicaddr = c64_vicaddr = c64_memory;
 
@@ -797,8 +831,8 @@ MACHINE_INIT( c128 )
 
 	c64mode = 0;
 	c128_mmu8722_reset ();
-	cpunum_set_input_line(0, INPUT_LINE_HALT, 0);
-	cpunum_set_input_line(1, INPUT_LINE_HALT, 1);
+	cpunum_set_input_line(0, INPUT_LINE_HALT, CLEAR_LINE);
+	cpunum_set_input_line(1, INPUT_LINE_HALT, ASSERT_LINE);
 }
 
 VIDEO_START( c128 )
