@@ -17,10 +17,10 @@
 #include "cpu/m6502/m6502.h"
 #include "cpu/z80/z80.h"
 #include "sound/sid6581.h"
+#include "machine/6526cia.h"
 
 #define VERBOSE_DBG 1
 #include "includes/cbm.h"
-#include "includes/cia6526.h"
 #include "includes/cbmserb.h"
 #include "includes/vc1541.h"
 #include "includes/vc20tape.h"
@@ -33,15 +33,12 @@
 
 #include "includes/c64.h"
 
+static void c64_driver_shutdown (void);
+
 unsigned char c65_keyline = { 0xff };
-int c65=0;
 UINT8 c65_6511_port=0xff;
 
-/* computer is a c128 */
-int c128 = 0;
-
-UINT8 c128_keyline[3] =
-{0xff, 0xff, 0xff};
+UINT8 c128_keyline[3] = {0xff, 0xff, 0xff};
 
 
 /* keyboard lines */
@@ -55,7 +52,6 @@ int c64_pal = 0;
 UINT8 c64_game=1, c64_exrom=1;
 
 /* cpu port */
-UINT8 c64_port6510, c64_ddr6510;
 int c128_va1617;
 UINT8 *c64_vicaddr, *c128_vicaddr;
 UINT8 *c64_memory;
@@ -77,32 +73,44 @@ static enum
 	CartridgeSuperGames, CartridgeRobocop2
 }
 cartridgetype = CartridgeAuto;
-static UINT8 cia0porta, cia0portb;
 static UINT8 serial_clock, serial_data, serial_atn;
-static UINT8 vicirq = 0, cia0irq = 0, cia1irq = 0;
+static UINT8 vicirq = 0;
+
+static int is_c65(void)
+{
+	return !strncmp(Machine->gamedrv->name, "c65", 3);
+}
+
+static int is_c128(void)
+{
+	return !strncmp(Machine->gamedrv->name, "c128", 4);
+}
 
 static void c64_nmi(void)
 {
-    static int nmilevel = 0;
-    if (nmilevel != KEY_RESTORE||cia1irq)
-    {
-	if (c128) {
-	    if (cpu_getactivecpu()==0) 
+	static int nmilevel = 0;
+	int cia1irq = cia_get_irq(1);
+
+	if (nmilevel != KEY_RESTORE||cia1irq)
+	{
+		if (is_c128())
 		{
-			/* z80 */
-			cpunum_set_input_line(0, INPUT_LINE_NMI, KEY_RESTORE||cia1irq);
-	    }
+			if (cpu_getactivecpu()==0) 
+			{
+				/* z80 */
+				cpunum_set_input_line(0, INPUT_LINE_NMI, KEY_RESTORE||cia1irq);
+			}
+			else
+			{
+				cpunum_set_input_line(1, INPUT_LINE_NMI, KEY_RESTORE||cia1irq);
+			}
+		}
 		else
 		{
-			cpunum_set_input_line(1, INPUT_LINE_NMI, KEY_RESTORE||cia1irq);
-	    }
+			cpunum_set_input_line(0, INPUT_LINE_NMI, KEY_RESTORE||cia1irq);
+		}
+		nmilevel = KEY_RESTORE||cia1irq;
 	}
-	else
-	{
-	    cpunum_set_input_line(0, INPUT_LINE_NMI, KEY_RESTORE||cia1irq);
-	}
-	nmilevel = KEY_RESTORE||cia1irq;
-    }
 }
 
 
@@ -122,116 +130,128 @@ static void c64_nmi(void)
  * flag cassette read input, serial request in
  * irq to irq connected
  */
-int c64_cia0_port_a_r (int offset)
+static UINT8 c64_cia0_port_a_r (void)
 {
-    int value = 0xff;
+	UINT8 value = 0xff;
+	UINT8 cia0portb = cia_get_output_b(0);
 
-    if (!(cia0portb&0x80)) {
-	UINT8 t=0xff;
-	if (!(c64_keyline[7]&0x80)) t&=~0x80;
-	if (!(c64_keyline[6]&0x80)) t&=~0x40;
-	if (!(c64_keyline[5]&0x80)) t&=~0x20;
-	if (!(c64_keyline[4]&0x80)) t&=~0x10;
-	if (!(c64_keyline[3]&0x80)) t&=~0x08;
-	if (!(c64_keyline[2]&0x80)) t&=~0x04;
-	if (!(c64_keyline[1]&0x80)) t&=~0x02;
-	if (!(c64_keyline[0]&0x80)) t&=~0x01;
-	value &=t;
-    }
-    if (!(cia0portb&0x40)) {
-	UINT8 t=0xff;
-	if (!(c64_keyline[7]&0x40)) t&=~0x80;
-	if (!(c64_keyline[6]&0x40)) t&=~0x40;
-	if (!(c64_keyline[5]&0x40)) t&=~0x20;
-	if (!(c64_keyline[4]&0x40)) t&=~0x10;
-	if (!(c64_keyline[3]&0x40)) t&=~0x08;
-	if (!(c64_keyline[2]&0x40)) t&=~0x04;
-	if (!(c64_keyline[1]&0x40)) t&=~0x02;
-	if (!(c64_keyline[0]&0x40)) t&=~0x01;
-	value &=t;
-    }
-    if (!(cia0portb&0x20)) {
-	UINT8 t=0xff;
-	if (!(c64_keyline[7]&0x20)) t&=~0x80;
-	if (!(c64_keyline[6]&0x20)) t&=~0x40;
-	if (!(c64_keyline[5]&0x20)) t&=~0x20;
-	if (!(c64_keyline[4]&0x20)) t&=~0x10;
-	if (!(c64_keyline[3]&0x20)) t&=~0x08;
-	if (!(c64_keyline[2]&0x20)) t&=~0x04;
-	if (!(c64_keyline[1]&0x20)) t&=~0x02;
-	if (!(c64_keyline[0]&0x20)) t&=~0x01;
-	value &=t;
-    }
-    if (!(cia0portb&0x10)) {
-	UINT8 t=0xff;
-	if (!(c64_keyline[7]&0x10)) t&=~0x80;
-	if (!(c64_keyline[6]&0x10)) t&=~0x40;
-	if (!(c64_keyline[5]&0x10)) t&=~0x20;
-	if (!(c64_keyline[4]&0x10)) t&=~0x10;
-	if (!(c64_keyline[3]&0x10)) t&=~0x08;
-	if (!(c64_keyline[2]&0x10)) t&=~0x04;
-	if (!(c64_keyline[1]&0x10)) t&=~0x02;
-	if (!(c64_keyline[0]&0x10)) t&=~0x01;
-	value &=t;
-    }
-    if (!(cia0portb&0x08)) {
-	UINT8 t=0xff;
-	if (!(c64_keyline[7]&0x08)) t&=~0x80;
-	if (!(c64_keyline[6]&0x08)) t&=~0x40;
-	if (!(c64_keyline[5]&0x08)) t&=~0x20;
-	if (!(c64_keyline[4]&0x08)) t&=~0x10;
-	if (!(c64_keyline[3]&0x08)) t&=~0x08;
-	if (!(c64_keyline[2]&0x08)) t&=~0x04;
-	if (!(c64_keyline[1]&0x08)) t&=~0x02;
-	if (!(c64_keyline[0]&0x08)) t&=~0x01;
-	value &=t;
-    }
-    if (!(cia0portb&0x04)) {
-	UINT8 t=0xff;
-	if (!(c64_keyline[7]&0x04)) t&=~0x80;
-	if (!(c64_keyline[6]&0x04)) t&=~0x40;
-	if (!(c64_keyline[5]&0x04)) t&=~0x20;
-	if (!(c64_keyline[4]&0x04)) t&=~0x10;
-	if (!(c64_keyline[3]&0x04)) t&=~0x08;
-	if (!(c64_keyline[2]&0x04)) t&=~0x04;
-	if (!(c64_keyline[1]&0x04)) t&=~0x02;
-	if (!(c64_keyline[0]&0x04)) t&=~0x01;
-	value &=t;
-    }
-    if (!(cia0portb&0x02)) {
-	UINT8 t=0xff;
-	if (!(c64_keyline[7]&0x02)) t&=~0x80;
-	if (!(c64_keyline[6]&0x02)) t&=~0x40;
-	if (!(c64_keyline[5]&0x02)) t&=~0x20;
-	if (!(c64_keyline[4]&0x02)) t&=~0x10;
-	if (!(c64_keyline[3]&0x02)) t&=~0x08;
-	if (!(c64_keyline[2]&0x02)) t&=~0x04;
-	if (!(c64_keyline[1]&0x02)) t&=~0x02;
-	if (!(c64_keyline[0]&0x02)) t&=~0x01;
-	value &=t;
-    }
-    if (!(cia0portb&0x01)) {
-	UINT8 t=0xff;
-	if (!(c64_keyline[7]&0x01)) t&=~0x80;
-	if (!(c64_keyline[6]&0x01)) t&=~0x40;
-	if (!(c64_keyline[5]&0x01)) t&=~0x20;
-	if (!(c64_keyline[4]&0x01)) t&=~0x10;
-	if (!(c64_keyline[3]&0x01)) t&=~0x08;
-	if (!(c64_keyline[2]&0x01)) t&=~0x04;
-	if (!(c64_keyline[1]&0x01)) t&=~0x02;
-	if (!(c64_keyline[0]&0x01)) t&=~0x01;
-	value &=t;
-    }
+	if (!(cia0portb&0x80))
+	{
+		UINT8 t=0xff;
+		if (!(c64_keyline[7]&0x80)) t&=~0x80;
+		if (!(c64_keyline[6]&0x80)) t&=~0x40;
+		if (!(c64_keyline[5]&0x80)) t&=~0x20;
+		if (!(c64_keyline[4]&0x80)) t&=~0x10;
+		if (!(c64_keyline[3]&0x80)) t&=~0x08;
+		if (!(c64_keyline[2]&0x80)) t&=~0x04;
+		if (!(c64_keyline[1]&0x80)) t&=~0x02;
+		if (!(c64_keyline[0]&0x80)) t&=~0x01;
+		value &=t;
+	}
+	if (!(cia0portb&0x40))
+	{
+		UINT8 t=0xff;
+		if (!(c64_keyline[7]&0x40)) t&=~0x80;
+		if (!(c64_keyline[6]&0x40)) t&=~0x40;
+		if (!(c64_keyline[5]&0x40)) t&=~0x20;
+		if (!(c64_keyline[4]&0x40)) t&=~0x10;
+		if (!(c64_keyline[3]&0x40)) t&=~0x08;
+		if (!(c64_keyline[2]&0x40)) t&=~0x04;
+		if (!(c64_keyline[1]&0x40)) t&=~0x02;
+		if (!(c64_keyline[0]&0x40)) t&=~0x01;
+		value &=t;
+	}
+	if (!(cia0portb&0x20))
+	{
+		UINT8 t=0xff;
+		if (!(c64_keyline[7]&0x20)) t&=~0x80;
+		if (!(c64_keyline[6]&0x20)) t&=~0x40;
+		if (!(c64_keyline[5]&0x20)) t&=~0x20;
+		if (!(c64_keyline[4]&0x20)) t&=~0x10;
+		if (!(c64_keyline[3]&0x20)) t&=~0x08;
+		if (!(c64_keyline[2]&0x20)) t&=~0x04;
+		if (!(c64_keyline[1]&0x20)) t&=~0x02;
+		if (!(c64_keyline[0]&0x20)) t&=~0x01;
+		value &=t;
+	}
+	if (!(cia0portb&0x10))
+	{
+		UINT8 t=0xff;
+		if (!(c64_keyline[7]&0x10)) t&=~0x80;
+		if (!(c64_keyline[6]&0x10)) t&=~0x40;
+		if (!(c64_keyline[5]&0x10)) t&=~0x20;
+		if (!(c64_keyline[4]&0x10)) t&=~0x10;
+		if (!(c64_keyline[3]&0x10)) t&=~0x08;
+		if (!(c64_keyline[2]&0x10)) t&=~0x04;
+		if (!(c64_keyline[1]&0x10)) t&=~0x02;
+		if (!(c64_keyline[0]&0x10)) t&=~0x01;
+		value &=t;
+	}
+	if (!(cia0portb&0x08))
+	{
+		UINT8 t=0xff;
+		if (!(c64_keyline[7]&0x08)) t&=~0x80;
+		if (!(c64_keyline[6]&0x08)) t&=~0x40;
+		if (!(c64_keyline[5]&0x08)) t&=~0x20;
+		if (!(c64_keyline[4]&0x08)) t&=~0x10;
+		if (!(c64_keyline[3]&0x08)) t&=~0x08;
+		if (!(c64_keyline[2]&0x08)) t&=~0x04;
+		if (!(c64_keyline[1]&0x08)) t&=~0x02;
+		if (!(c64_keyline[0]&0x08)) t&=~0x01;
+		value &=t;
+	}
+	if (!(cia0portb&0x04))
+	{
+		UINT8 t=0xff;
+		if (!(c64_keyline[7]&0x04)) t&=~0x80;
+		if (!(c64_keyline[6]&0x04)) t&=~0x40;
+		if (!(c64_keyline[5]&0x04)) t&=~0x20;
+		if (!(c64_keyline[4]&0x04)) t&=~0x10;
+		if (!(c64_keyline[3]&0x04)) t&=~0x08;
+		if (!(c64_keyline[2]&0x04)) t&=~0x04;
+		if (!(c64_keyline[1]&0x04)) t&=~0x02;
+		if (!(c64_keyline[0]&0x04)) t&=~0x01;
+		value &=t;
+	}
+	if (!(cia0portb&0x02))
+	{
+		UINT8 t=0xff;
+		if (!(c64_keyline[7]&0x02)) t&=~0x80;
+		if (!(c64_keyline[6]&0x02)) t&=~0x40;
+		if (!(c64_keyline[5]&0x02)) t&=~0x20;
+		if (!(c64_keyline[4]&0x02)) t&=~0x10;
+		if (!(c64_keyline[3]&0x02)) t&=~0x08;
+		if (!(c64_keyline[2]&0x02)) t&=~0x04;
+		if (!(c64_keyline[1]&0x02)) t&=~0x02;
+		if (!(c64_keyline[0]&0x02)) t&=~0x01;
+		value &=t;
+	}
+	if (!(cia0portb&0x01))
+	{
+		UINT8 t=0xff;
+		if (!(c64_keyline[7]&0x01)) t&=~0x80;
+		if (!(c64_keyline[6]&0x01)) t&=~0x40;
+		if (!(c64_keyline[5]&0x01)) t&=~0x20;
+		if (!(c64_keyline[4]&0x01)) t&=~0x10;
+		if (!(c64_keyline[3]&0x01)) t&=~0x08;
+		if (!(c64_keyline[2]&0x01)) t&=~0x04;
+		if (!(c64_keyline[1]&0x01)) t&=~0x02;
+		if (!(c64_keyline[0]&0x01)) t&=~0x01;
+		value &=t;
+	}
 
-    if (JOYSTICK_SWAP) value &= c64_keyline[8];
-    else value &= c64_keyline[9];
+	if (JOYSTICK_SWAP)
+		value &= c64_keyline[8];
+	else
+		value &= c64_keyline[9];
 
-    return value;
+	return value;
 }
 
-int c64_cia0_port_b_r (int offset)
+static UINT8 c64_cia0_port_b_r (void)
 {
-    int value = 0xff;
+    UINT8 value = 0xff;
+	UINT8 cia0porta = cia_get_output_a(0);
 
     if (!(cia0porta & 0x80)) value &= c64_keyline[7];
     if (!(cia0porta & 0x40)) value &= c64_keyline[6];
@@ -245,31 +265,26 @@ int c64_cia0_port_b_r (int offset)
     if (JOYSTICK_SWAP) value &= c64_keyline[9];
     else value &= c64_keyline[8];
 
-    if (c128)
+    if (is_c128())
     {
-	if (!vic2e_k0_r ())
-	    value &= c128_keyline[0];
-	if (!vic2e_k1_r ())
-	    value &= c128_keyline[1];
-	if (!vic2e_k2_r ())
-	    value &= c128_keyline[2];
+		if (!vic2e_k0_r ())
+			value &= c128_keyline[0];
+		if (!vic2e_k1_r ())
+			value &= c128_keyline[1];
+		if (!vic2e_k2_r ())
+			value &= c128_keyline[2];
     }
-    if (c65) {
-	if (!(c65_6511_port&2))
-	    value&=c65_keyline;
+    if (is_c65())
+	{
+		if (!(c65_6511_port&2))
+			value&=c65_keyline;
     }
 
     return value;
 }
 
-void c64_cia0_port_a_w (int offset, int data)
+static void c64_cia0_port_b_w (UINT8 data)
 {
-    cia0porta = data;
-}
-
-static void c64_cia0_port_b_w (int offset, int data)
-{
-    cia0portb =data;
     vic2_lightpen_write (data & 0x10);
 }
 
@@ -280,13 +295,19 @@ static void c64_irq (int level)
 	if (level != old_level)
 	{
 		DBG_LOG (3, "mos6510", ("irq %s\n", level ? "start" : "end"));
-		if (c128) {
-			if (0&&(cpu_getactivecpu()==0)) {
+		if (is_c128())
+		{
+			if (0&&(cpu_getactivecpu()==0))
+			{
 				cpunum_set_input_line (0, 0, level);
-			} else {
+			}
+			else
+			{
 				cpunum_set_input_line (1, M6510_IRQ_LINE, level);
 			}
-		} else {
+		}
+		else
+		{
 			cpunum_set_input_line (0, M6510_IRQ_LINE, level);
 		}
 		old_level = level;
@@ -295,16 +316,12 @@ static void c64_irq (int level)
 
 WRITE8_HANDLER(c64_tape_read)
 {
-	cia6526_0_set_input_flag (data);
+	cia_issue_index(0);
 }
 
 static void c64_cia0_interrupt (int level)
 {
-	if (level != cia0irq)
-	{
-		c64_irq (level || vicirq);
-		cia0irq = level;
-	}
+	c64_irq (level || vicirq);
 }
 
 void c64_vic_interrupt (int level)
@@ -312,7 +329,7 @@ void c64_vic_interrupt (int level)
 #if 1
 	if (level != vicirq)
 	{
-		c64_irq (level || cia0irq);
+		c64_irq (level || cia_get_irq(0));
 		vicirq = level;
 	}
 #endif
@@ -341,9 +358,9 @@ void c64_vic_interrupt (int level)
  * flag restore key or rs232 received data input
  * irq to nmi connected ?
  */
-int c64_cia1_port_a_r (int offset)
+UINT8 c64_cia1_port_a_r (void)
 {
-	int value = 0xff;
+	UINT8 value = 0xff;
 
 	if (!serial_clock || !cbm_serial_clock_read ())
 		value &= ~0x40;
@@ -352,52 +369,47 @@ int c64_cia1_port_a_r (int offset)
 	return value;
 }
 
-static void c64_cia1_port_a_w (int offset, int data)
+static void c64_cia1_port_a_w (UINT8 data)
 {
-	static int helper[4] =
-	{0xc000, 0x8000, 0x4000, 0x0000};
+	static int helper[4] = {0xc000, 0x8000, 0x4000, 0x0000};
 
 	cbm_serial_clock_write (serial_clock = !(data & 0x10));
 	cbm_serial_data_write (serial_data = !(data & 0x20));
 	cbm_serial_atn_write (serial_atn = !(data & 8));
 	c64_vicaddr = c64_memory + helper[data & 3];
-	if (c128) {
+	if (is_c128())
+	{
 		c128_vicaddr = c64_memory + helper[data & 3] + c128_va1617;
 	}
 }
 
 static void c64_cia1_interrupt (int level)
 {
-	cia1irq = level;
 	c64_nmi();
 }
 
-struct cia6526_interface c64_cia0 =
+const cia6526_interface c64_cia0 =
 {
-	c64_cia0_port_a_r,
-	c64_cia0_port_b_r,
-	c64_cia0_port_a_w,
-	c64_cia0_port_b_w,
-	0,								   /*c64_cia0_pc_w */
-	0,								   /*c64_cia0_sp_r */
-	0,								   /*c64_cia0_sp_w */
-	0,								   /*c64_cia0_cnt_r */
-	0,								   /*c64_cia0_cnt_w */
+	CIA6526,
 	c64_cia0_interrupt,
-	0xff, 0xff, 0
-}, c64_cia1 =
+	0.0, 60,
+
+	{
+		{ c64_cia0_port_a_r, NULL },
+		{ c64_cia0_port_b_r, c64_cia0_port_b_w }
+	}
+};
+
+const cia6526_interface c64_cia1 =
 {
-	c64_cia1_port_a_r,
-	0,								   /*c64_cia1_port_b_r, */
-	c64_cia1_port_a_w,
-	0,								   /*c64_cia1_port_b_w, */
-	0,								   /*c64_cia1_pc_w */
-	0,								   /*c64_cia1_sp_r */
-	0,								   /*c64_cia1_sp_w */
-	0,								   /*c64_cia1_cnt_r */
-	0,								   /*c64_cia1_cnt_w */
+	CIA6526,
 	c64_cia1_interrupt,
-	0xc7, 0xff, 0
+	0.0, 60,
+
+	{
+		{ c64_cia1_port_a_r, c64_cia1_port_a_w },
+		{ 0, 0 }
+	}
 };
 
 static void c64_bankswitch (int reset);
@@ -410,18 +422,19 @@ static void c64_robocop2_w(int offset, int value)
 	roml=cbm_rom[value&0xf].chip;
 	romh=cbm_rom[(value&0xf)+0x10].chip;
 	if (value & 0x80)
-		{
-			c64_game = value & 0x10;
-			c64_exrom = 1;
-		}
+	{
+		c64_game = value & 0x10;
+		c64_exrom = 1;
+	}
 	else
-		{
-			c64_game = c64_exrom = 1;
-		}
-	if (c128)
-		c128_bankswitch_64 (0);
+	{
+		c64_game = c64_exrom = 1;
+	}
+
+	if (is_c128())
+		c128_bankswitch_64(0);
 	else
-		c64_bankswitch (0);
+		c64_bankswitch(0);
 }
 
 static void c64_supergames_w(int offset, int value)
@@ -433,19 +446,20 @@ static void c64_supergames_w(int offset, int value)
 	roml=cbm_rom[value&3].chip;
 	romh=cbm_rom[value&3].chip+0x2000;
 	if (value & 4)
-		{
-			c64_game = 0;
-			c64_exrom = 1;
-		}
+	{
+		c64_game = 0;
+		c64_exrom = 1;
+	}
 	else
-		{
-			c64_game = c64_exrom = 1;
-		}
+	{
+		c64_game = c64_exrom = 1;
+	}
 	if (value == 0xc)
-		{
-			c64_game = c64_exrom = 0;
-		}
-	if (c128)
+	{
+		c64_game = c64_exrom = 0;
+	}
+
+	if (is_c128())
 		c128_bankswitch_64 (0);
 	else
 		c64_bankswitch (0);
@@ -460,11 +474,11 @@ WRITE8_HANDLER( c64_write_io )
 	} else if (offset < 0xc00)
 		c64_colorram[offset & 0x3ff] = data | 0xf0;
 	else if (offset < 0xd00)
-		cia6526_0_port_w (offset & 0xff, data);
+		cia_0_w(offset, data);
 	else if (offset < 0xe00)
 	{
 		if (c64_cia1_on)
-			cia6526_1_port_w (offset & 0xff, data);
+			cia_1_w(offset, data);
 		else
 			DBG_LOG (1, "io write", ("%.3x %.2x\n", offset, data));
 	}
@@ -499,9 +513,9 @@ READ8_HANDLER( c64_read_io )
 	else if (offset < 0xc00)
 		return c64_colorram[offset & 0x3ff];
 	else if (offset < 0xd00)
-		return cia6526_0_port_r (offset & 0xff);
+		return cia_0_r(offset);
 	else if (c64_cia1_on && (offset < 0xe00))
-		return cia6526_1_port_r (offset & 0xff);
+		return cia_1_r(offset);
 	DBG_LOG (1, "io read", ("%.3x\n", offset));
 	return 0xff;
 }
@@ -569,7 +583,7 @@ static void c64_bankswitch (int reset)
 	static int old = -1, exrom, game;
 	int data, loram, hiram, charen;
 
-	data = ((c64_port6510 & c64_ddr6510) | (c64_ddr6510 ^ 0xff)) & 7;
+	data = (UINT8) cpunum_get_info_int(0, CPUINFO_INT_M6510_PORT) & 7;
 	if ((data == old)&&(exrom==c64_exrom)&&(game==c64_game)&&!reset) return;
 
 	DBG_LOG (1, "bankswitch", ("%d\n", data & 7));
@@ -582,12 +596,12 @@ static void c64_bankswitch (int reset)
 /*	    || (loram && hiram && !c64_exrom)) */
 	{
 		memory_set_bankptr (1, roml);
-		memory_install_write8_handler(0, ADDRESS_SPACE_PROGRAM, 0x8000, 0x9fff, 0, 0, MWA8_RAM);	/* always ram: pitstop */
+		memory_set_bankptr (2, c64_memory + 0x8000);
 	}
 	else
 	{
 		memory_set_bankptr (1, c64_memory + 0x8000);
-		memory_install_write8_handler(0, ADDRESS_SPACE_PROGRAM, 0x8000, 0x9fff, 0, 0, MWA8_RAM);
+		memory_set_bankptr (2, c64_memory + 0x8000);
 	}
 
 #if 1
@@ -637,15 +651,11 @@ static void c64_bankswitch (int reset)
 	}
 	else
 	{
-		memory_install_write8_handler(0, ADDRESS_SPACE_PROGRAM, 0xe000, 0xffff, 0, 0, MWA8_RAM);
 		if (hiram)
-		{
 			memory_set_bankptr (7, c64_kernal);
-		}
 		else
-		{
 			memory_set_bankptr (7, c64_memory + 0xe000);
-		}
+		memory_set_bankptr (8, c64_memory + 0xe000);
 	}
 	game = c64_game;
 	exrom = c64_exrom;
@@ -664,27 +674,16 @@ static void c64_bankswitch (int reset)
   p5 output cassette motor
   p6,7 not available on M6510
  */
-WRITE8_HANDLER(c64_m6510_port_w)
+void c64_m6510_port_write(UINT8 data)
 {
-	if (offset)
-	{
-		if (c64_port6510 != data)
-			c64_port6510 = data;
-	}
-	else
-	{
-		if (c64_ddr6510 != data)
-			c64_ddr6510 = data;
-	}
-	data = (c64_port6510 & c64_ddr6510) | (c64_ddr6510 ^ 0xff);
 	if (c64_tape_on)
 	{
 		vc20_tape_write (!(data & 8));
 		vc20_tape_motor (data & 0x20);
 	}
-	if (c128)
+	if (is_c128())
 		c128_bankswitch_64 (0);
-	else if (c65)
+	else if (is_c65())
 	{
 		/* NPW 8-Feb-2004 - Don't know why I have to do this */
 		/*c65_bankswitch(); */
@@ -693,29 +692,24 @@ WRITE8_HANDLER(c64_m6510_port_w)
 		c64_bankswitch (0);
 }
 
- READ8_HANDLER(c64_m6510_port_r)
+UINT8 c64_m6510_port_read(void)
 {
-	if (offset)
-	{
-		int data = (c64_ddr6510 & c64_port6510) | (c64_ddr6510 ^ 0xff);
+	UINT8 data = 0xFF;
 
-		if (c64_tape_on && !(c64_ddr6510 & 0x10) && !vc20_tape_switch ())
-			data &= ~0x10;
-		if (c128 && !c128_capslock_r ())
-			data &= ~0x40;
-		if (c65 && C65_KEY_DIN)
-			data &= ~0x40; /*? */
-		return data;
-	}
-	else
-	{
-		return c64_ddr6510;
-	}
+	if (c64_tape_on && !vc20_tape_switch ())
+		data &= ~0x10;
+	if (is_c128() && !c128_capslock_r ())
+		data &= ~0x40;
+	if (is_c65() && C65_KEY_DIN)
+		data &= ~0x40; /*? */
+	return data;
 }
 
 int c64_paddle_read (int which)
 {
 	int pot1=0xff, pot2=0xff, pot3=0xff, pot4=0xff, temp;
+	UINT8 cia0porta = cia_get_output_a(0);
+
 	if (PADDLES34)
 	{
 		if (which) pot4=PADDLE4_VALUE;
@@ -797,6 +791,10 @@ static int c64_dma_read_color (int offset)
 
 static void c64_common_driver_init (void)
 {
+	/* configure the M6510 port */
+	cpunum_set_info_fct(0, CPUINFO_PTR_M6510_PORTREAD, (genf *) c64_m6510_port_read);
+	cpunum_set_info_fct(0, CPUINFO_PTR_M6510_PORTWRITE, (genf *) c64_m6510_port_write);
+
 	/*    memset(c64_memory, 0, 0xfd00); */
 	if (!ultimax) {
 		c64_basic=memory_region(REGION_CPU1)+0x10000;
@@ -817,14 +815,19 @@ static void c64_common_driver_init (void)
 	if (c64_tape_on)
 		vc20_tape_open (c64_tape_read);
 
-	cia6526_init();
-
-	c64_cia0.todin50hz = c64_pal;
-	cia6526_config (0, &c64_cia0);
-	if (c64_cia1_on)
 	{
-		c64_cia1.todin50hz = c64_pal;
-		cia6526_config (1, &c64_cia1);
+		cia6526_interface cia_intf[2];
+
+		cia_intf[0] = c64_cia0;
+		cia_intf[0].tod_clock = c64_pal ? 50 : 60;
+		cia_config(0, &cia_intf[0]);
+
+		if (c64_cia1_on)
+		{
+			cia_intf[1] = c64_cia1;
+			cia_intf[1].tod_clock = c64_pal ? 50 : 60;
+			cia_config(1, &cia_intf[1]);
+		}
 	}
 
 	if (ultimax)
@@ -837,28 +840,29 @@ static void c64_common_driver_init (void)
 		vic6567_init (0, c64_pal, c64_dma_read, c64_dma_read_color,
 					  c64_vic_interrupt);
 	}
-	cia6526_reset ();
+	cia_reset();
+	add_exit_callback(c64_driver_shutdown);
 }
 
-void c64_driver_init (void)
+DRIVER_INIT( c64 )
 {
 	c64_common_driver_init ();
 }
 
-void c64pal_driver_init (void)
+DRIVER_INIT( c64pal )
 {
 	c64_pal = 1;
 	c64_common_driver_init ();
 }
 
-void ultimax_driver_init (void)
+DRIVER_INIT( ultimax )
 {
 	ultimax = 1;
     c64_cia1_on = 0;
 	c64_common_driver_init ();
 }
 
-void c64gs_driver_init (void)
+DRIVER_INIT( c64gs )
 {
 	c64_pal = 1;
 	c64_tape_on = 0;
@@ -866,7 +870,7 @@ void c64gs_driver_init (void)
 	c64_common_driver_init ();
 }
 
-void sx64_driver_init (void)
+DRIVER_INIT( sx64 )
 {
 	VC1541_CONFIG vc1541 = { 1, 8 };
 	c64_tape_on = 0;
@@ -875,7 +879,7 @@ void sx64_driver_init (void)
 	vc1541_config (0, 0, &vc1541);
 }
 
-void c64_driver_shutdown (void)
+static void c64_driver_shutdown (void)
 {
 	if (c64_tape_on)
 		vc20_tape_close ();
@@ -886,32 +890,30 @@ void c64_common_init_machine (void)
 #ifdef VC1541
 	vc1541_reset ();
 #endif
-	sndti_reset(SOUND_SID6581, 0);
 
 	if (c64_cia1_on)
 	{
 		cbm_serial_reset_write (0);
-		cbm_drive_0_config (SERIAL8ON ? SERIAL : 0, c65?10:8);
-		cbm_drive_1_config (SERIAL9ON ? SERIAL : 0, c65?11:9);
+		cbm_drive_0_config (SERIAL, is_c65() ? 10 : 8);
+		cbm_drive_1_config (SERIAL, is_c65() ? 11 : 9);
 		serial_clock = serial_data = serial_atn = 1;
 	}
 	c64_vicaddr = c64_memory;
-	vicirq = cia0irq = 0;
-	c64_port6510 = 0xff;
-	c64_ddr6510 = 0;
+	vicirq = 0;
 }
 
-MACHINE_INIT( c64 )
+MACHINE_START( c64 )
 {
 	c64_common_init_machine ();
 
 	c64_rom_recognition ();
 	c64_rom_load();
 
-	if (c128)
+	if (is_c128())
 		c128_bankswitch_64 (1);
 	if (!ultimax)
 		c64_bankswitch (1);
+	return 0;
 }
 
 
@@ -1049,13 +1051,18 @@ INTERRUPT_GEN( c64_frame_interrupt )
 
 	c64_nmi();
 
-	if (c128) {
-		if (MONITOR_TV!=monitor) {
-			if (MONITOR_TV) {
+	if (is_c128())
+	{
+		if (MONITOR_TV!=monitor)
+		{
+			if (MONITOR_TV)
+			{
 				vic2_set_rastering(0);
 				vdc8563_set_rastering(1);
 				set_visible_area(0,655,0,215);
-			} else {
+			}
+			else
+			{
 				vic2_set_rastering(1);
 				vdc8563_set_rastering(0);
 				set_visible_area(0,335,0,215);
@@ -1065,7 +1072,8 @@ INTERRUPT_GEN( c64_frame_interrupt )
 	}
 
 	value = 0xff;
-	if (c128) {
+	if (is_c128())
+	{
 		if (C128_KEY_CURSOR_DOWN)
 			value &= ~0x80;
 		if (C128_KEY_F5)
@@ -1078,7 +1086,7 @@ INTERRUPT_GEN( c64_frame_interrupt )
 			value &= ~8;
 		if (C128_KEY_CURSOR_RIGHT)
 			value &= ~4;
-	} else if (c65) {
+	} else if (is_c65()) {
 		if (C65_KEY_CURSOR_DOWN)
 			value &= ~0x80;
 		if (C65_KEY_F5)
@@ -1208,13 +1216,18 @@ INTERRUPT_GEN( c64_frame_interrupt )
 		value &= ~0x40;
 	if (KEY_EQUALS)
 		value &= ~0x20;
-	if (c128) {
+	if (is_c128())
+	{
 		if (C128_KEY_RIGHT_SHIFT)
 		value &= ~0x10;
-	} else if (c65) {
+	}
+	else if (is_c65())
+	{
 		if (C65_KEY_RIGHT_SHIFT)
 		value &= ~0x10;
-	} else {
+	}
+	else
+	{
 		if (KEY_RIGHT_SHIFT)
 		value &= ~0x10;
 	}
@@ -1229,7 +1242,7 @@ INTERRUPT_GEN( c64_frame_interrupt )
 	c64_keyline[6] = value;
 
 	value = 0xff;
-	if (c65) {
+	if (is_c65()) {
 		if (C65_KEY_STOP)
 			value &= ~0x80;
 		if (C65_KEY_SPACE)
@@ -1304,7 +1317,8 @@ INTERRUPT_GEN( c64_frame_interrupt )
 	}
 	c64_keyline[9] = value2;
 
-	if ( c128 ) {
+	if (is_c128())
+	{
 		value = 0xff;
 		if (KEY_NUM1)
 			value &= ~0x80;
@@ -1363,7 +1377,7 @@ INTERRUPT_GEN( c64_frame_interrupt )
 		c128_keyline[2] = value;
 	}
 
-	if (c65) {
+	if (is_c65()) {
 		value = 0xff;
 		if (C65_KEY_ESCAPE)
 			value &= ~0x80;
