@@ -9,10 +9,10 @@
 #include "driver.h"
 #include "cpu/m6502/m6502.h"
 #include "sound/sid6581.h"
+#include "machine/6526cia.h"
 
 #define VERBOSE_DBG 1
 #include "includes/cbm.h"
-#include "includes/cia6526.h"
 #include "includes/cbmserb.h"
 #include "includes/vc1541.h"
 #include "includes/vic4567.h"
@@ -35,36 +35,22 @@ UINT8 *c65_interface;
 /* processor has only 1 mega address space !? */
 /* and system 8 megabyte */
 /* dma controller and bankswitch hardware ?*/
-static  READ8_HANDLER(c65_read_mem)
+static READ8_HANDLER(c65_read_mem)
 {
-	int data=0;
-
-	if (offset<0x800000)
-		data=c64_memory[offset];
-
-#if 0
-	if (offset<0x100000)
-	else data=c64_memory[offset];
-#endif
-
-	return data;
+	UINT8 result;
+	if (offset <= 0x0FFFF)
+		result = c64_memory[offset];
+	else
+		result = program_read_byte(offset);
+	return result;
 }
 
 static WRITE8_HANDLER(c65_write_mem)
 {
-	if (offset<0x20000)
-		c64_memory[offset]=data;
-	else if (offset<0x80000) ;
-	else if (offset<0x100000) {
-		if (C65_MAIN_MEMORY==C65_512KB) c64_memory[offset]=data;
-	} else if (offset<0x400000) ;
-	else if (offset<0x800000) {
-		if (C65_MAIN_MEMORY==C65_4096KB) c64_memory[offset]=data;
-	}
-#if 0
-	if (offset<0x100000) program_write_byte_8(offset,data);
-	else c64_memory[offset]=data;
-#endif
+	if (offset <= 0x0FFFF)
+		c64_memory[offset] = data;
+	else
+		program_write_byte(offset, data);
 }
 
 static struct {
@@ -438,28 +424,36 @@ static int c65_fdc_r(int offset)
 */
 static struct {
 	UINT8 reg;
-} expansion_ram= {0};
-static  READ8_HANDLER(c65_ram_expansion_r)
+} expansion_ram = {0};
+
+static READ8_HANDLER(c65_ram_expansion_r)
 {
-	int data=0xff;
-	if (C65_MAIN_MEMORY==C65_4096KB)
-		data=expansion_ram.reg;
-	DBG_LOG (1, "expansion read", ("%.5x %.2x %.2x\n", activecpu_get_pc(),offset,data));
+	UINT8 data = 0xff;
+	if (mess_ram_size > (128 * 1024))
+		data = expansion_ram.reg;
 	return data;
 }
 
 static WRITE8_HANDLER(c65_ram_expansion_w)
 {
-	DBG_LOG (1, "expansion write", ("%.5x %.2x %.2x\n", activecpu_get_pc(), offset, data));
-	expansion_ram.reg=data;
+	offs_t expansion_ram_begin;
+	offs_t expansion_ram_end;
 
-#if 0
-	if ( (data==0)&&(C65_MAIN_MEMORY==C65_512KB) ) {
-		memory_set_bankhandler_w (16, 0, MWA8_BANK16);
-	} else {
-		memory_set_bankhandler_w (16, 0, MWA8_NOP);
+	if (mess_ram_size > (128 * 1024))
+	{
+		expansion_ram.reg = data;
+
+		expansion_ram_begin = 0x80000;
+		expansion_ram_end = 0x80000 + (mess_ram_size - 128*1024) - 1;
+
+		memory_install_read8_handler(0, ADDRESS_SPACE_PROGRAM, expansion_ram_begin, expansion_ram_end,
+			0, 0, (data == 0x00) ? MRA8_BANK16 : MRA8_NOP);
+		memory_install_write8_handler(0, ADDRESS_SPACE_PROGRAM, expansion_ram_begin, expansion_ram_end,
+			0, 0, (data == 0x00) ? MWA8_BANK16 : MWA8_NOP);
+
+		if (data == 0x00)
+			memory_set_bankptr(16, mess_ram + 128*1024);
 	}
-#endif
 }
 
 static WRITE8_HANDLER ( c65_write_io )
@@ -502,10 +496,10 @@ static WRITE8_HANDLER ( c65_write_io_dc00 )
 {
 	switch(offset&0xf00) {
 	case 0x000:
-		cia6526_0_port_w (offset & 0xff, data);
+		cia_0_w(offset, data);
 		break;
 	case 0x100:
-		cia6526_1_port_w (offset & 0xff, data);
+		cia_1_w(offset, data);
 		break;
 	case 0x200:
 	case 0x300:
@@ -514,7 +508,7 @@ static WRITE8_HANDLER ( c65_write_io_dc00 )
 	}
 }
 
-static  READ8_HANDLER ( c65_read_io )
+static READ8_HANDLER ( c65_read_io )
 {
 	switch(offset&0xf00) {
 	case 0x000:
@@ -549,13 +543,13 @@ static  READ8_HANDLER ( c65_read_io )
 	return 0xff;
 }
 
-static  READ8_HANDLER ( c65_read_io_dc00 )
+static READ8_HANDLER ( c65_read_io_dc00 )
 {
 	switch(offset&0x300) {
 	case 0x000:
-		return cia6526_0_port_r (offset & 0xff);
+		return cia_0_r(offset);
 	case 0x100:
-		return cia6526_1_port_r (offset & 0xff);
+		return cia_1_r(offset);
 	case 0x200:
 	case 0x300:
 		DBG_LOG (1, "io read", ("%.3x\n", offset+0xc00));
@@ -587,8 +581,8 @@ static void c65_bankswitch_interface(int value)
 	{
 		if (value&1)
 		{
-			cpu_setbank (8, c64_colorram + 0x400);
-			cpu_setbank (9, c64_colorram + 0x400);
+			memory_set_bankptr (8, c64_colorram + 0x400);
+			memory_set_bankptr (9, c64_colorram + 0x400);
 			rh = MRA8_BANK8;
 			wh = MWA8_BANK9;
 		}
@@ -604,20 +598,20 @@ static void c65_bankswitch_interface(int value)
 	c65_io_dc00_on=!(value&1);
 #if 0
 	/* cartridge roms !?*/
-	if (value&0x08) { cpu_setbank (1, c64_roml); }
-	else { cpu_setbank (1, c64_memory + 0x8000); }
-	if (value&0x10) { cpu_setbank (2, c64_basic); }
-	else { cpu_setbank (2, c64_memory + 0xa000); }
+	if (value&0x08) { memory_set_bankptr (1, c64_roml); }
+	else { memory_set_bankptr (1, c64_memory + 0x8000); }
+	if (value&0x10) { memory_set_bankptr (2, c64_basic); }
+	else { memory_set_bankptr (2, c64_memory + 0xa000); }
 #endif
 	if ((old^value)&0x20) { /* bankswitching faulty when doing actual page */
-		if (value&0x20) { cpu_setbank (3, c65_interface); }
-		else { cpu_setbank (3, c64_memory + 0xc000); }
+		if (value&0x20) { memory_set_bankptr (3, c65_interface); }
+		else { memory_set_bankptr (3, c64_memory + 0xc000); }
 	}
 	c65_charset_select=value&0x40;
 #if 0
 	/* cartridge roms !?*/
-	if (value&0x80) { cpu_setbank (8, c64_kernal); }
-	else { cpu_setbank (6, c64_memory + 0xe000); }
+	if (value&0x80) { memory_set_bankptr (8, c64_kernal); }
+	else { memory_set_bankptr (6, c64_memory + 0xe000); }
 #endif
 	old=value;
 }
@@ -629,7 +623,7 @@ void c65_bankswitch (void)
 	read8_handler rh4, rh8;
 	write8_handler wh5, wh9;
 
-	data = ((c64_port6510 & c64_ddr6510) | (c64_ddr6510 ^ 0xff)) & 7;
+	data = (UINT8) cpunum_get_info_int(0, CPUINFO_INT_M6510_PORT);
 	if (data == old)
 		return;
 
@@ -641,25 +635,25 @@ void c65_bankswitch (void)
 	if ((!c64_game && c64_exrom)
 		|| (loram && hiram && !c64_exrom))
 	{
-		cpu_setbank (1, c64_roml);
+		memory_set_bankptr (1, c64_roml);
 	}
 	else
 	{
-		cpu_setbank (1, c64_memory + 0x8000);
+		memory_set_bankptr (1, c64_memory + 0x8000);
 	}
 
 	if ((!c64_game && c64_exrom && hiram)
 		|| (!c64_exrom))
 	{
-		cpu_setbank (2, c64_romh);
+		memory_set_bankptr (2, c64_romh);
 	}
 	else if (loram && hiram)
 	{
-		cpu_setbank (2, c64_basic);
+		memory_set_bankptr (2, c64_basic);
 	}
 	else
 	{
-		cpu_setbank (2, c64_memory + 0xa000);
+		memory_set_bankptr (2, c64_memory + 0xa000);
 	}
 
 	if ((!c64_game && c64_exrom)
@@ -668,8 +662,8 @@ void c65_bankswitch (void)
 		c65_io_on = 1;
 		rh4 = c65_read_io;
 		wh5 = c65_write_io;
-		cpu_setbank (6, c64_colorram);
-		cpu_setbank (7, c64_colorram);
+		memory_set_bankptr (6, c64_colorram);
+		memory_set_bankptr (7, c64_colorram);
 
 		if (c65_io_dc00_on)
 		{
@@ -680,8 +674,8 @@ void c65_bankswitch (void)
 		{
 			rh8 = MRA8_BANK8;
 			wh9 = MWA8_BANK9;
-			cpu_setbank (8, c64_colorram+0x400);
-			cpu_setbank (9, c64_colorram+0x400);
+			memory_set_bankptr (8, c64_colorram+0x400);
+			memory_set_bankptr (9, c64_colorram+0x400);
 		}
 		memory_install_read8_handler(0, ADDRESS_SPACE_PROGRAM, 0x0dc00, 0x0dfff, 0, 0, rh8);
 		memory_install_write8_handler(0, ADDRESS_SPACE_PROGRAM, 0x0dc00, 0x0dfff, 0, 0, wh9);
@@ -691,20 +685,20 @@ void c65_bankswitch (void)
 		c65_io_on = 0;
 		rh4 = MRA8_BANK4;
 		wh5 = MWA8_BANK5;
-		cpu_setbank(5, c64_memory+0xd000);
-		cpu_setbank(7, c64_memory+0xd800);
-		cpu_setbank(9, c64_memory+0xdc00);
+		memory_set_bankptr(5, c64_memory+0xd000);
+		memory_set_bankptr(7, c64_memory+0xd800);
+		memory_set_bankptr(9, c64_memory+0xdc00);
 		if (!charen && (loram || hiram))
 		{
-			cpu_setbank (4, c64_chargen);
-			cpu_setbank (6, c64_chargen+0x800);
-			cpu_setbank (8, c64_chargen+0xc00);
+			memory_set_bankptr (4, c64_chargen);
+			memory_set_bankptr (6, c64_chargen+0x800);
+			memory_set_bankptr (8, c64_chargen+0xc00);
 		}
 		else
 		{
-			cpu_setbank (4, c64_memory + 0xd000);
-			cpu_setbank (6, c64_memory + 0xd800);
-			cpu_setbank (8, c64_memory + 0xdc00);
+			memory_set_bankptr (4, c64_memory + 0xd000);
+			memory_set_bankptr (6, c64_memory + 0xd800);
+			memory_set_bankptr (8, c64_memory + 0xdc00);
 		}
 	}
 	memory_install_read8_handler(0, ADDRESS_SPACE_PROGRAM, 0x0d000, 0x0d7ff, 0, 0, rh4);
@@ -712,17 +706,17 @@ void c65_bankswitch (void)
 
 	if (!c64_game && c64_exrom)
 	{
-		cpu_setbank (10, c64_romh);
+		memory_set_bankptr (10, c64_romh);
 	}
 	else
 	{
 		if (hiram)
 		{
-			cpu_setbank (10, c64_kernal);
+			memory_set_bankptr (10, c64_kernal);
 		}
 		else
 		{
-			cpu_setbank (10, c64_memory + 0xe000);
+			memory_set_bankptr (10, c64_memory + 0xe000);
 		}
 	}
 	old = data;
@@ -769,18 +763,29 @@ static int c65_dma_read_color (int offset)
 
 static void c65_common_driver_init (void)
 {
-	c65=1;
-	c64_tape_on=0;
+	c64_memory = auto_malloc(0x10000);
+	memory_set_bankptr(11, c64_memory + 0x00000);
+	memory_set_bankptr(12, c64_memory + 0x08000);
+	memory_set_bankptr(13, c64_memory + 0x0a000);
+	memory_set_bankptr(14, c64_memory + 0x0c000);
+	memory_set_bankptr(15, c64_memory + 0x0e000);
+
+	c64_tape_on = 0;
 	/*memset(c64_memory+0x40000, 0, 0x800000-0x40000); */
 
-	cia6526_init();
+	{
+		cia6526_interface cia_intf[2];
+		cia_intf[0] = c64_cia0;
+		cia_intf[1] = c64_cia1;
+		cia_intf[0].tod_clock = c64_pal ? 50 : 60;
+		cia_intf[1].tod_clock = c64_pal ? 50 : 60;
+
+		cia_config(0, &cia_intf[0]);
+		cia_config(1, &cia_intf[1]);
+	}
 
-	c64_cia0.todin50hz = c64_cia1.todin50hz = c64_pal;
-	cia6526_config (0, &c64_cia0);
-	cia6526_config (1, &c64_cia1);
 	vic4567_init (c64_pal, c65_dma_read, c65_dma_read_color,
 				  c64_vic_interrupt, c65_bankswitch_interface);
-	statetext_add_function(c65_state);
 }
 
 void c65_driver_init (void)
@@ -803,21 +808,17 @@ void c65pal_driver_init (void)
 	c65_common_driver_init ();
 }
 
-MACHINE_INIT( c65 )
+MACHINE_START( c65 )
 {
-	memset(c64_memory+0x40000, 0xff, 0xc0000);
-
-	sndti_reset(SOUND_SID8580, 0);
-	sndti_reset(SOUND_SID8580, 1);
+	/* clear upper memory */
+	memset(mess_ram + 128*1024, 0xff, mess_ram_size -  128*1024);
 
 	cbm_serial_reset_write (0);
-	cbm_drive_0_config (SERIAL8ON ? SERIAL : 0, 10);
-	cbm_drive_1_config (SERIAL9ON ? SERIAL : 0, 11);
-	cia6526_reset ();
+	cbm_drive_0_config (SERIAL, 10);
+	cbm_drive_1_config (SERIAL, 11);
+	cia_reset();
 	c64_vicaddr = c64_memory;
 
-	c64_port6510 = 0xff;
-	c64_ddr6510 = 0;
 	c64mode = 0;
 
 	c64_rom_recognition ();
@@ -825,22 +826,5 @@ MACHINE_INIT( c65 )
 
 	c65_bankswitch_interface(0xff);
 	c65_bankswitch ();
-}
-
-void c65_state (void)
-{
-	char text[70];
-
-#if VERBOSE_DBG
-	cia6526_status (text, sizeof (text));
-	statetext_display_text (text);
-
-	snprintf (text, sizeof(text), "c65 vic:%.4x m6510:%d c64:%d",
-			  c64_vicaddr - c64_memory, c64_port6510 & 7, c64mode);
-#endif
-	cbm_drive_0_status (text, sizeof (text));
-	statetext_display_text (text);
-
-	cbm_drive_1_status (text, sizeof (text));
-	statetext_display_text (text);
+	return 0;
 }
