@@ -1,7 +1,7 @@
 #include <time.h>
 #include "driver.h"
 #include "includes/europc.h"
-#include "includes/pcshare.h"
+#include "machine/pcshare.h"
 #include "machine/pit8253.h"
 #include "vidhrdw/pc_aga.h"
 #include "mscommon.h"
