@@ -21,7 +21,6 @@ io bug? controls don't work in decap attack
 */
 
 #include "driver.h"
-#include "machine/random.h"
 #include "includes/genesis.h"
 #include "sound/2612intf.h"
 #include "sound/sn76496.h"
@@ -115,9 +114,8 @@ void genesis_vdp_start (genvdp *current_vdp)
 /*		return 1; */
 
 	/* create the char set (gfx will then be updated dynamically from RAM) */
-	Machine->gfx[gfx_index] = decodegfx((UINT8 *)&current_vdp->genesis_vdp_vram,&charlayout);
-/*	if (!Machine->gfx[gfx_index]) */
-/*		return 1; */
+	Machine->gfx[gfx_index] = allocgfx(&charlayout);
+	decodegfx(Machine->gfx[gfx_index] , (UINT8 *)&current_vdp->genesis_vdp_vram, 0, 1);
 
 	/* set the color information */
 	Machine->gfx[gfx_index]->colortable = Machine->remapped_colortable;
@@ -131,8 +129,9 @@ void genesis_vdp_draw_scanline (genvdp *current_vdp, int line)
 {
 	UINT32 *destline;
 	int i;
+	extern mame_bitmap *scrbitmap[8];
 
-	destline = (UINT32 *)(Machine->scrbitmap->line[line]);
+	destline = (UINT32 *)(scrbitmap[0]->line[line]);
 
 	for (i = 0; i < 320; i++)
 	{
@@ -2328,9 +2327,9 @@ INTERRUPT_GEN( genesis_interrupt )
 	/* nothing? */
 /*} */
 
-MACHINE_INIT ( genesis )
+MACHINE_RESET ( genesis )
 {
-/*	logerror("MACHINE_INIT ( genesis )\n"); */
+/*	logerror("MACHINE_RESET ( genesis )\n"); */
 	/* prevent the z80 from running (code must be uploaded by the 68k first) */
 	cpunum_set_input_line(1, INPUT_LINE_RESET, ASSERT_LINE);
 	genesis_z80_is_reset = 1;
@@ -2363,6 +2362,10 @@ void genesis_common_init( void )
 
 	memset( genesis_mainram, 0x00, 0x10000);
 
+	/* Another brutal hack to work around 0.101u1 memory changes */
+	memory_install_read8_handler(1, ADDRESS_SPACE_PROGRAM, 0x0000, 0x1fff, 0, 0, MRA8_BANK10);
+	memory_install_write8_handler(1, ADDRESS_SPACE_PROGRAM, 0x0000, 0x1fff, 0, 0, MWA8_BANK10);
+	memory_set_bankptr(10, memory_region(REGION_CPU2));
 
 /*	memory_set_bankptr(1,memory_region(REGION_USER1));    cartridge at BANK1    */
 	memory_set_bankptr(2,genesis_mainram); /* BANK2 = mainram */
