@@ -17,6 +17,10 @@
 #include "99_ide.h"
 #include "99_usbsm.h"
 
+#include "sound/tms5220.h"	/* for tms5220_set_variant() */
+#include "sound/5220intf.h"
+#include "sound/sn76496.h"
+
 
 /* prototypes */
 static void inta_callback(int state);
@@ -128,6 +132,8 @@ static int KeyFakeUnshiftState;
 static int KeyAutoRepeatKey;
 static int KeyAutoRepeatTimer;
 
+static void machine_stop_geneve(void);
+
 /*
 	GROM support.
 
@@ -184,18 +190,18 @@ enum
 	initialization, cart loading, etc.
 */
 
-void init_geneve(void)
+DRIVER_INIT( geneve )
 {
 	/*has_genmod = FALSE;*/
 }
 
-void init_genmod(void)
+DRIVER_INIT( genmod )
 {
 	/*has_genmod = TRUE;*/
 }
 
 
-void machine_init_geneve(void)
+MACHINE_START( geneve )
 {
 	mode_flags = /*0*/mf_mapmode;
 	/* initialize page lookup */
@@ -281,9 +287,12 @@ void machine_init_geneve(void)
 
 	if (has_usb_sm)
 		ti99_usbsm_init(TRUE);
+
+	add_exit_callback(machine_stop_geneve);
+	return 0;
 }
 
-void machine_stop_geneve(void)
+static void machine_stop_geneve(void)
 {
 	if (has_ide)
 		ti99_ide_save_memcard();
@@ -298,7 +307,7 @@ void machine_stop_geneve(void)
 /*
 	video initialization.
 */
-int video_start_geneve(void)
+VIDEO_START(geneve)
 {
 	return v9938_init(MODEL_V9938, /*0x20000*/0x30000, tms9901_set_int2);	/* v38 with 128 kb of video RAM */
 }
