@@ -39,7 +39,7 @@
 #include "driver.h"
 #include "machine/6522via.h"
 #include "machine/applefdc.h"
-#include "machine/sonydriv.h"
+#include "devices/sonydriv.h"
 #include "machine/lisa.h"
 #include "cpu/m68000/m68k.h"
 #include "sound/speaker.h"
@@ -62,12 +62,8 @@ UINT8 *lisa_rom_ptr;
 /* 1kb of RAM for 6504 floppy disk controller (shared with 68000), and 4kb of
 ROM (8kb on some boards, but then only one 4kb bank is selected, according to
 the drive type (TWIGGY or 3.5'')) */
-static UINT8 *fdc_ram;
-static UINT8 *fdc_rom;
-
-/* offsets in REGION_CPU2 */
-#define FDC_RAM_OFFSET 0x0000
-#define FDC_ROM_OFFSET 0x1000
+UINT8 *lisa_fdc_ram;
+UINT8 *lisa_fdc_rom;
 
 /* special ROM (includes S/N) */
 UINT8 *videoROM_ptr;
@@ -149,11 +145,8 @@ static struct via6522_interface lisa_via6522_intf[2] =
 		NULL, NULL,
 		COPS_via_out_a, COPS_via_out_b,
 		COPS_via_out_ca2, COPS_via_out_cb2,
+		NULL, NULL,
 		COPS_via_irq_func,
-		NULL,
-		NULL,
-		NULL,
-		NULL,
 	},
 	{	/* parallel interface via - incomplete */
 		NULL, parallel_via_in_b,
@@ -161,11 +154,7 @@ static struct via6522_interface lisa_via6522_intf[2] =
 		NULL, NULL,
 		NULL, NULL,
 		NULL, NULL,
-		NULL,
-		NULL,
-		NULL,
-		NULL,
-		NULL,
+		NULL, NULL,
 	}
 };
 
@@ -1033,35 +1022,16 @@ static OPBASE_HANDLER (lisa_fdc_OPbaseoverride)
 /* TODO : save time difference with host clock, set default date, etc */
 NVRAM_HANDLER(lisa)
 {
-	UINT8 *l_fdc_ram = memory_region(REGION_CPU2) + FDC_RAM_OFFSET;	/* fdc_ram is not necessarily set yet */
-
-
 	if (read_or_write)
 	{
-		if (file)
-		{
-#if 0
-			logerror("Writing PRAM to file\n");
-#endif
-			mame_fwrite(file, l_fdc_ram, 1024);
-		}
+		mame_fwrite(file, lisa_fdc_ram, 1024);
 	}
 	else
 	{
 		if (file)
-		{
-#if 0
-			logerror("Reading PRAM from file\n");
-#endif
-			mame_fread(file, l_fdc_ram, 1024);
-		}
+			mame_fread(file, lisa_fdc_ram, 1024);
 		else
-		{
-#if 0
-			logerror("trashing PRAM\n");
-#endif
-			memset(l_fdc_ram, 0, 1024);
-		}
+			memset(lisa_fdc_ram, 0, 1024);
 
 		{
 			/* Now we copy the host clock into the Lisa clock */
@@ -1153,25 +1123,19 @@ static void lisa210_set_iwm_enable_lines(int enable_mask)
 	sony_set_enable_lines(enable_mask >> 1);
 }
 
-MACHINE_INIT( lisa )
+MACHINE_RESET( lisa )
 {
 	mouse_timer = timer_alloc(handle_mouse);
 
 	lisa_ram_ptr = memory_region(REGION_CPU1) + RAM_OFFSET;
 	lisa_rom_ptr = memory_region(REGION_CPU1) + ROM_OFFSET;
 
-	fdc_ram = memory_region(REGION_CPU2) + FDC_RAM_OFFSET;
-	fdc_rom = memory_region(REGION_CPU2) + FDC_ROM_OFFSET;
-
 	videoROM_ptr = memory_region(REGION_GFX1);
 
 	memory_set_opbase_handler(0, lisa_OPbaseoverride);
 	memory_set_opbase_handler(1, lisa_fdc_OPbaseoverride);
 
-	/* swap to the CPU's context */
-	cpuintrf_push_context(0);
-	m68k_set_reset_instr_callback(/*lisa_reset_instr_callback*/NULL);
-	cpuintrf_pop_context();
+	cpunum_set_info_fct(0, CPUINFO_PTR_M68K_RESET_CALLBACK, (genf *)/*lisa_reset_instr_callback*/NULL);
 
 	/* init MMU */
 
@@ -1443,36 +1407,36 @@ WRITE8_HANDLER ( lisa_fdc_io_w )
 	}
 }
 
- READ8_HANDLER ( lisa_fdc_r )
+READ8_HANDLER ( lisa_fdc_r )
 {
 	if (! (offset & 0x1000))
 	{
 		if (! (offset & 0x0800))
 			if (! (offset & 0x0400))
-				return fdc_ram[offset & 0x03ff];
+				return lisa_fdc_ram[offset & 0x03ff];
 			else
 				return lisa_fdc_io_r(offset & 0x03ff);
 		else
 			return 0;	/* ??? */
 	}
 	else
-		return fdc_rom[offset & 0x0fff];
+		return lisa_fdc_rom[offset & 0x0fff];
 }
 
- READ8_HANDLER ( lisa210_fdc_r )
+READ8_HANDLER ( lisa210_fdc_r )
 {
 	if (! (offset & 0x1000))
 	{
 		if (! (offset & 0x0400))
 			if (! (offset & 0x0800))
-				return fdc_ram[offset & 0x03ff];
+				return lisa_fdc_ram[offset & 0x03ff];
 			else
 				return lisa_fdc_io_r(offset & 0x03ff);
 		else
 			return 0;	/* ??? */
 	}
 	else
-		return fdc_rom[offset & 0x0fff];
+		return lisa_fdc_rom[offset & 0x0fff];
 }
 
 WRITE8_HANDLER ( lisa_fdc_w )
@@ -1482,7 +1446,7 @@ WRITE8_HANDLER ( lisa_fdc_w )
 		if (! (offset & 0x0800))
 		{
 			if (! (offset & 0x0400))
-				fdc_ram[offset & 0x03ff] = data;
+				lisa_fdc_ram[offset & 0x03ff] = data;
 			else
 				lisa_fdc_io_w(offset & 0x03ff, data);
 		}
@@ -1496,7 +1460,7 @@ WRITE8_HANDLER ( lisa210_fdc_w )
 		if (! (offset & 0x0400))
 		{
 			if (! (offset & 0x0800))
-				fdc_ram[offset & 0x03ff] = data;
+				lisa_fdc_ram[offset & 0x03ff] = data;
 			else
 				lisa_fdc_io_w(offset & 0x03ff, data);
 		}
@@ -2003,7 +1967,7 @@ static READ16_HANDLER ( lisa_IO_r )
 			if (! (offset & 0x400))
 			{
 				/*if (ACCESSING_LSB)*/	/* Geez, who cares ? */
-					answer = fdc_ram[offset & 0x03ff] & 0xff;	/* right ??? */
+					answer = lisa_fdc_ram[offset & 0x03ff] & 0xff;	/* right ??? */
 			}
 		}
 		else
@@ -2098,7 +2062,7 @@ static WRITE16_HANDLER ( lisa_IO_w )
 			if (! (offset & 0x0400))
 			{
 				if (ACCESSING_LSB)
-					fdc_ram[offset & 0x03ff] = data & 0xff;
+					lisa_fdc_ram[offset & 0x03ff] = data & 0xff;
 			}
 		}
 		else
