@@ -1,51 +1,58 @@
 /******************************************************************************
  PeT mess@utanet.at 2000,2001
 ******************************************************************************/
+
 #include <assert.h>
+
 #include "includes/lynx.h"
 #include "cpu/m6502/m6502.h"
+#include "state.h"
 
-UINT16 lynx_granularity=1;
+UINT16 lynx_granularity = 1;
 static int lynx_line;
 
-typedef struct {
-    union {
-	UINT8 data[0x100];
-	struct {
-	    struct { UINT8 l, h; } 
-	    /* eng used by the blitter engine */
-	    /* scb written by the blitter scb blocks to engine expander */
-	    /*     used by the engine */
-	    /*     might be used directly by software! */
-	    eng1, eng2,		
-		h_offset, v_offset, vidbas, colbas,
-		eng3, eng4, 
-		scb1, scb2, scb3, scb4, scb5, scb6,
-		eng5, eng6, eng7, eng8,
-		colloff,
-		eng9,
-		hsizoff, vsizoff,
-		eng10, eng11;
-	    UINT8 res[0x20];
-	    UINT8 used[2];
-	    UINT8 D,C,B,A,P,N;
-	    UINT8 res1[8];
-	    UINT8 H,G,F,E;
-	    UINT8 res2[8];
-	    UINT8 M,L,K,J;
-	    UINT8 res3[0x21];
-	    UINT8 SPRG0;
-	    UINT8 SPRSYS;
-	} s;
+typedef struct
+{
+    union
+	{
+		UINT8 data[0x100];
+		struct
+		{
+			struct { UINT8 l, h; } 
+			/* eng used by the blitter engine */
+			/* scb written by the blitter scb blocks to engine expander */
+			/*     used by the engine */
+			/*     might be used directly by software! */
+			eng1, eng2,		
+			h_offset, v_offset, vidbas, colbas,
+			eng3, eng4, 
+			scb1, scb2, scb3, scb4, scb5, scb6,
+			eng5, eng6, eng7, eng8,
+			colloff,
+			eng9,
+			hsizoff, vsizoff,
+			eng10, eng11;
+			UINT8 res[0x20];
+			UINT8 used[2];
+			UINT8 D,C,B,A,P,N;
+			UINT8 res1[8];
+			UINT8 H,G,F,E;
+			UINT8 res2[8];
+			UINT8 M,L,K,J;
+			UINT8 res3[0x21];
+			UINT8 SPRG0;
+			UINT8 SPRSYS;
+		} s;
     } u;
     bool accumulate_overflow;    
     UINT8 high;
     int low;
 } SUZY;
 
-static SUZY suzy={ { { 0 } } };
+static SUZY suzy;
 
-static struct {
+static struct
+{
     UINT8 *mem;
     /* global */
     UINT16 screen;
@@ -68,6 +75,15 @@ static struct {
     double time;
 } blitter;
 
+UINT8 *lynx_mem_0000;
+UINT8 *lynx_mem_fc00;
+UINT8 *lynx_mem_fd00;
+UINT8 *lynx_mem_fe00;
+UINT8 *lynx_mem_fffa;
+size_t lynx_mem_fe00_size;
+
+static UINT8 lynx_memory_config;
+
 #define GET_WORD(mem, index) ((mem)[(index)]|((mem)[(index)+1]<<8))
 
 /*
@@ -88,7 +104,7 @@ INLINE void lynx_plot_pixel(const int mode, const int x, const int y, const int
     UINT8 *screen;
     UINT8 *colbuf;
     
-    blitter.everon=true;
+    blitter.everon=TRUE;
     screen=blitter.mem+blitter.screen+y*80+x/2;
     colbuf=blitter.mem+blitter.colbuf+y*80+x/2;
     switch (mode) {
@@ -354,7 +370,7 @@ static void lynx_blit_lines(void)
 	int ydir=0, xdir=0;
 	int flip=blitter.mem[blitter.cmd+1]&3;
 
-	blitter.everon=false;
+	blitter.everon=FALSE;
 
 	/* flipping sprdemo3 */
 	/* fat bobby 0x10 */
@@ -516,7 +532,7 @@ static void lynx_blitter(void)
     int i; int o;int colors;
     
     blitter.memory_accesses=0;
-    blitter.mem=memory_region(REGION_CPU1);
+    blitter.mem = memory_get_read_ptr(0, ADDRESS_SPACE_PROGRAM, 0x0000);
     blitter.colbuf=GET_WORD(suzy.u.data, 0xa);
     blitter.screen=GET_WORD(suzy.u.data, 8);
     blitter.xoff=GET_WORD(suzy.u.data,4);
@@ -600,9 +616,9 @@ static void lynx_divide(void)
 	UINT32 left=suzy.u.s.H|(suzy.u.s.G<<8)|(suzy.u.s.F<<16)|(suzy.u.s.E<<24);
 	UINT16 right=suzy.u.s.P|(suzy.u.s.N<<8);
 	UINT32 res, mod;
-	suzy.accumulate_overflow=false;
+	suzy.accumulate_overflow=FALSE;
 	if (right==0) {
-	    suzy.accumulate_overflow=true;
+	    suzy.accumulate_overflow=TRUE;
 	    res=0xffffffff;
 	    mod=0; /*? */
 	} else {
@@ -638,7 +654,7 @@ static void lynx_multiply(void)
 	if (suzy.u.s.SPRSYS&0x40) {
 	    accu=suzy.u.s.M|suzy.u.s.L<<8|suzy.u.s.K<<16|suzy.u.s.J<<24;
 	    accu+=res;
-	    if (accu<res) suzy.accumulate_overflow=true;
+	    if (accu<res) suzy.accumulate_overflow=TRUE;
 	    suzy.u.s.M=accu;
 	    suzy.u.s.L=accu>>8;
 	    suzy.u.s.K=accu>>16;
@@ -718,7 +734,7 @@ WRITE8_HANDLER(suzy_write)
 	    break;
 	case 0x6c:
 	    suzy.u.data[offset+1]=0;
-	    suzy.accumulate_overflow=false;
+	    suzy.accumulate_overflow=FALSE;
 	    break;
 	case 0x55: lynx_multiply();break;
 	case 0x63: lynx_divide();break;
@@ -844,7 +860,7 @@ void lynx_timer_count_down(int nr)
 	    This->counter--;
 	    return;
 	} else if (This->counter==0) {
-	    This->shot=true;
+	    This->shot=TRUE;
 	    lynx_timer_signal_irq(This);
 	    if (This->u.s.cntrl1&0x10) {
 		This->counter=This->u.s.bakup;
@@ -859,7 +875,7 @@ void lynx_timer_count_down(int nr)
 static void lynx_timer_shot(int nr)
 {
     LYNX_TIMER *This=lynx_timer+nr;
-    This->shot=true;
+    This->shot=TRUE;
     lynx_timer_signal_irq(This);
     if (!(This->u.s.cntrl1&0x10))
 		This->timer_active = 0;
@@ -904,7 +920,7 @@ static void lynx_timer_write(LYNX_TIMER *This, int offset, UINT8 data)
 	logerror("timer %d write %x %.2x\n",This-lynx_timer,offset,data);
 	This->u.data[offset]=data;
 
-	if ((offset==1) && (data&0x40)) This->shot=false;
+	if ((offset==1) && (data&0x40)) This->shot=FALSE;
 
 	switch (offset) {
 	case 0:
@@ -952,10 +968,10 @@ static void lynx_uart_timer(int param)
 {
     if (uart.buffer_loaded) {
 	uart.data_to_send=uart.buffer;
-	uart.buffer_loaded=false;
+	uart.buffer_loaded=FALSE;
 	timer_set(1.0e-6*11, 0, lynx_uart_timer);	
     } else {
-	uart.sending=false;
+	uart.sending=FALSE;
     }
 /*    mikey.data[0x80]|=0x10; */
     if (uart.serctl&0x80) {
@@ -991,9 +1007,9 @@ static WRITE8_HANDLER(lynx_uart_w)
     case 0x8d:
 	if (uart.sending) {
 	    uart.buffer=data;
-	    uart.buffer_loaded=true;
+	    uart.buffer_loaded=TRUE;
 	} else {
-	    uart.sending=true;
+	    uart.sending=TRUE;
 	    uart.data_to_send=data;
 	    timer_set(1.0e-6*11, 0, lynx_uart_timer);
 	}
@@ -1121,39 +1137,46 @@ WRITE8_HANDLER(mikey_write)
     }
 }
 
-WRITE8_HANDLER( lynx_memory_config )
+READ8_HANDLER( lynx_memory_config_r )
+{
+	return lynx_memory_config;
+}
+
+WRITE8_HANDLER( lynx_memory_config_w )
 {
     /* bit 7: hispeed, uses page mode accesses (4 instead of 5 cycles )
      * when these are safe in the cpu */
-    memory_region(REGION_CPU1)[0xfff9]=data;
+    lynx_memory_config = data;
 
-	memory_install_read8_handler(0,  ADDRESS_SPACE_PROGRAM, 0xfc00, 0xfcff, 0, 0, (data & 1) ? MRA8_RAM : suzy_read);
-	memory_install_write8_handler(0, ADDRESS_SPACE_PROGRAM, 0xfc00, 0xfcff, 0, 0, (data & 1) ? MWA8_RAM : suzy_write);
-	memory_install_read8_handler(0,  ADDRESS_SPACE_PROGRAM, 0xfd00, 0xfdff, 0, 0, (data & 2) ? MRA8_RAM : mikey_read);
-	memory_install_write8_handler(0, ADDRESS_SPACE_PROGRAM, 0xfd00, 0xfdff, 0, 0, (data & 2) ? MWA8_RAM : mikey_write);
-	memory_install_read8_handler(0,  ADDRESS_SPACE_PROGRAM, 0xfe00, 0xfff7, 0, 0, (data & 4) ? MRA8_RAM : MRA8_BANK3);
-	memory_install_read8_handler(0,  ADDRESS_SPACE_PROGRAM, 0xfffa, 0xffff, 0, 0, (data & 8) ? MRA8_RAM : MRA8_BANK4);
+	memory_install_read8_handler(0,  ADDRESS_SPACE_PROGRAM, 0xfc00, 0xfcff, 0, 0, (data & 1) ? MRA8_BANK1 : suzy_read);
+	memory_install_write8_handler(0, ADDRESS_SPACE_PROGRAM, 0xfc00, 0xfcff, 0, 0, (data & 1) ? MWA8_BANK1 : suzy_write);
+	memory_install_read8_handler(0,  ADDRESS_SPACE_PROGRAM, 0xfd00, 0xfdff, 0, 0, (data & 2) ? MRA8_BANK2 : mikey_read);
+	memory_install_write8_handler(0, ADDRESS_SPACE_PROGRAM, 0xfd00, 0xfdff, 0, 0, (data & 2) ? MWA8_BANK2 : mikey_write);
 
-	cpu_setbank(3, memory_region(REGION_CPU1) + 0x10000);
-	cpu_setbank(4, memory_region(REGION_CPU1) + 0x101fa);
+	if (data & 1)
+		memory_set_bankptr(1, lynx_mem_fc00);
+	if (data & 2)
+		memory_set_bankptr(2, lynx_mem_fd00);
+	memory_set_bank(3, (data & 4) ? 1 : 0);
+	memory_set_bank(4, (data & 8) ? 1 : 0);
 }
 
-MACHINE_INIT( lynx )
+static void lynx_reset(void)
 {
 	int i;
-	lynx_memory_config(0,0);
+	lynx_memory_config_w(0, 0);
 
 	cpunum_set_input_line(0, M65SC02_IRQ_LINE, CLEAR_LINE);	    
 
 	memset(&suzy, 0, sizeof(suzy));
 	memset(&mikey, 0, sizeof(mikey));
 
-	mikey.data[0x80]=0;
-	mikey.data[0x81]=0;
+	mikey.data[0x80] = 0;
+	mikey.data[0x81] = 0;
 
 	lynx_uart_reset();
 
-	for (i=0; i<ARRAY_LENGTH(lynx_timer); i++)
+	for (i = 0; i < (sizeof(lynx_timer) / sizeof(lynx_timer[0])); i++)
 		lynx_timer_init(lynx_timer+i);
 
 	lynx_audio_reset();
@@ -1166,3 +1189,25 @@ MACHINE_INIT( lynx )
 	lynx_timer_write(lynx_timer+2, 1, 0x10|0x8|7);
 #endif
 }
+
+static void lynx_postload(void)
+{
+	lynx_memory_config_w(0, lynx_memory_config);
+}
+
+MACHINE_START( lynx )
+{
+	state_save_register_global(lynx_memory_config);
+	state_save_register_global_pointer(lynx_mem_fe00, lynx_mem_fe00_size);
+	state_save_register_func_postload(lynx_postload);
+
+	memory_configure_bank(3, 0, 1, memory_region(REGION_CPU1) + 0x0000, 0);
+	memory_configure_bank(3, 1, 1, lynx_mem_fe00, 0);
+	memory_configure_bank(4, 0, 1, memory_region(REGION_CPU1) + 0x01fa, 0);
+	memory_configure_bank(4, 1, 1, lynx_mem_fffa, 0);
+
+	memset(&suzy, 0, sizeof(suzy));
+
+	add_reset_callback(lynx_reset);
+	return 0;
+}
