@@ -8,12 +8,15 @@
 ****************************************************************************/
 
 #include "driver.h"
-#include "machine/z80fmly.h"
+#include "machine/z80ctc.h"
+#include "machine/z80pio.h"
+#include "machine/z80sio.h"
 #include "vidhrdw/generic.h"
-#include "includes/wd179x.h"
+#include "machine/wd17xx.h"
 #include "includes/mbee.h"
 #include "devices/cassette.h"
 #include "cpu/z80/z80.h"
+#include "sound/speaker.h"
 #include "image.h"
 
 static UINT8 fdc_drv = 0;
@@ -25,10 +28,9 @@ static void mbee_fdc_callback(int);
 
 static z80pio_interface pio_intf =
 {
-	1,					/* number of PIOs to emulate */
-	{ pio_interrupt },	/* callback when change interrupt status */
-	{ 0 },				/* portA ready active callback (do not support yet)*/
-	{ 0 }				/* portB ready active callback (do not support yet)*/
+	pio_interrupt,	/* callback when change interrupt status */
+	0,				/* portA ready active callback (do not support yet)*/
+	0				/* portB ready active callback (do not support yet)*/
 };
 
 static void pio_interrupt(int state)
@@ -36,9 +38,9 @@ static void pio_interrupt(int state)
 	cpunum_set_input_line(0, 0, state ? ASSERT_LINE : CLEAR_LINE);
 }
 
-MACHINE_INIT( mbee )
+MACHINE_RESET( mbee )
 {
-	z80pio_init(&pio_intf);
+	z80pio_init(0, &pio_intf);
     wd179x_init(WD_TYPE_179X,mbee_fdc_callback);
 }
 
@@ -57,9 +59,9 @@ static mess_image *cassette_device_image(void)
  * 6	speaker
  * 7	network interrupt
  */
- READ8_HANDLER ( mbee_pio_r )
+READ8_HANDLER ( mbee_pio_r )
 {
-    int data = z80pio_0_r(offset);
+    UINT8 data = (offset & 2) ? z80pio_c_r(0, offset & 1) : z80pio_d_r(0, offset & 1);
 	if( offset != 2 )
 		return data;
 
@@ -72,7 +74,11 @@ static mess_image *cassette_device_image(void)
 
 WRITE8_HANDLER ( mbee_pio_w )
 {
-    z80pio_0_w(offset,data);
+	if (offset & 2)
+		z80pio_c_w(0, offset & 1, data);
+	else
+		z80pio_d_w(0, offset & 1, data);
+
 	if( offset == 2 )
 	{
 		cassette_output(cassette_device_image(), (data & 0x02) ? -1.0 : +1.0);
