@@ -20,7 +20,7 @@
 #include "driver.h"
 #include "includes/msx_slot.h"
 #include "includes/msx.h"
-#include "includes/wd179x.h"
+#include "machine/wd17xx.h"
 #include "sound/k051649.h"
 #include "sound/2413intf.h"
 #include "sound/dac.h"
@@ -33,28 +33,28 @@ static void msx_cpu_setbank (int page, UINT8 *mem)
 	case 1:
 	case 2:
 	case 3:
-		cpu_setbank (page, mem);
+		memory_set_bankptr (page, mem);
 		break;
 	case 4:
-		cpu_setbank (4, mem);
-		cpu_setbank (5, mem + 0x1ff8);
+		memory_set_bankptr (4, mem);
+		memory_set_bankptr (5, mem + 0x1ff8);
 		memory_install_read8_handler (0, ADDRESS_SPACE_PROGRAM, 0x7ff8, 0x7fff, 0, 0, MRA8_BANK5);
 		break;
 	case 5:
-		cpu_setbank (6, mem);
-		cpu_setbank (7, mem + 0x1800);
+		memory_set_bankptr (6, mem);
+		memory_set_bankptr (7, mem + 0x1800);
 		memory_install_read8_handler (0, ADDRESS_SPACE_PROGRAM, 0x9800, 0x9fff, 0, 0, MRA8_BANK7);
 		break;
 	case 6:
-		cpu_setbank (8, mem);
-		cpu_setbank (9, mem + 0x1800);
+		memory_set_bankptr (8, mem);
+		memory_set_bankptr (9, mem + 0x1800);
 		memory_install_read8_handler (0, ADDRESS_SPACE_PROGRAM, 0xb800, 0xbfff, 0, 0, MRA8_BANK9);
 		break;
 	case 7:
-		cpu_setbank (10, mem);
+		memory_set_bankptr (10, mem);
 		break;
 	case 8:
-		cpu_setbank (11, mem);
+		memory_set_bankptr (11, mem);
 		msx1.top_page = mem;
 		break;
 	}
@@ -104,10 +104,6 @@ MSX_SLOT_MAP(rom)
 MSX_SLOT_INIT(ram)
 {
 	state->mem = auto_malloc (size);
-	if (!state->mem) {
-		logerror ("ram: error: out of memory\n");
-		return 1;
-	}
 	memset (state->mem, 0, size);
 	state->type = SLOT_RAM;
 	state->start_page = page;
@@ -151,10 +147,6 @@ MSX_SLOT_INIT(rammm)
 		return 1;
 	}
 	state->mem = auto_malloc (size);
-	if (!state->mem) {
-		logerror ("ram mapper: error: out of memory\n");
-		return 1;
-	}
 	memset (state->mem, 0, size);
 
 #ifdef MONMSX
@@ -573,10 +565,6 @@ MSX_SLOT_INIT(ascii8_sram)
 	int banks;
 
 	state->cart.sram.mem = auto_malloc (0x2000);
-	if (!state->cart.sram.mem) {
-		logerror ("ascii8_sram: error: failed to malloc sram memory\n");
-		return 1;
-	}
 	if (size > 0x100000) {
 		logerror ("ascii8_sram: warning: truncating to 1mb\n");
 		size = 0x100000;
@@ -725,10 +713,6 @@ MSX_SLOT_INIT(ascii16_sram)
 	int banks;
 
 	state->cart.sram.mem = auto_malloc (0x4000);
-	if (!state->cart.sram.mem) {
-		logerror ("ascii16_sram: error: failed to malloc sram memory\n");
-		return 1;
-	}
 
 	if (size > 0x200000) {
 		logerror ("ascii16_sram: warning: truncating to 2mb\n");
@@ -966,11 +950,6 @@ MSX_SLOT_INIT(gmaster2)
 	state->mem = mem;
 
 	p = auto_malloc (0x4000);
-	if (!p) {
-		logerror ("gmaster2: error: out of memory\n");
-		return 1;
-	}
-
 	memset (p, 0, 0x4000);
 	state->cart.sram.mem = p;
 	if (!state->sramfile) {
@@ -1474,10 +1453,6 @@ MSX_SLOT_INIT(fmpac)
 	if (!strncmp ((char*)mem + 0x18, "PAC2", 4)) {
 		state->cart.fmpac.sram_support = 1;
 		p = auto_malloc (0x4000);
-		if (!p) {
-			logerror ("fmpac: error: out of memory\n");
-			return 1;
-		}
 		memset (p, 0, 0x2000);
 		memset (p + 0x2000, 0xff, 0x2000);
 		state->cart.fmpac.mem = p;
@@ -1964,10 +1939,6 @@ MSX_SLOT_INIT(soundcartridge)
 	UINT8 *p;
 
 	p = auto_malloc (0x20000);
-	if (!p) {
-		logerror ("soundcartridge: error: failed to malloc ram\n");
-		return 1;
-	}
 	memset (p, 0, 0x20000);
 
 	state->mem = p;
