@@ -17,10 +17,11 @@
                 PCW and PC drivers
 	- resolve "ready" state stuff (ready state when reset for PC, ready state change while processing command AND
 	while idle)
+
 ***************************************************************************/
 
 #include "driver.h"
-#include "includes/nec765.h"
+#include "machine/nec765.h"
 
 typedef enum
 {
@@ -32,17 +33,14 @@ typedef enum
 } NEC765_PHASE;
 
 /* uncomment the following line for verbose information */
-#define VERBOSE
+#define LOG_VERBOSE		1
+#define LOG_COMMAND		0
+#define LOG_EXTRA		0
+#define LOG_INTERRUPT	0
 
 /* uncomment this to not allow end of cylinder "error" */
 #define NO_END_OF_CYLINDER
 
-#ifdef VERBOSE
-/* uncomment the following line for super-verbose information i.e. data
-transfer bytes */
-/*#define SUPER_VERBOSE */
-#endif
-
 
 
 /* state of nec765 Interrupt (INT) output */
@@ -68,7 +66,7 @@ typedef struct nec765
 {
 	unsigned long	sector_counter;
 	/* version of fdc to emulate */
-	int version;
+	NEC765_VERSION version;
 	/* main status register */
 	unsigned char    FDC_main;
 	/* data register */
@@ -131,7 +129,7 @@ static NEC765 fdc;
 static char nec765_data_buffer[32*1024];
 
 
-nec765_interface nec765_iface;
+static nec765_interface nec765_iface;
 
 
 static const INT8 nec765_cmd_size[32] =
@@ -144,9 +142,18 @@ static const INT8 nec765_cmd_size[32] =
 
 static mess_image *current_image(void)
 {
-	if (fdc.drive >= device_count(IO_FLOPPY))
-		return NULL;
-	return image_from_devtype_and_index(IO_FLOPPY, fdc.drive);
+	mess_image *image = NULL;
+
+	if (!nec765_iface.get_image)
+	{
+		if (fdc.drive < device_count(IO_FLOPPY))
+			image = image_from_devtype_and_index(IO_FLOPPY, fdc.drive);
+	}
+	else
+	{
+		image = nec765_iface.get_image(fdc.drive);
+	}
+	return image;
 }
 
 static void nec765_setup_drive_and_side(void)
@@ -598,6 +605,8 @@ static void nec765_change_flags(unsigned int flags, unsigned int mask)
 /* set int output */
 static void nec765_set_int(int state)
 {
+	if (LOG_INTERRUPT)
+		logerror("nec765_set_int(): state=%d\n", state);
 	nec765_change_flags(state ? NEC765_INT : 0, NEC765_INT);
 }
 
@@ -659,7 +668,7 @@ static void nec765_set_ready_change_callback(mess_image *img, int state)
 
 
 
-void nec765_init(nec765_interface *iface, int version)
+void nec765_init(const nec765_interface *iface, NEC765_VERSION version)
 {
 	int i;
 
@@ -725,11 +734,10 @@ void nec765_set_tc_state(int state)
 	}
 }
 
- READ8_HANDLER(nec765_status_r)
+READ8_HANDLER(nec765_status_r)
 {
-#ifdef SUPER_VERBOSE
-	logerror("nec765 status r: %02x\n",fdc.FDC_main);
-#endif
+	if (LOG_EXTRA)
+		logerror("nec765 status r: %02x\n",fdc.FDC_main);
 	return fdc.FDC_main;
 }
 
@@ -932,9 +940,10 @@ static void nec765_read_data(void)
 		nec765_setup_result_phase(7);
 		return;
 	}
-#ifdef VERBOSE
-	logerror("sector c: %02x h: %02x r: %02x n: %02x\n",fdc.nec765_command_bytes[2], fdc.nec765_command_bytes[3],fdc.nec765_command_bytes[4], fdc.nec765_command_bytes[5]);
-#endif
+
+	if (LOG_VERBOSE)
+		logerror("sector c: %02x h: %02x r: %02x n: %02x\n",fdc.nec765_command_bytes[2], fdc.nec765_command_bytes[3],fdc.nec765_command_bytes[4], fdc.nec765_command_bytes[5]);
+
 	/* find a sector to read data from */
 	{
 		int found_sector_to_read;
@@ -1505,7 +1514,7 @@ static int nec765_get_command_byte_count(void)
 
 				/* configure */
 				case 0x013:
-					return 3;
+					return 4;
 
 				/* dumpreg */
 				case 0x0e:
@@ -1563,9 +1572,8 @@ void nec765_update_state(void)
 			}
 		}
 
-#ifdef VERBOSE
-		logerror("NEC765: RESULT: %02x\n", fdc.nec765_data_reg);
-#endif
+		if (LOG_VERBOSE)
+			logerror("NEC765: RESULT: %02x\n", fdc.nec765_data_reg);
 
 		fdc.nec765_transfer_bytes_count++;
 		fdc.nec765_transfer_bytes_remaining--;
@@ -1586,9 +1594,8 @@ void nec765_update_state(void)
 		fdc.nec765_transfer_bytes_count++;
 		fdc.nec765_transfer_bytes_remaining--;
 
-#ifdef SUPER_VERBOSE
-		logerror("EXECUTION PHASE READ: %02x\n", fdc.nec765_data_reg);
-#endif
+		if (LOG_EXTRA)
+			logerror("EXECUTION PHASE READ: %02x\n", fdc.nec765_data_reg);
 
 		if ((fdc.nec765_transfer_bytes_remaining==0) || (fdc.nec765_flags & NEC765_TC))
 		{
@@ -1604,9 +1611,9 @@ void nec765_update_state(void)
 	case NEC765_COMMAND_PHASE_FIRST_BYTE:
 		fdc.FDC_main |= 0x10;                      /* set BUSY */
 
-#ifdef VERBOSE
-		logerror("nec765(): pc=0x%08x command=0x%02x\n", activecpu_get_pc(), fdc.nec765_data_reg);
-#endif
+		if (LOG_VERBOSE)
+			logerror("nec765(): pc=0x%08x command=0x%02x\n", activecpu_get_pc(), fdc.nec765_data_reg);
+
 		/* seek in progress? */
 		if (fdc.nec765_flags & NEC765_SEEK_ACTIVE)
 		{
@@ -1635,9 +1642,9 @@ void nec765_update_state(void)
         break;
 
     case NEC765_COMMAND_PHASE_BYTES:
-#ifdef VERBOSE
-		logerror("nec765(): pc=0x%08x command=0x%02x\n", activecpu_get_pc(), fdc.nec765_data_reg);
-#endif
+		if (LOG_VERBOSE)
+			logerror("nec765(): pc=0x%08x command=0x%02x\n", activecpu_get_pc(), fdc.nec765_data_reg);
+
 		fdc.nec765_command_bytes[fdc.nec765_transfer_bytes_count] = fdc.nec765_data_reg;
 		fdc.nec765_transfer_bytes_count++;
 		fdc.nec765_transfer_bytes_remaining--;
@@ -1691,18 +1698,16 @@ void nec765_update_state(void)
 		nec765_update_state();
 	}
 
-#ifdef SUPER_VERBOSE
-	logerror("DATA R: %02x\n", fdc.nec765_data_reg);
-#endif
+	if (LOG_EXTRA)
+		logerror("DATA R: %02x\n", fdc.nec765_data_reg);
 
 	return fdc.nec765_data_reg;
 }
 
 WRITE8_HANDLER(nec765_data_w)
 {
-#ifdef SUPER_VERBOSE
-	logerror("DATA W: %02x\n", data);
-#endif
+	if (LOG_EXTRA)
+		logerror("DATA W: %02x\n", data);
 
 	/* write data to data reg */
 	fdc.nec765_data_reg = data;
@@ -1735,7 +1740,33 @@ static void nec765_setup_invalid(void)
 
 static void nec765_setup_command(void)
 {
+	static const char *commands[] =
+	{
+		NULL,						/* [00] */
+		NULL,						/* [01] */
+		"Read Track",				/* [02] */
+		"Specify",					/* [03] */
+		"Sense Drive Status",		/* [04] */
+		"Write Data",				/* [05] */
+		"Read Data",				/* [06] */
+		"Recalibrate",				/* [07] */
+		"Sense Interrupt Status",	/* [08] */
+		"Write Deleted Data",		/* [09] */
+		"Read ID",					/* [0A] */
+		NULL,						/* [0B] */
+		"Read Deleted Data",		/* [0C] */
+		"Format Track",				/* [0D] */
+		"Dump Registers",			/* [0E] */
+		"Seek",						/* [0F] */
+		"Version",					/* [10] */
+		NULL,						/* [11] */
+		"Perpendicular Mode",		/* [12] */
+		"Configure",				/* [13] */
+		"Lock"						/* [14] */
+	};
+
 	mess_image *img = current_image();
+	const char *cmd = NULL;
 	chrn_id id;
 
 	/* if not in dma mode set execution phase bit */
@@ -1744,288 +1775,303 @@ static void nec765_setup_command(void)
         fdc.FDC_main |= 0x020;              /* execution phase */
 	}
 
-	switch (fdc.nec765_command_bytes[0] & 0x01f) {
-	case 0x03:      /* specify */
-		/* setup step rate */
-		fdc.srt_in_ms = 16-((fdc.nec765_command_bytes[1]>>4) & 0x0f);
+	if (LOG_COMMAND)
+	{
+		if ((fdc.nec765_command_bytes[0] & 0x1f) < sizeof(commands) / sizeof(commands[0]))
+			cmd = commands[fdc.nec765_command_bytes[0] & 0x1f];
+		logerror("nec765_setup_command(): Setting up command 0x%02X (%s)\n",
+			fdc.nec765_command_bytes[0] & 0x1f, cmd ? cmd : "???");
+	}
 
-		fdc.nec765_flags &= ~NEC765_DMA_MODE;
+	switch (fdc.nec765_command_bytes[0] & 0x1f)
+	{
+		case 0x03:      /* specify */
+			/* setup step rate */
+			fdc.srt_in_ms = 16-((fdc.nec765_command_bytes[1]>>4) & 0x0f);
 
-		if ((fdc.nec765_command_bytes[2] & 0x01)==0)
-		{
-			fdc.nec765_flags |= NEC765_DMA_MODE;
-		}
+			fdc.nec765_flags &= ~NEC765_DMA_MODE;
 
-		nec765_idle();
-		break;
-
-	case 0x04:  /* sense drive status */
-		nec765_setup_drive_and_side();
-
-		fdc.nec765_status[3] = fdc.drive | (fdc.side<<2);
-
-		if (floppy_drive_get_flag_state(img, FLOPPY_DRIVE_DISK_WRITE_PROTECTED))
-		{
-			fdc.nec765_status[3] |= 0x040;
-		}
-
-		if (floppy_drive_get_flag_state(img, FLOPPY_DRIVE_READY))
-		{
-			fdc.nec765_status[3] |= 0x020;
-		}
-
-		if (floppy_drive_get_flag_state(img, FLOPPY_DRIVE_HEAD_AT_TRACK_0))
-		{
-			fdc.nec765_status[3] |= 0x010;
-		}
-
-		fdc.nec765_status[3] |= 0x08;
-                               
-		/* two side and fault not set but should be? */
-		fdc.nec765_result_bytes[0] = fdc.nec765_status[3];
-		nec765_setup_result_phase(1);
-		break;
-
-	case 0x07:          /* recalibrate */
-		nec765_seek_setup(1);
-		break;
-
-	case 0x0f:          /* seek */
-		nec765_seek_setup(0);
-		break;
-
-	case 0x0a:      /* read id */
-		nec765_setup_drive_and_side();
-
-		fdc.nec765_status[0] = fdc.drive | (fdc.side<<2);
-		fdc.nec765_status[1] = 0;
-		fdc.nec765_status[2] = 0;
-
-		/* drive ready? */
-		if (floppy_drive_get_flag_state(img, FLOPPY_DRIVE_READY))
-		{
-			/* is disk inserted? */
-			if (image_exists(img))
+			if ((fdc.nec765_command_bytes[2] & 0x01)==0)
 			{
-				int index_count = 0;
+				fdc.nec765_flags |= NEC765_DMA_MODE;
+			}
 
-				/* floppy drive is ready and disc is inserted */
+			nec765_idle();
+			break;
 
-				/* this is the id that appears when a disc is not formatted */
-				/* to be checked on Amstrad */
-				id.C = 0;
-				id.H = 0;
-				id.R = 0x01;
-				id.N = 0x02;
+		case 0x04:  /* sense drive status */
+			nec765_setup_drive_and_side();
 
-				/* repeat for two index counts before quitting */
-				do
+			fdc.nec765_status[3] = fdc.drive | (fdc.side<<2);
+
+			if (floppy_drive_get_flag_state(img, FLOPPY_DRIVE_DISK_WRITE_PROTECTED))
+			{
+				fdc.nec765_status[3] |= 0x40;
+			}
+
+			if (floppy_drive_get_flag_state(img, FLOPPY_DRIVE_READY))
+			{
+				fdc.nec765_status[3] |= 0x20;
+			}
+
+			if (floppy_drive_get_flag_state(img, FLOPPY_DRIVE_HEAD_AT_TRACK_0))
+			{
+				fdc.nec765_status[3] |= 0x10;
+			}
+
+			fdc.nec765_status[3] |= 0x08;
+	                               
+			/* two side and fault not set but should be? */
+			fdc.nec765_result_bytes[0] = fdc.nec765_status[3];
+			nec765_setup_result_phase(1);
+			break;
+
+		case 0x07:          /* recalibrate */
+			nec765_seek_setup(1);
+			break;
+
+		case 0x0f:          /* seek */
+			nec765_seek_setup(0);
+			break;
+
+		case 0x0a:      /* read id */
+			nec765_setup_drive_and_side();
+
+			fdc.nec765_status[0] = fdc.drive | (fdc.side<<2);
+			fdc.nec765_status[1] = 0;
+			fdc.nec765_status[2] = 0;
+
+			/* drive ready? */
+			if (floppy_drive_get_flag_state(img, FLOPPY_DRIVE_READY))
+			{
+				/* is disk inserted? */
+				if (image_exists(img))
 				{
-					/* get next id from disc */
-					if (floppy_drive_get_next_id(img, fdc.side, &id))
-					{
-						/* got an id - quit */
-						break;
-					}
+					int index_count = 0;
 
-					if (floppy_drive_get_flag_state(img, FLOPPY_DRIVE_INDEX))
+					/* floppy drive is ready and disc is inserted */
+
+					/* this is the id that appears when a disc is not formatted */
+					/* to be checked on Amstrad */
+					id.C = 0;
+					id.H = 0;
+					id.R = 0x01;
+					id.N = 0x02;
+
+					/* repeat for two index counts before quitting */
+					do
 					{
-						/* update index count */
-						index_count++;
+						/* get next id from disc */
+						if (floppy_drive_get_next_id(img, fdc.side, &id))
+						{
+							/* got an id - quit */
+							break;
+						}
+
+						if (floppy_drive_get_flag_state(img, FLOPPY_DRIVE_INDEX))
+						{
+							/* update index count */
+							index_count++;
+						}
 					}
+					while (index_count!=2);
+						
+					/* at this point, we have seen a id or two index pulses have occured! */
+					fdc.nec765_result_bytes[0] = fdc.nec765_status[0];
+					fdc.nec765_result_bytes[1] = fdc.nec765_status[1];
+					fdc.nec765_result_bytes[2] = fdc.nec765_status[2];
+					fdc.nec765_result_bytes[3] = id.C; /* C */
+					fdc.nec765_result_bytes[4] = id.H; /* H */
+					fdc.nec765_result_bytes[5] = id.R; /* R */
+					fdc.nec765_result_bytes[6] = id.N; /* N */
+
+					nec765_setup_result_phase(7);
+				}
+				else
+				{
+					/* floppy drive is ready, but no disc is inserted */
+					/* this occurs on the PC */
+					/* in this case, the command never quits! */
+					/* there are no index pulses to stop the command! */
 				}
-				while (index_count!=2);
-					
-				/* at this point, we have seen a id or two index pulses have occured! */
-				fdc.nec765_result_bytes[0] = fdc.nec765_status[0];
-				fdc.nec765_result_bytes[1] = fdc.nec765_status[1];
-				fdc.nec765_result_bytes[2] = fdc.nec765_status[2];
-				fdc.nec765_result_bytes[3] = id.C; /* C */
-				fdc.nec765_result_bytes[4] = id.H; /* H */
-				fdc.nec765_result_bytes[5] = id.R; /* R */
-				fdc.nec765_result_bytes[6] = id.N; /* N */
-
-				nec765_setup_result_phase(7);
 			}
 			else
 			{
-				/* floppy drive is ready, but no disc is inserted */
-				/* this occurs on the PC */
-				/* in this case, the command never quits! */
-				/* there are no index pulses to stop the command! */
+				/* what are id values when drive not ready? */
+
+				/* not ready, abnormal termination */
+				fdc.nec765_status[0] |= (1<<3) | (1<<6);
+				fdc.nec765_result_bytes[0] = fdc.nec765_status[0];
+				fdc.nec765_result_bytes[1] = fdc.nec765_status[1];
+				fdc.nec765_result_bytes[2] = fdc.nec765_status[2];
+				fdc.nec765_result_bytes[3] = 0; /* C */
+				fdc.nec765_result_bytes[4] = 0; /* H */
+				fdc.nec765_result_bytes[5] = 0; /* R */
+				fdc.nec765_result_bytes[6] = 0; /* N */
 			}
-		}
-		else
-		{
-			/* what are id values when drive not ready? */
-
-			/* not ready, abnormal termination */
-			fdc.nec765_status[0] |= (1<<3) | (1<<6);
-			fdc.nec765_result_bytes[0] = fdc.nec765_status[0];
-			fdc.nec765_result_bytes[1] = fdc.nec765_status[1];
-			fdc.nec765_result_bytes[2] = fdc.nec765_status[2];
-			fdc.nec765_result_bytes[3] = 0; /* C */
-			fdc.nec765_result_bytes[4] = 0; /* H */
-			fdc.nec765_result_bytes[5] = 0; /* R */
-			fdc.nec765_result_bytes[6] = 0; /* N */
-		}
-		break;
-
-
-	case 0x08: /* sense interrupt status */
-		/* interrupt pending? */
-		if (fdc.nec765_flags & NEC765_INT)
-		{
-			/* yes. Clear int */
-			nec765_set_int(CLEAR_LINE);
-
-			/* clear drive seek bits */
-			fdc.FDC_main &= ~(1 | 2 | 4 | 8);
-
-			/* return status */
-			fdc.nec765_result_bytes[0] = fdc.nec765_status[0];
-			/* return pcn */
-			fdc.nec765_result_bytes[1] = fdc.pcn[fdc.drive];
-
-			/* return result */
-			nec765_setup_result_phase(2);
-		}
-		else
-		{
-			/* no int */
-			nec765_setup_invalid();
-		}
-		break;
-
-	case 0x06:  /* read data */
-		nec765_setup_drive_and_side();
-
-		fdc.nec765_status[0] = fdc.drive | (fdc.side<<2);
-		fdc.nec765_status[1] = 0;
-		fdc.nec765_status[2] = 0;
-
-
-		nec765_read_data();
-		break;
-
-	case 0x0c:
-		/* read deleted data */
-		nec765_setup_drive_and_side();
-
-        fdc.nec765_status[0] = fdc.drive | (fdc.side<<2);
-		fdc.nec765_status[1] = 0;
-		fdc.nec765_status[2] = 0;
-
-
-		/* .. for now */
-		nec765_read_data();
-		break;
-
-	case 0x09:
-		/* write deleted data */
-		nec765_setup_drive_and_side();
-
-		fdc.nec765_status[0] = fdc.drive | (fdc.side<<2);
-		fdc.nec765_status[1] = 0;
-		fdc.nec765_status[2] = 0;
-
-		/* ... for now */
-		nec765_write_data();
-		break;
-
-	case 0x02:
-		/* read a track */
-		nec765_setup_drive_and_side();
-
-		fdc.nec765_status[0] = fdc.drive | (fdc.side<<2);
-		fdc.nec765_status[1] = 0;
-		fdc.nec765_status[2] = 0;
-
-		fdc.nec765_status[0] |= NEC765_ST1_NO_DATA;
-
-		/* wait for index */
-		do
-		{
-			/* get next id from disc */
-			floppy_drive_get_next_id(img, fdc.side,&id);
-		}
-		while ((floppy_drive_get_flag_state(img, FLOPPY_DRIVE_INDEX))==0);
-
-		fdc.sector_counter = 0;
-
-		nec765_read_a_track();
-		break;
-
-	case 0x05:  /* write data */
-		nec765_setup_drive_and_side();
-
-		fdc.nec765_status[0] = fdc.drive | (fdc.side<<2);
-		fdc.nec765_status[1] = 0;
-		fdc.nec765_status[2] = 0;
-
-		nec765_write_data();
-		break;
-
-	case 0x0d:	/* format a track */
-		nec765_setup_drive_and_side();
-
-		fdc.nec765_status[0] = fdc.drive | (fdc.side<<2);
-		fdc.nec765_status[1] = 0;
-		fdc.nec765_status[2] = 0;
-
-		fdc.sector_counter = 0;
-
-		nec765_format_track();
-		break;
-
-	default:	/* invalid */
-		switch (fdc.version) {
-		case NEC765A:
-			nec765_setup_invalid();
 			break;
 
-		case NEC765B:
-			/* from nec765b data sheet */
-			if ((fdc.nec765_command_bytes[0] & 0x01f)==0x010)
+
+		case 0x08: /* sense interrupt status */
+			/* interrupt pending? */
+			if (fdc.nec765_flags & NEC765_INT)
 			{
-				/* version */
-				fdc.nec765_status[0] = 0x090;
+				/* yes. Clear int */
+				nec765_set_int(CLEAR_LINE);
+
+				/* clear drive seek bits */
+				fdc.FDC_main &= ~(1 | 2 | 4 | 8);
+
+				/* return status */
 				fdc.nec765_result_bytes[0] = fdc.nec765_status[0];
-				nec765_setup_result_phase(1);
+				/* return pcn */
+				fdc.nec765_result_bytes[1] = fdc.pcn[fdc.drive];
+
+				/* return result */
+				nec765_setup_result_phase(2);
+			}
+			else
+			{
+				/* no int */
+				fdc.nec765_result_bytes[0] = 0x80;
+				/* return pcn */
+				fdc.nec765_result_bytes[1] = fdc.pcn[fdc.drive];
+
+				/* return result */
+				nec765_setup_result_phase(2);
 			}
 			break;
 
-		case SMC37C78:
-			/* TO BE COMPLETED!!! !*/
-			switch (fdc.nec765_command_bytes[0] & 0x1f) {
-			case 0x10:		/* version */
-				fdc.nec765_status[0] = 0x90;
-				fdc.nec765_result_bytes[0] = fdc.nec765_status[0];
-				nec765_setup_result_phase(1);
-				break;
+		case 0x06:  /* read data */
+			nec765_setup_drive_and_side();
 
-			case 0x13:		/* configure */
-				break;
-				
-			case 0x0e:		/* dump reg */
-				fdc.nec765_result_bytes[0] = fdc.pcn[0];
-				fdc.nec765_result_bytes[1] = fdc.pcn[1];
-				fdc.nec765_result_bytes[2] = fdc.pcn[2];
-				fdc.nec765_result_bytes[3] = fdc.pcn[3];
-					
-				nec765_setup_result_phase(10);
-				break;
+			fdc.nec765_status[0] = fdc.drive | (fdc.side<<2);
+			fdc.nec765_status[1] = 0;
+			fdc.nec765_status[2] = 0;
 
-			case 0x12:		/* perpendicular mode */
-				nec765_idle();
-				break;
-
-			case 0x14:		/* lock */
-				nec765_setup_result_phase(1);
-				break;
-			}
+			nec765_read_data();
 			break;
-		}
+
+		case 0x0c:
+			/* read deleted data */
+			nec765_setup_drive_and_side();
+
+			fdc.nec765_status[0] = fdc.drive | (fdc.side<<2);
+			fdc.nec765_status[1] = 0;
+			fdc.nec765_status[2] = 0;
+
+			/* .. for now */
+			nec765_read_data();
+			break;
+
+		case 0x09:
+			/* write deleted data */
+			nec765_setup_drive_and_side();
+
+			fdc.nec765_status[0] = fdc.drive | (fdc.side<<2);
+			fdc.nec765_status[1] = 0;
+			fdc.nec765_status[2] = 0;
+
+			/* ... for now */
+			nec765_write_data();
+			break;
+
+		case 0x02:
+			/* read a track */
+			nec765_setup_drive_and_side();
+
+			fdc.nec765_status[0] = fdc.drive | (fdc.side<<2);
+			fdc.nec765_status[1] = 0;
+			fdc.nec765_status[2] = 0;
+
+			fdc.nec765_status[0] |= NEC765_ST1_NO_DATA;
+
+			/* wait for index */
+			do
+			{
+				/* get next id from disc */
+				floppy_drive_get_next_id(img, fdc.side,&id);
+			}
+			while ((floppy_drive_get_flag_state(img, FLOPPY_DRIVE_INDEX))==0);
+
+			fdc.sector_counter = 0;
+
+			nec765_read_a_track();
+			break;
+
+		case 0x05:  /* write data */
+			nec765_setup_drive_and_side();
+
+			fdc.nec765_status[0] = fdc.drive | (fdc.side<<2);
+			fdc.nec765_status[1] = 0;
+			fdc.nec765_status[2] = 0;
+
+			nec765_write_data();
+			break;
+
+		case 0x0d:	/* format a track */
+			nec765_setup_drive_and_side();
+
+			fdc.nec765_status[0] = fdc.drive | (fdc.side<<2);
+			fdc.nec765_status[1] = 0;
+			fdc.nec765_status[2] = 0;
+
+			fdc.sector_counter = 0;
+
+			nec765_format_track();
+			break;
+
+		default:	/* invalid */
+			switch (fdc.version)
+			{
+				case NEC765A:
+					nec765_setup_invalid();
+					break;
+
+				case NEC765B:
+					/* from nec765b data sheet */
+					if ((fdc.nec765_command_bytes[0] & 0x01f)==0x010)
+					{
+						/* version */
+						fdc.nec765_status[0] = 0x090;
+						fdc.nec765_result_bytes[0] = fdc.nec765_status[0];
+						nec765_setup_result_phase(1);
+					}
+					break;
+
+				case SMC37C78:
+					/* TO BE COMPLETED!!! !*/
+					switch (fdc.nec765_command_bytes[0] & 0x1f)
+					{
+						case 0x10:		/* version */
+							fdc.nec765_status[0] = 0x90;
+							fdc.nec765_result_bytes[0] = fdc.nec765_status[0];
+							nec765_setup_result_phase(1);
+							break;
+
+						case 0x13:		/* configure */
+							nec765_idle();
+							break;
+							
+						case 0x0e:		/* dump reg */
+							fdc.nec765_result_bytes[0] = fdc.pcn[0];
+							fdc.nec765_result_bytes[1] = fdc.pcn[1];
+							fdc.nec765_result_bytes[2] = fdc.pcn[2];
+							fdc.nec765_result_bytes[3] = fdc.pcn[3];
+								
+							nec765_setup_result_phase(10);
+							break;
+
+						case 0x12:		/* perpendicular mode */
+							nec765_idle();
+							break;
+
+						case 0x14:		/* lock */
+							nec765_setup_result_phase(1);
+							break;
+					}
+					break;
+			}
 	}
 }
 
@@ -2072,7 +2118,7 @@ void nec765_reset(int offset)
 		fdc.nec765_status[0] = 0x080 | 0x040;
 	
 		/* for the purpose of pc-xt. If any of the drives have a disk inserted,
-		do not set not-ready - need to check with pc_fdc_hw.c whether all drives
+		do not set not-ready - need to check with pc_fdc.c whether all drives
 		are checked or only the drive selected with the drive select bits?? */
 
 		a_drive_is_ready = 0;
