@@ -1,14 +1,15 @@
+#include <math.h>
+
 #include "driver.h"
 #include "cpu/m6502/m6502.h"
 #include "vidhrdw/generic.h"
 #include "vidhrdw/ppu2c03b.h"
 #include "includes/nes.h"
 #include "machine/nes_mmc.h"
-#include "sound/nesintf.h"
+#include "sound/nes_apu.h"
 #include "zlib.h"
 #include "image.h"
-
-#include <math.h>
+#include "hash.h"
 
 
 /* Uncomment this to dump reams of ppu state info to the errorlog */
@@ -34,7 +35,8 @@ static UINT32 in_0_shift;
 static UINT32 in_1_shift;
 
 /* local prototypes */
-static void init_nes_core (void);
+static void init_nes_core(void);
+static void nes_machine_stop(void);
 
 static mess_image *cartslot_image(void)
 {
@@ -49,6 +51,12 @@ static void init_nes_core (void)
 	nes.vram = memory_region(REGION_GFX2);
 	nes.wram = memory_region(REGION_USER1);
 
+	/* Brutal hack put in as a consequence of the new memory system; we really
+	 * need to fix the NES code */
+	memory_install_read8_handler(0, ADDRESS_SPACE_PROGRAM, 0x0000, 0x07ff, 0, 0x1800, MRA8_BANK10);
+	memory_install_write8_handler(0, ADDRESS_SPACE_PROGRAM, 0x0000, 0x07ff, 0, 0x1800, MWA8_BANK10);
+	memory_set_bankptr(10, nes.rom);
+
 	battery_ram = nes.wram;
 
 	/* Set up the memory handlers for the mapper */
@@ -58,7 +66,8 @@ static void init_nes_core (void)
 			nes.slow_banking = 0;
 			memory_install_read8_handler(0, ADDRESS_SPACE_PROGRAM, 0x4030, 0x403f, 0, 0, fds_r);
 			memory_install_read8_handler(0, ADDRESS_SPACE_PROGRAM, 0x6000, 0xdfff, 0, 0, MRA8_RAM);
-			memory_install_read8_handler(0, ADDRESS_SPACE_PROGRAM, 0xe000, 0xffff, 0, 0, MRA8_ROM);
+			memory_install_read8_handler(0, ADDRESS_SPACE_PROGRAM, 0xe000, 0xffff, 0, 0, MRA8_BANK1);
+			memory_set_bankptr(1, &nes.rom[0xe000]);
 
 			memory_install_write8_handler(0, ADDRESS_SPACE_PROGRAM, 0x4020, 0x402f, 0, 0, fds_w);
 			memory_install_write8_handler(0, ADDRESS_SPACE_PROGRAM, 0x6000, 0xdfff, 0, 0, MWA8_RAM);
@@ -119,19 +128,7 @@ static void init_nes_core (void)
 	memcpy (battery_ram, battery_data, BATTERY_SIZE);
 }
 
-DRIVER_INIT( nes )
-{
-	ppu_scanlines_per_frame = ceil(NTSC_SCANLINES_PER_FRAME);
-	init_nes_core ();
-}
-
-DRIVER_INIT( nespal )
-{
-	ppu_scanlines_per_frame = ceil(PAL_SCANLINES_PER_FRAME);
-	init_nes_core ();
-}
-
-static int ppu_vidaccess( int num, int address, int data )
+int nes_ppu_vidaccess( int num, int address, int data )
 {
 	/* TODO: this is a bit of a hack, needed to get Argus, ASO, etc to work */
 	/* but, B-Wings, submath (j) seem to use this location differently... */
@@ -144,28 +141,8 @@ static int ppu_vidaccess( int num, int address, int data )
 	return data;
 }
 
-MACHINE_INIT( nes )
+static void nes_machine_reset(void)
 {
-	ppu2c03b_reset( 0, 1 );
-	ppu2c03b_set_vidaccess_callback(0, ppu_vidaccess);
-	ppu2c03b_set_scanlines_per_frame(0, ppu_scanlines_per_frame);
-
-	if (nes.four_screen_vram)
-	{
-		/* TODO: figure out what to do here */
-	}
-	else
-	{
-		switch(nes.hard_mirroring) {
-		case 0:
-			ppu2c03b_set_mirroring(0, PPU_MIRROR_HORZ);
-			break;
-		case 1:
-			ppu2c03b_set_mirroring(0, PPU_MIRROR_VERT);
-			break;
-		}
-	}
-
 	/* Some carts have extra RAM and require it on at startup, e.g. Metroid */
 	nes.mid_ram_enable = 1;
 
@@ -177,9 +154,24 @@ MACHINE_INIT( nes )
 	in_1_shift = 0;
 }
 
+MACHINE_START( nes )
+{
+	init_nes_core();
+	add_reset_callback(nes_machine_reset);
+	add_exit_callback(nes_machine_stop);
 
+	if (!image_exists(image_from_devtype_and_index(IO_CARTSLOT, 0)))
+	{
+		/* NPW 05-Mar-2006 - Hack to keep the Famicom from crashing */
+		static const UINT8 infinite_loop[] = { 0x4C, 0xF9, 0xFF, 0xF9, 0xFF }; /* JMP $FFF9, DC.W $FFF9 */
+		memory_install_read8_handler(0, ADDRESS_SPACE_PROGRAM, 0xFFF9, 0xFFFD, 0, 0, MRA8_BANK11);
+		memory_install_write8_handler(0, ADDRESS_SPACE_PROGRAM, 0xFFF9, 0xFFFD, 0, 0, MWA8_BANK11);
+		memory_set_bankptr(11, (void *) infinite_loop);
+	}
+	return 0;
+}
 
-MACHINE_STOP( nes )
+static void nes_machine_stop(void)
 {
 	/* Write out the battery file if necessary */
 	if (nes.battery)
@@ -192,7 +184,9 @@ static int zapper_hit_pixel(const UINT32 *input)
 {
 	UINT16 pix;
 	UINT8 r, g, b;
-	pix = read_pixel(Machine->scrbitmap, input[1], input[2]);
+	extern mame_bitmap *scrbitmap[8];
+
+	pix = read_pixel(scrbitmap[0], input[1], input[2]);
 	palette_get_color(pix, &r, &g, &b);
 	return (((UINT16) r) + ((UINT16) g) + ((UINT16) b)) >= 240*3;
 }
@@ -578,10 +572,6 @@ DEVICE_LOAD(nes_disk)
 		mame_fread (file, nes_fds.data + ((nes_fds.sides-1) * 65500), 65500);
 	}
 
-	/* adjust for eof */
-	nes_fds.sides --;
-	nes_fds.data = image_realloc(image, nes_fds.data, nes_fds.sides * 65500);
-
 	logerror ("Number of sides: %d\n", nes_fds.sides);
 
 	return INIT_PASS;
@@ -599,10 +589,10 @@ DEVICE_UNLOAD(nes_disk)
 
 void ppu_mirror_custom (int page, int address)
 {
-	osd_die("Unimplemented");
+	fatalerror("Unimplemented");
 }
 
 void ppu_mirror_custom_vrom (int page, int address)
 {
-	osd_die("Unimplemented");
+	fatalerror("Unimplemented");
 }
