@@ -20,7 +20,7 @@
 #include <stdio.h>
 #include "driver.h"
 #include "includes/oric.h"
-#include "includes/wd179x.h"
+#include "machine/wd17xx.h"
 #include "machine/6522via.h"
 #include "machine/applefdc.h"
 #include "includes/6551.h"
@@ -32,6 +32,8 @@
 #include "sound/ay8910.h"
 #include "image.h"
 
+UINT8 *oric_ram;
+
 static int enable_logging = 0;
 /* static int save_done = 0; */
 
@@ -460,13 +462,11 @@ struct via6522_interface oric_6522_interface=
 	oric_via_in_cb2_func,
 	oric_via_out_a_func,
 	oric_via_out_b_func,
+	NULL,
+	NULL,
 	oric_via_out_ca2_func,
 	oric_via_out_cb2_func,
 	oric_via_irq_func,
-	NULL,
-	NULL,
-	NULL,
-	NULL
 };
 
 
@@ -491,7 +491,7 @@ static void oric_install_apple2_interface(void)
 
 	memory_install_write8_handler(0, ADDRESS_SPACE_PROGRAM, 0x0300, 0x030f, 0, 0, oric_IO_w);
 	memory_install_write8_handler(0, ADDRESS_SPACE_PROGRAM, 0x0310, 0x031f, 0, 0, applefdc_w);
-	cpu_setbank(4, 	memory_region(REGION_CPU1) + 0x014000 + 0x020);
+	memory_set_bankptr(4, 	memory_region(REGION_CPU1) + 0x014000 + 0x020);
 }
 
 
@@ -538,7 +538,7 @@ static WRITE8_HANDLER(apple2_v2_interface_w)
 /*	logerror("apple 2 interface v2 rom page: %01x\n",(offset & 0x02)>>1); */
 
 	/* bit 0 is 0 for page 0, 1 for page 1 */
-	cpu_setbank(4, memory_region(REGION_CPU1) + 0x014000 + 0x0100 + (((offset & 0x02)>>1)<<8));
+	memory_set_bankptr(4, memory_region(REGION_CPU1) + 0x014000 + 0x0100 + (((offset & 0x02)>>1)<<8));
 
 	oric_enable_memory(1, 3, TRUE, TRUE);
 
@@ -551,24 +551,24 @@ static WRITE8_HANDLER(apple2_v2_interface_w)
 
 		/* enable rom */
 		rom_ptr = memory_region(REGION_CPU1) + 0x010000;
-		cpu_setbank(1, rom_ptr);
-		cpu_setbank(2, rom_ptr+0x02000);
-		cpu_setbank(3, rom_ptr+0x03800);
-		cpu_setbank(5, oric_ram_0x0c000);
-		cpu_setbank(6, oric_ram_0x0c000+0x02000);
-		cpu_setbank(7, oric_ram_0x0c000+0x03800);
+		memory_set_bankptr(1, rom_ptr);
+		memory_set_bankptr(2, rom_ptr+0x02000);
+		memory_set_bankptr(3, rom_ptr+0x03800);
+		memory_set_bankptr(5, oric_ram_0x0c000);
+		memory_set_bankptr(6, oric_ram_0x0c000+0x02000);
+		memory_set_bankptr(7, oric_ram_0x0c000+0x03800);
 	}
 	else
 	{
 		/*logerror("apple 2 interface v2: ram enabled\n"); */
 
 		/* enable ram */
-		cpu_setbank(1, oric_ram_0x0c000);
-		cpu_setbank(2, oric_ram_0x0c000+0x02000);
-		cpu_setbank(3, oric_ram_0x0c000+0x03800);
-		cpu_setbank(5, oric_ram_0x0c000);
-		cpu_setbank(6, oric_ram_0x0c000+0x02000);
-		cpu_setbank(7, oric_ram_0x0c000+0x03800);
+		memory_set_bankptr(1, oric_ram_0x0c000);
+		memory_set_bankptr(2, oric_ram_0x0c000+0x02000);
+		memory_set_bankptr(3, oric_ram_0x0c000+0x03800);
+		memory_set_bankptr(5, oric_ram_0x0c000);
+		memory_set_bankptr(6, oric_ram_0x0c000+0x02000);
+		memory_set_bankptr(7, oric_ram_0x0c000+0x03800);
 	}
 }
 
@@ -625,9 +625,9 @@ static void oric_jasmin_set_mem_0x0c000(void)
 			oric_enable_memory(1, 3, TRUE, FALSE);
 
 			rom_ptr = memory_region(REGION_CPU1) + 0x010000;
-			cpu_setbank(1, rom_ptr);
-			cpu_setbank(2, rom_ptr+0x02000);
-			cpu_setbank(3, rom_ptr+0x03800);
+			memory_set_bankptr(1, rom_ptr);
+			memory_set_bankptr(2, rom_ptr+0x02000);
+			memory_set_bankptr(3, rom_ptr+0x03800);
 		}
 		else
 		{
@@ -635,12 +635,12 @@ static void oric_jasmin_set_mem_0x0c000(void)
 
 			oric_enable_memory(1, 3, TRUE, TRUE);
 
-			cpu_setbank(1, oric_ram_0x0c000);
-			cpu_setbank(2, oric_ram_0x0c000+0x02000);
-			cpu_setbank(3, oric_ram_0x0c000+0x03800);
-			cpu_setbank(5, oric_ram_0x0c000);
-			cpu_setbank(6, oric_ram_0x0c000+0x02000);
-			cpu_setbank(7, oric_ram_0x0c000+0x03800);
+			memory_set_bankptr(1, oric_ram_0x0c000);
+			memory_set_bankptr(2, oric_ram_0x0c000+0x02000);
+			memory_set_bankptr(3, oric_ram_0x0c000+0x03800);
+			memory_set_bankptr(5, oric_ram_0x0c000);
+			memory_set_bankptr(6, oric_ram_0x0c000+0x02000);
+			memory_set_bankptr(7, oric_ram_0x0c000+0x03800);
 		}
 	}
 	else
@@ -659,10 +659,10 @@ static void oric_jasmin_set_mem_0x0c000(void)
 			/*logerror("&c000-&f8ff is ram!\n"); */
 			oric_enable_memory(1, 2, TRUE, TRUE);
 
-			cpu_setbank(1, oric_ram_0x0c000);
-			cpu_setbank(2, oric_ram_0x0c000+0x02000);
-			cpu_setbank(5, oric_ram_0x0c000);
-			cpu_setbank(6, oric_ram_0x0c000+0x02000);
+			memory_set_bankptr(1, oric_ram_0x0c000);
+			memory_set_bankptr(2, oric_ram_0x0c000+0x02000);
+			memory_set_bankptr(5, oric_ram_0x0c000);
+			memory_set_bankptr(6, oric_ram_0x0c000+0x02000);
 		}
 
 		{
@@ -673,8 +673,8 @@ static void oric_jasmin_set_mem_0x0c000(void)
 			/* jasmin rom enabled */
 			oric_enable_memory(3, 3, TRUE, TRUE);
 			rom_ptr = memory_region(REGION_CPU1) + 0x010000+0x04000+0x02000;
-			cpu_setbank(3, rom_ptr);
-			cpu_setbank(7, rom_ptr);
+			memory_set_bankptr(3, rom_ptr);
+			memory_set_bankptr(7, rom_ptr);
 		}
 	}
 }
@@ -881,8 +881,8 @@ static void	oric_microdisc_set_mem_0x0c000(void)
 		/*logerror("&c000-&dfff is ram\n"); */
 		/* rom disabled enable ram */
 		oric_enable_memory(1, 1, TRUE, TRUE);
-		cpu_setbank(1, oric_ram_0x0c000);
-		cpu_setbank(5, oric_ram_0x0c000);
+		memory_set_bankptr(1, oric_ram_0x0c000);
+		memory_set_bankptr(5, oric_ram_0x0c000);
 	}
 	else
 	{
@@ -891,8 +891,8 @@ static void	oric_microdisc_set_mem_0x0c000(void)
 		/* basic rom */
 		oric_enable_memory(1, 1, TRUE, FALSE);
 		rom_ptr = memory_region(REGION_CPU1) + 0x010000;
-		cpu_setbank(1, rom_ptr);
-		cpu_setbank(5, rom_ptr);
+		memory_set_bankptr(1, rom_ptr);
+		memory_set_bankptr(5, rom_ptr);
 	}
 
 	/* for 0x0e000-0x0ffff */
@@ -904,10 +904,10 @@ static void	oric_microdisc_set_mem_0x0c000(void)
 		/* basic rom */
 		oric_enable_memory(2, 3, TRUE, FALSE);
 		rom_ptr = memory_region(REGION_CPU1) + 0x010000;
-		cpu_setbank(2, rom_ptr+0x02000);
-		cpu_setbank(3, rom_ptr+0x03800);
-		cpu_setbank(6, rom_ptr+0x02000);
-		cpu_setbank(7, rom_ptr+0x03800);
+		memory_set_bankptr(2, rom_ptr+0x02000);
+		memory_set_bankptr(3, rom_ptr+0x03800);
+		memory_set_bankptr(6, rom_ptr+0x02000);
+		memory_set_bankptr(7, rom_ptr+0x03800);
 
 	}
 	else
@@ -920,25 +920,25 @@ static void	oric_microdisc_set_mem_0x0c000(void)
 			oric_enable_memory(2, 3, TRUE, FALSE);
 			/* enable rom of microdisc interface */
 			rom_ptr = memory_region(REGION_CPU1) + 0x014000;
-			cpu_setbank(2, rom_ptr);
-			cpu_setbank(3, rom_ptr+0x01800);
+			memory_set_bankptr(2, rom_ptr);
+			memory_set_bankptr(3, rom_ptr+0x01800);
 		}
 		else
 		{
 			/*logerror("&e000-&ffff is ram\n"); */
 			/* rom disabled enable ram */
 			oric_enable_memory(2, 3, TRUE, TRUE);
-			cpu_setbank(2, oric_ram_0x0c000+0x02000);
-			cpu_setbank(3, oric_ram_0x0c000+0x03800);
-			cpu_setbank(6, oric_ram_0x0c000+0x02000);
-			cpu_setbank(7, oric_ram_0x0c000+0x03800);
+			memory_set_bankptr(2, oric_ram_0x0c000+0x02000);
+			memory_set_bankptr(3, oric_ram_0x0c000+0x03800);
+			memory_set_bankptr(6, oric_ram_0x0c000+0x02000);
+			memory_set_bankptr(7, oric_ram_0x0c000+0x03800);
 		}
 	}
 }
 
 
 
-static  READ8_HANDLER (oric_microdisc_r)
+READ8_HANDLER (oric_microdisc_r)
 {
 	unsigned char data = 0x0ff;
 
@@ -975,7 +975,7 @@ static  READ8_HANDLER (oric_microdisc_r)
 	return data;
 }
 
-static WRITE8_HANDLER(oric_microdisc_w)
+WRITE8_HANDLER(oric_microdisc_w)
 {
 	switch (offset & 0x0ff)
 	{
@@ -1111,14 +1111,9 @@ static void oric_common_init_machine(void)
 	/* assumption: select is tied low */
 	centronics_write_handshake(0, CENTRONICS_SELECT | CENTRONICS_NO_RESET, CENTRONICS_SELECT| CENTRONICS_NO_RESET);
     via_set_input_ca1(0, 1);
-
-
-#ifdef ORIC_DUMP_RAM
-	previous_input_port5 = readinputport(5);
-#endif
 }
 
-MACHINE_INIT( oric )
+MACHINE_START( oric )
 {
 	int disc_interface_id;
 
@@ -1143,12 +1138,12 @@ MACHINE_INIT( oric )
 			/* os rom */
 			oric_enable_memory(1, 3, TRUE, FALSE);
 			rom_ptr = memory_region(REGION_CPU1) + 0x010000;
-			cpu_setbank(1, rom_ptr);
-			cpu_setbank(2, rom_ptr+0x02000);
-			cpu_setbank(3, rom_ptr+0x03800);
-			cpu_setbank(5, rom_ptr);
-			cpu_setbank(6, rom_ptr+0x02000);
-			cpu_setbank(7, rom_ptr+0x03800);
+			memory_set_bankptr(1, rom_ptr);
+			memory_set_bankptr(2, rom_ptr+0x02000);
+			memory_set_bankptr(3, rom_ptr+0x03800);
+			memory_set_bankptr(5, rom_ptr);
+			memory_set_bankptr(6, rom_ptr+0x02000);
+			memory_set_bankptr(7, rom_ptr+0x03800);
 
 
 			if (disc_interface_id==ORIC_FLOPPY_INTERFACE_APPLE2)
@@ -1185,21 +1180,12 @@ MACHINE_INIT( oric )
 
 
 	wd179x_init(WD_TYPE_179X,oric_wd179x_callback);
+	return 0;
 }
 
 
 
-MACHINE_STOP( oric )
-{
-#ifdef ORIC_DUMP_RAM
-	oric_dump_ram();
-#endif
-
-	oric_ram_0x0c000 = NULL;
-}
-
-
- READ8_HANDLER ( oric_IO_r )
+READ8_HANDLER ( oric_IO_r )
 {
 #if 0
 	switch (readinputport(9) & 0x07)
@@ -1362,8 +1348,8 @@ static void	telestrat_refresh_mem(void)
 		{
 			rh = MRA8_BANK1;
 			wh = MWA8_BANK2;
-			cpu_setbank(1, mem_block->ptr);
-			cpu_setbank(2, mem_block->ptr);
+			memory_set_bankptr(1, mem_block->ptr);
+			memory_set_bankptr(2, mem_block->ptr);
 		}
 		break;
 
@@ -1371,7 +1357,7 @@ static void	telestrat_refresh_mem(void)
 		{
 			rh = MRA8_BANK1;
 			wh = MWA8_NOP;
-			cpu_setbank(1, mem_block->ptr);
+			memory_set_bankptr(1, mem_block->ptr);
 		}
 		break;
 
@@ -1460,11 +1446,9 @@ struct via6522_interface telestrat_via2_interface=
 	telestrat_via2_out_b_func,
 	NULL,
 	NULL,
+	NULL,
+	NULL,
 	telestrat_via2_irq_func,
-	NULL,
-	NULL,
-	NULL,
-	NULL
 };
 
 #if 0
@@ -1482,7 +1466,7 @@ static void telestrat_acia_callback(int irq_state)
 }
 #endif
 
-MACHINE_INIT( telestrat )
+MACHINE_START( telestrat )
 {
 	oric_common_init_machine();
 
@@ -1529,77 +1513,5 @@ MACHINE_INIT( telestrat )
 	via_set_clock(1,1000000);
 
 	wd179x_init(WD_TYPE_179X,oric_wd179x_callback);
+	return 0;
 }
-
-MACHINE_STOP( telestrat )
-{
-	int i;
-
-	/* this supports different cartridges now. In the init machine
-	a cartridge is hard-coded, but if other cartridges exist it could
-	be changed above */
-	for (i=0; i<8; i++)
-	{
-		if (telestrat_blocks[i].MemType == TELESTRAT_MEM_BLOCK_RAM)
-			telestrat_blocks[i].ptr = NULL;
-	}
-	machine_stop_oric();
-}
-
-
-WRITE8_HANDLER(telestrat_IO_w)
-{
-	if (offset<0x010)
-	{
-		via_0_w(offset & 0x0f,data);
-		return;
-	}
-
-	if ((offset>=0x020) && (offset<=0x02f))
-	{
-		via_1_w(offset & 0x0f,data);
-		return;
-	}
-
-	if ((offset>=0x010) && (offset<=0x01b))
-	{
-		oric_microdisc_w(offset & 0x0f, data);
-		return;
-	}
-
-	if ((offset>=0x01c) && (offset<=0x01f))
-	{
-		acia_6551_w(offset, data);
-		return;
-	}
-
-	logerror("null write %04x %02x\n",offset,data);
-
-}
-
- READ8_HANDLER(telestrat_IO_r)
-{
-	if (offset<0x010)
-	{
-		return via_0_r(offset & 0x0f);
-	}
-
-	if ((offset>=0x020) && (offset<=0x02f))
-	{
-		return via_1_r(offset & 0x0f);
-	}
-
-	if ((offset>=0x010) && (offset<=0x01b))
-	{
-		return oric_microdisc_r(offset & 0x0f);
-	}
-
-	if ((offset>=0x01c) && (offset<=0x01f))
-	{
-		return acia_6551_r(offset);
-	}
-
-	logerror("null read %04x\n",offset);
-	return 0x0ff;
-}
-
