@@ -241,12 +241,12 @@ void primo_common_machine_init (void)
 	cpunum_set_clockscale(0, readinputport(5) ? 1.5 : 1.0);
 }
 
-MACHINE_INIT( primoa )
+MACHINE_RESET( primoa )
 {
 	primo_common_machine_init();
 }
 
-MACHINE_INIT( primob )
+MACHINE_RESET( primob )
 {
 	primo_common_machine_init();
 
@@ -366,27 +366,3 @@ QUICKLOAD_LOAD( primo )
 	free(quickload_data);
 	return INIT_PASS;
 }
-
-/*******************************************************************************
-
-	EPROM expansion files (.rom)
-
-*******************************************************************************/
-
-const char *device_name_cartslot_primo(const struct IODevice *dev, int id, char *buf, size_t bufsize)
-{
-	snprintf(buf, bufsize, "EPROM Expansion Bank #%d", id + 1);
-	return buf;
-}
-
-DEVICE_LOAD( cartslot_primo )
-{
-	int id = image_index_in_device(image);
-	return cartslot_load_generic (file, REGION_CPU1, id ? 0x14000 : 0x18000, 0, 0x4000, 0);
-}
-
-DEVICE_UNLOAD( cartslot_primo )
-{
-	int id = image_index_in_device(image);
-	memset (memory_region(REGION_CPU1) + (id ? 0x14000 : 0x18000), 0x4000, 0xff);
-}
