@@ -170,7 +170,7 @@ static void update_ti86_memory (void)
   Machine Initialization
 ***************************************************************************/
 
-MACHINE_INIT( ti81 )
+MACHINE_START( ti81 )
 {
 	ti85_timer_interrupt_mask = 0;
 	ti85_timer_interrupt_status = 0;
@@ -199,9 +199,10 @@ MACHINE_INIT( ti81 )
 	memory_install_write8_handler(0, ADDRESS_SPACE_PROGRAM, 0x4000, 0x7fff, 0, 0, MWA8_ROM);
 	memory_set_bankptr(1,memory_region(REGION_CPU1) + 0x010000);
 	memory_set_bankptr(2,memory_region(REGION_CPU1) + 0x014000);
+	return 0;
 }
 
-MACHINE_INIT( ti85 )
+MACHINE_START( ti85 )
 {
 	ti85_timer_interrupt_mask = 0;
 	ti85_timer_interrupt_status = 0;
@@ -225,20 +226,17 @@ MACHINE_INIT( ti85 )
 
 	timer_pulse(TIME_IN_HZ(200), 0, ti85_timer_callback);
 
-	ti85_reset_serial();
-
 	memory_install_write8_handler(0, ADDRESS_SPACE_PROGRAM, 0x0000, 0x3fff, 0, 0, MWA8_ROM);
 	memory_install_write8_handler(0, ADDRESS_SPACE_PROGRAM, 0x4000, 0x7fff, 0, 0, MWA8_ROM);
 	memory_set_bankptr(1,memory_region(REGION_CPU1) + 0x010000);
 	memory_set_bankptr(2,memory_region(REGION_CPU1) + 0x014000);
+
+	add_reset_callback(ti85_reset_serial);
+	add_exit_callback(ti85_free_serial_data_memory);
+	return 0;
 }
 
-MACHINE_STOP( ti85 )
-{
-	ti85_free_serial_data_memory();
-}
-
-MACHINE_INIT( ti86 )
+MACHINE_START( ti86 )
 {
 	ti85_timer_interrupt_mask = 0;
 	ti85_timer_interrupt_status = 0;
@@ -255,7 +253,6 @@ MACHINE_INIT( ti86 )
 	ti85_video_buffer_width = 0;
 	ti85_interrupt_speed = 0;
 	ti85_port4_bit0 = 0;
-	ti85_reset_serial();
 
 	if (ti86_ram)
 	{
@@ -274,17 +271,15 @@ MACHINE_INIT( ti86 )
 
 		timer_pulse(TIME_IN_HZ(200), 0, ti85_timer_callback);
 	}
-}
 
-MACHINE_STOP( ti86 )
-{
-	ti85_free_serial_data_memory();
+	add_reset_callback(ti85_reset_serial);
+	add_exit_callback(ti85_free_serial_data_memory);
+	return 0;
 }
 
-
 /* I/O ports handlers */
 
- READ8_HANDLER ( ti85_port_0000_r )
+READ8_HANDLER ( ti85_port_0000_r )
 {
 	return 0xff;
 }
@@ -683,18 +678,16 @@ DEVICE_LOAD( ti85_serial )
 
 	if (file_size != 0)
 	{
-		if ((file_data = (UINT8*) auto_malloc(file_size)))
-		{
-			mame_fread(file, file_data, file_size);
+		file_data = (UINT8*) auto_malloc(file_size);
+		mame_fread(file, file_data, file_size);
 
-			if(!ti85_convert_file_data_to_serial_stream(file_data, file_size, &ti85_serial_stream, (char*)Machine->gamedrv->name))
-			{
-				ti85_free_serial_stream (&ti85_serial_stream);
-				return INIT_FAIL;
-			}
-				                                    
-			ti85_serial_status = TI85_SEND_HEADER;
+		if(!ti85_convert_file_data_to_serial_stream(file_data, file_size, &ti85_serial_stream, (char*)Machine->gamedrv->name))
+		{
+			ti85_free_serial_stream (&ti85_serial_stream);
+			return INIT_FAIL;
 		}
+			                                    
+		ti85_serial_status = TI85_SEND_HEADER;
 	}
 	else 
 	{
