@@ -509,27 +509,27 @@ DEVICE_LOAD( ti99_cart )
 
 	if (ch)
 	{
-		if ((! stricmp(ch2, "g.bin")) || (! stricmp(ch, ".grom")) || (! stricmp(ch, ".g")))
+		if ((! mame_stricmp(ch2, "g.bin")) || (! mame_stricmp(ch, ".grom")) || (! mame_stricmp(ch, ".g")))
 		{
 			/* grom */
 			type = SLOT_GROM;
 		}
-		else if ((! stricmp(ch2, "c.bin")) || (! stricmp(ch, ".crom")) || (! stricmp(ch, ".c")))
+		else if ((! mame_stricmp(ch2, "c.bin")) || (! mame_stricmp(ch, ".crom")) || (! mame_stricmp(ch, ".c")))
 		{
 			/* rom first page */
 			type = SLOT_CROM;
 		}
-		else if ((! stricmp(ch2, "d.bin")) || (! stricmp(ch, ".drom")) || (! stricmp(ch, ".d")))
+		else if ((! mame_stricmp(ch2, "d.bin")) || (! mame_stricmp(ch, ".drom")) || (! mame_stricmp(ch, ".d")))
 		{
 			/* rom second page */
 			type = SLOT_DROM;
 		}
-		else if ((! stricmp(ch2, "m.bin")) || (! stricmp(ch, ".mrom")) || (! stricmp(ch, ".m")))
+		else if ((! mame_stricmp(ch2, "m.bin")) || (! mame_stricmp(ch, ".mrom")) || (! mame_stricmp(ch, ".m")))
 		{
 			/* rom minimemory  */
 			type = SLOT_MINIMEM;
 		}
-		else if ((! stricmp(ch2, "b.bin")) || (! stricmp(ch, ".brom")) || (! stricmp(ch, ".b")))
+		else if ((! mame_stricmp(ch2, "b.bin")) || (! mame_stricmp(ch, ".brom")) || (! mame_stricmp(ch, ".b")))
 		{
 			/* rom MBX  */
 			type = SLOT_MBX;
@@ -640,64 +640,22 @@ DEVICE_UNLOAD( ti99_cart )
 	slot_type[id] = SLOT_EMPTY;
 }
 
-DEVICE_INIT( ti99_hd )
-{
-	int id = image_index_in_device(image);
-
-	switch (id)
-	{
-	case 0:
-	case 1:
-	case 2:
-		return device_init_mess_hd(image);
-
-	case 3:
-		return device_init_ti99_ide(image);
-	}
-
-	return INIT_FAIL;
-}
-
 DEVICE_LOAD( ti99_hd )
 {
 	int id = image_index_in_device(image);
-
-	switch (id)
-	{
-	case 0:
-	case 1:
-	case 2:
-		return smc92x4_hd_load(image, id);
-
-	case 3:
-		return device_load_ti99_ide(image, file);
-	}
-
-	return INIT_FAIL;
+	return smc92x4_hd_load(image, id);
 }
 
 DEVICE_UNLOAD( ti99_hd )
 {
 	int id = image_index_in_device(image);
-
-	switch (id)
-	{
-	case 0:
-	case 1:
-	case 2:
-		smc92x4_hd_unload(image, id);
-		break;
-
-	case 3:
-		device_unload_ti99_ide(image);
-		break;
-	}
+	smc92x4_hd_unload(image, id);
 }
 
 /*
 	ti99_init_machine(); called before ti99_load_rom...
 */
-void machine_init_ti99(void)
+MACHINE_RESET( ti99 )
 {
 	/*console_GROMs.data_ptr = memory_region(region_grom);*/
 	console_GROMs.addr = 0;
