@@ -15,6 +15,7 @@ static void reader_callback(int dummy);
 static void puncher_callback(int dummy);
 static void prt_callback(int dummy);
 static void dis_callback(int dummy);
+static void tx0_machine_stop(void);
 
 
 /* tape reader registers */
@@ -140,6 +141,7 @@ enum
 	PF_EOT = 004
 };
 
+
 static OPBASE_HANDLER(setOPbasefunc)
 {
 	/* just to get rid of the warnings */
@@ -147,25 +149,33 @@ static OPBASE_HANDLER(setOPbasefunc)
 }
 
 
-MACHINE_INIT( tx0 )
+static void tx0_machine_reset(void)
 {
-	memory_set_opbase_handler(0, setOPbasefunc);
+	/* reset device state */
+	tape_reader.rcl = tape_reader.rc = 0;
+}
+
+
+static void tx0_machine_stop(void)
+{
+	/* the core will take care of freeing the timers, BUT we must set the variables
+	to NULL if we don't want to risk confusing the tape image init function */
+	tape_reader.timer = tape_puncher.timer = typewriter.prt_timer = dis_timer = NULL;
+}
+
+
+MACHINE_START( tx0 )
+{
+	memory_set_opbase_handler(0, setOPbasefunc);;
 
 	tape_reader.timer = timer_alloc(reader_callback);
 	tape_puncher.timer = timer_alloc(puncher_callback);
 	typewriter.prt_timer = timer_alloc(prt_callback);
 	dis_timer = timer_alloc(dis_callback);
 
-	/* reset device state */
-	tape_reader.rcl = tape_reader.rc = 0;
-}
-
-
-MACHINE_STOP( tx0 )
-{
-	/* the core will take care of freeing the timers, BUT we must set the variables
-	to NULL if we don't want to risk confusing the tape image init function */
-	tape_reader.timer = tape_puncher.timer = typewriter.prt_timer = dis_timer = NULL;
+	add_reset_callback(tx0_machine_reset);
+	add_exit_callback(tx0_machine_stop);
+	return 0;
 }
 
 
