@@ -87,7 +87,7 @@ void mess_ui_update(void)
 	}
 
 	/* run display routine for device */
-	if (devices_inited)
+	if (Machine->devices)
 	{
 		for (dev = Machine->devices; dev->type < IO_COUNT; dev++)
 		{
@@ -96,7 +96,7 @@ void mess_ui_update(void)
 				for (id = 0; id < device_count(dev->type); id++)
 				{
 					mess_image *img = image_from_devtype_and_index(dev->type, id);
-					dev->display(img, NULL);
+					dev->display(img);
 				}
 			}
 		}
@@ -145,7 +145,7 @@ int ui_sprintf_image_info(char *buf)
 
 				/* display long filename, if present and doesn't correspond to name */
 				info = image_longname(img);
-				if (info && (!base_filename_noextension || strcmpi(info, base_filename_noextension)))
+				if (info && (!base_filename_noextension || mame_stricmp(info, base_filename_noextension)))
 					dst += sprintf(dst,"%s\n", info);
 
 				/* display manufacturer, if available */
