@@ -27,11 +27,6 @@ struct SystemConfigurationParamBlock
 	int default_ram_option;
 	UINT32 *ram_options;
 
-	/* for natural keyboard input */
-	int (*queue_chars)(const unicode_char_t *text, size_t text_len);
-	int (*accept_char)(unicode_char_t ch);
-	int (*charqueue_empty)(void);
-
 	/* device specification */
 	int device_slotcount;
 	device_getinfo_handler *device_handlers;
@@ -64,15 +59,6 @@ struct SystemConfigurationParamBlock
 		CONFIG_RAM(ram);																	\
 	}																						\
 
-#define CONFIG_QUEUE_CHARS(queue_chars_)													\
-	cfg->queue_chars = inputx_queue_chars_##queue_chars_;									\
-
-#define CONFIG_ACCEPT_CHAR(accept_char_)													\
-	cfg->accept_char = inputx_accept_char_##accept_char_;									\
-
-#define CONFIG_CHARQUEUE_EMPTY(charqueue_empty_)											\
-	cfg->charqueue_empty = inputx_charqueue_empty_##charqueue_empty_;						\
-
 #define CONFIG_DEVICE(getinfo)										\
 	if (cfg->device_position < cfg->device_slotcount)				\
 	{																\
@@ -87,52 +73,19 @@ struct SystemConfigurationParamBlock
 		cfg->device_position++;										\
 	}																\
 
-/*****************************************************************************/
-
-#define QUEUE_CHARS(name)																	\
-	int inputx_queue_chars_##name(const unicode_char_t *text, size_t text_len)				\
-
-#define ACCEPT_CHAR(name)																	\
-	int inputx_accept_char_##name(unicode_char_t ch)										\
-
-#define CHARQUEUE_EMPTY(name)																	\
-	int inputx_charqueue_empty_##name(void)										\
-
 /******************************************************************************
- * MESS' version of the GAME() and GAMEX() macros of MAME
- * CONS and CONSX are for consoles
- * COMP and COMPX are for computers
+ * MESS' version of the GAME() macros of MAME
+ * CONS is for consoles
+ * COMP is for computers
  ******************************************************************************/
-#define CONS(YEAR,NAME,PARENT,COMPAT,MACHINE,INPUT,INIT,CONFIG,COMPANY,FULLNAME)	\
-extern const struct GameDriver driver_##PARENT; \
-extern const struct GameDriver driver_##COMPAT;   \
-extern const struct GameDriver driver_##NAME;   \
-const struct GameDriver driver_##NAME = 	\
+#define CONS(YEAR,NAME,PARENT,COMPAT,MACHINE,INPUT,INIT,CONFIG,COMPANY,FULLNAME,FLAGS)	\
+extern const game_driver driver_##PARENT;   \
+extern const game_driver driver_##COMPAT;   \
+extern const game_driver driver_##NAME;   \
+const game_driver driver_##NAME = 	\
 {											\
 	__FILE__,								\
-	&driver_##PARENT,						\
-	#NAME,									\
-	system_bios_0,							\
-	FULLNAME,								\
-	#YEAR,									\
-	COMPANY,								\
-	construct_##MACHINE,					\
-	construct_ipt_##INPUT,					\
-	init_##INIT,							\
-	rom_##NAME,								\
-	construct_sysconfig_##CONFIG,			\
-	&driver_##COMPAT,						\
-	ROT0									\
-};
-
-#define CONSX(YEAR,NAME,PARENT,COMPAT,MACHINE,INPUT,INIT,CONFIG,COMPANY,FULLNAME,FLAGS)	\
-extern const struct GameDriver driver_##PARENT;   \
-extern const struct GameDriver driver_##COMPAT;   \
-extern const struct GameDriver driver_##NAME;   \
-const struct GameDriver driver_##NAME = 	\
-{											\
-	__FILE__,								\
-	&driver_##PARENT,						\
+	#PARENT,								\
 	#NAME,									\
 	system_bios_0,							\
 	FULLNAME,								\
@@ -147,14 +100,36 @@ const struct GameDriver driver_##NAME = 	\
 	ROT0|(FLAGS)							\
 };
 
-#define COMP(YEAR,NAME,PARENT,COMPAT,MACHINE,INPUT,INIT,CONFIG,COMPANY,FULLNAME)	\
-extern const struct GameDriver driver_##PARENT;   \
-extern const struct GameDriver driver_##COMPAT;   \
-extern const struct GameDriver driver_##NAME;   \
-const struct GameDriver driver_##NAME = 	\
+#define CONSB(YEAR,NAME,PARENT,BIOS,COMPAT,MACHINE,INPUT,INIT,CONFIG,COMPANY,FULLNAME,FLAGS)	\
+extern const game_driver driver_##PARENT;   \
+extern const game_driver driver_##COMPAT;   \
+extern const game_driver driver_##NAME;   \
+const game_driver driver_##NAME = 	\
 {											\
 	__FILE__,								\
-	&driver_##PARENT,						\
+	#PARENT,								\
+	#NAME,									\
+	system_bios_##BIOS,						\
+	FULLNAME,								\
+	#YEAR,									\
+	COMPANY,								\
+	construct_##MACHINE,					\
+	construct_ipt_##INPUT,					\
+	init_##INIT,							\
+	rom_##NAME,								\
+	construct_sysconfig_##CONFIG,			\
+	&driver_##COMPAT,						\
+	ROT0|(FLAGS)							\
+};
+
+#define COMP(YEAR,NAME,PARENT,COMPAT,MACHINE,INPUT,INIT,CONFIG,COMPANY,FULLNAME,FLAGS)	\
+extern const game_driver driver_##PARENT;   \
+extern const game_driver driver_##COMPAT;   \
+extern const game_driver driver_##NAME;   \
+const game_driver driver_##NAME = 	\
+{											\
+	__FILE__,								\
+	#PARENT,								\
 	#NAME,									\
 	system_bios_0,							\
 	FULLNAME,								\
@@ -166,19 +141,19 @@ const struct GameDriver driver_##NAME = 	\
 	rom_##NAME,								\
 	construct_sysconfig_##CONFIG,			\
 	&driver_##COMPAT,						\
-	ROT0|GAME_COMPUTER 						\
+	ROT0|GAME_COMPUTER|(FLAGS)	 			\
 };
 
-#define COMPX(YEAR,NAME,PARENT,COMPAT,MACHINE,INPUT,INIT,CONFIG,COMPANY,FULLNAME,FLAGS)	\
-extern const struct GameDriver driver_##PARENT;   \
-extern const struct GameDriver driver_##COMPAT;   \
-extern const struct GameDriver driver_##NAME;   \
-const struct GameDriver driver_##NAME = 	\
+#define COMPB(YEAR,NAME,PARENT,BIOS,COMPAT,MACHINE,INPUT,INIT,CONFIG,COMPANY,FULLNAME,FLAGS)	\
+extern const game_driver driver_##PARENT;   \
+extern const game_driver driver_##COMPAT;   \
+extern const game_driver driver_##NAME;   \
+const game_driver driver_##NAME = 	\
 {											\
 	__FILE__,								\
-	&driver_##PARENT,						\
+	#PARENT,								\
 	#NAME,									\
-	system_bios_0,							\
+	system_bios_##BIOS,						\
 	FULLNAME,								\
 	#YEAR,									\
 	COMPANY,								\
