@@ -5,10 +5,11 @@
 
   main part in vidhrdw
 ***************************************************************************/
+
 #include <math.h>
-#include "osd_cpu.h"
-#include "sound/streams.h"
+
 #include "mame.h"
+#include "streams.h"
 
 #define VERBOSE_DBG 1
 #include "includes/cbm.h"
