@@ -71,16 +71,16 @@ INPUT_PORTS_START( a7800 )
 	PORT_BIT (0x80, IP_ACTIVE_HIGH, IPT_VBLANK)
 
 	PORT_START      /* IN3 */
-	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_UNKNOWN) PORT_NAME("Reset") PORT_CODE(KEYCODE_R)
-	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_UNKNOWN) PORT_NAME("Start") PORT_CODE(KEYCODE_S)
+	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_KEYBOARD ) PORT_NAME("Reset") PORT_CODE(KEYCODE_2)
+	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_START) PORT_NAME("Select")
 	PORT_BIT( 0x04, IP_ACTIVE_LOW, IPT_UNUSED )
-	PORT_BIT( 0x08, IP_ACTIVE_LOW, IPT_UNKNOWN) PORT_NAME(DEF_STR(Pause)) PORT_CODE(KEYCODE_P)
+	PORT_BIT( 0x08, IP_ACTIVE_LOW, IPT_UNKNOWN) PORT_NAME(DEF_STR(Pause)) PORT_CODE(KEYCODE_CLOSEBRACE)
 	PORT_BIT ( 0x10, IP_ACTIVE_LOW, IPT_UNUSED )
 	PORT_BIT ( 0x20, IP_ACTIVE_LOW, IPT_UNUSED )
-	PORT_DIPNAME( 0x40, 0x00, "Left Diff. Switch" )
+	PORT_DIPNAME( 0x40, 0x00, "Left Diff. Switch" ) PORT_CODE(KEYCODE_3) PORT_TOGGLE
 	PORT_DIPSETTING(    0x40, "A" )
 	PORT_DIPSETTING(    0x00, "B" )
-	PORT_DIPNAME( 0x80, 0x00, "Right Diff. Switch" )
+	PORT_DIPNAME( 0x80, 0x00, "Right Diff. Switch" ) PORT_CODE(KEYCODE_4) PORT_TOGGLE
 	PORT_DIPSETTING(    0x80, "A" )
 	PORT_DIPSETTING(    0x00, "B" )
 INPUT_PORTS_END
@@ -262,28 +262,8 @@ static PALETTE_INIT(a7800p)
 #define CLK_PAL 1773447
 #define CLK_NTSC 1789772
 
-static struct TIAinterface tia_interface =
-{
-    31400,
-    100,
-    TIA_DEFAULT_GAIN,
-};
 
 
-static struct POKEYinterface pokey_interfacen =
-{
-    1,
-    CLK_NTSC,
-    { 100 },
-};
-
-static struct POKEYinterface pokey_interfacep =
-{
-    1,
-    CLK_PAL,
-    { 100 },
-};
-
 static MACHINE_DRIVER_START( a7800_ntsc )
 	/* basic machine hardware */
 	MDRV_CPU_ADD_TAG("main", M6502, CLK_NTSC)	/* 1.79Mhz (note: The clock switches to 1.19Mhz
@@ -295,7 +275,7 @@ static MACHINE_DRIVER_START( a7800_ntsc )
 	MDRV_VBLANK_DURATION(DEFAULT_REAL_60HZ_VBLANK_DURATION)
 	MDRV_INTERLEAVE(1)
 
-	MDRV_MACHINE_INIT( a7800 )
+	MDRV_MACHINE_RESET( a7800 )
 
 	MDRV_VIDEO_ATTRIBUTES(VIDEO_TYPE_RASTER)
 	MDRV_SCREEN_SIZE(640,262)
@@ -308,8 +288,11 @@ static MACHINE_DRIVER_START( a7800_ntsc )
 	MDRV_VIDEO_UPDATE(a7800)
 
 	/* sound hardware */
-	MDRV_SOUND_ADD(TIA, tia_interface)
-	MDRV_SOUND_ADD_TAG("pokey", POKEY, pokey_interfacen)
+	MDRV_SPEAKER_STANDARD_MONO("mono")
+	MDRV_SOUND_ADD(TIA, 31400)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 1.00)
+	MDRV_SOUND_ADD_TAG("pokey", POKEY, CLK_NTSC)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 1.00)
 MACHINE_DRIVER_END
 
 
@@ -327,7 +310,8 @@ static MACHINE_DRIVER_START( a7800_pal )
 	MDRV_PALETTE_INIT( a7800p )
 
 	/* sound hardware */
-	MDRV_SOUND_REPLACE("pokey", POKEY, pokey_interfacep)
+	MDRV_SOUND_REPLACE("pokey", POKEY, CLK_PAL)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 1.00)
 MACHINE_DRIVER_END
 
 
@@ -351,30 +335,48 @@ ROM_START (a7800p)
     ROM_LOAD ("7800pal.rom", 0xc000, 0x4000, CRC(d5b61170) SHA1(5a140136a16d1d83e4ff32a19409ca376a8df874))
 ROM_END
 
-static void a7800_ntsc_cartslot_getinfo(struct IODevice *dev)
+static void a7800_ntsc_cartslot_getinfo(const device_class *devclass, UINT32 state, union devinfo *info)
 {
 	/* cartslot */
-	cartslot_device_getinfo(dev);
-	dev->count = 1;
-	dev->file_extensions = "a78\0";
-	dev->must_be_loaded = 1;
-	dev->load = device_load_a7800_cart;
-	dev->partialhash = a7800_partialhash;
+	switch(state)
+	{
+		/* --- the following bits of info are returned as 64-bit signed integers --- */
+		case DEVINFO_INT_COUNT:							info->i = 1; break;
+		case DEVINFO_INT_MUST_BE_LOADED:				info->i = 1; break;
+
+		/* --- the following bits of info are returned as pointers to data or functions --- */
+		case DEVINFO_PTR_LOAD:							info->load = device_load_a7800_cart; break;
+		case DEVINFO_PTR_PARTIAL_HASH:					info->partialhash = a7800_partialhash; break;
+
+		/* --- the following bits of info are returned as NULL-terminated strings --- */
+		case DEVINFO_STR_FILE_EXTENSIONS:				strcpy(info->s = device_temp_str(), "a78"); break;
+
+		default:										cartslot_device_getinfo(devclass, state, info); break;
+	}
 }
 
 SYSTEM_CONFIG_START(a7800_ntsc)
 	CONFIG_DEVICE(a7800_ntsc_cartslot_getinfo)
 SYSTEM_CONFIG_END
 
-static void a7800_pal_cartslot_getinfo(struct IODevice *dev)
+static void a7800_pal_cartslot_getinfo(const device_class *devclass, UINT32 state, union devinfo *info)
 {
 	/* cartslot */
-	cartslot_device_getinfo(dev);
-	dev->count = 1;
-	dev->file_extensions = "a78\0";
-	dev->must_be_loaded = 1;
-	dev->load = device_load_a7800_cart;
-	dev->partialhash = a7800_partialhash;
+	switch(state)
+	{
+		/* --- the following bits of info are returned as 64-bit signed integers --- */
+		case DEVINFO_INT_COUNT:							info->i = 1; break;
+		case DEVINFO_INT_MUST_BE_LOADED:				info->i = 1; break;
+
+		/* --- the following bits of info are returned as pointers to data or functions --- */
+		case DEVINFO_PTR_LOAD:							info->load = device_load_a7800_cart; break;
+		case DEVINFO_PTR_PARTIAL_HASH:					info->partialhash = a7800_partialhash; break;
+
+		/* --- the following bits of info are returned as NULL-terminated strings --- */
+		case DEVINFO_STR_FILE_EXTENSIONS:				strcpy(info->s = device_temp_str(), "a78"); break;
+
+		default:										cartslot_device_getinfo(devclass, state, info); break;
+	}
 }
 
 SYSTEM_CONFIG_START(a7800_pal)
@@ -388,5 +390,5 @@ SYSTEM_CONFIG_END
 ***************************************************************************/
 
 /*    YEAR  NAME      PARENT    COMPAT	MACHINE		INPUT     INIT			CONFIG		COMPANY   FULLNAME */
-CONS( 1986, a7800,    0,        0,		a7800_ntsc,	a7800,    a7800_ntsc,	a7800_ntsc,	"Atari",  "Atari 7800 NTSC" )
-CONS( 1986, a7800p,   a7800,    0,		a7800_pal,	a7800,    a7800_pal,	a7800_pal,	"Atari",  "Atari 7800 PAL" )
+CONS( 1986, a7800,    0,        0,		a7800_ntsc,	a7800,    a7800_ntsc,	a7800_ntsc,	"Atari",  "Atari 7800 NTSC" , 0)
+CONS( 1986, a7800p,   a7800,    0,		a7800_pal,	a7800,    a7800_pal,	a7800_pal,	"Atari",  "Atari 7800 PAL" , 0)
