@@ -191,38 +191,22 @@ TO DO:
 #include "devices/mflopimg.h"
 #include "formats/adam_dsk.h"
 
-static ADDRESS_MAP_START( adam_readmem , ADDRESS_SPACE_PROGRAM, 8)
-	AM_RANGE( 0x00000, 0x01fff) AM_READ( MRA8_BANK1 )
-	AM_RANGE( 0x02000, 0x03fff) AM_READ( MRA8_BANK2 )
-	AM_RANGE( 0x04000, 0x05fff) AM_READ( MRA8_BANK3 )
-	AM_RANGE( 0x06000, 0x07fff) AM_READ( MRA8_BANK4 )
-	AM_RANGE( 0x08000, 0x0ffff) AM_READ( MRA8_BANK5 )
+static ADDRESS_MAP_START( adam_mem, ADDRESS_SPACE_PROGRAM, 8)
+	AM_RANGE(0x00000, 0x01fff) AM_READWRITE( MRA8_BANK1, MWA8_BANK6 )
+	AM_RANGE(0x02000, 0x03fff) AM_READWRITE( MRA8_BANK2, MWA8_BANK7 )
+	AM_RANGE(0x04000, 0x05fff) AM_READWRITE( MRA8_BANK3, MWA8_BANK8 )
+	AM_RANGE(0x06000, 0x07fff) AM_READWRITE( MRA8_BANK4, MWA8_BANK9 )
+	AM_RANGE(0x08000, 0x0ffff) AM_READWRITE( MRA8_BANK5, common_writes_w )
 ADDRESS_MAP_END
 
-static ADDRESS_MAP_START( adam_writemem , ADDRESS_SPACE_PROGRAM, 8)
-	AM_RANGE( 0x00000, 0x01fff) AM_WRITE( MWA8_BANK6 )
-	AM_RANGE( 0x02000, 0x03fff) AM_WRITE( MWA8_BANK7 )
-	AM_RANGE( 0x04000, 0x05fff) AM_WRITE( MWA8_BANK8 )
-	AM_RANGE( 0x06000, 0x07fff) AM_WRITE( MWA8_BANK9 )
-	AM_RANGE( 0x08000, 0x0ffff) AM_WRITE( common_writes_w)
-ADDRESS_MAP_END
-
-static ADDRESS_MAP_START ( adam_readport , ADDRESS_SPACE_IO, 8)
+static ADDRESS_MAP_START ( adam_io, ADDRESS_SPACE_IO, 8)
 	ADDRESS_MAP_FLAGS( AMEF_ABITS(8) )
-	AM_RANGE( 0x20, 0x3F) AM_READ( adamnet_r )
-	AM_RANGE( 0x60, 0x7F) AM_READ( adam_memory_map_controller_r )
-	AM_RANGE( 0xA0, 0xBF) AM_READ( adam_video_r )
-	AM_RANGE( 0xE0, 0xFF) AM_READ( adam_paddle_r )
-ADDRESS_MAP_END
-
-static ADDRESS_MAP_START ( adam_writeport , ADDRESS_SPACE_IO, 8)
-	ADDRESS_MAP_FLAGS( AMEF_ABITS(8) )
-	AM_RANGE( 0x20, 0x3F) AM_WRITE( adamnet_w )
-	AM_RANGE( 0x60, 0x7F) AM_WRITE( adam_memory_map_controller_w )
-	AM_RANGE( 0x80, 0x9F) AM_WRITE( adam_paddle_toggle_off )
-	AM_RANGE( 0xA0, 0xBF) AM_WRITE( adam_video_w )
-	AM_RANGE( 0xC0, 0xDF) AM_WRITE( adam_paddle_toggle_on )
-	AM_RANGE( 0xE0, 0xFF) AM_WRITE( SN76496_0_w )
+	AM_RANGE(0x20, 0x3F) AM_READWRITE( adamnet_r, adamnet_w )
+	AM_RANGE(0x60, 0x7F) AM_READWRITE( adam_memory_map_controller_r, adam_memory_map_controller_w )
+	AM_RANGE(0x80, 0x9F) AM_WRITE( adam_paddle_toggle_off )
+	AM_RANGE(0xA0, 0xBF) AM_READWRITE( adam_video_r, adam_video_w )
+	AM_RANGE(0xC0, 0xDF) AM_WRITE( adam_paddle_toggle_on )
+	AM_RANGE(0xE0, 0xFF) AM_READWRITE( adam_paddle_r, SN76496_0_w )
 ADDRESS_MAP_END
 
 /*
@@ -230,14 +214,9 @@ I do now know the real memory map of the Master 6801...
 and the 6801 ASM code is a replacement coded for this driver.
 */
 
-static ADDRESS_MAP_START( master6801_readmem , ADDRESS_SPACE_PROGRAM, 8)
-	AM_RANGE( 0x0100, 0x3fff) AM_READ( MRA8_ROM ) /* Replacement Master ROM code */
-	AM_RANGE( 0x4000, 0xffff) AM_READ( master6801_ram_r ) /* RAM Memory shared with Z80 not banked*/
-ADDRESS_MAP_END
-
-static ADDRESS_MAP_START( master6801_writemem , ADDRESS_SPACE_PROGRAM, 8)
-	AM_RANGE( 0x0100, 0x3fff) AM_WRITE( MWA8_NOP ) /* Unused */
-    AM_RANGE( 0x4000, 0xffff) AM_WRITE( master6801_ram_w ) /* RAM Memory shared with Z80 not banked*/
+static ADDRESS_MAP_START( master6801_mem , ADDRESS_SPACE_PROGRAM, 8)
+	AM_RANGE( 0x0100, 0x3fff) AM_ROM /* Replacement Master ROM code */
+	AM_RANGE( 0x4000, 0xffff) AM_READWRITE( master6801_ram_r, master6801_ram_w ) /* RAM Memory shared with Z80 not banked*/
 ADDRESS_MAP_END
 
 INPUT_PORTS_START( adam )
@@ -590,7 +569,7 @@ void resetPCB(void)
 		memory_region(REGION_CPU1)[(adam_pcb+4+i*21)&0xFFFF]=i+1;
 }
 
-static MACHINE_INIT( adam )
+static MACHINE_RESET( adam )
 {
 	if (image_exists(image_from_devtype_and_index(IO_CARTSLOT, 0)))
 	{
@@ -624,19 +603,19 @@ static const TMS9928a_interface tms9928a_interface =
 static MACHINE_DRIVER_START( adam )
 	/* Machine hardware */
 	MDRV_CPU_ADD_TAG("Main", Z80, 3579545)       /* 3.579545 Mhz */
-	MDRV_CPU_PROGRAM_MAP(adam_readmem,adam_writemem)
-	MDRV_CPU_IO_MAP(adam_readport,adam_writeport)
+	MDRV_CPU_PROGRAM_MAP(adam_mem, 0)
+	MDRV_CPU_IO_MAP(adam_io, 0)
 
     /* Master M6801 AdamNet controller */
 	/*MDRV_CPU_ADD(M6800, 4000000)          4.0 Mhz    */
-	/*MDRV_CPU_PROGRAM_MAP(master6801_readmem,master6801_writemem) */
+	/*MDRV_CPU_PROGRAM_MAP(master6801_mem, 0) */
 
 	MDRV_CPU_VBLANK_INT(adam_interrupt,1)
 	MDRV_FRAMES_PER_SECOND(60)
 	MDRV_VBLANK_DURATION(DEFAULT_REAL_60HZ_VBLANK_DURATION)
 	MDRV_INTERLEAVE(1)
 
-	MDRV_MACHINE_INIT( adam )
+	MDRV_MACHINE_RESET( adam )
 
     /* video hardware */
 	MDRV_TMS9928A( &tms9928a_interface )
@@ -676,29 +655,42 @@ Lineal virtual memory map:
 0x42000, 0x47fff -> Low unused EOS ROM
 */
 ROM_START (adam)
-    ROM_REGION( 0x42000, REGION_CPU1, 0)
-    ROM_LOAD ("wp.rom", 0x20000, 0x8000, CRC(58d86a2a) SHA1(d4aec4efe1431e56fe52d83baf9118542c525255))
-    ROM_LOAD ("os7.rom", 0x30000, 0x2000, CRC(3aa93ef3) SHA1(45bedc4cbdeac66c7df59e9e599195c778d86a92))
-    ROM_LOAD ("eos.rom", 0x38000, 0x2000, CRC(05a37a34) SHA1(ad3c20ef444f10af7ae8eb75c81e500d9b1bba3d))
-    /*ROM_REGION( 0x10000, REGION_CPU2, 0) */
-    /*ROM_LOAD ("master68.rom", 0x0100, 0x0E4, CRC(619a47b8))    Replacement 6801 Master ROM    */
+	ROM_REGION( 0x42000, REGION_CPU1, 0)
+	ROM_LOAD ("wp.rom", 0x20000, 0x8000, CRC(58d86a2a) SHA1(d4aec4efe1431e56fe52d83baf9118542c525255))
+	ROM_LOAD ("os7.rom", 0x30000, 0x2000, CRC(3aa93ef3) SHA1(45bedc4cbdeac66c7df59e9e599195c778d86a92))
+	ROM_LOAD ("eos.rom", 0x38000, 0x2000, CRC(05a37a34) SHA1(ad3c20ef444f10af7ae8eb75c81e500d9b1bba3d))
+
+	ROM_CART_LOAD(0, "rom\0col\0bin\0", 0x28000, 0x8000, ROM_NOMIRROR | ROM_OPTIONAL)
+
+	/*ROM_REGION( 0x10000, REGION_CPU2, 0) */
+	/*ROM_LOAD ("master68.rom", 0x0100, 0x0E4, CRC(619a47b8))    Replacement 6801 Master ROM    */
 ROM_END
 
-static void adam_cartslot_getinfo(struct IODevice *dev)
+static void adam_cartslot_getinfo(const device_class *devclass, UINT32 state, union devinfo *info)
 {
 	/* cartslot */
-	cartslot_device_getinfo(dev);
-	dev->count = 1;
-	dev->file_extensions = "rom\0col\0bin\0";
-	dev->load = device_load_adam_cart;
-	dev->imgverify = adam_cart_verify;
+	switch(state)
+	{
+		/* --- the following bits of info are returned as pointers to data or functions --- */
+		case DEVINFO_PTR_VERIFY:						info->imgverify = adam_cart_verify; break;
+
+		default:										cartslot_device_getinfo(devclass, state, info); break;
+	}
 }
 
-static void adam_floppy_getinfo(struct IODevice *dev)
+static void adam_floppy_getinfo(const device_class *devclass, UINT32 state, union devinfo *info)
 {
 	/* floppy */
-	floppy_device_getinfo(dev, floppyoptions_adam);
-	dev->count = 4;
+	switch(state)
+	{
+		/* --- the following bits of info are returned as 64-bit signed integers --- */
+		case DEVINFO_INT_COUNT:							info->i = 4; break;
+
+		/* --- the following bits of info are returned as pointers to data or functions --- */
+		case DEVINFO_PTR_FLOPPY_OPTIONS:				info->p = (void *) floppyoptions_adam; break;
+
+		default:										floppy_device_getinfo(devclass, state, info); break;
+	}
 }
 
 SYSTEM_CONFIG_START(adam)
@@ -713,5 +705,5 @@ SYSTEM_CONFIG_END
 ***************************************************************************/
 
 /*    YEAR  NAME    PARENT	COMPAT	MACHINE INPUT   INIT	CONFIG	COMPANY FULLNAME */
-COMP( 1982, adam,   0,		coleco,	adam,   adam,   0,		adam,	"Adam", "ColecoAdam" )
+COMP( 1982, adam,   0,		coleco,	adam,   adam,   0,		adam,	"Adam", "ColecoAdam" , 0)
 
