@@ -6,7 +6,7 @@
 #include "includes/apf.h"
 
 #include "machine/6821pia.h"
-#include "includes/wd179x.h"
+#include "machine/wd17xx.h"
 #include "devices/basicdsk.h"
 #include "devices/cassette.h"
 #include "formats/apf_apt.h"
@@ -37,51 +37,37 @@ static unsigned char pad_data;
 
 static  READ8_HANDLER(apf_m1000_pia_in_a_func)
 {
-	logerror("pia 0 a r: %04x\n",offset);
-
 	return pad_data;
 }
 
 static  READ8_HANDLER(apf_m1000_pia_in_b_func)
 {
-	
-	logerror("pia 0 b r: %04x\n",offset);
-
 	return 0x0ff;
 }
 
 static  READ8_HANDLER(apf_m1000_pia_in_ca1_func)
 {
-	logerror("pia 0 ca1 r: %04x\n",offset);
-
 	return 0;
 }
 
 static  READ8_HANDLER(apf_m1000_pia_in_cb1_func)
 {
-	logerror("pia 0 cb1 r: %04x\n",offset);
-
 	return 0x00;
 }
 
 static  READ8_HANDLER(apf_m1000_pia_in_ca2_func)
 {
-	logerror("pia 0 ca2 r: %04x\n",offset);
-
 	return 0;
 }
 
 static  READ8_HANDLER(apf_m1000_pia_in_cb2_func)
 {
-	logerror("pia 0 cb2 r: %04x\n",offset);
-
 	return 0x00;
 }
 
 
 static WRITE8_HANDLER(apf_m1000_pia_out_a_func)
 {
-	logerror("pia 0 a w: %04x %02x\n",offset,data);
 }
 
 unsigned char previous_mode;
@@ -111,22 +97,21 @@ static WRITE8_HANDLER(apf_m1000_pia_out_b_func)
 	/* 222 = 1101 mono graphics */
 	/*	if (((previous_mode^data) & 0x0f0)!=0) */
 	{
+		extern UINT8 apf_m6847_attr;
+
 		/* not sure if this is correct - need to check */
-		m6847_ag_w(0,	data & 0x80);
-		m6847_gm0_w(0,	data & 0x10);
-		m6847_gm1_w(0,	data & 0x20);
-		m6847_gm2_w(0,	data & 0x40);
-/*		m6847_set_cannonical_row_height(); */
+		apf_m6847_attr = 0x00;
+		if (data & 0x80)	apf_m6847_attr |= M6847_AG;
+		if (data & 0x40)	apf_m6847_attr |= M6847_GM2;
+		if (data & 0x20)	apf_m6847_attr |= M6847_GM1;
+		if (data & 0x10)	apf_m6847_attr |= M6847_GM0;
 		previous_mode = data;
 	}
 	/*	schedule_full_refresh(); */
-
-	logerror("pia 0 b w: %04x %02x\n",offset,data);
 }
 
 static WRITE8_HANDLER(apf_m1000_pia_out_ca2_func)
 {
-	logerror("pia 0 ca2 w: %04x %02x\n",offset,data);
 }
 
 static WRITE8_HANDLER(apf_m1000_pia_out_cb2_func)
@@ -144,22 +129,11 @@ unsigned char apf_ints;
 
 void apf_update_ints(void)
 {
-	if (apf_ints!=0)
-	{
-		cpunum_set_input_line(0,0,HOLD_LINE);
-		logerror("set int\n");
-	}
-	else
-	{
-		cpunum_set_input_line(0,0,CLEAR_LINE);
-		logerror("clear int\n");
-	}
+	cpunum_set_input_line(0, 0, apf_ints ? HOLD_LINE : CLEAR_LINE);
 }
 
 static void	apf_m1000_irq_a_func(int state)
 {
-	/*logerror("pia 0 irq a %d\n",state); */
-
 	if (state)
 	{
 		apf_ints|=1;
@@ -190,7 +164,7 @@ static void	apf_m1000_irq_b_func(int state)
 
 }
 
-struct pia6821_interface apf_m1000_pia_interface=
+static const pia6821_interface apf_m1000_pia_interface=
 {
 	apf_m1000_pia_in_a_func,
 	apf_m1000_pia_in_b_func,
@@ -209,8 +183,6 @@ struct pia6821_interface apf_m1000_pia_interface=
 
 static  READ8_HANDLER(apf_imagination_pia_in_a_func)
 {
-	logerror("pia 1 a r: %04x\n",offset);
-
 	return keyboard_data;
 }
 
@@ -228,36 +200,27 @@ static READ8_HANDLER(apf_imagination_pia_in_b_func)
 
 static  READ8_HANDLER(apf_imagination_pia_in_ca1_func)
 {
-	logerror("pia 1 ca1 r: %04x\n",offset);
-
 	return 0x00;
 }
 
 static  READ8_HANDLER(apf_imagination_pia_in_cb1_func)
 {
-	logerror("pia 1 cb1 r: %04x\n",offset);
-
 	return 0x00;
 }
 
 static  READ8_HANDLER(apf_imagination_pia_in_ca2_func)
 {
-	logerror("pia 1 ca2 r: %04x\n",offset);
-
 	return 0x00;
 }
 
 static  READ8_HANDLER(apf_imagination_pia_in_cb2_func)
 {
-	logerror("pia 1 cb2 r: %04x\n",offset);
-
 	return 0x00;
 }
 
 
 static WRITE8_HANDLER(apf_imagination_pia_out_a_func)
 {
-	logerror("pia 1 a w: %04x %02x\n",offset,data);
 }
 
 static WRITE8_HANDLER(apf_imagination_pia_out_b_func)
@@ -283,24 +246,18 @@ static WRITE8_HANDLER(apf_imagination_pia_out_b_func)
 	/* bit 6: cassette write */
 	cassette_output(image_from_devtype_and_index(IO_CASSETTE, 0),
 		(data & 0x40) ? -1.0 : 1.0);
-
-
-	logerror("pia 1 b w: %04x %02x\n",offset,data);
 }
 
 static WRITE8_HANDLER(apf_imagination_pia_out_ca2_func)
 {
-	/*logerror("pia 1 ca2 w: %04x %02x\n",offset,data); */
 }
 
 static WRITE8_HANDLER(apf_imagination_pia_out_cb2_func)
 {
-	/*logerror("pia 1 cb2 w: %04x %02x\n",offset,data); */
 }
 
 static void	apf_imagination_irq_a_func(int state)
 {
-	/*logerror("pia 1 irq a %d\n",state); */
 	if (state)
 	{
 		apf_ints|=4;
@@ -316,8 +273,6 @@ static void	apf_imagination_irq_a_func(int state)
 
 static void	apf_imagination_irq_b_func(int state)
 {
-	/*logerror("pia 1 irq b %d\n",state); */
-
 	if (state)
 	{
 		apf_ints|=8;
@@ -331,7 +286,7 @@ static void	apf_imagination_irq_b_func(int state)
 
 }
 
-struct pia6821_interface apf_imagination_pia_interface=
+static const pia6821_interface apf_imagination_pia_interface=
 {
 	apf_imagination_pia_in_a_func,
 	apf_imagination_pia_in_b_func,
@@ -352,57 +307,23 @@ extern unsigned char *apf_video_ram;
 
 static void apf_common_init(void)
 {
-	unsigned char *rom_ptr = memory_region(REGION_CPU1) + 0x010000;
-
 	apf_ints = 0;
-
-	memory_set_bankptr(1, rom_ptr);
-	memory_set_bankptr(2, rom_ptr);
-	memory_set_bankptr(3, rom_ptr);
-	memory_set_bankptr(4, rom_ptr);
-	memory_set_bankptr(5, rom_ptr);
-	memory_set_bankptr(6, rom_ptr);
-	memory_set_bankptr(7, rom_ptr);
-	memory_set_bankptr(8, rom_ptr);
-
 	pia_config(0, PIA_STANDARD_ORDERING,&apf_m1000_pia_interface);
-
 	pia_reset();
-
 }
 
-static  READ8_HANDLER(apf_pia_0_r)
-{
-	return pia_0_r(offset & 0x03);
-}
-
-static WRITE8_HANDLER(apf_pia_0_w)
-{
-	pia_0_w(offset & 0x03, data);
-}
-
-static  READ8_HANDLER(apf_pia_1_r)
-{
-	return pia_1_r(offset & 0x03);
-}
-
-static WRITE8_HANDLER(apf_pia_1_w)
-{
-	pia_1_w(offset & 0x03, data);
-}
-
-static MACHINE_INIT( apf_imagination )
+static MACHINE_START( apf_imagination )
 {
 	pia_config(1, PIA_STANDARD_ORDERING,&apf_imagination_pia_interface);
-
 	apf_common_init();
-
 	wd179x_init(WD_TYPE_179X,NULL);
+	return 0;
 }
 
-static MACHINE_INIT( apf_m1000 )
+static MACHINE_START( apf_m1000 )
 {
 	apf_common_init();
+	return 0;
 }
 
 static WRITE8_HANDLER(apf_dischw_w)
@@ -448,119 +369,52 @@ static WRITE8_HANDLER(apf_wd179x_data_w)
 	wd179x_data_w(offset,~data);
 }
 
-static  READ8_HANDLER(apf_wd179x_status_r)
+static READ8_HANDLER(apf_wd179x_status_r)
 {
 	return ~wd179x_status_r(offset);
 }
 
-static  READ8_HANDLER(apf_wd179x_track_r)
+static READ8_HANDLER(apf_wd179x_track_r)
 {
 	return ~wd179x_track_r(offset);
 }
 
-static  READ8_HANDLER(apf_wd179x_sector_r)
+static READ8_HANDLER(apf_wd179x_sector_r)
 {
 	return ~wd179x_sector_r(offset);
 }
 
-static  READ8_HANDLER(apf_wd179x_data_r)
+static READ8_HANDLER(apf_wd179x_data_r)
 {
 	return wd179x_data_r(offset);
 }
 
-static ADDRESS_MAP_START( apf_imagination_readmem , ADDRESS_SPACE_PROGRAM, 8)
-	AM_RANGE( 0x00000, 0x003ff) AM_READ( apf_video_r)
-	AM_RANGE( 0x00400, 0x007ff) AM_READ( apf_video_r)
-	AM_RANGE( 0x00800, 0x00bff) AM_READ( apf_video_r)
-	AM_RANGE( 0x00c00, 0x00fff) AM_READ( apf_video_r)
-	AM_RANGE( 0x01000, 0x01fff) AM_READ( apf_video_r)
-	AM_RANGE( 0x01000, 0x013ff) AM_READ( apf_video_r)
-	AM_RANGE( 0x01400, 0x017ff) AM_READ( apf_video_r)
-	AM_RANGE( 0x01800, 0x01bff) AM_READ( apf_video_r)
-	AM_RANGE( 0x01c00, 0x01fff) AM_READ( apf_video_r)
-	AM_RANGE( 0x02000, 0x03fff) AM_READ( apf_pia_0_r)		
-	AM_RANGE( 0x04000, 0x047ff) AM_READ( MRA8_BANK1)
-	AM_RANGE( 0x04800, 0x04fff) AM_READ( MRA8_BANK2)
-	AM_RANGE( 0x05000, 0x057ff) AM_READ( MRA8_BANK3)
-	AM_RANGE( 0x05800, 0x05fff) AM_READ( MRA8_BANK4)
-	AM_RANGE( 0x06000, 0x063ff) AM_READ( apf_pia_1_r)
-	AM_RANGE( 0x06400, 0x064ff) AM_READ( serial_r)
-	AM_RANGE( 0x06500, 0x06500) AM_READ( apf_wd179x_status_r)
-	AM_RANGE( 0x06501, 0x06501) AM_READ( apf_wd179x_track_r)
-	AM_RANGE( 0x06502, 0x06502) AM_READ( apf_wd179x_sector_r)
-	AM_RANGE( 0x06503, 0x06503) AM_READ( apf_wd179x_data_r)
-	AM_RANGE( 0x06800, 0x077ff) AM_READ( MRA8_ROM)
-	AM_RANGE( 0x07800, 0x07fff) AM_READ( MRA8_NOP)
-	AM_RANGE( 0x08000, 0x09fff) AM_READ( MRA8_ROM)
-	AM_RANGE( 0x0a000, 0x0dfff) AM_READ( MRA8_RAM)
-	AM_RANGE( 0x0e000, 0x0e7ff) AM_READ( MRA8_BANK5)
-	AM_RANGE( 0x0e800, 0x0efff) AM_READ( MRA8_BANK6)
-	AM_RANGE( 0x0f000, 0x0f7ff) AM_READ( MRA8_BANK7)
-	AM_RANGE( 0x0f800, 0x0ffff) AM_READ( MRA8_BANK8)
-ADDRESS_MAP_END
-
-
-static ADDRESS_MAP_START( apf_imagination_writemem , ADDRESS_SPACE_PROGRAM, 8)
-	AM_RANGE( 0x00000, 0x003ff) AM_WRITE( apf_video_w)
-	AM_RANGE( 0x00400, 0x007ff) AM_WRITE( apf_video_w)
-	AM_RANGE( 0x00800, 0x00bff) AM_WRITE( apf_video_w)
-	AM_RANGE( 0x00c00, 0x00fff) AM_WRITE( apf_video_w)
-	AM_RANGE( 0x01000, 0x01fff) AM_WRITE( apf_video_w)
-	AM_RANGE( 0x01000, 0x013ff) AM_WRITE( apf_video_w)
-	AM_RANGE( 0x01400, 0x017ff) AM_WRITE( apf_video_w)
-	AM_RANGE( 0x01800, 0x01bff) AM_WRITE( apf_video_w)
-	AM_RANGE( 0x01c00, 0x01fff) AM_WRITE( apf_video_w)
-	AM_RANGE( 0x02000, 0x02003) AM_WRITE( pia_0_w)
-	AM_RANGE( 0x04000, 0x05fff) AM_WRITE( MWA8_ROM)
-	AM_RANGE( 0x06000, 0x063ff) AM_WRITE( apf_pia_1_w)
-	AM_RANGE( 0x06400, 0x064ff) AM_WRITE( serial_w)
-	AM_RANGE( 0x06500, 0x06500) AM_WRITE( apf_wd179x_command_w)
-	AM_RANGE( 0x06501, 0x06501) AM_WRITE( apf_wd179x_track_w)
-	AM_RANGE( 0x06502, 0x06502) AM_WRITE( apf_wd179x_sector_w)
-	AM_RANGE( 0x06503, 0x06503) AM_WRITE( apf_wd179x_data_w)
+static ADDRESS_MAP_START(apf_imagination_map, ADDRESS_SPACE_PROGRAM, 8)
+	AM_RANGE( 0x00000, 0x003ff) AM_RAM AM_BASE(&apf_video_ram) AM_MIRROR(0x1c00)
+	AM_RANGE( 0x02000, 0x03fff) AM_READWRITE(pia_0_r, pia_0_w)	
+	AM_RANGE( 0x04000, 0x047ff) AM_ROM AM_REGION(REGION_CPU1, 0x10000) AM_MIRROR(0x1800)
+	AM_RANGE( 0x06000, 0x063ff) AM_READWRITE(pia_1_r, pia_1_w)
+	AM_RANGE( 0x06400, 0x064ff) AM_READWRITE(serial_r, serial_w)
+	AM_RANGE( 0x06500, 0x06500) AM_READWRITE(apf_wd179x_status_r, apf_wd179x_command_w)
+	AM_RANGE( 0x06501, 0x06501) AM_READWRITE(apf_wd179x_track_r, apf_wd179x_track_w)
+	AM_RANGE( 0x06502, 0x06502) AM_READWRITE(apf_wd179x_sector_r, apf_wd179x_sector_w)
+	AM_RANGE( 0x06503, 0x06503) AM_READWRITE(apf_wd179x_data_r, apf_wd179x_data_w)
 	AM_RANGE( 0x06600, 0x06600) AM_WRITE( apf_dischw_w)
-	AM_RANGE( 0x0a000, 0x0dfff) AM_WRITE( MWA8_RAM)
-	AM_RANGE( 0x0e000, 0x0ffff) AM_WRITE( MWA8_ROM)
+	AM_RANGE( 0x06800, 0x077ff) AM_ROM
+	AM_RANGE( 0x07800, 0x07fff) AM_NOP
+	AM_RANGE( 0x08000, 0x09fff) AM_ROM
+	AM_RANGE( 0x0a000, 0x0dfff) AM_RAM
+	AM_RANGE( 0x0e000, 0x0e7ff) AM_ROM AM_REGION(REGION_CPU1, 0x10000) AM_MIRROR(0x1800)
 ADDRESS_MAP_END
 
-static ADDRESS_MAP_START(apf_m1000_readmem, ADDRESS_SPACE_PROGRAM, 8)
-	AM_RANGE( 0x00000, 0x003ff) AM_READ( apf_video_r)
-	AM_RANGE( 0x00400, 0x007ff) AM_READ( apf_video_r)
-	AM_RANGE( 0x00800, 0x00bff) AM_READ( apf_video_r)
-	AM_RANGE( 0x00c00, 0x00fff) AM_READ( apf_video_r)
-	AM_RANGE( 0x01000, 0x01fff) AM_READ( apf_video_r)
-	AM_RANGE( 0x01000, 0x013ff) AM_READ( apf_video_r)
-	AM_RANGE( 0x01400, 0x017ff) AM_READ( apf_video_r)
-	AM_RANGE( 0x01800, 0x01bff) AM_READ( apf_video_r)
-	AM_RANGE( 0x01c00, 0x01fff) AM_READ( apf_video_r)
-	AM_RANGE( 0x02000, 0x03fff) AM_READ( apf_pia_0_r)		
-	AM_RANGE( 0x04000, 0x047ff) AM_READ( MRA8_BANK1)
-	AM_RANGE( 0x04800, 0x04fff) AM_READ( MRA8_BANK2)
-	AM_RANGE( 0x05000, 0x057ff) AM_READ( MRA8_BANK3)
-	AM_RANGE( 0x05800, 0x05fff) AM_READ( MRA8_BANK4)
-	AM_RANGE( 0x06800, 0x077ff) AM_READ( MRA8_ROM)
-	AM_RANGE( 0x08000, 0x09fff) AM_READ( MRA8_ROM)
-	AM_RANGE( 0x0a000, 0x0dfff) AM_READ( MRA8_RAM)
-	AM_RANGE( 0x0e000, 0x0e7ff) AM_READ( MRA8_BANK5)
-	AM_RANGE( 0x0e800, 0x0efff) AM_READ( MRA8_BANK6)
-	AM_RANGE( 0x0f000, 0x0f7ff) AM_READ( MRA8_BANK7)
-	AM_RANGE( 0x0f800, 0x0ffff) AM_READ( MRA8_BANK8)
-ADDRESS_MAP_END
-
-static ADDRESS_MAP_START( apf_m1000_writemem , ADDRESS_SPACE_PROGRAM, 8)
-	AM_RANGE( 0x00000, 0x003ff) AM_WRITE( apf_video_w)
-	AM_RANGE( 0x00400, 0x007ff) AM_WRITE( apf_video_w)
-	AM_RANGE( 0x00800, 0x00bff) AM_WRITE( apf_video_w)
-	AM_RANGE( 0x00c00, 0x00fff) AM_WRITE( apf_video_w)
-	AM_RANGE( 0x01000, 0x01fff) AM_WRITE( apf_video_w)
-	AM_RANGE( 0x01000, 0x013ff) AM_WRITE( apf_video_w)
-	AM_RANGE( 0x01400, 0x017ff) AM_WRITE( apf_video_w)
-	AM_RANGE( 0x01800, 0x01bff) AM_WRITE( apf_video_w)
-	AM_RANGE( 0x01c00, 0x01fff) AM_WRITE( apf_video_w)
-	AM_RANGE( 0x02000, 0x03fff) AM_WRITE( apf_pia_0_w)		
-	AM_RANGE( 0x04000, 0x05fff) AM_WRITE( MWA8_ROM)
-	AM_RANGE( 0x0a000, 0x0dfff) AM_WRITE( MWA8_RAM)
-	AM_RANGE( 0x0e000, 0x0ffff) AM_WRITE( MWA8_ROM)
+static ADDRESS_MAP_START(apf_m1000_map, ADDRESS_SPACE_PROGRAM, 8)
+	AM_RANGE( 0x00000, 0x003ff) AM_RAM AM_BASE(&apf_video_ram)  AM_MIRROR(0x1c00)
+	AM_RANGE( 0x02000, 0x03fff) AM_READWRITE(pia_0_r, pia_0_w)	
+	AM_RANGE( 0x04000, 0x047ff) AM_ROM AM_REGION(REGION_CPU1, 0x10000) AM_MIRROR(0x1800)
+	AM_RANGE( 0x06800, 0x077ff) AM_ROM
+	AM_RANGE( 0x08000, 0x09fff) AM_ROM
+	AM_RANGE( 0x0a000, 0x0dfff) AM_RAM
+	AM_RANGE( 0x0e000, 0x0e7ff) AM_ROM AM_REGION(REGION_CPU1, 0x10000) AM_MIRROR(0x1800)
 ADDRESS_MAP_END
 
 INPUT_PORTS_START( apf_m1000)
@@ -731,16 +585,18 @@ INPUT_PORTS_END
 static MACHINE_DRIVER_START( apf_imagination )
 	/* basic machine hardware */
 	MDRV_CPU_ADD_TAG("main", M6800, 3750000)        /* 7.8336 Mhz */
-	MDRV_CPU_PROGRAM_MAP(apf_imagination_readmem,apf_imagination_writemem)
-	MDRV_CPU_VBLANK_INT(m6847_vh_interrupt, M6847_INTERRUPTS_PER_FRAME)
-	MDRV_FRAMES_PER_SECOND(60)
-	MDRV_VBLANK_DURATION(DEFAULT_REAL_60HZ_VBLANK_DURATION)
+	MDRV_CPU_PROGRAM_MAP(apf_imagination_map, 0)
+	MDRV_FRAMES_PER_SECOND(M6847_NTSC_FRAMES_PER_SECOND)
 	MDRV_INTERLEAVE(0)
 
-	MDRV_MACHINE_INIT( apf_imagination )
+	MDRV_MACHINE_START( apf_imagination )
 
 	/* video hardware */
-	MDRV_M6847_NTSC( apf )
+	MDRV_VIDEO_START(apf)
+	MDRV_VIDEO_UPDATE(m6847)
+	MDRV_VIDEO_ATTRIBUTES(VIDEO_RGB_DIRECT | VIDEO_NEEDS_6BITS_PER_GUN)
+	MDRV_SCREEN_SIZE(320, 25+192+26)
+	MDRV_VISIBLE_AREA(0, 319, 1, 239)
 
 	/* sound hardware */
 	MDRV_SPEAKER_STANDARD_MONO("mono")
@@ -752,8 +608,8 @@ MACHINE_DRIVER_END
 static MACHINE_DRIVER_START( apf_m1000 )
 	MDRV_IMPORT_FROM( apf_imagination )
 	MDRV_CPU_MODIFY( "main" )
-	MDRV_CPU_PROGRAM_MAP( apf_m1000_readmem,apf_m1000_writemem )
-	MDRV_MACHINE_INIT( apf_m1000 )
+	MDRV_CPU_PROGRAM_MAP( apf_m1000_map, 0 )
+	MDRV_MACHINE_START( apf_m1000 )
 MACHINE_DRIVER_END
 
 
@@ -775,20 +631,37 @@ ROM_START(apfm1000)
 	ROM_LOAD("apf_4000.rom",0x010000, 0x0800, CRC(2a331a33) SHA1(387b90882cd0b66c192d9cbaa3bec250f897e4f1))
 ROM_END
 
-static void apfimag_cassette_getinfo(struct IODevice *dev)
+static void apfimag_cassette_getinfo(const device_class *devclass, UINT32 state, union devinfo *info)
 {
 	/* cassette */
-	cassette_device_getinfo(dev, apf_cassette_formats, NULL, (cassette_state) -1);
-	dev->count = 1;
+	switch(state)
+	{
+		/* --- the following bits of info are returned as 64-bit signed integers --- */
+		case DEVINFO_INT_COUNT:							info->i = 1; break;
+
+		/* --- the following bits of info are returned as pointers to data or functions --- */
+		case DEVINFO_PTR_CASSETTE_FORMATS:				info->p = (void *) apf_cassette_formats; break;
+
+		default:										cassette_device_getinfo(devclass, state, info); break;
+	}
 }
 
-static void apfimag_floppy_getinfo(struct IODevice *dev)
+static void apfimag_floppy_getinfo(const device_class *devclass, UINT32 state, union devinfo *info)
 {
 	/* floppy */
-	legacybasicdsk_device_getinfo(dev);
-	dev->count = 2;
-	dev->file_extensions = "apd\0";
-	dev->load = device_load_apfimag_floppy;
+	switch(state)
+	{
+		/* --- the following bits of info are returned as 64-bit signed integers --- */
+		case DEVINFO_INT_COUNT:							info->i = 2; break;
+
+		/* --- the following bits of info are returned as pointers to data or functions --- */
+		case DEVINFO_PTR_LOAD:							info->load = device_load_apfimag_floppy; break;
+
+		/* --- the following bits of info are returned as NULL-terminated strings --- */
+		case DEVINFO_STR_FILE_EXTENSIONS:				strcpy(info->s = device_temp_str(), "apd"); break;
+
+		default:										legacybasicdsk_device_getinfo(devclass, state, info); break;
+	}
 }
 
 SYSTEM_CONFIG_START( apfimag )
@@ -803,5 +676,5 @@ SYSTEM_CONFIG_END
 ***************************************************************************/
 
 /*    YEAR	NAME		PARENT	COMPAT	MACHINE				INPUT				INIT    CONFIG		COMPANY               FULLNAME */
-COMPX(1977, apfimag,	0,		0,		apf_imagination,	apf_imagination,	0,		apfimag,	"APF Electronics Inc",  "APF Imagination Machine" ,GAME_NOT_WORKING)
-COMPX(1978,	apfm1000,	0,		0,		apf_m1000,			apf_m1000,			0,		NULL,		"APF Electronics Inc",  "APF M-1000" ,GAME_NOT_WORKING)
+COMP(1977, apfimag,	0,		0,		apf_imagination,	apf_imagination,	0,		apfimag,	"APF Electronics Inc",  "APF Imagination Machine" ,GAME_NOT_WORKING)
+COMP(1978,	apfm1000,	0,		0,		apf_m1000,			apf_m1000,			0,		NULL,		"APF Electronics Inc",  "APF M-1000" ,GAME_NOT_WORKING)
