@@ -187,7 +187,7 @@ Apple 3.5 and Apple 5.25 drives - up to three devices
 #include "vidhrdw/generic.h"
 #include "includes/apple2.h"
 #include "machine/ay3600.h"
-#include "machine/appldriv.h"
+#include "devices/appldriv.h"
 #include "devices/mflopimg.h"
 #include "formats/ap2_dsk.h"
 #include "sound/ay8910.h"
@@ -527,7 +527,7 @@ static const unsigned char apple2_palette[] =
 	0xFF, 0xFF, 0xFF	/* White */
 };
 
-static struct GfxLayout apple2_text_layout =
+static gfx_layout apple2_text_layout =
 {
 	14,8,		/* 14*8 characters */
 	256,		/* 256 characters */
@@ -538,7 +538,7 @@ static struct GfxLayout apple2_text_layout =
 	8*8			/* every char takes 8 bytes */
 };
 
-static struct GfxLayout apple2_dbltext_layout =
+static gfx_layout apple2_dbltext_layout =
 {
 	7,8,		/* 7*8 characters */
 	256,		/* 256 characters */
@@ -549,14 +549,14 @@ static struct GfxLayout apple2_dbltext_layout =
 	8*8			/* every char takes 8 bytes */
 };
 
-static struct GfxDecodeInfo apple2_gfxdecodeinfo[] =
+static gfx_decode apple2_gfxdecodeinfo[] =
 {
 	{ REGION_GFX1, 0x0000, &apple2_text_layout, 0, 2 },
 	{ REGION_GFX1, 0x0000, &apple2_dbltext_layout, 0, 2 },
 	{ -1 } /* end of array */
 };
 
-static struct GfxLayout apple2e_text_layout =
+static gfx_layout apple2e_text_layout =
 {
 	14,8,		/* 14*8 characters */
 	1024,		/* 256 characters */
@@ -567,7 +567,7 @@ static struct GfxLayout apple2e_text_layout =
 	8*8			/* every char takes 8 bytes */
 };
 
-static struct GfxLayout apple2e_dbltext_layout =
+static gfx_layout apple2e_dbltext_layout =
 {
 	7,8,		/* 7*8 characters */
 	1024,		/* 256 characters */
@@ -578,7 +578,7 @@ static struct GfxLayout apple2e_dbltext_layout =
 	8*8			/* every char takes 8 bytes */
 };
 
-static struct GfxDecodeInfo apple2e_gfxdecodeinfo[] =
+static gfx_decode apple2e_gfxdecodeinfo[] =
 {
 	{ REGION_GFX1, 0x0000, &apple2e_text_layout, 0, 2 },
 	{ REGION_GFX1, 0x0000, &apple2e_dbltext_layout, 0, 2 },
@@ -629,12 +629,6 @@ PALETTE_INIT( apple2 )
 	memcpy(colortable, apple2_colortable, sizeof(apple2_colortable));
 }
 
-static const char *apple2_floppy_getname(const struct IODevice *dev, int id, char *buf, size_t bufsize)
-{
-	snprintf(buf, bufsize, "Slot 6 Disk #%d", id + 1);
-	return buf;
-}
-
 static struct AY8910interface ay8910_interface =
 {
 	NULL
@@ -649,7 +643,7 @@ static MACHINE_DRIVER_START( apple2_common )
 	MDRV_VBLANK_DURATION(DEFAULT_REAL_60HZ_VBLANK_DURATION)
 	MDRV_INTERLEAVE(1)
 
-	MDRV_MACHINE_INIT( apple2 )
+	MDRV_MACHINE_START( apple2 )
 
 	MDRV_VIDEO_ATTRIBUTES(VIDEO_TYPE_RASTER | VIDEO_PIXEL_ASPECT_RATIO_1_2)
 	MDRV_SCREEN_SIZE(280*2, 192)
@@ -749,7 +743,7 @@ ROM_START(apple2p)
 	ROM_LOAD ( "a2p.e0", 0x2000, 0x0800, CRC(2b8d9a89) SHA1(8d82a1da63224859bd619005fab62c4714b25dd7))
 	ROM_LOAD ( "a2p.e8", 0x2800, 0x0800, CRC(5719871a) SHA1(37501be96d36d041667c15d63e0c1eff2f7dd4e9))
 	ROM_LOAD ( "a2p.f0", 0x3000, 0x0800, CRC(9a04eecf) SHA1(e6bf91ed28464f42b807f798fc6422e5948bf581))
-	ROM_LOAD ( "a2p.f8", 0x3800, 0x0800, CRC(ecffd453) SHA1(07a3bdce3e34bbed5246fe09a9938d8f334a8225))
+	ROM_LOAD ( "a2p.f8", 0x3800, 0x0800, CRC(079589c4) SHA1(a28852ff997b4790e53d8d0352112c4b1a395098))
 	ROM_LOAD ( "disk2_33.rom", 0x4500, 0x0100, CRC(ce7144f6) SHA1(d4181c9f046aafc3fb326b381baac809d9e38d16)) /* Disk II ROM - DOS 3.3 version */
 ROM_END
 
@@ -850,17 +844,29 @@ ROM_START(apple2cp)
 ROM_END
 
 
-static void apple2_floppy_getinfo(struct IODevice *dev)
+static void apple2_floppy_getinfo(const device_class *devclass, UINT32 state, union devinfo *info)
 {
 	/* floppy */
-	apple525_device_getinfo(dev, 15, 16);
-	dev->name = apple2_floppy_getname;
+	switch(state)
+	{
+		/* --- the following bits of info are returned as 64-bit signed integers --- */
+		case DEVINFO_INT_APPLE525_SPINFRACT_DIVIDEND:	info->i = 15; break;
+		case DEVINFO_INT_APPLE525_SPINFRACT_DIVISOR:	info->i = 16; break;
+
+		/* --- the following bits of info are returned as NULL-terminated strings --- */
+		case DEVINFO_STR_NAME+0:						strcpy(info->s = device_temp_str(), "slot6disk1"); break;
+		case DEVINFO_STR_NAME+1:						strcpy(info->s = device_temp_str(), "slot6disk2"); break;
+		case DEVINFO_STR_SHORT_NAME+0:					strcpy(info->s = device_temp_str(), "s6d1"); break;
+		case DEVINFO_STR_SHORT_NAME+1:					strcpy(info->s = device_temp_str(), "s6d2"); break;
+		case DEVINFO_STR_DESCRIPTION+0:					strcpy(info->s = device_temp_str(), "Slot 6 Disk #1"); break;
+		case DEVINFO_STR_DESCRIPTION+1:					strcpy(info->s = device_temp_str(), "Slot 6 Disk #2"); break;
+
+		default:										apple525_device_getinfo(devclass, state, info); break;
+	}
 }
 
 SYSTEM_CONFIG_START(apple2_common)
 	CONFIG_DEVICE(apple2_floppy_getinfo)
-	CONFIG_QUEUE_CHARS			( AY3600 )
-	CONFIG_ACCEPT_CHAR			( AY3600 )
 SYSTEM_CONFIG_END
 
 SYSTEM_CONFIG_START(apple2)
@@ -897,17 +903,17 @@ SYSTEM_CONFIG_END
 
 
 
-/*     YEAR  NAME      PARENT    COMPAT		MACHINE   INPUT     INIT      CONFIG	COMPANY            FULLNAME */
-COMP ( 1977, apple2,   0,        0,			apple2,   apple2,   apple2,   apple2,	"Apple Computer", "Apple ][" )
-COMP ( 1979, apple2p,  apple2,   0,			apple2p,  apple2p,  apple2,   apple2p,	"Apple Computer", "Apple ][+" )
-COMP ( 1982, ace100,   apple2,   0,			apple2,	  apple2e,  apple2,   apple2,	"Franklin Computer", "Franklin Ace 100" )
-COMP ( 1983, apple2e,  0,        apple2,	apple2e,  apple2e,  apple2,   apple2e,	"Apple Computer", "Apple //e" )
-COMP ( 1985, apple2ee, apple2e,  0,			apple2ee, apple2e,  apple2,   apple2e,	"Apple Computer", "Apple //e (enhanced)" )
-COMP ( 1987, apple2ep, apple2e,  0,			apple2ee, apple2ep, apple2,   apple2e,	"Apple Computer", "Apple //e (Platinum)" )
-COMP ( 1984, apple2c,  0,        apple2,	apple2c,  apple2e,  apple2,   apple2e,	"Apple Computer", "Apple //c" )
-COMPX( 1983, las3000,  apple2,   0,			apple2p,  apple2p,  apple2,   apple2p,	"Video Technology", "Laser 3000",		GAME_NOT_WORKING )
-COMPX( 1987, laser128, 0,        apple2c0,  apple2c,  apple2e,  apple2,   apple2e,	"Video Technology", "Laser 128 (rev 4)",		GAME_NOT_WORKING )
-COMPX( 1987, las128ex, apple2c,  0,			apple2c,  apple2e,  apple2,   apple2e,	"Video Technology", "Laser 128ex (rev 4a)",		GAME_NOT_WORKING )
-COMP ( 1985, apple2c0, apple2c,  0,			apple2c,  apple2e,  apple2,   apple2e,	"Apple Computer", "Apple //c (UniDisk 3.5)" )
-COMP ( 1986, apple2c3, apple2c,  0,			apple2c,  apple2e,  apple2,   apple2e,	"Apple Computer", "Apple //c (Original Memory Expansion)" )
-COMP ( 1988, apple2cp, apple2c,  0,			apple2c,  apple2e,  apple2,   apple2e,	"Apple Computer", "Apple //c Plus" )
+/*    YEAR  NAME      PARENT    COMPAT		MACHINE   INPUT     INIT CONFIG		COMPANY            FULLNAME */
+COMP( 1977, apple2,   0,        0,			apple2,   apple2,   0,   apple2,	"Apple Computer", "Apple ][" , 0)
+COMP( 1979, apple2p,  apple2,   0,			apple2p,  apple2p,  0,   apple2p,	"Apple Computer", "Apple ][+" , 0)
+COMP( 1982, ace100,   apple2,   0,			apple2,	  apple2e,  0,   apple2,	"Franklin Computer", "Franklin Ace 100" , 0)
+COMP( 1983, apple2e,  0,        apple2,		apple2e,  apple2e,  0,   apple2e,	"Apple Computer", "Apple //e" , 0)
+COMP( 1985, apple2ee, apple2e,  0,			apple2ee, apple2e,  0,   apple2e,	"Apple Computer", "Apple //e (enhanced)" , 0)
+COMP( 1987, apple2ep, apple2e,  0,			apple2ee, apple2ep, 0,   apple2e,	"Apple Computer", "Apple //e (Platinum)" , 0)
+COMP( 1984, apple2c,  0,        apple2,		apple2c,  apple2e,  0,   apple2e,	"Apple Computer", "Apple //c" , 0)
+COMP( 1983, las3000,  apple2,   0,			apple2p,  apple2p,  0,   apple2p,	"Video Technology", "Laser 3000",		GAME_NOT_WORKING )
+COMP( 1987, laser128, 0,        apple2c0,	apple2c,  apple2e,  0,   apple2e,	"Video Technology", "Laser 128 (rev 4)",		GAME_NOT_WORKING )
+COMP( 1987, las128ex, apple2c,  0,			apple2c,  apple2e,  0,   apple2e,	"Video Technology", "Laser 128ex (rev 4a)",		GAME_NOT_WORKING )
+COMP( 1985, apple2c0, apple2c,  0,			apple2c,  apple2e,  0,   apple2e,	"Apple Computer", "Apple //c (UniDisk 3.5)" , 0)
+COMP( 1986, apple2c3, apple2c,  0,			apple2c,  apple2e,  0,	 apple2e,	"Apple Computer", "Apple //c (Original Memory Expansion)" , 0)
+COMP( 1988, apple2cp, apple2c,  0,			apple2c,  apple2e,  0,	 apple2e,	"Apple Computer", "Apple //c Plus" , 0)
