@@ -295,10 +295,10 @@ U102 23256 (read compatible 27256?) 32kB 1571 system rom
 
 #include "driver.h"
 #include "sound/sid6581.h"
+#include "machine/6526cia.h"
 
 #define VERBOSE_DBG 0
 #include "includes/cbm.h"
-#include "includes/cia6526.h"
 #include "includes/vic6567.h"
 #include "includes/vdc8563.h"
 #include "includes/cbmserb.h"
@@ -320,124 +320,72 @@ U102 23256 (read compatible 27256?) 32kB 1571 system rom
  * 0x0000-0xedff ram (dram bank 1?)
  * 0xe000-0xffff ram as bank 0
  */
-static ADDRESS_MAP_START( c128_z80_readmem , ADDRESS_SPACE_PROGRAM, 8)
+static ADDRESS_MAP_START(c128_z80_mem , ADDRESS_SPACE_PROGRAM, 8)
 #if 1
-	AM_RANGE(0x0000, 0x0fff) AM_READ( MRA8_BANK10)
-	AM_RANGE(0x1000, 0xbfff) AM_READ( MRA8_BANK11)
-	AM_RANGE(0xc000, 0xffff) AM_READ( MRA8_RAM)
+	AM_RANGE(0x0000, 0x0fff) AM_READWRITE(MRA8_BANK10, c128_write_0000)
+	AM_RANGE(0x1000, 0xbfff) AM_READWRITE(MRA8_BANK11, c128_write_1000)
+	AM_RANGE(0xc000, 0xffff) AM_RAM
 #else
 	/* best to do reuse bankswitching numbers */
-	AM_RANGE(0x0000, 0x03ff) AM_READ( MRA8_BANK10)
-	AM_RANGE(0x0400, 0x0fff) AM_READ( MRA8_BANK11)
-	AM_RANGE(0x1000, 0x1fff) AM_READ( MRA8_BANK3)
-	AM_RANGE(0x2000, 0x3fff) AM_READ( MRA8_BANK4)
-
-	AM_RANGE(0x4000, 0xbfff) AM_READ( MRA8_BANK5)
-	AM_RANGE(0xc000, 0xdfff) AM_READ( MRA8_BANK6)
-	AM_RANGE(0xe000, 0xefff) AM_READ( MRA8_BANK7)
-	AM_RANGE(0xf000, 0xfeff) AM_READ( MRA8_BANK8)
-	AM_RANGE(0xff00, 0xff04) AM_READ( c128_mmu8722_ff00_r)
-	AM_RANGE(0xff05, 0xffff) AM_READ( MRA8_BANK9)
-#endif
-ADDRESS_MAP_END
-
-static ADDRESS_MAP_START( c128_z80_writemem , ADDRESS_SPACE_PROGRAM, 8)
-#if 1
-	AM_RANGE(0x0000, 0x0fff) AM_WRITE( c128_write_0000) AM_BASE( &c64_memory)
-	AM_RANGE(0x1000, 0xbfff) AM_WRITE( c128_write_1000 )
-	AM_RANGE(0xc000, 0xffff) AM_WRITE( MWA8_RAM )
-#else
-	AM_RANGE(0x0000, 0x03ff) AM_WRITE( MWA8_BANK1) AM_BASE( &c64_memory)
-	AM_RANGE(0x0400, 0x0fff) AM_WRITE( MWA8_BANK2)
-	AM_RANGE(0x1000, 0x1fff) AM_WRITE( MWA8_BANK3)
-	AM_RANGE(0x2000, 0x3fff) AM_WRITE( MWA8_BANK4)
-	AM_RANGE(0x4000, 0xbfff) AM_WRITE( MWA8_BANK5)
-	AM_RANGE(0xc000, 0xdfff) AM_WRITE( MWA8_BANK6)
-	AM_RANGE(0xe000, 0xefff) AM_WRITE( MWA8_BANK7)
-	AM_RANGE(0xf000, 0xfeff) AM_WRITE( MWA8_BANK8)
-	AM_RANGE(0xff00, 0xff04) AM_WRITE( c128_mmu8722_ff00_w)
-	AM_RANGE(0xff05, 0xffff) AM_WRITE( MWA8_BANK9)
+	AM_RANGE(0x0000, 0x03ff) AM_READWRITE(MRA8_BANK10, MWA8_BANK1)
+	AM_RANGE(0x0400, 0x0fff) AM_READWRITE(MRA8_BANK11, MWA8_BANK2)
+	AM_RANGE(0x1000, 0x1fff) AM_RAMBANK(3)
+	AM_RANGE(0x2000, 0x3fff) AM_RAMBANK(4)
+	AM_RANGE(0x4000, 0xbfff) AM_RAMBANK(5)
+	AM_RANGE(0xc000, 0xdfff) AM_RAMBANK(6)
+	AM_RANGE(0xe000, 0xefff) AM_RAMBANK(7)
+	AM_RANGE(0xf000, 0xfeff) AM_RAMBANK(8)
+	AM_RANGE(0xff00, 0xff04) AM_READWRITE(c128_mmu8722_ff00_r, c128_mmu8722_ff00_w)
+	AM_RANGE(0xff05, 0xffff) AM_RAMBANK(9)
 #endif
 
 #if 0
-	AM_RANGE(0x10000, 0x1ffff) AM_WRITE( MWA8_RAM)
-	AM_RANGE(0x20000, 0xfffff) AM_WRITE( MWA8_RAM)	   /* or nothing */
-	AM_RANGE(0x100000, 0x107fff) AM_WRITE( MWA8_ROM) AM_BASE( &c128_basic)	/* maps to 0x4000 */
-	AM_RANGE(0x108000, 0x109fff) AM_WRITE( MWA8_ROM) AM_BASE( &c64_basic)	/* maps to 0xa000 */
-	AM_RANGE(0x10a000, 0x10bfff) AM_WRITE( MWA8_ROM) AM_BASE( &c64_kernal)	/* maps to 0xe000 */
-	AM_RANGE(0x10c000, 0x10cfff) AM_WRITE( MWA8_ROM) AM_BASE( &c128_editor)
-	AM_RANGE(0x10d000, 0x10dfff) AM_WRITE( MWA8_ROM) AM_BASE( &c128_z80)		/* maps to z80 0 */
-	AM_RANGE(0x10e000, 0x10ffff) AM_WRITE( MWA8_ROM) AM_BASE( &c128_kernal)
-	AM_RANGE(0x110000, 0x117fff) AM_WRITE( MWA8_ROM) AM_BASE( &c128_internal_function)
-	AM_RANGE(0x118000, 0x11ffff) AM_WRITE( MWA8_ROM) AM_BASE( &c128_external_function)
-	AM_RANGE(0x120000, 0x120fff) AM_WRITE( MWA8_ROM) AM_BASE( &c64_chargen)
-	AM_RANGE(0x121000, 0x121fff) AM_WRITE( MWA8_ROM) AM_BASE( &c128_chargen)
-	AM_RANGE(0x122000, 0x1227ff) AM_WRITE( MWA8_RAM) AM_BASE( &c64_colorram)
-	AM_RANGE(0x122800, 0x1327ff) AM_WRITE( MWA8_RAM) AM_BASE( &c128_vdcram)
+	AM_RANGE(0x10000, 0x1ffff) AM_WRITE(MWA8_RAM)
+	AM_RANGE(0x20000, 0xfffff) AM_WRITE(MWA8_RAM)	   /* or nothing */
+	AM_RANGE(0x100000, 0x107fff) AM_WRITE(MWA8_ROM) AM_BASE(&c128_basic)	/* maps to 0x4000 */
+	AM_RANGE(0x108000, 0x109fff) AM_WRITE(MWA8_ROM) AM_BASE(&c64_basic)	/* maps to 0xa000 */
+	AM_RANGE(0x10a000, 0x10bfff) AM_WRITE(MWA8_ROM) AM_BASE(&c64_kernal)	/* maps to 0xe000 */
+	AM_RANGE(0x10c000, 0x10cfff) AM_WRITE(MWA8_ROM) AM_BASE(&c128_editor)
+	AM_RANGE(0x10d000, 0x10dfff) AM_WRITE(MWA8_ROM) AM_BASE(&c128_z80)		/* maps to z80 0 */
+	AM_RANGE(0x10e000, 0x10ffff) AM_WRITE(MWA8_ROM) AM_BASE(&c128_kernal)
+	AM_RANGE(0x110000, 0x117fff) AM_WRITE(MWA8_ROM) AM_BASE(&c128_internal_function)
+	AM_RANGE(0x118000, 0x11ffff) AM_WRITE(MWA8_ROM) AM_BASE(&c128_external_function)
+	AM_RANGE(0x120000, 0x120fff) AM_WRITE(MWA8_ROM) AM_BASE(&c64_chargen)
+	AM_RANGE(0x121000, 0x121fff) AM_WRITE(MWA8_ROM) AM_BASE(&c128_chargen)
+	AM_RANGE(0x122000, 0x1227ff) AM_WRITE(MWA8_ROM) AM_BASE(&c64_colorram)
+	AM_RANGE(0x122800, 0x1327ff) AM_WRITE(MWA8_ROM) AM_BASE(&c128_vdcram)
 	/* 2 kbyte by 8 bits, only 1 kbyte by 4 bits used) */
 #endif
 ADDRESS_MAP_END
 
-static ADDRESS_MAP_START( c128_z80_readio , ADDRESS_SPACE_IO, 8)
-	ADDRESS_MAP_FLAGS( AMEF_ABITS(8) ) 
-	AM_RANGE(0x1000, 0x13ff) AM_READ( c64_colorram_read)
-	AM_RANGE(0xd000, 0xd3ff) AM_READ( vic2_port_r)
-	AM_RANGE(0xd400, 0xd4ff) AM_READ( sid6581_0_port_r)
-	AM_RANGE(0xd500, 0xd5ff) AM_READ( c128_mmu8722_port_r)
-	AM_RANGE(0xd600, 0xd7ff) AM_READ( vdc8563_port_r)
-	AM_RANGE(0xdc00, 0xdcff) AM_READ( cia6526_0_port_r)
-	AM_RANGE(0xdd00, 0xddff) AM_READ( cia6526_1_port_r)
-	/*{ 0xdf00, 0xdfff, dma_port_r }, */
+static ADDRESS_MAP_START( c128_z80_io , ADDRESS_SPACE_IO, 8)
+	AM_RANGE(0x1000, 0x13ff) AM_READWRITE(c64_colorram_read, c64_colorram_write)
+	AM_RANGE(0xd000, 0xd3ff) AM_READWRITE(vic2_port_r, vic2_port_w)
+	AM_RANGE(0xd400, 0xd4ff) AM_READWRITE(sid6581_0_port_r, sid6581_0_port_w)
+	AM_RANGE(0xd500, 0xd5ff) AM_READWRITE(c128_mmu8722_port_r, c128_mmu8722_port_w)
+	AM_RANGE(0xd600, 0xd7ff) AM_READWRITE(vdc8563_port_r, vdc8563_port_w)
+	AM_RANGE(0xdc00, 0xdcff) AM_READWRITE(cia_0_r, cia_0_w)
+	AM_RANGE(0xdd00, 0xddff) AM_READWRITE(cia_1_r, cia_1_w)
+/*	AM_RANGE(0xdf00, 0xdfff) AM_READWRITE(dma_port_r, dma_port_w) */
 ADDRESS_MAP_END
 
-static ADDRESS_MAP_START( c128_z80_writeio , ADDRESS_SPACE_IO, 8)
-	ADDRESS_MAP_FLAGS( AMEF_ABITS(8) ) 
-	AM_RANGE(0x1000, 0x13ff) AM_WRITE( c64_colorram_write)
-	AM_RANGE(0xd000, 0xd3ff) AM_WRITE( vic2_port_w)
-	AM_RANGE(0xd400, 0xd4ff) AM_WRITE( sid6581_0_port_w)
-	AM_RANGE(0xd500, 0xd5ff) AM_WRITE( c128_mmu8722_port_w)
-	AM_RANGE(0xd600, 0xd7ff) AM_WRITE( vdc8563_port_w)
-	AM_RANGE(0xdc00, 0xdcff) AM_WRITE( cia6526_0_port_w)
-	AM_RANGE(0xdd00, 0xddff) AM_WRITE( cia6526_1_port_w)
-	/*{ 0xdf00, 0xdfff, dma_port_w }, */
-ADDRESS_MAP_END
+static ADDRESS_MAP_START( c128_mem, ADDRESS_SPACE_PROGRAM, 8)
+	AM_RANGE(0x0000, 0x00ff) AM_RAMBANK(1)
+	AM_RANGE(0x0100, 0x01ff) AM_RAMBANK(2)
+	AM_RANGE(0x0200, 0x03ff) AM_RAMBANK(3)
+	AM_RANGE(0x0400, 0x0fff) AM_RAMBANK(4)
+	AM_RANGE(0x1000, 0x1fff) AM_RAMBANK(5)
+	AM_RANGE(0x2000, 0x3fff) AM_RAMBANK(6)
 
-static ADDRESS_MAP_START( c128_readmem , ADDRESS_SPACE_PROGRAM, 8)
-	AM_RANGE(0x0000, 0x0001) AM_READ( c64_m6510_port_r)
-	AM_RANGE(0x0002, 0x00ff) AM_READ( MRA8_BANK1)
-	AM_RANGE(0x0100, 0x01ff) AM_READ( MRA8_BANK2)
-	AM_RANGE(0x0200, 0x03ff) AM_READ( MRA8_BANK3)
-	AM_RANGE(0x0400, 0x0fff) AM_READ( MRA8_BANK4)
-	AM_RANGE(0x1000, 0x1fff) AM_READ( MRA8_BANK5)
-	AM_RANGE(0x2000, 0x3fff) AM_READ( MRA8_BANK6)
+	AM_RANGE(0x4000, 0x7fff) AM_READWRITE( MRA8_BANK7, c128_write_4000 )
+	AM_RANGE(0x8000, 0x9fff) AM_READWRITE( MRA8_BANK8, c128_write_8000 )
+	AM_RANGE(0xa000, 0xbfff) AM_READWRITE( MRA8_BANK9, c128_write_a000 )
 
-	AM_RANGE(0x4000, 0x7fff) AM_READ( MRA8_BANK7)
-	AM_RANGE(0x8000, 0x9fff) AM_READ( MRA8_BANK8)
-	AM_RANGE(0xa000, 0xbfff) AM_READ( MRA8_BANK9)
-
-	AM_RANGE(0xc000, 0xcfff) AM_READ( MRA8_BANK12)
-	AM_RANGE(0xd000, 0xdfff) AM_READ( MRA8_BANK13)
-	AM_RANGE(0xe000, 0xfeff) AM_READ( MRA8_BANK14)
-	AM_RANGE(0xff00, 0xff04) AM_READ( MRA8_BANK15)	   /* mmu c128 modus */
-	AM_RANGE(0xff05, 0xffff) AM_READ( MRA8_BANK16)
-ADDRESS_MAP_END
-
-static ADDRESS_MAP_START( c128_writemem , ADDRESS_SPACE_PROGRAM, 8)
-	AM_RANGE(0x0000, 0x0001) AM_WRITE( c64_m6510_port_w)
-	AM_RANGE(0x0002, 0x00ff) AM_WRITE( MWA8_BANK1)
-	AM_RANGE(0x0100, 0x01ff) AM_WRITE( MWA8_BANK2)
-	AM_RANGE(0x0200, 0x03ff) AM_WRITE( MWA8_BANK3)
-	AM_RANGE(0x0400, 0x0fff) AM_WRITE( MWA8_BANK4)
-	AM_RANGE(0x1000, 0x1fff) AM_WRITE( MWA8_BANK5)
-	AM_RANGE(0x2000, 0x3fff) AM_WRITE( MWA8_BANK6)
-
-	AM_RANGE(0x4000, 0x7fff) AM_WRITE( c128_write_4000)
-	AM_RANGE(0x8000, 0x9fff) AM_WRITE( c128_write_8000)
-	AM_RANGE(0xa000, 0xcfff) AM_WRITE( c128_write_a000)
-	AM_RANGE(0xd000, 0xdfff) AM_WRITE( c128_write_d000)
-	AM_RANGE(0xe000, 0xfeff) AM_WRITE( c128_write_e000)
-	AM_RANGE(0xff00, 0xff04) AM_WRITE( c128_write_ff00)
-	AM_RANGE(0xff05, 0xffff) AM_WRITE( c128_write_ff05)
+	AM_RANGE(0xc000, 0xcfff) AM_READWRITE( MRA8_BANK12, c128_write_c000 )
+	AM_RANGE(0xd000, 0xdfff) AM_READWRITE( MRA8_BANK13, c128_write_d000 )
+	AM_RANGE(0xe000, 0xfeff) AM_READWRITE( MRA8_BANK14, c128_write_e000 )
+	AM_RANGE(0xff00, 0xff04) AM_READWRITE( MRA8_BANK15, c128_write_ff00 )	   /* mmu c128 modus */
+	AM_RANGE(0xff05, 0xffff) AM_READWRITE( MRA8_BANK16, c128_write_ff05 )
 ADDRESS_MAP_END
 
 #define DIPS_HELPER(bit, name, keycode) \
@@ -475,12 +423,6 @@ ADDRESS_MAP_END
 	 /*PORT_DIPSETTING (0x10, "C64 CBM Supergames")*/\
 	 /*PORT_DIPSETTING (0x14, "C64 Ocean Robocop2")*/\
 	 /*PORT_DIPSETTING (0x1c, "C128")*/\
-	 PORT_DIPNAME (0x02, 0x02, "Serial Bus/Device 8")\
-	 PORT_DIPSETTING (0, DEF_STR( None ))\
-	 PORT_DIPSETTING (2, "VC1541 Floppy Drive")\
-	 PORT_DIPNAME (0x01, 0x01, "Serial Bus/Device 9")\
-	 PORT_DIPSETTING (0, DEF_STR( None ))\
-	 PORT_DIPSETTING (1, "VC1541 Floppy Drive")
 
 #define DIPS_KEYS_BOTH \
 	PORT_START \
@@ -1037,7 +979,7 @@ static PALETTE_INIT( c128 )
 	}
 }
 
-static struct GfxLayout c128_charlayout =
+static gfx_layout c128_charlayout =
 {
 	8,16,
 	512,                                    /* 256 characters */
@@ -1052,7 +994,7 @@ static struct GfxLayout c128_charlayout =
 	8*16
 };
 
-static struct GfxLayout c128graphic_charlayout =
+static gfx_layout c128graphic_charlayout =
 {
 	8,1,
 	256,                                    /* 256 characters */
@@ -1065,9 +1007,10 @@ static struct GfxLayout c128graphic_charlayout =
 	8
 };
 
-static struct GfxDecodeInfo c128_gfxdecodeinfo[] = {
-	{ 1, 0x0000, &c128_charlayout, 0, 0x100 },
-	{ 2, 0x0000, &c128graphic_charlayout, 0, 0x100 },
+static gfx_decode c128_gfxdecodeinfo[] =
+{
+	{ REGION_GFX1, 0x0000, &c128_charlayout, 0, 0x100 },
+	{ REGION_GFX2, 0x0000, &c128graphic_charlayout, 0, 0x100 },
     { -1 } /* end of array */
 };
 
@@ -1157,23 +1100,25 @@ ROM_START (c128)
 	ROM_LOAD ("318020.05", 0x10c000, 0x4000, CRC(ba456b8e) SHA1(ceb6e1a1bf7e08eb9cbc651afa29e26adccf38ab))
 	ROM_LOAD ("390059.01", 0x120000, 0x2000, CRC(6aaaafe6) SHA1(29ed066d513f2d5c09ff26d9166ba23c2afb2b3f))
 	ROM_REGION (0x10000, REGION_CPU2, 0)
-	ROM_REGION (0x100, REGION_GFX1, 0)
+	ROM_REGION (0x2000, REGION_GFX1, 0)
+	ROM_REGION (0x100, REGION_GFX2, 0)
 ROM_END
 
 ROM_START (c128d)
 	ROM_REGION (0x132800, REGION_CPU1, 0)
-	ROM_LOAD ("318022.02", 0x100000, 0x8000, CRC(af1ae1e8))
-	ROM_LOAD ("318023.02", 0x108000, 0x8000, CRC(eedc120a))
+	ROM_LOAD ("318022.02", 0x100000, 0x8000, CRC(af1ae1e8) SHA1(953dcdf5784a6b39ef84dd6fd968c7a03d8d6816))
+	ROM_LOAD ("318023.02", 0x108000, 0x8000, CRC(eedc120a) SHA1(f98c5a986b532c78bb68df9ec6dbcf876913b99f))
 	ROM_LOAD ("390059.01", 0x120000, 0x2000, CRC(6aaaafe6) SHA1(29ed066d513f2d5c09ff26d9166ba23c2afb2b3f))
 	ROM_REGION (0x10000, REGION_CPU2, 0)
 	C1571_ROM(REGION_CPU3)
-	ROM_REGION (0x100, REGION_GFX1, 0)
+	ROM_REGION (0x2000, REGION_GFX1, 0)
+	ROM_REGION (0x100, REGION_GFX2, 0)
 ROM_END
 
 /* submitted as cost reduced set! */
 ROM_START (c128dita)
 	ROM_REGION (0x132800, REGION_CPU1, 0)
-	ROM_LOAD ("318022.02", 0x100000, 0x8000, CRC(af1ae1e8))
+	ROM_LOAD ("318022.02", 0x100000, 0x8000, CRC(af1ae1e8) SHA1(953dcdf5784a6b39ef84dd6fd968c7a03d8d6816))
 
     /* in a cost reduced set this should be 1 rom */
 	ROM_LOAD ("251913.01", 0x108000, 0x4000, CRC(0010ec31))
@@ -1189,7 +1134,8 @@ ROM_START (c128dita)
 	ROM_REGION (0x10000, REGION_CPU2, 0)
     /* not included in submission */
 /*	C1571_ROM(REGION_CPU3) */
-	ROM_REGION (0x100, REGION_GFX1, 0)
+	ROM_REGION (0x2000, REGION_GFX1, 0)
+	ROM_REGION (0x100, REGION_GFX2, 0)
 ROM_END
 
 ROM_START (c128ger)
@@ -1199,7 +1145,8 @@ ROM_START (c128ger)
 	ROM_LOAD ("318077.01", 0x108000, 0x8000, CRC(eb6e2c8f) SHA1(6b3d891fedabb5335f388a5d2a71378472ea60f4))
 	ROM_LOAD ("315079.01", 0x120000, 0x2000, CRC(fe5a2db1) SHA1(638f8aff51c2ac4f99a55b12c4f8c985ef4bebd3))
 	ROM_REGION (0x10000, REGION_CPU2, 0)
-	ROM_REGION (0x100, REGION_GFX1, 0)
+	ROM_REGION (0x2000, REGION_GFX1, 0)
+	ROM_REGION (0x100, REGION_GFX2, 0)
 ROM_END
 
 ROM_START (c128fra)
@@ -1216,7 +1163,8 @@ ROM_START (c128fra)
 #endif
 	ROM_LOAD ("325167.01", 0x120000, 0x2000, CRC(bad36b88) SHA1(9119b27a1bf885fa4c76fff5d858c74c194dd2b8))
 	ROM_REGION (0x10000, REGION_CPU2, 0)
-	ROM_REGION (0x100, REGION_GFX1, 0)
+	ROM_REGION (0x2000, REGION_GFX1, 0)
+	ROM_REGION (0x100, REGION_GFX2, 0)
 ROM_END
 
 ROM_START (c128ita)
@@ -1228,7 +1176,8 @@ ROM_START (c128ita)
 	ROM_LOAD ("italian.bin", 0x10c000, 0x4000, CRC(74d6b084) SHA1(592a626eb2b5372596ac374d3505c3ce78dd040f))
 	ROM_LOAD ("325167.01", 0x120000, 0x2000, CRC(bad36b88) SHA1(9119b27a1bf885fa4c76fff5d858c74c194dd2b8))
 	ROM_REGION (0x10000, REGION_CPU2, 0)
-	ROM_REGION (0x100, REGION_GFX1, 0)
+	ROM_REGION (0x2000, REGION_GFX1, 0)
+	ROM_REGION (0x100, REGION_GFX2, 0)
 ROM_END
 
 ROM_START (c128swe)
@@ -1237,7 +1186,8 @@ ROM_START (c128swe)
 	ROM_LOAD ("318034.01", 0x108000, 0x8000, CRC(cb4e1719) SHA1(9b0a0cef56d00035c611e07170f051ee5e63aa3a))
 	ROM_LOAD ("325181.01", 0x120000, 0x2000, CRC(7a70d9b8) SHA1(aca3f7321ee7e6152f1f0afad646ae41964de4fb))
 	ROM_REGION (0x10000, REGION_CPU2, 0)
-	ROM_REGION (0x100, REGION_GFX1, 0)
+	ROM_REGION (0x2000, REGION_GFX1, 0)
+	ROM_REGION (0x100, REGION_GFX2, 0)
 ROM_END
 
 ROM_START (c128nor)
@@ -1249,10 +1199,11 @@ ROM_START (c128nor)
 	/* standard c64, vic20 based norwegian */
 	ROM_LOAD ("char.nor", 0x120000, 0x2000, BAD_DUMP CRC(ba95c625))
 	ROM_REGION (0x10000, REGION_CPU2, 0)
-	ROM_REGION (0x100, REGION_GFX1, 0)
+	ROM_REGION (0x2000, REGION_GFX1, 0)
+	ROM_REGION (0x100, REGION_GFX2, 0)
 ROM_END
 
-static SID6581_interface sound_interface =
+static SID6581_interface c128_sound_interface =
 {
 	c64_paddle_read
 };
@@ -1262,21 +1213,21 @@ static SID6581_interface sound_interface =
 static MACHINE_DRIVER_START( c128 )
 	/* basic machine hardware */
 	MDRV_CPU_ADD_TAG("main", Z80, VIC6567_CLOCK)
-	MDRV_CPU_PROGRAM_MAP( c128_z80_readmem, c128_z80_writemem )
-	MDRV_CPU_IO_MAP( c128_z80_readio, c128_z80_writeio )
+	MDRV_CPU_PROGRAM_MAP( c128_z80_mem, 0 )
+	MDRV_CPU_IO_MAP( c128_z80_io, 0 )
 	MDRV_CPU_VBLANK_INT(c64_frame_interrupt, 1)
-	MDRV_CPU_PERIODIC_INT(vic2_raster_irq, VIC2_HRETRACERATE)
+	MDRV_CPU_PERIODIC_INT(vic2_raster_irq, TIME_IN_HZ(VIC2_HRETRACERATE))
 
 	MDRV_CPU_ADD_TAG("m8502", M8502, VIC6567_CLOCK)
-	MDRV_CPU_PROGRAM_MAP( c128_readmem, c128_writemem )
+	MDRV_CPU_PROGRAM_MAP( c128_mem, 0 )
 	MDRV_CPU_VBLANK_INT(c64_frame_interrupt, 1)
-	MDRV_CPU_PERIODIC_INT(vic2_raster_irq, VIC2_HRETRACERATE)
+	MDRV_CPU_PERIODIC_INT(vic2_raster_irq, TIME_IN_HZ(VIC2_HRETRACERATE))
 
 	MDRV_FRAMES_PER_SECOND(VIC6567_VRETRACERATE)
 	MDRV_VBLANK_DURATION(DEFAULT_REAL_60HZ_VBLANK_DURATION)
 	MDRV_INTERLEAVE(0)
 
-	MDRV_MACHINE_INIT( c128 )
+	MDRV_MACHINE_RESET( c128 )
 
     /* video hardware */
 	/*MDRV_VIDEO_ATTRIBUTES(VIDEO_TYPE_RASTER)	//when it is supported in vic6567 */
@@ -1294,7 +1245,7 @@ static MACHINE_DRIVER_START( c128 )
 	/* sound hardware */
 	MDRV_SPEAKER_STANDARD_MONO("mono")
 	MDRV_SOUND_ADD_TAG("sid6581", SID6581, VIC6567_CLOCK)
-	MDRV_SOUND_CONFIG(sound_interface)
+	MDRV_SOUND_CONFIG(c128_sound_interface)
 	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.50)
 	MDRV_SOUND_ADD_TAG("dac", DAC, 0)
 	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.25)
@@ -1315,22 +1266,35 @@ static MACHINE_DRIVER_START( c128pal )
 
 	/* sound hardware */
 	MDRV_SOUND_REPLACE("sid6581", SID6581, VIC6569_CLOCK)
-	MDRV_SOUND_CONFIG(sound_interface)
+	MDRV_SOUND_CONFIG(c128_sound_interface)
 MACHINE_DRIVER_END
 
-#define init_c128 c128_driver_init
-#define init_c128pal c128pal_driver_init
-
-static void c128_cbmcartslot_getinfo(struct IODevice *dev)
+static void c128_cbmcartslot_getinfo(const device_class *devclass, UINT32 state, union devinfo *info)
 {
-	cbmcartslot_device_getinfo(dev);
-	dev->file_extensions = "crt\080\0";
+	switch(state)
+	{
+		/* --- the following bits of info are returned as NULL-terminated strings --- */
+		case DEVINFO_STR_FILE_EXTENSIONS:				strcpy(info->s = device_temp_str(), "crt,80"); break;
+
+		default:										cbmcartslot_device_getinfo(devclass, state, info); break;
+	}
 }
 
-static void c64_quickload_getinfo(struct IODevice *dev)
+static void c64_quickload_getinfo(const device_class *devclass, UINT32 state, union devinfo *info)
 {
-	quickload_device_getinfo(dev, quickload_load_cbm_c64, CBM_QUICKLOAD_DELAY);
-	dev->file_extensions = "p00\0prg\0";
+	switch(state)
+	{
+		/* --- the following bits of info are returned as NULL-terminated strings --- */
+		case DEVINFO_STR_FILE_EXTENSIONS:				strcpy(info->s = device_temp_str(), "p00,prg"); break;
+
+		/* --- the following bits of info are returned as pointers to data or functions --- */
+		case DEVINFO_PTR_QUICKLOAD_LOAD:				info->f = (genf *) quickload_load_cbm_c64; break;
+
+		/* --- the following bits of info are returned as doubles --- */
+		case DEVINFO_FLOAT_QUICKLOAD_DELAY:				info->d = CBM_QUICKLOAD_DELAY; break;
+
+		default:										quickload_device_getinfo(devclass, state, info); break;
+	}
 }
 
 SYSTEM_CONFIG_START(c128)
@@ -1348,14 +1312,14 @@ SYSTEM_CONFIG_START(c128d)
 SYSTEM_CONFIG_END
 
 /*	  YEAR	NAME		PARENT	COMPAT	MACHINE 	INPUT		INIT		CONFIG  COMPANY   FULLNAME */
-COMP (1985, c128,		0,		0,		c128,		c128,		c128,		c128,	"Commodore Business Machines Co.","Commodore 128 NTSC")
-COMP (1985, c128ger,	c128,	0,		c128pal,	c128ger,	c128pal,	c128,	"Commodore Business Machines Co.","Commodore 128 German (PAL)")
-COMP (1985, c128fra,	c128,	0,		c128pal,	c128fra,	c128pal,	c128,	"Commodore Business Machines Co.","Commodore 128 French (PAL)")
-COMP (1985, c128ita,	c128,	0,		c128pal,	c128ita,	c128pal,	c128,	"Commodore Business Machines Co.","Commodore 128 Italian (PAL)")
-COMP (1985, c128swe,	c128,	0,		c128pal,	c128swe,	c128pal,	c128,	"Commodore Business Machines Co.","Commodore 128 Swedish (PAL)")
+COMP (1985, c128,		0,		0,		c128,		c128,		c128,		c128,	"Commodore Business Machines Co.","Commodore 128 NTSC", 0)
+COMP (1985, c128ger,	c128,	0,		c128pal,	c128ger,	c128pal,	c128,	"Commodore Business Machines Co.","Commodore 128 German (PAL)", 0)
+COMP (1985, c128fra,	c128,	0,		c128pal,	c128fra,	c128pal,	c128,	"Commodore Business Machines Co.","Commodore 128 French (PAL)", 0)
+COMP (1985, c128ita,	c128,	0,		c128pal,	c128ita,	c128pal,	c128,	"Commodore Business Machines Co.","Commodore 128 Italian (PAL)", 0)
+COMP (1985, c128swe,	c128,	0,		c128pal,	c128swe,	c128pal,	c128,	"Commodore Business Machines Co.","Commodore 128 Swedish (PAL)", 0)
 /* other countries spanish, belgium, norwegian */
 /* please leave the following as testdriver */
-COMPX (1985, c128nor,	c128,	0,		c128pal,	c128ita,	c128pal,	c128,	"Commodore Business Machines Co.","Commodore 128 Norwegian (PAL)", GAME_NOT_WORKING)
-COMPX (1985, c128d,		c128,	0,		c128d,		c128,		c128,		c128d,	"Commodore Business Machines Co.","Commodore 128D NTSC", GAME_NOT_WORKING)
-/*COMPX(1985,c128dita,	c128,	0,		c128d,		c128,		c128,		c128d,	"Commodore Business Machines Co.","Commodore 128D Italian (PAL)", GAME_NOT_WORKING) */
-COMPX (1985, c128dita,	c128,	0,		c128pal,	c128ita,	c128pal,	c128d,	"Commodore Business Machines Co.","Commodore 128D Italian (PAL)", GAME_NOT_WORKING)
+COMP (1985, c128nor,	c128,	0,		c128pal,	c128ita,	c128pal,	c128,	"Commodore Business Machines Co.","Commodore 128 Norwegian (PAL)", GAME_NOT_WORKING)
+COMP (1985, c128d,		c128,	0,		c128d,		c128,		c128,		c128d,	"Commodore Business Machines Co.","Commodore 128D NTSC", GAME_NOT_WORKING)
+/*COMP(1985,c128dita,	c128,	0,		c128d,		c128,		c128,		c128d,	"Commodore Business Machines Co.","Commodore 128D Italian (PAL)", GAME_NOT_WORKING) */
+COMP (1985, c128dita,	c128,	0,		c128pal,	c128ita,	c128pal,	c128d,	"Commodore Business Machines Co.","Commodore 128D Italian (PAL)", GAME_NOT_WORKING)
