@@ -201,8 +201,7 @@ when problems start with -log and look into error.log file
  */
 
 static ADDRESS_MAP_START( c16_readmem , ADDRESS_SPACE_PROGRAM, 8)
-	AM_RANGE(0x0000, 0x0001) AM_READ( c16_m7501_port_r)
-	AM_RANGE(0x0002, 0x3fff) AM_READ( MRA8_RAM)
+	AM_RANGE(0x0000, 0x3fff) AM_READ( MRA8_BANK9)
 	AM_RANGE(0x4000, 0x7fff) AM_READ( MRA8_BANK1)	   /* only ram memory configuration */
 	AM_RANGE(0x8000, 0xbfff) AM_READ( MRA8_BANK2)
 	AM_RANGE(0xc000, 0xfbff) AM_READ( MRA8_BANK3)
@@ -220,13 +219,10 @@ static ADDRESS_MAP_START( c16_readmem , ADDRESS_SPACE_PROGRAM, 8)
 ADDRESS_MAP_END
 
 static ADDRESS_MAP_START( c16_writemem , ADDRESS_SPACE_PROGRAM, 8)
-	AM_RANGE(0x0000, 0x0001) AM_WRITE( c16_m7501_port_w) AM_BASE( &c16_memory)
-	AM_RANGE(0x0002, 0x3fff) AM_WRITE( MWA8_RAM)
-#ifndef NEW_BANKHANDLER
+	AM_RANGE(0x0000, 0x3fff) AM_WRITE( MWA8_BANK9)
 	AM_RANGE(0x4000, 0x7fff) AM_WRITE( MWA8_BANK5)
 	AM_RANGE(0x8000, 0xbfff) AM_WRITE( MWA8_BANK6)
 	AM_RANGE(0xc000, 0xfcff) AM_WRITE( MWA8_BANK7)
-#endif
 #if 0
 	AM_RANGE(0x4000, 0x7fff) AM_WRITE( c16_write_4000)  /*configured in c16_common_init */
 	AM_RANGE(0x8000, 0xbfff) AM_WRITE( c16_write_8000)  /*configured in c16_common_init */
@@ -254,8 +250,7 @@ static ADDRESS_MAP_START( c16_writemem , ADDRESS_SPACE_PROGRAM, 8)
 ADDRESS_MAP_END
 
 static ADDRESS_MAP_START( plus4_readmem , ADDRESS_SPACE_PROGRAM, 8)
-	AM_RANGE(0x0000, 0x0001) AM_READ( c16_m7501_port_r)
-	AM_RANGE(0x0002, 0x7fff) AM_READ( MRA8_RAM)
+	AM_RANGE(0x0000, 0x7fff) AM_READ( MRA8_BANK9)
 	AM_RANGE(0x8000, 0xbfff) AM_READ( MRA8_BANK2)
 	AM_RANGE(0xc000, 0xfbff) AM_READ( MRA8_BANK3)
 	AM_RANGE(0xfc00, 0xfcff) AM_READ( MRA8_BANK4)
@@ -273,8 +268,7 @@ static ADDRESS_MAP_START( plus4_readmem , ADDRESS_SPACE_PROGRAM, 8)
 ADDRESS_MAP_END
 
 static ADDRESS_MAP_START( plus4_writemem , ADDRESS_SPACE_PROGRAM, 8)
-	AM_RANGE(0x0000, 0x0001) AM_WRITE( c16_m7501_port_w) AM_BASE( &c16_memory)
-	AM_RANGE(0x0002, 0xfcff) AM_WRITE( MWA8_RAM)
+	AM_RANGE(0x0000, 0xfcff) AM_WRITE( MWA8_BANK9)
 	AM_RANGE(0xfd00, 0xfd0f) AM_WRITE( c16_6551_port_w)
 	AM_RANGE(0xfd10, 0xfd1f) AM_WRITE( plus4_6529_port_w)
 	AM_RANGE(0xfd30, 0xfd3f) AM_WRITE( c16_6529_port_w) /* 6529 keyboard matrix */
@@ -289,14 +283,13 @@ static ADDRESS_MAP_START( plus4_writemem , ADDRESS_SPACE_PROGRAM, 8)
 	AM_RANGE(0xff00, 0xff1f) AM_WRITE( ted7360_port_w)
 	AM_RANGE(0xff20, 0xff3d) AM_WRITE( MWA8_RAM)
 	AM_RANGE(0xff3e, 0xff3e) AM_WRITE( c16_switch_to_rom)
-	AM_RANGE(0xff3f, 0xff3f) AM_WRITE( plus4_switch_to_ram)
+	AM_RANGE(0xff3f, 0xff3f) AM_WRITE( c16_switch_to_ram)
 	AM_RANGE(0xff40, 0xffff) AM_WRITE( MWA8_RAM)
 /*	{0x10000, 0x3ffff, MWA8_ROM}, */
 ADDRESS_MAP_END
 
 static ADDRESS_MAP_START( c364_readmem , ADDRESS_SPACE_PROGRAM, 8)
-	AM_RANGE(0x0000, 0x0001) AM_READ( c16_m7501_port_r)
-	AM_RANGE(0x0002, 0x7fff) AM_READ( MRA8_RAM)
+	AM_RANGE(0x0000, 0x7fff) AM_READ( MRA8_BANK9)
 	AM_RANGE(0x8000, 0xbfff) AM_READ( MRA8_BANK2)
 	AM_RANGE(0xc000, 0xfbff) AM_READ( MRA8_BANK3)
 	AM_RANGE(0xfc00, 0xfcff) AM_READ( MRA8_BANK4)
@@ -315,8 +308,7 @@ static ADDRESS_MAP_START( c364_readmem , ADDRESS_SPACE_PROGRAM, 8)
 ADDRESS_MAP_END
 
 static ADDRESS_MAP_START( c364_writemem , ADDRESS_SPACE_PROGRAM, 8)
-	AM_RANGE(0x0000, 0x0001) AM_WRITE( c16_m7501_port_w) AM_BASE( &c16_memory)
-	AM_RANGE(0x0002, 0xfcff) AM_WRITE( MWA8_RAM)
+	AM_RANGE(0x0000, 0xfcff) AM_WRITE( MWA8_BANK9)
 	AM_RANGE(0xfd00, 0xfd0f) AM_WRITE( c16_6551_port_w)
 	AM_RANGE(0xfd10, 0xfd1f) AM_WRITE( plus4_6529_port_w)
 	AM_RANGE(0xfd20, 0xfd2f) AM_WRITE( c364_speech_w )
@@ -332,7 +324,7 @@ static ADDRESS_MAP_START( c364_writemem , ADDRESS_SPACE_PROGRAM, 8)
 	AM_RANGE(0xff00, 0xff1f) AM_WRITE( ted7360_port_w)
 	AM_RANGE(0xff20, 0xff3d) AM_WRITE( MWA8_RAM)
 	AM_RANGE(0xff3e, 0xff3e) AM_WRITE( c16_switch_to_rom)
-	AM_RANGE(0xff3f, 0xff3f) AM_WRITE( plus4_switch_to_ram)
+	AM_RANGE(0xff3f, 0xff3f) AM_WRITE( c16_switch_to_ram)
 	AM_RANGE(0xff40, 0xffff) AM_WRITE( MWA8_RAM)
 /*	{0x10000, 0x3ffff, MWA8_ROM}, */
 ADDRESS_MAP_END
@@ -473,10 +465,6 @@ INPUT_PORTS_START (c16)
 	PORT_DIPSETTING( 0x40, DEF_STR(On) )
 	PORT_BIT (0x10, 0x0, IPT_UNUSED)		   /* pal */
 	PORT_BIT (0xc, 0x0, IPT_UNUSED) 	   /* c16 */
-	PORT_DIPNAME (3, 3, "Memory")
-	PORT_DIPSETTING (0, "16 KByte")
-	PORT_DIPSETTING (2, "32 KByte")
-	PORT_DIPSETTING (3, "64 KByte")
 INPUT_PORTS_END
 
 INPUT_PORTS_START (c16c)
@@ -494,10 +482,6 @@ INPUT_PORTS_START (c16c)
 	PORT_DIPSETTING( 0x40, DEF_STR(On) )
 	PORT_BIT (0x10, 0x0, IPT_UNUSED)		   /* pal */
 	PORT_BIT (0xc, 0x0, IPT_UNUSED) 	   /* c16 */
-	PORT_DIPNAME (3, 3, "Memory")
-	PORT_DIPSETTING (0, "16 KByte")
-	PORT_DIPSETTING (2, "32 KByte")
-	PORT_DIPSETTING (3, "64 KByte")
 INPUT_PORTS_END
 
 INPUT_PORTS_START (c16v)
@@ -515,10 +499,6 @@ INPUT_PORTS_START (c16v)
 	PORT_DIPSETTING( 0x40, DEF_STR(On) )
 	PORT_BIT (0x10, 0x0, IPT_UNUSED)		   /* pal */
 	PORT_BIT (0xc, 0x0, IPT_UNUSED) 	   /* c16 */
-	PORT_DIPNAME (3, 3, "Memory")
-	PORT_DIPSETTING (0, "16 KByte")
-	PORT_DIPSETTING (2, "32 KByte")
-	PORT_DIPSETTING (3, "64 KByte")
 INPUT_PORTS_END
 
 INPUT_PORTS_START (plus4)
@@ -542,7 +522,6 @@ INPUT_PORTS_START (plus4)
 	PORT_DIPSETTING( 0x40, DEF_STR(On) )
 	PORT_BIT (0x10, 0x10, IPT_UNUSED)		   /* ntsc */
 	PORT_BIT (0xc, 0x4, IPT_UNUSED) 	   /* plus4 */
-	PORT_BIT (0x3, 0x3, IPT_UNUSED) 	   /* 64K Memory */
 INPUT_PORTS_END
 
 INPUT_PORTS_START (plus4c)
@@ -560,7 +539,6 @@ INPUT_PORTS_START (plus4c)
 	PORT_DIPSETTING( 0x40, DEF_STR(On) )
 	PORT_BIT (0x10, 0x10, IPT_UNUSED)		   /* ntsc */
 	PORT_BIT (0xc, 0x4, IPT_UNUSED) 	   /* plus4 */
-	PORT_BIT (0x3, 0x3, IPT_UNUSED) 	   /* 64K Memory */
 INPUT_PORTS_END
 
 INPUT_PORTS_START (plus4v)
@@ -578,7 +556,6 @@ INPUT_PORTS_START (plus4v)
 	PORT_DIPSETTING( 0x40, DEF_STR(On) )
 	PORT_BIT (0x10, 0x10, IPT_UNUSED)		   /* ntsc */
 	PORT_BIT (0xc, 0x4, IPT_UNUSED) 	   /* plus4 */
-	PORT_BIT (0x3, 0x3, IPT_UNUSED) 	   /* 64K Memory */
 INPUT_PORTS_END
 
 #if 0
@@ -603,7 +580,6 @@ INPUT_PORTS_START (c364)
 	PORT_DIPSETTING( 0x40, DEF_STR(On) )
 	PORT_BIT (0x10, 0x10, IPT_UNUSED)		   /* ntsc */
 	PORT_BIT (0xc, 0x8, IPT_UNUSED) 	   /* 364 */
-	PORT_BIT (0x3, 0x3, IPT_UNUSED) 	   /* 64K Memory */
 	 /* numeric block
 		hardware wired to other keys?
 		@ + - =
@@ -716,12 +692,12 @@ static MACHINE_DRIVER_START( c16 )
 	MDRV_CPU_ADD_TAG("main", M7501, 1400000)        /* 7.8336 Mhz */
 	MDRV_CPU_PROGRAM_MAP(c16_readmem, c16_writemem)
 	MDRV_CPU_VBLANK_INT(c16_frame_interrupt, 1)
-	MDRV_CPU_PERIODIC_INT(ted7360_raster_interrupt, TED7360_HRETRACERATE)
+	MDRV_CPU_PERIODIC_INT(ted7360_raster_interrupt, TIME_IN_HZ(TED7360_HRETRACERATE))
 	MDRV_FRAMES_PER_SECOND(TED7360PAL_VRETRACERATE)
 	MDRV_VBLANK_DURATION(DEFAULT_REAL_60HZ_VBLANK_DURATION)
 	MDRV_INTERLEAVE(1)
 
-	MDRV_MACHINE_INIT( c16 )
+	MDRV_MACHINE_RESET( c16 )
 
     /* video hardware */
 	MDRV_VIDEO_ATTRIBUTES(VIDEO_TYPE_RASTER)
@@ -731,7 +707,6 @@ static MACHINE_DRIVER_START( c16 )
 	MDRV_PALETTE_INIT(c16)
 
 	MDRV_VIDEO_START( ted7360 )
-	MDRV_VIDEO_STOP( ted7360 )
 	MDRV_VIDEO_UPDATE( ted7360 )
 
 	/* sound hardware */
@@ -816,19 +791,39 @@ MACHINE_DRIVER_END
 #define init_plus4v 	c16_driver_init
 #define init_c364		c16_driver_init
 
-static void c16cart_device_getinfo(struct IODevice *dev)
+static void c16cart_device_getinfo(const device_class *devclass, UINT32 state, union devinfo *info)
 {
-	cartslot_device_getinfo(dev);
-	dev->count = 2;
-	dev->file_extensions = "bin\0rom\0";
-	dev->load = device_load_c16_rom;
-	dev->unload = device_unload_c16_rom;
+	switch(state)
+	{
+		/* --- the following bits of info are returned as 64-bit signed integers --- */
+		case DEVINFO_INT_COUNT:							info->i = 2; break;
+
+		/* --- the following bits of info are returned as pointers to data or functions --- */
+		case DEVINFO_PTR_LOAD:							info->load = device_load_c16_rom; break;
+		case DEVINFO_PTR_UNLOAD:						info->unload = device_unload_c16_rom; break;
+
+		/* --- the following bits of info are returned as NULL-terminated strings --- */
+		case DEVINFO_STR_FILE_EXTENSIONS:				strcpy(info->s = device_temp_str(), "bin,rom"); break;
+
+		default:										cartslot_device_getinfo(devclass, state, info); break;
+	}
 }
 
-static void c16_quickload_getinfo(struct IODevice *dev)
+static void c16_quickload_getinfo(const device_class *devclass, UINT32 state, union devinfo *info)
 {
-	quickload_device_getinfo(dev, quickload_load_cbm_c16, CBM_QUICKLOAD_DELAY);
-	dev->file_extensions = "p00\0prg\0";
+	switch(state)
+	{
+		/* --- the following bits of info are returned as NULL-terminated strings --- */
+		case DEVINFO_STR_FILE_EXTENSIONS:				strcpy(info->s = device_temp_str(), "p00,prg"); break;
+
+		/* --- the following bits of info are returned as pointers to data or functions --- */
+		case DEVINFO_PTR_QUICKLOAD_LOAD:				info->f = (genf *) quickload_load_cbm_c16; break;
+
+		/* --- the following bits of info are returned as doubles --- */
+		case DEVINFO_FLOAT_QUICKLOAD_DELAY:				info->d = CBM_QUICKLOAD_DELAY; break;
+
+		default:										quickload_device_getinfo(devclass, state, info); break;
+	}
 }
 
 SYSTEM_CONFIG_START(c16)
@@ -836,6 +831,9 @@ SYSTEM_CONFIG_START(c16)
 	CONFIG_DEVICE(cbmfloppy_device_getinfo)
 	CONFIG_DEVICE(c16_quickload_getinfo)
 	CONFIG_DEVICE(vc20tape_device_getinfo)
+	CONFIG_RAM(16 * 1024)
+	CONFIG_RAM(32 * 1024)
+	CONFIG_RAM_DEFAULT(64 * 1024)
 SYSTEM_CONFIG_END
 
 SYSTEM_CONFIG_START(c16c)
@@ -843,6 +841,9 @@ SYSTEM_CONFIG_START(c16c)
 	CONFIG_DEVICE(c16_quickload_getinfo)
 	CONFIG_DEVICE(vc20tape_device_getinfo)
 	CONFIG_DEVICE(c1551_device_getinfo)
+	CONFIG_RAM(16 * 1024)
+	CONFIG_RAM(32 * 1024)
+	CONFIG_RAM_DEFAULT(64 * 1024)
 SYSTEM_CONFIG_END
 
 SYSTEM_CONFIG_START(c16v)
@@ -850,14 +851,41 @@ SYSTEM_CONFIG_START(c16v)
 	CONFIG_DEVICE(c16_quickload_getinfo)
 	CONFIG_DEVICE(vc20tape_device_getinfo)
 	CONFIG_DEVICE(vc1541_device_getinfo)
+	CONFIG_RAM(16 * 1024)
+	CONFIG_RAM(32 * 1024)
+	CONFIG_RAM_DEFAULT(64 * 1024)
+SYSTEM_CONFIG_END
+
+SYSTEM_CONFIG_START(plus)
+	CONFIG_DEVICE(c16cart_device_getinfo)
+	CONFIG_DEVICE(cbmfloppy_device_getinfo)
+	CONFIG_DEVICE(c16_quickload_getinfo)
+	CONFIG_DEVICE(vc20tape_device_getinfo)
+	CONFIG_RAM_DEFAULT(64 * 1024)
+SYSTEM_CONFIG_END
+
+SYSTEM_CONFIG_START(plusc)
+	CONFIG_DEVICE(c16cart_device_getinfo)
+	CONFIG_DEVICE(c16_quickload_getinfo)
+	CONFIG_DEVICE(vc20tape_device_getinfo)
+	CONFIG_DEVICE(c1551_device_getinfo)
+	CONFIG_RAM_DEFAULT(64 * 1024)
+SYSTEM_CONFIG_END
+
+SYSTEM_CONFIG_START(plusv)
+	CONFIG_DEVICE(c16cart_device_getinfo)
+	CONFIG_DEVICE(c16_quickload_getinfo)
+	CONFIG_DEVICE(vc20tape_device_getinfo)
+	CONFIG_DEVICE(vc1541_device_getinfo)
+	CONFIG_RAM_DEFAULT(64 * 1024)
 SYSTEM_CONFIG_END
 
 /*		YEAR	NAME	PARENT	COMPAT	MACHINE INPUT	INIT	CONFIG   COMPANY 								FULLNAME */
-COMP ( 1984,	c16,	0,		0,		c16,	c16,	c16,	c16,     "Commodore Business Machines Co.",      "Commodore 16/116/232/264 (PAL)")
-COMP ( 1984,	c16hun, c16,	0,		c16,	c16,	c16,	c16,     "Commodore Business Machines Co.",      "Commodore 16 Novotrade (PAL, Hungarian Character Set)")
-COMPX ( 1984,	c16c,	c16,	0,		c16c,	c16c,	c16,	c16c,    "Commodore Business Machines Co.",      "Commodore 16/116/232/264 (PAL), 1551", GAME_NOT_WORKING)
-COMP ( 1984,	plus4,	c16,	0,		plus4,	plus4,	plus4,	c16,     "Commodore Business Machines Co.",      "Commodore +4 (NTSC)")
-COMPX ( 1984,	plus4c, c16,	0,		plus4c, plus4c, plus4,	c16c,    "Commodore Business Machines Co.",      "Commodore +4 (NTSC), 1551", GAME_NOT_WORKING)
-COMPX ( 1984,	c364,	c16,	0,		c364,	plus4,	plus4,	c16,     "Commodore Business Machines Co.",      "Commodore 364 (Prototype)", GAME_IMPERFECT_SOUND)
-COMPX ( 1984,	c16v,	c16,	0,		c16v,	c16v,	c16,	c16v,    "Commodore Business Machines Co.",      "Commodore 16/116/232/264 (PAL), VC1541", GAME_NOT_WORKING)
-COMPX ( 1984,	plus4v, c16,	0,		plus4v, plus4v, plus4,	c16v,    "Commodore Business Machines Co.",      "Commodore +4 (NTSC), VC1541", GAME_NOT_WORKING)
+COMP ( 1984,	c16,	0,		0,		c16,	c16,	c16,	c16,     "Commodore Business Machines Co.",      "Commodore 16/116/232/264 (PAL)", 0)
+COMP ( 1984,	c16hun, c16,	0,		c16,	c16,	c16,	c16,     "Commodore Business Machines Co.",      "Commodore 16 Novotrade (PAL, Hungarian Character Set)", 0)
+COMP ( 1984,	c16c,	c16,	0,		c16c,	c16c,	c16,	c16c,    "Commodore Business Machines Co.",      "Commodore 16/116/232/264 (PAL), 1551", GAME_NOT_WORKING)
+COMP ( 1984,	plus4,	c16,	0,		plus4,	plus4,	plus4,	plus,    "Commodore Business Machines Co.",      "Commodore +4 (NTSC)", 0)
+COMP ( 1984,	plus4c, c16,	0,		plus4c, plus4c, plus4,	plusc,   "Commodore Business Machines Co.",      "Commodore +4 (NTSC), 1551", GAME_NOT_WORKING)
+COMP ( 1984,	c364,	c16,	0,		c364,	plus4,	plus4,	plusv,   "Commodore Business Machines Co.",      "Commodore 364 (Prototype)", GAME_IMPERFECT_SOUND)
+COMP ( 1984,	c16v,	c16,	0,		c16v,	c16v,	c16,	c16v,    "Commodore Business Machines Co.",      "Commodore 16/116/232/264 (PAL), VC1541", GAME_NOT_WORKING)
+COMP ( 1984,	plus4v, c16,	0,		plus4v, plus4v, plus4,	plusv,   "Commodore Business Machines Co.",      "Commodore +4 (NTSC), VC1541", GAME_NOT_WORKING)
