@@ -161,10 +161,10 @@ when problems start with -log and look into error.log file
 #include "vidhrdw/generic.h"
 #include "cpu/m6502/m6509.h"
 #include "sound/sid6581.h"
+#include "machine/6526cia.h"
 
 #define VERBOSE_DBG 0
 #include "includes/cbm.h"
-#include "includes/cia6526.h"
 #include "includes/tpi6525.h"
 #include "includes/vic6567.h"
 #include "includes/crtc6845.h"
@@ -237,7 +237,7 @@ static ADDRESS_MAP_START( cbmb_readmem , ADDRESS_SPACE_PROGRAM, 8)
 	/* disk units */
 	AM_RANGE(0xfda00, 0xfdaff) AM_READ( sid6581_0_port_r )
 	/* db00 coprocessor */
-	AM_RANGE(0xfdc00, 0xfdcff) AM_READ( cia6526_0_port_r )
+	AM_RANGE(0xfdc00, 0xfdcff) AM_READ( cia_0_r )
 	/* dd00 acia */
 	AM_RANGE(0xfde00, 0xfdeff) AM_READ( tpi6525_0_port_r)
 	AM_RANGE(0xfdf00, 0xfdfff) AM_READ( tpi6525_1_port_r)
@@ -303,7 +303,7 @@ static ADDRESS_MAP_START( cbmb_writemem , ADDRESS_SPACE_PROGRAM, 8)
 	/* disk units */
 	AM_RANGE(0xfda00, 0xfdaff) AM_WRITE( sid6581_0_port_w)
 	/* db00 coprocessor */
-	AM_RANGE(0xfdc00, 0xfdcff) AM_WRITE( cia6526_0_port_w)
+	AM_RANGE(0xfdc00, 0xfdcff) AM_WRITE( cia_0_w)
 	/* dd00 acia */
 	AM_RANGE(0xfde00, 0xfdeff) AM_WRITE( tpi6525_0_port_w)
 	AM_RANGE(0xfdf00, 0xfdfff) AM_WRITE( tpi6525_1_port_w)
@@ -374,7 +374,7 @@ static ADDRESS_MAP_START( cbm500_readmem , ADDRESS_SPACE_PROGRAM, 8)
 	/* disk units */
 	AM_RANGE(0xfda00, 0xfdaff) AM_READ( sid6581_0_port_r )
 	/* db00 coprocessor */
-	AM_RANGE(0xfdc00, 0xfdcff) AM_READ( cia6526_0_port_r )
+	AM_RANGE(0xfdc00, 0xfdcff) AM_READ( cia_0_r )
 	/* dd00 acia */
 	AM_RANGE(0xfde00, 0xfdeff) AM_READ( tpi6525_0_port_r)
 	AM_RANGE(0xfdf00, 0xfdfff) AM_READ( tpi6525_1_port_r)
@@ -441,7 +441,7 @@ static ADDRESS_MAP_START( cbm500_writemem , ADDRESS_SPACE_PROGRAM, 8)
 	/* disk units */
 	AM_RANGE(0xfda00, 0xfdaff) AM_WRITE( sid6581_0_port_w)
 	/* db00 coprocessor */
-	AM_RANGE(0xfdc00, 0xfdcff) AM_WRITE( cia6526_0_port_w)
+	AM_RANGE(0xfdc00, 0xfdcff) AM_WRITE( cia_0_w)
 	/* dd00 acia */
 	AM_RANGE(0xfde00, 0xfdeff) AM_WRITE( tpi6525_0_port_w)
 	AM_RANGE(0xfdf00, 0xfdfff) AM_WRITE( tpi6525_1_port_w)
@@ -686,7 +686,7 @@ static unsigned short cbmb_colortable[] = {
 	0, 1
 };
 
-static struct GfxLayout cbm600_charlayout =
+static gfx_layout cbm600_charlayout =
 {
 	8,16,
 	256,                                    /* 256 characters */
@@ -701,7 +701,7 @@ static struct GfxLayout cbm600_charlayout =
 	8*16
 };
 
-static struct GfxLayout cbm700_charlayout =
+static gfx_layout cbm700_charlayout =
 {
 	9,16,
 	256,                                    /* 256 characters */
@@ -716,15 +716,17 @@ static struct GfxLayout cbm700_charlayout =
 	8*16
 };
 
-static struct GfxDecodeInfo cbm600_gfxdecodeinfo[] = {
-	{ 1, 0x0000, &cbm600_charlayout, 0, 1 },
-	{ 1, 0x1000, &cbm600_charlayout, 0, 1 },
+static gfx_decode cbm600_gfxdecodeinfo[] =
+{
+	{ REGION_GFX1, 0x0000, &cbm600_charlayout, 0, 1 },
+	{ REGION_GFX1, 0x1000, &cbm600_charlayout, 0, 1 },
     { -1 } /* end of array */
 };
 
-static struct GfxDecodeInfo cbm700_gfxdecodeinfo[] = {
-	{ 1, 0x0000, &cbm700_charlayout, 0, 1 },
-	{ 1, 0x1000, &cbm700_charlayout, 0, 1 },
+static gfx_decode cbm700_gfxdecodeinfo[] =
+{
+	{ REGION_GFX1, 0x0000, &cbm700_charlayout, 0, 1 },
+	{ REGION_GFX1, 0x1000, &cbm700_charlayout, 0, 1 },
     { -1 } /* end of array */
 };
 
@@ -872,7 +874,7 @@ static MACHINE_DRIVER_START( cbm600 )
 	MDRV_VBLANK_DURATION(DEFAULT_REAL_60HZ_VBLANK_DURATION)
 	MDRV_INTERLEAVE(0)
 
-	MDRV_MACHINE_INIT( cbmb )
+	MDRV_MACHINE_RESET( cbmb )
 
     /* video hardware */
 #ifdef PET_TEST_CODE
@@ -917,12 +919,12 @@ static MACHINE_DRIVER_START( cbm500 )
 	/* basic machine hardware */
 	MDRV_CPU_ADD_TAG("main", M6509, VIC6567_CLOCK)        /* 7.8336 Mhz */
 	MDRV_CPU_PROGRAM_MAP(cbm500_readmem, cbm500_writemem)
-	MDRV_CPU_PERIODIC_INT(vic2_raster_irq, VIC2_HRETRACERATE)
+	MDRV_CPU_PERIODIC_INT(vic2_raster_irq, TIME_IN_HZ(VIC2_HRETRACERATE))
 	MDRV_FRAMES_PER_SECOND(VIC6567_VRETRACERATE)
 	MDRV_VBLANK_DURATION(DEFAULT_REAL_60HZ_VBLANK_DURATION)
 	MDRV_INTERLEAVE(0)
 
-	MDRV_MACHINE_INIT( cbmb )
+	MDRV_MACHINE_RESET( cbmb )
 
 	MDRV_IMPORT_FROM( vh_vic2 )
 
@@ -938,16 +940,32 @@ MACHINE_DRIVER_END
 #define init_cbm600pal cbm600pal_driver_init
 #define init_cbm700 cbm700_driver_init
 
-static void cbmb_cbmcartslot_getinfo(struct IODevice *dev)
+static void cbmb_cbmcartslot_getinfo(const device_class *devclass, UINT32 state, union devinfo *info)
 {
-	cbmcartslot_device_getinfo(dev);
-	dev->file_extensions = "crt\00010\00020\00040\00060\0";
+	switch(state)
+	{
+		/* --- the following bits of info are returned as NULL-terminated strings --- */
+		case DEVINFO_STR_FILE_EXTENSIONS:				strcpy(info->s = device_temp_str(), "crt,10,20,40,60"); break;
+
+		default:										cbmcartslot_device_getinfo(devclass, state, info); break;
+	}
 }
 
-static void cbmb_quickload_getinfo(struct IODevice *dev)
+static void cbmb_quickload_getinfo(const device_class *devclass, UINT32 state, union devinfo *info)
 {
-	quickload_device_getinfo(dev, quickload_load_cbmb, CBM_QUICKLOAD_DELAY);
-	dev->file_extensions = "p00\0prg\0";
+	switch(state)
+	{
+		/* --- the following bits of info are returned as NULL-terminated strings --- */
+		case DEVINFO_STR_FILE_EXTENSIONS:				strcpy(info->s = device_temp_str(), "p00,prg"); break;
+
+		/* --- the following bits of info are returned as pointers to data or functions --- */
+		case DEVINFO_PTR_QUICKLOAD_LOAD:				info->f = (genf *) quickload_load_cbmb; break;
+
+		/* --- the following bits of info are returned as doubles --- */
+		case DEVINFO_FLOAT_QUICKLOAD_DELAY:				info->d = CBM_QUICKLOAD_DELAY; break;
+
+		default:										quickload_device_getinfo(devclass, state, info); break;
+	}
 }
 
 SYSTEM_CONFIG_START(cbmb)
@@ -959,10 +977,21 @@ SYSTEM_CONFIG_START(cbmb)
 #endif
 SYSTEM_CONFIG_END
 
-static void cbm500_quickload_getinfo(struct IODevice *dev)
+static void cbm500_quickload_getinfo(const device_class *devclass, UINT32 state, union devinfo *info)
 {
-	quickload_device_getinfo(dev, quickload_load_cbm500, CBM_QUICKLOAD_DELAY);
-	dev->file_extensions = "p00\0prg\0";
+	switch(state)
+	{
+		/* --- the following bits of info are returned as NULL-terminated strings --- */
+		case DEVINFO_STR_FILE_EXTENSIONS:				strcpy(info->s = device_temp_str(), "p00,prg"); break;
+
+		/* --- the following bits of info are returned as pointers to data or functions --- */
+		case DEVINFO_PTR_QUICKLOAD_LOAD:				info->f = (genf *) quickload_load_cbm500; break;
+
+		/* --- the following bits of info are returned as doubles --- */
+		case DEVINFO_FLOAT_QUICKLOAD_DELAY:				info->d = CBM_QUICKLOAD_DELAY; break;
+
+		default:										quickload_device_getinfo(devclass, state, info); break;
+	}
 }
 
 SYSTEM_CONFIG_START(cbm500)
@@ -975,13 +1004,13 @@ SYSTEM_CONFIG_START(cbm500)
 SYSTEM_CONFIG_END
 
 /*     YEAR		NAME	  PARENT	COMPAT	MACHINE		INPUT		INIT		CONFIG  COMPANY								FULLNAME */
-COMPX (1983,	cbm500,	  0,		0,		cbm500,		cbm500,		cbm500,		cbm500,	"Commodore Business Machines Co.",	"Commodore B128-40/Pet-II/P500 60Hz",		GAME_NOT_WORKING)
-COMPX (1983,	cbm610,   0,		0,		cbm600, 	cbm600, 	cbm600, 	cbmb,	"Commodore Business Machines Co.",  "Commodore B128-80LP/610 60Hz",             GAME_NOT_WORKING)
-COMPX (1983,	cbm620,	  cbm610,	0,		cbm600pal,	cbm600pal,	cbm600pal,	cbmb,	"Commodore Business Machines Co.",	"Commodore B256-80LP/620 50Hz",	GAME_NOT_WORKING)
-COMPX (1983,	cbm620hu, cbm610,	0,		cbm600pal,	cbm600pal,	cbm600hu,	cbmb,	"Commodore Business Machines Co.",	"Commodore B256-80LP/620 Hungarian 50Hz",	GAME_NOT_WORKING)
-COMPX (1983,	cbm710,   cbm610,   0,		cbm700, 	cbm700, 	cbm700, 	cbmb,	"Commodore Business Machines Co.",  "Commodore B128-80HP/710",                  GAME_NOT_WORKING)
-COMPX (1983,	cbm720,	  cbm610,	0,		cbm700,		cbm700,		cbm700,		cbmb,	"Commodore Business Machines Co.",	"Commodore B256-80HP/720",					GAME_NOT_WORKING)
-COMPX (1983,	cbm720se, cbm610,	0,		cbm700,     cbm700,		cbm700,		cbmb,	"Commodore Business Machines Co.",	"Commodore B256-80HP/720 Swedish/Finnish",	GAME_NOT_WORKING)
+COMP (1983,	cbm500,	  0,		0,		cbm500,		cbm500,		cbm500,		cbm500,	"Commodore Business Machines Co.",	"Commodore B128-40/Pet-II/P500 60Hz",		GAME_NOT_WORKING)
+COMP (1983,	cbm610,   0,		0,		cbm600, 	cbm600, 	cbm600, 	cbmb,	"Commodore Business Machines Co.",  "Commodore B128-80LP/610 60Hz",             GAME_NOT_WORKING)
+COMP (1983,	cbm620,	  cbm610,	0,		cbm600pal,	cbm600pal,	cbm600pal,	cbmb,	"Commodore Business Machines Co.",	"Commodore B256-80LP/620 50Hz",	GAME_NOT_WORKING)
+COMP (1983,	cbm620hu, cbm610,	0,		cbm600pal,	cbm600pal,	cbm600hu,	cbmb,	"Commodore Business Machines Co.",	"Commodore B256-80LP/620 Hungarian 50Hz",	GAME_NOT_WORKING)
+COMP (1983,	cbm710,   cbm610,   0,		cbm700, 	cbm700, 	cbm700, 	cbmb,	"Commodore Business Machines Co.",  "Commodore B128-80HP/710",                  GAME_NOT_WORKING)
+COMP (1983,	cbm720,	  cbm610,	0,		cbm700,		cbm700,		cbm700,		cbmb,	"Commodore Business Machines Co.",	"Commodore B256-80HP/720",					GAME_NOT_WORKING)
+COMP (1983,	cbm720se, cbm610,	0,		cbm700,     cbm700,		cbm700,		cbmb,	"Commodore Business Machines Co.",	"Commodore B256-80HP/720 Swedish/Finnish",	GAME_NOT_WORKING)
 #if 0
-COMPX (1983,	cbm730,   cbm610,   0,		cbmbx, 		cbmb, 		cbmb, 		cbmb,    "Commodore Business Machines Co.",	"Commodore BX128-80HP/BX256-80HP/730", GAME_NOT_WORKING)
+COMP (1983,	cbm730,   cbm610,   0,		cbmbx, 		cbmb, 		cbmb, 		cbmb,    "Commodore Business Machines Co.",	"Commodore BX128-80HP/BX256-80HP/730", GAME_NOT_WORKING)
 #endif
