@@ -33,59 +33,33 @@ NMI
 #include "devices/cartslot.h"
 #include "sound/ay8910.h"
 
-static ADDRESS_MAP_START (readmem, ADDRESS_SPACE_PROGRAM, 8)
-	AM_RANGE( 0x0000, 0x3fff) AM_READ( MRA8_ROM )
-	AM_RANGE( 0x4000, 0x7fff) AM_READ( MRA8_RAM )
-/*	{ 0x8000, 0xbfff, MRA8_RAM },	// only if 32K RAM is enabled */
-/*	{ 0xc000, 0xdfff, MRA8_ROM },	// installed in cgenie_init_machine */
-/*	{ 0xe000, 0xefff, MRA8_ROM },	// installed in cgenie_init_machine */
-	AM_RANGE( 0xf000, 0xf3ff) AM_READ( cgenie_colorram_r )
-	AM_RANGE( 0xf400, 0xf7ff) AM_READ( cgenie_fontram_r	)
-	AM_RANGE( 0xf800, 0xf8ff) AM_READ( cgenie_keyboard_r )
-	AM_RANGE( 0xf900, 0xffdf) AM_READ( MRA8_NOP )
-	AM_RANGE( 0xffe0, 0xffe3) AM_READ( cgenie_irq_status_r )
-	AM_RANGE( 0xffe4, 0xffeb) AM_READ( MRA8_NOP )
-	AM_RANGE( 0xffec, 0xffec) AM_READ( cgenie_status_r )
-	AM_RANGE( 0xffe4, 0xffeb) AM_READ( MRA8_NOP )
-	AM_RANGE( 0xffed, 0xffed) AM_READ( cgenie_track_r )
-	AM_RANGE( 0xffee, 0xffee) AM_READ( cgenie_sector_r )
-	AM_RANGE( 0xffef, 0xffef) AM_READ( cgenie_data_r )
-	AM_RANGE( 0xfff0, 0xffff) AM_READ( MRA8_NOP )
+static ADDRESS_MAP_START (cgenie_mem, ADDRESS_SPACE_PROGRAM, 8)
+	AM_RANGE(0x0000, 0x3fff) AM_ROM
+/*	AM_RANGE(0x4000, 0xbfff) AM_RAM	// set up in MACHINE_START */
+/*	AM_RANGE(0xc000, 0xdfff) AM_ROM	// installed in cgenie_init_machine */
+/*	AM_RANGE(0xe000, 0xefff) AM_ROM	// installed in cgenie_init_machine */
+	AM_RANGE(0xf000, 0xf3ff) AM_READWRITE( cgenie_colorram_r, cgenie_colorram_w ) AM_BASE( &colorram )
+	AM_RANGE(0xf400, 0xf7ff) AM_READWRITE( cgenie_fontram_r, cgenie_fontram_w) AM_BASE( &cgenie_fontram )
+	AM_RANGE(0xf800, 0xf8ff) AM_READ( cgenie_keyboard_r )
+	AM_RANGE(0xf900, 0xffdf) AM_NOP
+	AM_RANGE(0xffe0, 0xffe3) AM_READWRITE( cgenie_irq_status_r, cgenie_motor_w )
+	AM_RANGE(0xffe4, 0xffeb) AM_NOP
+	AM_RANGE(0xffec, 0xffec) AM_READWRITE( cgenie_status_r, cgenie_command_w )
+	AM_RANGE(0xffe4, 0xffeb) AM_NOP
+	AM_RANGE(0xffec, 0xffec) AM_WRITE( cgenie_command_w )
+	AM_RANGE(0xffed, 0xffed) AM_READWRITE( cgenie_track_r, cgenie_track_w )
+	AM_RANGE(0xffee, 0xffee) AM_READWRITE( cgenie_sector_r, cgenie_sector_w )
+	AM_RANGE(0xffef, 0xffef) AM_READWRITE( cgenie_data_r, cgenie_data_w )
+	AM_RANGE(0xfff0, 0xffff) AM_NOP
 ADDRESS_MAP_END
 
-static ADDRESS_MAP_START (writemem, ADDRESS_SPACE_PROGRAM, 8)
-	AM_RANGE( 0x0000, 0x3fff) AM_WRITE( MWA8_ROM )
-	AM_RANGE( 0x4000, 0x7fff) AM_WRITE( cgenie_videoram_w) AM_BASE( &videoram )
-/*	{ 0x8000, 0xbfff, MWA8_RAM },	// only if 32K RAM is enabled */
-/*	{ 0xc000, 0xdfff, MWA8_ROM },	// installed in cgenie_init_machine */
-/*	{ 0xe000, 0xefff, MWA8_ROM },	// installed in cgenie_init_machine */
-	AM_RANGE( 0xf000, 0xf3ff) AM_WRITE( cgenie_colorram_w) AM_BASE( &colorram )
-	AM_RANGE( 0xf400, 0xf7ff) AM_WRITE( cgenie_fontram_w) AM_BASE( &cgenie_fontram )
-	AM_RANGE( 0xf800, 0xf8ff) AM_WRITE( MWA8_NOP )
-	AM_RANGE( 0xf900, 0xffdf) AM_WRITE( MWA8_NOP )
-	AM_RANGE( 0xffe0, 0xffe3) AM_WRITE( cgenie_motor_w )
-	AM_RANGE( 0xffe4, 0xffeb) AM_WRITE( MWA8_NOP )
-	AM_RANGE( 0xffec, 0xffec) AM_WRITE( cgenie_command_w )
-	AM_RANGE( 0xffed, 0xffed) AM_WRITE( cgenie_track_w )
-	AM_RANGE( 0xffee, 0xffee) AM_WRITE( cgenie_sector_w )
-	AM_RANGE( 0xffef, 0xffef) AM_WRITE( cgenie_data_w )
-	AM_RANGE( 0xfff0, 0xffff) AM_WRITE( MWA8_NOP )
-ADDRESS_MAP_END
-
-static ADDRESS_MAP_START (readport, ADDRESS_SPACE_IO, 8)
-	AM_RANGE( 0xf8, 0xf8) AM_READ( cgenie_sh_control_port_r )
-	AM_RANGE( 0xf9, 0xf9) AM_READ( cgenie_sh_data_port_r )
-	AM_RANGE( 0xfa, 0xfa) AM_READ( cgenie_index_r )
-	AM_RANGE( 0xfb, 0xfb) AM_READ( cgenie_register_r )
-	AM_RANGE( 0xff, 0xff) AM_READ( cgenie_port_ff_r )
-ADDRESS_MAP_END
-
-static ADDRESS_MAP_START (writeport, ADDRESS_SPACE_IO, 8)
-	AM_RANGE( 0xf8, 0xf8) AM_WRITE( cgenie_sh_control_port_w )
-	AM_RANGE( 0xf9, 0xf9) AM_WRITE( cgenie_sh_data_port_w )
-	AM_RANGE( 0xfa, 0xfa) AM_WRITE( cgenie_index_w )
-	AM_RANGE( 0xfb, 0xfb) AM_WRITE( cgenie_register_w )
-	AM_RANGE( 0xff, 0xff) AM_WRITE( cgenie_port_ff_w )
+static ADDRESS_MAP_START (cgenie_io, ADDRESS_SPACE_IO, 8)
+	ADDRESS_MAP_FLAGS( AMEF_ABITS(8) ) 
+	AM_RANGE(0xf8, 0xf8) AM_READWRITE( cgenie_sh_control_port_r, cgenie_sh_control_port_w )
+	AM_RANGE(0xf9, 0xf9) AM_READWRITE( cgenie_sh_data_port_r, cgenie_sh_data_port_w )
+	AM_RANGE(0xfa, 0xfa) AM_READWRITE( cgenie_index_r, cgenie_index_w )
+	AM_RANGE(0xfb, 0xfb) AM_READWRITE( cgenie_register_r, cgenie_register_w )
+	AM_RANGE(0xff, 0xff) AM_READWRITE( cgenie_port_ff_r, cgenie_port_ff_w )
 ADDRESS_MAP_END
 
 INPUT_PORTS_START( cgenie )
@@ -105,9 +79,6 @@ INPUT_PORTS_START( cgenie )
 	PORT_BIT(	  0x08, 0x08, IPT_DIPSWITCH_NAME) PORT_NAME("Virtual tape support") PORT_CODE(KEYCODE_F6) PORT_TOGGLE
 	PORT_DIPSETTING(	0x00, DEF_STR( Off ) )
 	PORT_DIPSETTING(	0x08, DEF_STR( On ) )
-	PORT_DIPNAME(	  0x04, 0x04, "Memory Size")
-	PORT_DIPSETTING(	0x04, "32K" )
-	PORT_DIPSETTING(	0x00, "16K" )
 	PORT_BIT(0x07, 0x07, IPT_UNUSED)
 
 /**************************************************************************
@@ -133,7 +104,7 @@ INPUT_PORTS_START( cgenie )
 ***************************************************************************/
 
 	PORT_START /* IN1 KEY ROW 0 */
-		PORT_BIT(0x01, 0x00, IPT_KEYBOARD) PORT_NAME("0.0: @   ")
+		PORT_BIT(0x01, 0x00, IPT_KEYBOARD) PORT_NAME("0.0: @")
 		PORT_BIT(0x02, 0x00, IPT_KEYBOARD) PORT_NAME("0.1: A  a") PORT_CODE(KEYCODE_A)
 		PORT_BIT(0x04, 0x00, IPT_KEYBOARD) PORT_NAME("0.2: B  b") PORT_CODE(KEYCODE_B)
 		PORT_BIT(0x08, 0x00, IPT_KEYBOARD) PORT_NAME("0.3: C  c") PORT_CODE(KEYCODE_C)
@@ -174,10 +145,10 @@ INPUT_PORTS_START( cgenie )
 		PORT_BIT(0x10, 0x00, IPT_KEYBOARD) PORT_NAME("3.4: \\  |") PORT_CODE(KEYCODE_ASTERISK)
 		PORT_BIT(0x20, 0x00, IPT_KEYBOARD) PORT_NAME("3.5: ]  }") PORT_CODE(KEYCODE_CLOSEBRACE)
 		PORT_BIT(0x40, 0x00, IPT_KEYBOARD) PORT_NAME("3.6: ^  ~") PORT_CODE(KEYCODE_TILDE)
-		PORT_BIT(0x80, 0x00, IPT_KEYBOARD) PORT_NAME("3.7: _   ") PORT_CODE(KEYCODE_EQUALS)
+		PORT_BIT(0x80, 0x00, IPT_KEYBOARD) PORT_NAME("3.7: _") PORT_CODE(KEYCODE_EQUALS)
 
 	PORT_START /* IN5 KEY ROW 4 */
-		PORT_BIT(0x01, 0x00, IPT_KEYBOARD) PORT_NAME("4.0: 0   ") PORT_CODE(KEYCODE_0)
+		PORT_BIT(0x01, 0x00, IPT_KEYBOARD) PORT_NAME("4.0: 0") PORT_CODE(KEYCODE_0)
 		PORT_BIT(0x02, 0x00, IPT_KEYBOARD) PORT_NAME("4.1: 1  !") PORT_CODE(KEYCODE_1)
 		PORT_BIT(0x04, 0x00, IPT_KEYBOARD) PORT_NAME("4.2: 2  \"") PORT_CODE(KEYCODE_2)
 		PORT_BIT(0x08, 0x00, IPT_KEYBOARD) PORT_NAME("4.3: 3  #") PORT_CODE(KEYCODE_3)
@@ -271,7 +242,7 @@ INPUT_PORTS_START( cgenie )
 	PORT_BIT(0x80, 0x00, IPT_UNKNOWN) PORT_NAME("Joy 2 [*]") PORT_CODE(JOYCODE_2_BUTTON1)
 INPUT_PORTS_END
 
-struct GfxLayout cgenie_charlayout =
+gfx_layout cgenie_charlayout =
 {
 	8,8,		   /* 8*8 characters */
 	384,		   /* 256 fixed + 128 defineable characters */
@@ -282,7 +253,7 @@ struct GfxLayout cgenie_charlayout =
 	8*8 		   /* every char takes 8 bytes */
 };
 
-static struct GfxLayout cgenie_gfxlayout =
+static gfx_layout cgenie_gfxlayout =
 {
 	8,8,			/* 4*8 characters */
 	256,			/* 256 graphics patterns */
@@ -293,7 +264,7 @@ static struct GfxLayout cgenie_gfxlayout =
 	8*8 			/* every char takes 8 bytes */
 };
 
-static struct GfxDecodeInfo cgenie_gfxdecodeinfo[] =
+static gfx_decode cgenie_gfxdecodeinfo[] =
 {
 	{ REGION_GFX1, 0, &cgenie_charlayout,	  0, 3*16},
 	{ REGION_GFX2, 0, &cgenie_gfxlayout, 3*16*2, 3*4},
@@ -402,17 +373,16 @@ static struct AY8910interface ay8910_interface =
 static MACHINE_DRIVER_START( cgenie )
 	/* basic machine hardware */
 	MDRV_CPU_ADD_TAG("main", Z80, 2216800)        /* 2,2168 Mhz */
-	MDRV_CPU_PROGRAM_MAP(readmem,writemem)
-	MDRV_CPU_IO_MAP(readport,writeport)
+	MDRV_CPU_PROGRAM_MAP(cgenie_mem, 0)
+	MDRV_CPU_IO_MAP(cgenie_io, 0)
 	MDRV_CPU_VBLANK_INT(cgenie_frame_interrupt,1)
-	MDRV_CPU_PERIODIC_INT(cgenie_timer_interrupt,40)
+	MDRV_CPU_PERIODIC_INT(cgenie_timer_interrupt, TIME_IN_HZ(40))
 	MDRV_FRAMES_PER_SECOND(60)
 	MDRV_VBLANK_DURATION(DEFAULT_REAL_60HZ_VBLANK_DURATION)
 	MDRV_INTERLEAVE(4)
 
-	MDRV_MACHINE_INIT( cgenie )
-	MDRV_MACHINE_STOP( cgenie )
-
+	MDRV_MACHINE_START( cgenie )
+	
     /* video hardware */
 	MDRV_VIDEO_ATTRIBUTES(VIDEO_TYPE_RASTER)
 	MDRV_SCREEN_SIZE(48*8, (32)*8)
@@ -444,6 +414,7 @@ ROM_START (cgenie)
 	ROM_REGION(0x13000,REGION_CPU1,0)
 	ROM_LOAD ("cgenie.rom",  0x00000, 0x4000, CRC(d359ead7) SHA1(d8c2fc389ad38c45fba0ed556a7d91abac5463f4))
 	ROM_LOAD ("cgdos.rom",   0x10000, 0x2000, CRC(2a96cf74) SHA1(6dcac110f87897e1ee7521aefbb3d77a14815893))
+	ROM_CART_LOAD(0, "rom\0", 0x12000, 0x1000, ROM_NOMIRROR | ROM_OPTIONAL)
 
 	ROM_REGION(0x0c00,REGION_GFX1,0)
 	ROM_LOAD ("cgenie1.fnt", 0x0000, 0x0800, CRC(4fed774a) SHA1(d53df8212b521892cc56be690db0bb474627d2ff))
@@ -453,41 +424,51 @@ ROM_START (cgenie)
 
 ROM_END
 
-static void cgenie_cartslot_getinfo(struct IODevice *dev)
-{
-	/* cartslot */
-	cartslot_device_getinfo(dev);
-	dev->count = 1;
-	dev->file_extensions = "rom\0";
-	dev->load = device_load_cgenie_cart;
-}
-
-static void cgenie_floppy_getinfo(struct IODevice *dev)
+static void cgenie_floppy_getinfo(const device_class *devclass, UINT32 state, union devinfo *info)
 {
 	/* floppy */
-	legacybasicdsk_device_getinfo(dev);
-	dev->count = 4;
-	dev->file_extensions = "dsk\0";
-	dev->load = device_load_cgenie_floppy;
+	switch(state)
+	{
+		/* --- the following bits of info are returned as 64-bit signed integers --- */
+		case DEVINFO_INT_COUNT:							info->i = 4; break;
+
+		/* --- the following bits of info are returned as pointers to data or functions --- */
+		case DEVINFO_PTR_LOAD:							info->load = device_load_cgenie_floppy; break;
+
+		/* --- the following bits of info are returned as NULL-terminated strings --- */
+		case DEVINFO_STR_FILE_EXTENSIONS:				strcpy(info->s = device_temp_str(), "dsk"); break;
+
+		default:										legacybasicdsk_device_getinfo(devclass, state, info); break;
+	}
 }
 
-static void cgenie_cassette_getinfo(struct IODevice *dev)
+static void cgenie_cassette_getinfo(const device_class *devclass, UINT32 state, union devinfo *info)
 {
 	/* cassette */
-	dev->type = IO_CASSETTE;
-	dev->count = 1;
-	dev->file_extensions = "cas\0";
-	dev->readable = 0;	/* INVALID */
-	dev->writeable = 0;	/* INVALID */
-	dev->creatable = 0;	/* INVALID */
-	dev->load = device_load_cgenie_cassette;
+	switch(state)
+	{
+		/* --- the following bits of info are returned as 64-bit signed integers --- */
+		case DEVINFO_INT_TYPE:							info->i = IO_CASSETTE; break;
+		case DEVINFO_INT_READABLE:						info->i = 0;	/* INVALID */ break;
+		case DEVINFO_INT_WRITEABLE:						info->i = 0;	/* INVALID */ break;
+		case DEVINFO_INT_CREATABLE:						info->i = 0;	/* INVALID */ break;
+		case DEVINFO_INT_COUNT:							info->i = 1; break;
+
+		/* --- the following bits of info are returned as pointers to data or functions --- */
+		case DEVINFO_PTR_LOAD:							info->load = device_load_cgenie_cassette; break;
+
+		/* --- the following bits of info are returned as NULL-terminated strings --- */
+		case DEVINFO_STR_FILE_EXTENSIONS:				strcpy(info->s = device_temp_str(), "cas"); break;
+	}
 }
 
 SYSTEM_CONFIG_START(cgenie)
-	CONFIG_DEVICE(cgenie_cartslot_getinfo)
+	CONFIG_DEVICE(cartslot_device_getinfo)
 	CONFIG_DEVICE(cgenie_floppy_getinfo)
 	CONFIG_DEVICE(cgenie_cassette_getinfo)
+	CONFIG_RAM_DEFAULT	(16 * 1024)
+	CONFIG_RAM			(32 * 1024)
 SYSTEM_CONFIG_END
 
 /*	  YEAR	NAME	  PARENT	COMPAT	MACHINE   INPUT 	INIT	  CONFIG     COMPANY	FULLNAME */
-COMP( 1982, cgenie,   0,		0,		cgenie,   cgenie,	cgenie,   cgenie,    "EACA Computers Ltd.",  "Colour Genie EG2000" )
+COMP( 1982, cgenie,   0,		0,		cgenie,   cgenie,	0,        cgenie,    "EACA Computers Ltd.",  "Colour Genie EG2000" , 0)
