@@ -25,7 +25,7 @@
 	  manual pp. 76 through 78. and User Guide p. 2-1 through 2-9.
 	Clock: mm58174 RTC
 
-	Raphael Nabet, 2003
+	Raphael Nabet, Brett Wyer, 2003-2005
 */
 
 #include "driver.h"
@@ -33,17 +33,16 @@
 #include "includes/concept.h"
 #include "devices/mflopimg.h"
 #include "formats/basicdsk.h"
+#include "devices/harddriv.h"
 
 static ADDRESS_MAP_START(concept_memmap, ADDRESS_SPACE_PROGRAM, 16)
+	AM_RANGE(0x000000, 0x000007) AM_ROM AM_REGION(REGION_CPU1, 0x010000) 	/* boot ROM mirror */
+	AM_RANGE(0x000008, 0x000fff) AM_RAM										/* static RAM */
+	AM_RANGE(0x010000, 0x011fff) AM_ROM AM_REGION(REGION_CPU1, 0x010000)	/* boot ROM */
+	AM_RANGE(0x020000, 0x021fff) AM_ROM										/* macsbugs ROM (optional) */
+	AM_RANGE(0x030000, 0x03ffff) AM_READWRITE(concept_io_r,concept_io_w)	/* I/O space */
 
-	AM_RANGE(0x000000, 0x000007) AM_READWRITE(MRA16_BANK1, MWA16_ROM)	/* boot ROM mirror */
-	AM_RANGE(0x000008, 0x000fff) AM_READWRITE(MRA16_RAM, MWA16_RAM)		/* static RAM */
-	AM_RANGE(0x010000, 0x011fff) AM_READWRITE(MRA16_ROM, MWA16_ROM)		/* boot ROM */
-	AM_RANGE(0x020000, 0x021fff) AM_READWRITE(MRA16_ROM, MWA16_ROM)		/* macsbugs ROM (optional) */
-	AM_RANGE(0x030000, 0x03ffff) AM_READWRITE(concept_io_r,concept_io_w)/* I/O space */
-
-	AM_RANGE(0x080000, 0x0fffff) AM_READWRITE(/*MRA16_BANK2, MWA16_BANK2*/MRA16_RAM, MWA16_RAM)	/* DRAM */
-
+	AM_RANGE(0x080000, 0x0fffff) AM_RAM AM_BASE(&videoram16)/* AM_RAMBANK(2) */	/* DRAM */
 ADDRESS_MAP_END
 
 /* init with simple, fixed, B/W palette */
@@ -64,7 +63,7 @@ static MACHINE_DRIVER_START( concept )
 	MDRV_FRAMES_PER_SECOND(60)			/* 50 or 60, jumper-selectable */
 	MDRV_VBLANK_DURATION(DEFAULT_REAL_60HZ_VBLANK_DURATION)
 	MDRV_INTERLEAVE(1)
-	MDRV_MACHINE_INIT(concept)
+	MDRV_MACHINE_RESET(concept)
 
 	MDRV_VIDEO_ATTRIBUTES(VIDEO_TYPE_RASTER | VIDEO_UPDATE_BEFORE_VBLANK)
 	MDRV_SCREEN_SIZE(720, 560)
@@ -186,7 +185,39 @@ INPUT_PORTS_START( concept )
 		PORT_BIT(0x1000, IP_ACTIVE_HIGH, IPT_KEYBOARD) PORT_NAME("F10") PORT_CODE(KEYCODE_F10)
 		PORT_BIT(0x2000, IP_ACTIVE_HIGH, IPT_KEYBOARD) PORT_NAME("(up)") PORT_CODE(KEYCODE_UP)
 		PORT_BIT(0x4000, IP_ACTIVE_HIGH, IPT_KEYBOARD) PORT_NAME("???") PORT_CODE(KEYCODE_SLASH_PAD)
-		PORT_BIT(0x8000, IP_ACTIVE_HIGH, IPT_KEYBOARD) PORT_NAME("BREAK") PORT_CODE(KEYCODE_NUMLOCK)
+		PORT_BIT(0x8000, IP_ACTIVE_HIGH, IPT_KEYBOARD) PORT_NAME("BREAK") PORT_CODE(KEYCODE_PAUSE)
+
+	PORT_START	/* port 6: on-board DIP switches */
+		PORT_DIPNAME(0x01, 0x00, "Omninet Address bit 0")
+		PORT_DIPSETTING(0x00, DEF_STR( Off ))
+		PORT_DIPSETTING(0x01, DEF_STR( On ))
+		PORT_DIPNAME(0x02, 0x02, "Omninet Address bit 1")
+		PORT_DIPSETTING(0x00, DEF_STR( Off ))
+		PORT_DIPSETTING(0x02, DEF_STR( On ))
+		PORT_DIPNAME(0x04, 0x00, "Omninet Address bit 2")
+		PORT_DIPSETTING(0x00, DEF_STR( Off ))
+		PORT_DIPSETTING(0x04, DEF_STR( On ))
+		PORT_DIPNAME(0x08, 0x00, "Omninet Address bit 3")
+		PORT_DIPSETTING(0x00, DEF_STR( Off ))
+		PORT_DIPSETTING(0x08, DEF_STR( On ))
+		PORT_DIPNAME(0x10, 0x00, "Omninet Address bit 4")
+		PORT_DIPSETTING(0x00, DEF_STR( Off ))
+		PORT_DIPSETTING(0x10, DEF_STR( On ))
+		PORT_DIPNAME(0x20, 0x00, "Omninet Address bit 5")
+		PORT_DIPSETTING(0x00, DEF_STR( Off ))
+		PORT_DIPSETTING(0x20, DEF_STR( On ))
+		PORT_DIPNAME(0xc0, 0x00, "Type of Boot")
+		PORT_DIPSETTING(0x00, "Prompt fo type of Boot")		/* Documentation has 0x00 and 0xc0 reversed per boot PROM */
+		PORT_DIPSETTING(0x40, "Boot from Omninet")
+		PORT_DIPSETTING(0x80, "Boot from Local Disk")
+		PORT_DIPSETTING(0xc0, "Boot from Diskette")
+
+#if 0
+	PORT_START	/* port 7: Display orientation */
+		PORT_DIPNAME(0x01, 0x00, "Screen Orientation")
+		PORT_DIPSETTING(0x00, "Horizontal")
+		PORT_DIPSETTING(0x01, "Vertical")
+#endif
 
 INPUT_PORTS_END
 
@@ -203,10 +234,10 @@ ROM_START( concept )
 	/* version 1 lvl 7 release */
 	ROM_LOAD16_BYTE("bootl17h", 0x010000, 0x1000, CRC(6dd9718f))
 	ROM_LOAD16_BYTE("bootl17l", 0x010001, 0x1000, CRC(107a3830))
-#elif 0
+#elif 1
 	/* version 0 lvl 8 release */
-	ROM_LOAD16_BYTE("bootl08h", 0x010000, 0x1000, CRC(ee479f51))
-	ROM_LOAD16_BYTE("bootl08l", 0x010001, 0x1000, CRC(acaefd07))
+	ROM_LOAD16_BYTE("bootl08h", 0x010000, 0x1000, CRC(ee479f51) SHA1(b20ba18564672196076e46507020c6d69a640a2f))
+	ROM_LOAD16_BYTE("bootl08l", 0x010001, 0x1000, CRC(acaefd07) SHA1(de0c7eaacaf4c0652aa45e523cebce2b2993c437))
 #else
 	/* version $F lvl 8 (development version found on a floppy disk along with */
 	/* the source code) */
@@ -267,18 +298,39 @@ static FLOPPY_OPTIONS_START(concept)
 #endif
 FLOPPY_OPTIONS_END
 
-static void concept_floppy_getinfo(struct IODevice *dev)
+static void concept_floppy_getinfo(const device_class *devclass, UINT32 state, union devinfo *info)
 {
 	/* floppy */
-	floppy_device_getinfo(dev, floppyoptions_concept);
-	dev->count = 4;
+	switch(state)
+	{
+		/* --- the following bits of info are returned as 64-bit signed integers --- */
+		case DEVINFO_INT_COUNT:							info->i = 4; break;
+
+		/* --- the following bits of info are returned as pointers to data or functions --- */
+		case DEVINFO_PTR_FLOPPY_OPTIONS:				info->p = (void *) floppyoptions_concept; break;
+
+		default:										floppy_device_getinfo(devclass, state, info); break;
+	}
+}
+
+static void concept_harddisk_getinfo(const device_class *devclass, UINT32 state, union devinfo *info)
+{
+	/* Hard Drive */
+	switch(state)
+	{
+		/* --- the following bits of info are returned as 64-bit signed integers --- */
+		case DEVINFO_INT_COUNT:							info->i = 1; break;
+
+		default:										harddisk_device_getinfo(devclass, state, info); break;
+	}
 }
 
 SYSTEM_CONFIG_START(concept)
 	/* The concept should eventually support floppies, hard disks, etc. */
 	CONFIG_DEVICE(concept_floppy_getinfo)
+	CONFIG_DEVICE(concept_harddisk_getinfo)
 SYSTEM_CONFIG_END
 
 
 /*	  YEAR  NAME	  PARENT	COMPAT	MACHINE   INPUT	   INIT	 CONFIG   COMPANY           FULLNAME */
-COMP( 1982, concept,  0,		0,		concept,  concept, 0,    concept, "Corvus Systems", "Concept" )
+COMP( 1982, concept,  0,		0,		concept,  concept, 0,    concept, "Corvus Systems", "Concept" , 0)
