@@ -29,23 +29,16 @@ Changes:
 #include "cpu/z80/z80.h"
 #include "vidhrdw/generic.h"
 #include "includes/coupe.h"
-#include "includes/wd179x.h"
+#include "machine/wd17xx.h"
 #include "devices/basicdsk.h"
 #include "sound/saa1099.h"
 #include "sound/speaker.h"
 
-ADDRESS_MAP_START( coupe_readmem , ADDRESS_SPACE_PROGRAM, 8)
-	AM_RANGE( 0x0000, 0x3FFF) AM_READ( MRA8_BANK1 )
-	AM_RANGE( 0x4000, 0x7FFF) AM_READ( MRA8_BANK2 )
-	AM_RANGE( 0x8000, 0xBFFF) AM_READ( MRA8_BANK3 )
-	AM_RANGE( 0xC000, 0xFFFF) AM_READ( MRA8_BANK4 )
-ADDRESS_MAP_END
-
-ADDRESS_MAP_START( coupe_writemem , ADDRESS_SPACE_PROGRAM, 8)
-	AM_RANGE( 0x0000, 0x3FFF) AM_WRITE( MWA8_BANK1 )
-	AM_RANGE( 0x4000, 0x7FFF) AM_WRITE( MWA8_BANK2 )
-	AM_RANGE( 0x8000, 0xBFFF) AM_WRITE( MWA8_BANK3 )
-	AM_RANGE( 0xC000, 0xFFFF) AM_WRITE( MWA8_BANK4 )
+ADDRESS_MAP_START( coupe_mem , ADDRESS_SPACE_PROGRAM, 8)
+	AM_RANGE( 0x0000, 0x3FFF) AM_RAMBANK(1)
+	AM_RANGE( 0x4000, 0x7FFF) AM_RAMBANK(2)
+	AM_RANGE( 0x8000, 0xBFFF) AM_RAMBANK(3)
+	AM_RANGE( 0xC000, 0xFFFF) AM_RAMBANK(4)
 ADDRESS_MAP_END
 
 static INTERRUPT_GEN( coupe_line_interrupt )
@@ -154,7 +147,7 @@ static unsigned char getSamKey2(unsigned char hi)
 }
 
 
-static  READ8_HANDLER( coupe_port_r )
+static READ8_HANDLER( coupe_port_r )
 {
     if (offset==SSND_ADDR)  /* Sound address request */
 		return SOUND_ADDR;
@@ -270,7 +263,6 @@ static WRITE8_HANDLER( coupe_port_w )
 }
 
 ADDRESS_MAP_START( coupe_io , ADDRESS_SPACE_IO, 8)	
-	ADDRESS_MAP_FLAGS( AMEF_ABITS(8) ) 
 	AM_RANGE( 0x0000, 0x0ffff) AM_READWRITE( coupe_port_r, coupe_port_w )
 ADDRESS_MAP_END
 
@@ -416,14 +408,14 @@ static PALETTE_INIT( coupe )
 static MACHINE_DRIVER_START( coupe )
 	/* basic machine hardware */
 	MDRV_CPU_ADD(Z80, 6000000)        /* 6 Mhz */
-	MDRV_CPU_PROGRAM_MAP(coupe_readmem,coupe_writemem)
+	MDRV_CPU_PROGRAM_MAP(coupe_mem, 0)
 	MDRV_CPU_IO_MAP(coupe_io, 0)
 	MDRV_CPU_VBLANK_INT(coupe_line_interrupt, 192 + 10)	/* 192 scanlines + 10 lines of vblank (approx).. */
 	MDRV_FRAMES_PER_SECOND(50)
 	MDRV_VBLANK_DURATION(0)
 	MDRV_INTERLEAVE(1)
 
-	MDRV_MACHINE_INIT( coupe )
+	MDRV_MACHINE_RESET( coupe )
 
     /* video hardware */
 	MDRV_VIDEO_ATTRIBUTES(VIDEO_TYPE_RASTER)
@@ -457,13 +449,22 @@ ROM_START(coupe)
 	ROM_LOAD("sam_rom1.rom", 0x4000, 0x4000, CRC(F031AED4) SHA1(a7f06facc6f0a3713215f4befc307914836706a4))
 ROM_END
 
-static void coupe_floppy_getinfo(struct IODevice *dev)
+static void coupe_floppy_getinfo(const device_class *devclass, UINT32 state, union devinfo *info)
 {
 	/* floppy */
-	legacybasicdsk_device_getinfo(dev);
-	dev->count = 2;
-	dev->file_extensions = "dsk\0";
-	dev->load = device_load_coupe_floppy;
+	switch(state)
+	{
+		/* --- the following bits of info are returned as 64-bit signed integers --- */
+		case DEVINFO_INT_COUNT:							info->i = 2; break;
+
+		/* --- the following bits of info are returned as pointers to data or functions --- */
+		case DEVINFO_PTR_LOAD:							info->load = device_load_coupe_floppy; break;
+
+		/* --- the following bits of info are returned as NULL-terminated strings --- */
+		case DEVINFO_STR_FILE_EXTENSIONS:				strcpy(info->s = device_temp_str(), "dsk"); break;
+
+		default:										legacybasicdsk_device_getinfo(devclass, state, info); break;
+	}
 }
 
 SYSTEM_CONFIG_START(coupe)
@@ -474,4 +475,4 @@ SYSTEM_CONFIG_START(coupe)
 SYSTEM_CONFIG_END
 
 /*    YEAR  NAME      PARENT	COMPAT	MACHINE         INPUT     INIT  CONFIG  COMPANY                 		  FULLNAME */
-COMP( 1989, coupe,	  0,		0,		coupe,			coupe,	  0,	coupe,	"Miles Gordon Technology plc",    "Sam Coupe" )
+COMP( 1989, coupe,	  0,		0,		coupe,			coupe,	  0,	coupe,	"Miles Gordon Technology plc",    "Sam Coupe" , 0)
