@@ -65,7 +65,7 @@ static int video_start_exelv(void)
 	return tms3556_init(/*0x8000*/0x10000);	/* tms3556 with 32 kb of video RAM */
 }
 
-static void machine_init_exelv(void)
+static void machine_reset_exelv(void)
 {
 	tms3556_reset();
 	io_reset();
@@ -81,7 +81,7 @@ static void exelv_hblank_interrupt(void)
 	return INIT_PASS;
 }
 
-static DEVICE_UNLOAD(exelv_cart)
+static void device_unload_exelv_cart(mess_image *image)
 {
 }*/
 
@@ -555,7 +555,7 @@ static MACHINE_DRIVER_START(exelv)
 	MDRV_VBLANK_DURATION(DEFAULT_REAL_60HZ_VBLANK_DURATION)
 	/*MDRV_INTERLEAVE(interleave)*/
 
-	MDRV_MACHINE_INIT( exelv )
+	MDRV_MACHINE_RESET( exelv )
 	/*MDRV_NVRAM_HANDLER( NULL )*/
 
 	/* video hardware */
@@ -586,5 +586,5 @@ SYSTEM_CONFIG_START(exelv)
 SYSTEM_CONFIG_END
 
 /*		YEAR	NAME	PARENT		COMPAT	MACHINE		INPUT	INIT	CONFIG		COMPANY			FULLNAME */
-/*COMP(	1984,	exl100,	0,			0,		exelv,		exelv,	NULL,	exelv,		"Exelvision",	"exl 100" )*/
-COMP(	1986,	exeltel,0/*exl100*/,0,		exelv,		exelv,	NULL,	exelv,		"Exelvision",	"exeltel" )
+/*COMP(	1984,	exl100,	0,			0,		exelv,		exelv,	NULL,	exelv,		"Exelvision",	"exl 100" , 0)*/
+COMP(	1986,	exeltel,0/*exl100*/,0,		exelv,		exelv,	NULL,	exelv,		"Exelvision",	"exeltel" , 0)
