@@ -13,26 +13,16 @@
 #include "includes/kaypro.h"
 #include "devices/basicdsk.h"
 
-static ADDRESS_MAP_START( readmem_kaypro , ADDRESS_SPACE_PROGRAM, 8)
-    AM_RANGE( 0x0000, 0xffff) AM_READ( MRA8_RAM )
+static ADDRESS_MAP_START( kaypro_mem , ADDRESS_SPACE_PROGRAM, 8)
+	AM_RANGE( 0x0000, 0xffff) AM_RAM
 ADDRESS_MAP_END
 
-static ADDRESS_MAP_START( writemem_kaypro , ADDRESS_SPACE_PROGRAM, 8)
-    AM_RANGE( 0x0000, 0xffff) AM_WRITE( MWA8_RAM )
-ADDRESS_MAP_END
-
-ADDRESS_MAP_START( readport_kaypro , ADDRESS_SPACE_IO, 8)
-    AM_RANGE( BIOS_CONST,  BIOS_CONST) AM_READ(  kaypro_const_r )
-    AM_RANGE( BIOS_CONIN,  BIOS_CONIN) AM_READ(  kaypro_conin_r )
-    AM_RANGE( BIOS_CONOUT, BIOS_CONOUT) AM_READ( kaypro_conout_r )
-    AM_RANGE( BIOS_CMD,    BIOS_CMD) AM_READ(    cpm_bios_command_r )
-ADDRESS_MAP_END
-
-ADDRESS_MAP_START( writeport_kaypro , ADDRESS_SPACE_IO, 8)
-    AM_RANGE( BIOS_CONST,  BIOS_CONST) AM_WRITE(  kaypro_const_w )
-    AM_RANGE( BIOS_CONIN,  BIOS_CONIN) AM_WRITE(  kaypro_conin_w )
-    AM_RANGE( BIOS_CONOUT, BIOS_CONOUT) AM_WRITE( kaypro_conout_w )
-    AM_RANGE( BIOS_CMD,    BIOS_CMD) AM_WRITE(    cpm_bios_command_w )
+ADDRESS_MAP_START( kaypro_io , ADDRESS_SPACE_IO, 8)
+	ADDRESS_MAP_FLAGS( AMEF_ABITS(8) )
+	AM_RANGE( BIOS_CONST,  BIOS_CONST)  AM_READWRITE( kaypro_const_r, kaypro_const_w )
+	AM_RANGE( BIOS_CONIN,  BIOS_CONIN)  AM_READWRITE( kaypro_conin_r, kaypro_conin_w )
+	AM_RANGE( BIOS_CONOUT, BIOS_CONOUT) AM_READWRITE( kaypro_conout_r, kaypro_conout_w )
+	AM_RANGE( BIOS_CMD,    BIOS_CMD)    AM_READWRITE( cpm_bios_command_r, cpm_bios_command_w )
 ADDRESS_MAP_END
 
 /*
@@ -181,28 +171,28 @@ INPUT_PORTS_END
 #define FW  ((KAYPRO_FONT_W+7)/8)*8
 #define FH  KAYPRO_FONT_H
 
-static struct GfxLayout charlayout =
+static gfx_layout charlayout =
 {
-    FW, FH,         /* 8*16 characters */
-    4 * 256,        /* 4 * 256 characters */
-    1,              /* 1 bits per pixel */
-    { 0 },          /* no bitplanes; 1 bit per pixel */
-    /* x offsets */
-    { 0, 1, 2, 3, 4, 5, 6, 7,
-      8, 9,10,11,12,13,14,15,
-     16,17,18,19,20,21,22,23,
-     24,25,26,27,28,29,30,31 },
-    /* y offsets */
-    { 0*FW, 1*FW, 2*FW, 3*FW, 4*FW, 5*FW, 6*FW, 7*FW,
-      8*FW, 9*FW,10*FW,11*FW,12*FW,13*FW,14*FW,15*FW,
-     16*FW,17*FW,18*FW,19*FW,20*FW,21*FW,22*FW,23*FW,
-     24*FW,25*FW,26*FW,27*FW,28*FW,29*FW,30*FW,31*FW },
-    FW * FH         /* every char takes 16 bytes */
+	FW, FH,         /* 8*16 characters */
+	4 * 256,        /* 4 * 256 characters */
+	1,              /* 1 bits per pixel */
+	{ 0 },          /* no bitplanes; 1 bit per pixel */
+	/* x offsets */
+	{ 0, 1, 2, 3, 4, 5, 6, 7,
+		8, 9,10,11,12,13,14,15,
+		16,17,18,19,20,21,22,23,
+		24,25,26,27,28,29,30,31 },
+	/* y offsets */
+	{ 0*FW, 1*FW, 2*FW, 3*FW, 4*FW, 5*FW, 6*FW, 7*FW,
+		8*FW, 9*FW,10*FW,11*FW,12*FW,13*FW,14*FW,15*FW,
+		16*FW,17*FW,18*FW,19*FW,20*FW,21*FW,22*FW,23*FW,
+		24*FW,25*FW,26*FW,27*FW,28*FW,29*FW,30*FW,31*FW },
+	FW * FH         /* every char takes 16 bytes */
 };
 
-static struct GfxDecodeInfo gfxdecodeinfo[] =
+static gfx_decode gfxdecodeinfo[] =
 {
-    { 1, 0, &charlayout, 0, 4},
+	{ REGION_GFX1, 0, &charlayout, 0, 4},
 	{-1}
 };   /* end of array */
 
@@ -239,15 +229,14 @@ static PALETTE_INIT( kaypro )
 static MACHINE_DRIVER_START( kaypro )
 	/* basic machine hardware */
 	MDRV_CPU_ADD_TAG("main", Z80, 4000000)        /* 4 Mhz */
-	MDRV_CPU_PROGRAM_MAP(readmem_kaypro,writemem_kaypro)
-	MDRV_CPU_IO_MAP(readport_kaypro,writeport_kaypro)
+	MDRV_CPU_PROGRAM_MAP(kaypro_mem, 0)
+	MDRV_CPU_IO_MAP(kaypro_io, 0)
 	MDRV_CPU_VBLANK_INT(kaypro_interrupt, 1)
 	MDRV_FRAMES_PER_SECOND(60)
 	MDRV_VBLANK_DURATION(DEFAULT_REAL_60HZ_VBLANK_DURATION)
 	MDRV_INTERLEAVE(4)
 
-	MDRV_MACHINE_INIT( kaypro )
-	MDRV_MACHINE_STOP( kaypro )
+	MDRV_MACHINE_RESET( kaypro )
 
     /* video hardware */
 	MDRV_VIDEO_ATTRIBUTES(VIDEO_TYPE_RASTER)
@@ -274,13 +263,22 @@ ROM_START (kaypro)
     ROM_LOAD ("cpm62k.sys",   0x0000, 0x1600, CRC(d10cd036) SHA1(68c04701711fcb5ac1586eb8f060f3f0e02ba3dd))
 ROM_END
 
-static void kaypro_floppy_getinfo(struct IODevice *dev)
+static void kaypro_floppy_getinfo(const device_class *devclass, UINT32 state, union devinfo *info)
 {
 	/* floppy */
-	legacybasicdsk_device_getinfo(dev);
-	dev->count = 4;
-	dev->file_extensions = "dsk\0";
-	dev->load = device_load_cpm_floppy;
+	switch(state)
+	{
+		/* --- the following bits of info are returned as 64-bit signed integers --- */
+		case DEVINFO_INT_COUNT:							info->i = 4; break;
+
+		/* --- the following bits of info are returned as pointers to data or functions --- */
+		case DEVINFO_PTR_LOAD:							info->load = device_load_cpm_floppy; break;
+
+		/* --- the following bits of info are returned as NULL-terminated strings --- */
+		case DEVINFO_STR_FILE_EXTENSIONS:				strcpy(info->s = device_temp_str(), "dsk"); break;
+
+		default:										legacybasicdsk_device_getinfo(devclass, state, info); break;
+	}
 }
 
 SYSTEM_CONFIG_START(kaypro)
@@ -288,4 +286,4 @@ SYSTEM_CONFIG_START(kaypro)
 SYSTEM_CONFIG_END
 
 /*    YEAR  NAME      PARENT	COMPAT	MACHINE   INPUT     INIT      CONFIG    COMPANY   FULLNAME */
-COMP( 1982, kaypro,   0,		0,		kaypro,   kaypro,   kaypro,   kaypro,   "Non Linear Systems",  "Kaypro 2x" )
+COMP( 1982, kaypro,   0,		0,		kaypro,   kaypro,   kaypro,   kaypro,   "Non Linear Systems",  "Kaypro 2x" , 0)
