@@ -39,10 +39,9 @@
 #include "inputx.h"
 #include "vidhrdw/generic.h"
 #include "machine/6522via.h"
-#include "machine/sonydriv.h"
+#include "devices/sonydriv.h"
 #include "devices/harddriv.h"
 #include "includes/mac.h"
-#include "videomap.h"
 
 
 static ADDRESS_MAP_START(mac512ke_map, ADDRESS_SPACE_PROGRAM, 16)
@@ -78,7 +77,7 @@ static MACHINE_DRIVER_START( mac512ke )
 	MDRV_VBLANK_DURATION(DEFAULT_REAL_60HZ_VBLANK_DURATION)
 	MDRV_INTERLEAVE(1)
 
-	MDRV_MACHINE_INIT( mac )
+	MDRV_MACHINE_RESET( mac )
 
     /* video hardware */
 	MDRV_VIDEO_ATTRIBUTES(VIDEO_TYPE_RASTER | VIDEO_UPDATE_BEFORE_VBLANK)
@@ -89,7 +88,7 @@ static MACHINE_DRIVER_START( mac512ke )
 	MDRV_PALETTE_INIT(mac)
 
 	MDRV_VIDEO_START(mac)
-	MDRV_VIDEO_UPDATE(videomap)
+	MDRV_VIDEO_UPDATE(mac)
 
 	/* sound hardware */
 	MDRV_SPEAKER_STANDARD_MONO("mono")
@@ -270,30 +269,40 @@ ROM_START( macse )
 ROM_END
 
 
-static void mac128512_floppy_getinfo(struct IODevice *dev)
+static void mac128512_floppy_getinfo(const device_class *devclass, UINT32 state, union devinfo *info)
 {
 	/* floppy */
-	sonydriv_device_getinfo(dev, SONY_FLOPPY_ALLOW400K);
+	switch(state)
+	{
+		/* --- the following bits of info are returned as 64-bit signed integers --- */
+		case DEVINFO_INT_SONYDRIV_ALLOWABLE_SIZES:		info->i = SONY_FLOPPY_ALLOW400K; break;
+
+		default:										sonydriv_device_getinfo(devclass, state, info); break;
+	}
 }
 
-static void mac_floppy_getinfo(struct IODevice *dev)
+static void mac_floppy_getinfo(const device_class *devclass, UINT32 state, union devinfo *info)
 {
 	/* floppy */
-	sonydriv_device_getinfo(dev, SONY_FLOPPY_ALLOW400K | SONY_FLOPPY_ALLOW800K);
+	switch(state)
+	{
+		/* --- the following bits of info are returned as 64-bit signed integers --- */
+		case DEVINFO_INT_SONYDRIV_ALLOWABLE_SIZES:		info->i = SONY_FLOPPY_ALLOW400K | SONY_FLOPPY_ALLOW800K; break;
+
+		default:										sonydriv_device_getinfo(devclass, state, info); break;
+	}
 }
 
-static void mac_harddisk_getinfo(struct IODevice *dev)
+static void mac_harddisk_getinfo(const device_class *devclass, UINT32 state, union devinfo *info)
 {
 	/* harddisk */
-	dev->type = IO_HARDDISK;
-	dev->count = 2;
-	dev->file_extensions = "chd\0";
-	dev->readable = 1;
-	dev->writeable = 1;
-	dev->creatable = 0;
-	dev->init = device_init_mess_hd;
-	dev->load = device_load_mess_hd;
-	dev->unload = device_unload_mess_hd;
+	switch(state)
+	{
+		/* --- the following bits of info are returned as 64-bit signed integers --- */
+		case DEVINFO_INT_COUNT:							info->i = 2; break;
+
+		default: harddisk_device_getinfo(devclass, state, info); break;
+	}
 }
 
 SYSTEM_CONFIG_START(mac128k)
@@ -329,11 +338,11 @@ SYSTEM_CONFIG_END
 
 
 /*	   YEAR		NAME	  PARENT	COMPAT	MACHINE   INPUT		INIT			CONFIG		COMPANY				FULLNAME */
-/*COMPX( 1984,	mac128k,  0, 		0,		mac128k,  macplus,	mac128k512k,	macplus,	"Apple Computer",	"Macintosh 128k",  0 )
-COMPX( 1984,	mac512k,  mac128k,	0,		mac128k,  macplus,  mac128k512k,	macplus,	"Apple Computer",	"Macintosh 512k",  0 )*/
-COMPX( 1986,	mac512ke, macplus,  0,		mac512ke, macplus,  mac512ke,		mac512k,	"Apple Computer",	"Macintosh 512ke", 0 )
-COMPX( 1986,	macplus,  0,		0,		macplus,  macplus,  macplus,		macplus,	"Apple Computer",	"Macintosh Plus",  0 )
-COMPX( 1987,	macse,    0,		0,		macplus,  macplus,  macse,		    macse,		"Apple Computer",	"Macintosh SE",  GAME_NOT_WORKING )
+/*COMP( 1984,	mac128k,  0, 		0,		mac128k,  macplus,	mac128k512k,	macplus,	"Apple Computer",	"Macintosh 128k",  0 )
+COMP( 1984,	mac512k,  mac128k,	0,		mac128k,  macplus,  mac128k512k,	macplus,	"Apple Computer",	"Macintosh 512k",  0 )*/
+COMP( 1986,	mac512ke, macplus,  0,		mac512ke, macplus,  mac512ke,		mac512k,	"Apple Computer",	"Macintosh 512ke", 0 )
+COMP( 1986,	macplus,  0,		0,		macplus,  macplus,  macplus,		macplus,	"Apple Computer",	"Macintosh Plus",  0 )
+COMP( 1987,	macse,    0,		0,		macplus,  macplus,  macse,		    macse,		"Apple Computer",	"Macintosh SE",  GAME_NOT_WORKING )
 
 
 
@@ -343,19 +352,11 @@ COMPX( 1987,	macse,    0,		0,		macplus,  macplus,  macse,		    macse,		"Apple Co
 
 /* Early Mac2 driver - does not work at all, but enabled me to disassemble the ROMs */
 
-static ADDRESS_MAP_START (mac2_readmem, ADDRESS_SPACE_PROGRAM, 16)
+static ADDRESS_MAP_START (mac2_mem, ADDRESS_SPACE_PROGRAM, 16)
 
-	AM_RANGE( 0x00000000, 0x007fffff) AM_READ( MRA8_RAM )	/* ram */
-	AM_RANGE( 0x00800000, 0x008fffff) AM_READ( MRA8_ROM )	/* rom */
-	AM_RANGE( 0x00900000, 0x00ffffff) AM_READ( MRA8_NOP )
-
-ADDRESS_MAP_END
-
-static ADDRESS_MAP_START (mac2_writemem, ADDRESS_SPACE_PROGRAM, 16)
-
-	AM_RANGE( 0x00000000, 0x007fffff) AM_WRITE( MWA8_RAM )	/* ram */
-	AM_RANGE( 0x00800000, 0x008fffff) AM_WRITE( MWA8_ROM )	/* rom */
-	AM_RANGE( 0x00900000, 0x00ffffff) AM_WRITE( MWA8_NOP )
+	AM_RANGE( 0x00000000, 0x007fffff) AM_RAM
+	AM_RANGE( 0x00800000, 0x008fffff) AM_ROM
+	AM_RANGE( 0x00900000, 0x00ffffff) AM_NOP
 
 ADDRESS_MAP_END
 
@@ -372,7 +373,7 @@ static struct MachineDriver machine_driver_mac2 =
 		{
 			CPU_M68020,
 			16000000,			/* +/- 16 Mhz */
-			mac2_readmem,mac2_writemem,0,0,
+			mac2_mem,0,0,0,
 			0,0,
 		}
 	},
