@@ -101,25 +101,15 @@ static WRITE8_HANDLER(mk1_f8_w)
 	if (!(mk1_f8[1]&8)) mk1_led[3]=mk1_f8[0];
 }
 
-static ADDRESS_MAP_START( mk1_readmem , ADDRESS_SPACE_PROGRAM, 8)
-	AM_RANGE( 0x0000, 0x07ff) AM_READ( MRA8_ROM )
-	AM_RANGE( 0x1800, 0x18ff) AM_READ( MRA8_RAM )
-ADDRESS_MAP_END
-
-static ADDRESS_MAP_START( mk1_writemem , ADDRESS_SPACE_PROGRAM, 8)
-	AM_RANGE( 0x0000, 0x07ff) AM_WRITE( MWA8_ROM )
-	AM_RANGE( 0x1800, 0x18ff) AM_WRITE( MWA8_RAM )
+static ADDRESS_MAP_START( mk1_mem, ADDRESS_SPACE_PROGRAM, 8)
+	AM_RANGE(0x0000, 0x07ff) AM_ROM
+	AM_RANGE(0x1800, 0x18ff) AM_RAM
 ADDRESS_MAP_END
 
 
-static ADDRESS_MAP_START( mk1_readport , ADDRESS_SPACE_IO, 8)
-AM_RANGE( 0x0, 0x1) AM_READ( mk1_f8_r )
-AM_RANGE( 0xc, 0xf) AM_READ( f3853_r )
-ADDRESS_MAP_END
-
-static ADDRESS_MAP_START( mk1_writeport , ADDRESS_SPACE_IO, 8)
-AM_RANGE( 0x0, 0x1) AM_WRITE( mk1_f8_w )
-AM_RANGE( 0xc, 0xf) AM_WRITE( f3853_w )
+static ADDRESS_MAP_START( mk1_io, ADDRESS_SPACE_IO, 8)
+	AM_RANGE(0x0, 0x1) AM_READWRITE( mk1_f8_r, mk1_f8_w )
+	AM_RANGE(0xc, 0xf) AM_READWRITE( f3853_r, f3853_w )
 ADDRESS_MAP_END
 
 #define DIPS_HELPER(bit, name, keycode, r) \
@@ -156,7 +146,7 @@ INPUT_PORTS_START( mk1 )
 	DIPS_HELPER( 0x10, "Black 8    ep", KEYCODE_8, CODE_NONE)
 INPUT_PORTS_END
 
-static MACHINE_INIT( mk1 )
+static MACHINE_RESET( mk1 )
 {
     f3853_reset();
 }
@@ -164,13 +154,13 @@ static MACHINE_INIT( mk1 )
 static MACHINE_DRIVER_START( mk1 )
 	/* basic machine hardware */
 	MDRV_CPU_ADD(F8, 1000000)        /* MK3850 */
-	MDRV_CPU_PROGRAM_MAP(mk1_readmem,mk1_writemem)
-	MDRV_CPU_IO_MAP(mk1_readport,mk1_writeport)
+	MDRV_CPU_PROGRAM_MAP(mk1_mem, 0)
+	MDRV_CPU_IO_MAP(mk1_io, 0)
 	MDRV_FRAMES_PER_SECOND(LCD_FRAMES_PER_SECOND)
 	MDRV_VBLANK_DURATION(DEFAULT_REAL_60HZ_VBLANK_DURATION)
 	MDRV_INTERLEAVE(1)
 
-	MDRV_MACHINE_INIT( mk1 )
+	MDRV_MACHINE_RESET( mk1 )
 
     /* video hardware */
 	MDRV_VIDEO_ATTRIBUTES(VIDEO_TYPE_RASTER)
@@ -216,5 +206,5 @@ static DRIVER_INIT( mk1 )
 
 /* seams to be developed by mostek (MK) */
 /*     YEAR   NAME  PARENT  COMPAT	MACHINE INPUT   INIT	CONFIG	COMPANY                 FULLNAME */
-CONSX( 1979,  mk1,  0, 		0,		mk1,	mk1,	mk1,	NULL,	"Computer Electronic",  "Chess Champion MK I", GAME_NOT_WORKING)
+CONS( 1979,  mk1,  0, 		0,		mk1,	mk1,	mk1,	NULL,	"Computer Electronic",  "Chess Champion MK I", GAME_NOT_WORKING)
 
