@@ -114,7 +114,7 @@
 
 /* the serial clock is generated by the nc hardware and connected to the msm8251
 receive clock and transmit clock inputs */
-static void *nc_serial_timer;
+static mame_timer *nc_serial_timer;
 
 static void nc_printer_update(int);
 
@@ -128,6 +128,9 @@ static int nc_membank_rom_mask;
 static int nc_membank_internal_ram_mask;
 int nc_membank_card_ram_mask;
 
+static void nc100_machine_stop(void);
+static void nc200_machine_stop(void);
+
 /*
 	Port 0x00:
 	==========
@@ -973,10 +976,8 @@ static CENTRONICS_CONFIG nc100_cent_config[1]={
 	},
 };
 
-static MACHINE_INIT( nc100 )
+static void nc100_machine_reset(void)
 {
-    nc_type = NC_TYPE_1xx;
-
     /* 256k of rom */
     nc_membank_rom_mask = 0x0f;
 
@@ -1003,10 +1004,9 @@ static MACHINE_INIT( nc100 )
 
 	/* serial */
 	nc_irq_latch_mask = (1<<0) | (1<<1);
-
 }
 
-static MACHINE_STOP( nc100 )
+static void nc100_machine_stop(void)
 {
 	nc_common_open_stream_for_writing();
 	tc8521_save_stream(file);
@@ -1014,6 +1014,15 @@ static MACHINE_STOP( nc100 )
 	nc_common_close_stream();
 }
 
+static MACHINE_START( nc100 )
+{
+    nc_type = NC_TYPE_1xx;
+
+	add_reset_callback(nc100_machine_reset);
+	add_exit_callback(nc100_machine_stop);
+	return 0;
+}
+
 
 static WRITE8_HANDLER(nc100_poweroff_control_w)
 {
@@ -1364,10 +1373,8 @@ static void nc200_floppy_drive_index_callback(int drive_id)
 /*	nc_update_interrupts(); */
 }
 
-static MACHINE_INIT( nc200 )
+static void nc200_machine_reset(void)
 {
-    nc_type = NC_TYPE_200;
-
 	/* 512k of rom */
 	nc_membank_rom_mask = 0x1f;
 
@@ -1405,7 +1412,7 @@ static MACHINE_INIT( nc200 )
 	nc200_video_set_backlight(0);
 }
 
-static MACHINE_STOP( nc200 )
+static void nc200_machine_stop(void)
 {
 	nc_common_open_stream_for_writing();
 	if (file)
@@ -1416,6 +1423,15 @@ static MACHINE_STOP( nc200 )
 	nc_common_close_stream();
 }
 
+static MACHINE_START( nc200 )
+{
+    nc_type = NC_TYPE_200;
+
+	add_reset_callback(nc200_machine_reset);
+	add_exit_callback(nc200_machine_stop);
+	return 0;
+}
+
 /*
 NC200:
 
@@ -1641,7 +1657,7 @@ INPUT_PORTS_START(nc200)
 	/* 7 */
 	PORT_START
 	PORT_BIT (0x001, 0x00, IPT_UNUSED)
-	PORT_BIT(0x002, IP_ACTIVE_HIGH, IPT_KEYBOARD) PORT_NAME("+ = ") PORT_CODE(KEYCODE_EQUALS)
+	PORT_BIT(0x002, IP_ACTIVE_HIGH, IPT_KEYBOARD) PORT_NAME("+ =") PORT_CODE(KEYCODE_EQUALS)
 	PORT_BIT(0x004, IP_ACTIVE_HIGH, IPT_KEYBOARD) PORT_NAME("/ |") PORT_CODE(KEYCODE_BACKSLASH)
 	PORT_BIT(0x008, IP_ACTIVE_HIGH, IPT_KEYBOARD) PORT_NAME("UP") PORT_CODE(KEYCODE_UP)
 	PORT_BIT(0x010, IP_ACTIVE_HIGH, IPT_KEYBOARD) PORT_NAME("MENU") PORT_CODE(KEYCODE_PGUP)
@@ -1692,8 +1708,7 @@ static MACHINE_DRIVER_START( nc100 )
 	MDRV_VBLANK_DURATION(DEFAULT_REAL_60HZ_VBLANK_DURATION)
 	MDRV_INTERLEAVE(1)
 
-	MDRV_MACHINE_INIT( nc100 )
-	MDRV_MACHINE_STOP( nc100 )
+	MDRV_MACHINE_START( nc100 )
 
     /* video hardware */
 	MDRV_VIDEO_ATTRIBUTES(VIDEO_TYPE_RASTER)
@@ -1720,8 +1735,7 @@ static MACHINE_DRIVER_START( nc200 )
 	MDRV_CPU_MODIFY( "main" )
 	MDRV_CPU_IO_MAP(nc200_io, 0)
 
-	MDRV_MACHINE_INIT( nc200 )
-	MDRV_MACHINE_STOP( nc200 )
+	MDRV_MACHINE_START( nc200 )
 
     /* video hardware */
 	MDRV_SCREEN_SIZE(NC200_SCREEN_WIDTH, NC200_SCREEN_HEIGHT)
@@ -1752,36 +1766,58 @@ ROM_START(nc200)
         ROM_LOAD("nc200.rom", 0x010000, 0x080000, CRC(bb8180e7) SHA1(fb5c93b0a3e199202c6a12548d2617f7a09bae47))
 ROM_END
 
-static void nc_common_printer_getinfo(struct IODevice *dev)
+static void nc_common_printer_getinfo(const device_class *devclass, UINT32 state, union devinfo *info)
 {
 	/* printer */
-	printer_device_getinfo(dev);
-	dev->count = 1;
+	switch(state)
+	{
+		/* --- the following bits of info are returned as 64-bit signed integers --- */
+		case DEVINFO_INT_COUNT:							info->i = 1; break;
+
+		default:										printer_device_getinfo(devclass, state, info); break;
+	}
 }
 
-static void nc_common_cartslot_getinfo(struct IODevice *dev)
+static void nc_common_cartslot_getinfo(const device_class *devclass, UINT32 state, union devinfo *info)
 {
 	/* cartslot */
-	cartslot_device_getinfo(dev);
-	dev->count = 1;
-	dev->file_extensions = "crd\0card\0";
-	dev->init = device_init_nc_pcmcia_card;
-	dev->load = device_load_nc_pcmcia_card;
-	dev->unload = device_unload_nc_pcmcia_card;
+	switch(state)
+	{
+		/* --- the following bits of info are returned as 64-bit signed integers --- */
+		case DEVINFO_INT_COUNT:							info->i = 1; break;
+
+		/* --- the following bits of info are returned as pointers to data or functions --- */
+		case DEVINFO_PTR_INIT:							info->init = device_init_nc_pcmcia_card; break;
+		case DEVINFO_PTR_LOAD:							info->load = device_load_nc_pcmcia_card; break;
+		case DEVINFO_PTR_UNLOAD:						info->unload = device_unload_nc_pcmcia_card; break;
+
+		/* --- the following bits of info are returned as NULL-terminated strings --- */
+		case DEVINFO_STR_FILE_EXTENSIONS:				strcpy(info->s = device_temp_str(), "crd,card"); break;
+
+		default:										cartslot_device_getinfo(devclass, state, info); break;
+	}
 }
 
-static void nc_common_serial_getinfo(struct IODevice *dev)
+static void nc_common_serial_getinfo(const device_class *devclass, UINT32 state, union devinfo *info)
 {
 	/* serial */
-	dev->type = IO_SERIAL;
-	dev->count = 1;
-	dev->file_extensions = "txt\0";
-	dev->readable = 1;
-	dev->writeable = 0;
-	dev->creatable = 0;
-	dev->init = serial_device_init;
-	dev->load = device_load_nc_serial;
-	dev->unload = serial_device_unload;
+	switch(state)
+	{
+		/* --- the following bits of info are returned as 64-bit signed integers --- */
+		case DEVINFO_INT_TYPE:							info->i = IO_SERIAL; break;
+		case DEVINFO_INT_READABLE:						info->i = 1; break;
+		case DEVINFO_INT_WRITEABLE:						info->i = 0; break;
+		case DEVINFO_INT_CREATABLE:						info->i = 0; break;
+		case DEVINFO_INT_COUNT:							info->i = 1; break;
+
+		/* --- the following bits of info are returned as pointers to data or functions --- */
+		case DEVINFO_PTR_INIT:							info->init = serial_device_init; break;
+		case DEVINFO_PTR_LOAD:							info->load = device_load_nc_serial; break;
+		case DEVINFO_PTR_UNLOAD:						info->unload = serial_device_unload; break;
+
+		/* --- the following bits of info are returned as NULL-terminated strings --- */
+		case DEVINFO_STR_FILE_EXTENSIONS:				strcpy(info->s = device_temp_str(), "txt"); break;
+	}
 }
 
 SYSTEM_CONFIG_START(nc_common)
@@ -1795,11 +1831,19 @@ SYSTEM_CONFIG_START(nc100)
 	CONFIG_RAM_DEFAULT(64 * 1024)
 SYSTEM_CONFIG_END
 
-static void nc200_floppy_getinfo(struct IODevice *dev)
+static void nc200_floppy_getinfo(const device_class *devclass, UINT32 state, union devinfo *info)
 {
 	/* floppy */
-	floppy_device_getinfo(dev, floppyoptions_pc);
-	dev->count = 1;
+	switch(state)
+	{
+		/* --- the following bits of info are returned as 64-bit signed integers --- */
+		case DEVINFO_INT_COUNT:							info->i = 1; break;
+
+		/* --- the following bits of info are returned as pointers to data or functions --- */
+		case DEVINFO_PTR_FLOPPY_OPTIONS:				info->p = (void *) floppyoptions_pc; break;
+
+		default:										floppy_device_getinfo(devclass, state, info); break;
+	}
 }
 
 SYSTEM_CONFIG_START(nc200)
@@ -1809,6 +1853,6 @@ SYSTEM_CONFIG_START(nc200)
 SYSTEM_CONFIG_END
 
 /*    YEAR  NAME       PARENT  COMPAT	MACHINE    INPUT     INIT     CONFIG,  COMPANY               FULLNAME */
-COMP( 1992, nc100,     0,      0,		nc100,     nc100,    0,       nc100,   "Amstrad plc", "NC100")
-COMP( 1992, nc100a,    nc100,  0,		nc100,     nc100,    0,       nc100,   "Amstrad plc", "NC100 (Version 1.09)")
-COMP( 1993, nc200,     0,      0,		nc200,     nc200,    0,       nc200,   "Amstrad plc", "NC200")
+COMP( 1992, nc100,     0,      0,		nc100,     nc100,    0,       nc100,   "Amstrad plc", "NC100", 0)
+COMP( 1992, nc100a,    nc100,  0,		nc100,     nc100,    0,       nc100,   "Amstrad plc", "NC100 (Version 1.09)", 0)
+COMP( 1993, nc200,     0,      0,		nc200,     nc200,    0,       nc200,   "Amstrad plc", "NC200", 0)
