@@ -34,6 +34,7 @@
 
 #include "includes/pc_ide.h"
 #include "machine/pc_fdc.h"
+#include "machine/pc_joy.h"
 #include "machine/pckeybrd.h"
 #include "includes/pclpt.h"
 #include "includes/sblaster.h"
@@ -44,7 +45,7 @@
 #include "includes/amstr_pc.h"
 #include "includes/ibmpc.h"
 
-#include "includes/pcshare.h"
+#include "machine/pcshare.h"
 #include "includes/pc.h"
 
 #include "machine/pc_hdc.h"
@@ -57,6 +58,8 @@
 #include "sound/sn76496.h"
 #include "sound/3812intf.h"
 
+#include "inputx.h"
+
 #define ym3812_StdClock 3579545
 
 /*
@@ -89,7 +92,7 @@
 static ADDRESS_MAP_START( pc_map, ADDRESS_SPACE_PROGRAM, 8 )
 	AM_RANGE(0x00000, 0x9ffff) AM_READWRITE(MRA8_BANK10, MWA8_BANK10)
 	AM_RANGE(0xa0000, 0xbffff) AM_NOP
-	AM_RANGE(0xc0000, 0xc7fff) AM_NOP
+	AM_RANGE(0xc0000, 0xc7fff) AM_ROM
 	AM_RANGE(0xc8000, 0xcffff) AM_ROM
 	AM_RANGE(0xd0000, 0xeffff) AM_NOP
 	AM_RANGE(0xf0000, 0xfffff) AM_ROM
@@ -109,8 +112,8 @@ static ADDRESS_MAP_START(pc_io, ADDRESS_SPACE_IO, 8)
 #endif
 	AM_RANGE(0x0240, 0x0257) AM_READWRITE(pc_rtc_r,					pc_rtc_w)
 	AM_RANGE(0x0278, 0x027b) AM_READWRITE(pc_parallelport2_r,		pc_parallelport2_w)
-	AM_RANGE(0x02e8, 0x02ef) AM_READWRITE(pc_COM4_r,				pc_COM4_w)
-	AM_RANGE(0x02f8, 0x02ff) AM_READWRITE(pc_COM2_r,				pc_COM2_w)
+	AM_RANGE(0x02e8, 0x02ef) AM_READWRITE(uart8250_3_r,				uart8250_3_w)
+	AM_RANGE(0x02f8, 0x02ff) AM_READWRITE(uart8250_1_r,				uart8250_1_w)
 	AM_RANGE(0x0320, 0x0323) AM_READWRITE(pc_HDC1_r,				pc_HDC1_w)
 	AM_RANGE(0x0324, 0x0327) AM_READWRITE(pc_HDC2_r,				pc_HDC2_w)
 	AM_RANGE(0x0340, 0x0357) AM_READ(return8_FF) /* anonymous bios should not recogniced realtimeclock */
@@ -120,9 +123,9 @@ static ADDRESS_MAP_START(pc_io, ADDRESS_SPACE_IO, 8)
 	AM_RANGE(0x0389, 0x0389) AM_WRITE(								YM3812_write_port_0_w)
 #endif
 	AM_RANGE(0x03bc, 0x03be) AM_READWRITE(pc_parallelport0_r,		pc_parallelport0_w)
-	AM_RANGE(0x03e8, 0x03ef) AM_READWRITE(pc_COM3_r,				pc_COM3_w)
+	AM_RANGE(0x03e8, 0x03ef) AM_READWRITE(uart8250_2_r,				uart8250_2_w)
 	AM_RANGE(0x03f0, 0x03f7) AM_READWRITE(pc_fdc_r,					pc_fdc_w)
-	AM_RANGE(0x03f8, 0x03ff) AM_READWRITE(pc_COM1_r,				pc_COM1_w)
+	AM_RANGE(0x03f8, 0x03ff) AM_READWRITE(uart8250_0_r,				uart8250_0_w)
 ADDRESS_MAP_END
 
 
@@ -149,8 +152,8 @@ static ADDRESS_MAP_START(europc_io, ADDRESS_SPACE_IO, 8)
 	AM_RANGE(0x0250, 0x025f) AM_READWRITE(europc_jim_r,				europc_jim_w)
 	AM_RANGE(0x0278, 0x027b) AM_READWRITE(pc_parallelport2_r,		pc_parallelport2_w)
 	AM_RANGE(0x02e0, 0x02e0) AM_READ     (europc_jim2_r)
-	AM_RANGE(0x02e8, 0x02ef) AM_READWRITE(pc_COM4_r,				pc_COM4_w)
-	AM_RANGE(0x02f8, 0x02ff) AM_READWRITE(pc_COM2_r,				pc_COM2_w)
+	AM_RANGE(0x02e8, 0x02ef) AM_READWRITE(uart8250_3_r,				uart8250_3_w)
+	AM_RANGE(0x02f8, 0x02ff) AM_READWRITE(uart8250_1_r,				uart8250_1_w)
 	AM_RANGE(0x0320, 0x0323) AM_READWRITE(pc_HDC1_r,				pc_HDC1_w)
 	AM_RANGE(0x0324, 0x0327) AM_READWRITE(pc_HDC2_r,				pc_HDC2_w)
 	AM_RANGE(0x0378, 0x037b) AM_READWRITE(pc_parallelport1_r,		pc_parallelport1_w)
@@ -159,9 +162,9 @@ static ADDRESS_MAP_START(europc_io, ADDRESS_SPACE_IO, 8)
 	AM_RANGE(0x0389, 0x0389) AM_WRITE(								YM3812_write_port_0_w)
 #endif
 /*	AM_RANGE(0x03bc, 0x03be) AM_READWRITE(pc_parallelport0_r,		pc_parallelport0_w) */
-	AM_RANGE(0x03e8, 0x03ef) AM_READWRITE(pc_COM3_r,				pc_COM3_w)
+	AM_RANGE(0x03e8, 0x03ef) AM_READWRITE(uart8250_2_r,				uart8250_2_w)
 	AM_RANGE(0x03f0, 0x03f7) AM_READWRITE(pc_fdc_r,					pc_fdc_w)
-	AM_RANGE(0x03f8, 0x03ff) AM_READWRITE(pc_COM1_r,				pc_COM1_w)
+	AM_RANGE(0x03f8, 0x03ff) AM_READWRITE(uart8250_0_r,				uart8250_0_w)
 ADDRESS_MAP_END
 
 
@@ -188,14 +191,14 @@ static ADDRESS_MAP_START(tandy1000_io, ADDRESS_SPACE_IO, 8)
 	AM_RANGE(0x0080, 0x0087) AM_READWRITE(pc_page_r,				pc_page_w)
 	AM_RANGE(0x00c0, 0x00c0) AM_WRITE(								SN76496_0_w)
 	AM_RANGE(0x0200, 0x0207) AM_READWRITE(pc_JOY_r,					pc_JOY_w)
-	AM_RANGE(0x02f8, 0x02ff) AM_READWRITE(pc_COM2_r,				pc_COM2_w)
+	AM_RANGE(0x02f8, 0x02ff) AM_READWRITE(uart8250_1_r,				uart8250_1_w)
 	AM_RANGE(0x0320, 0x0323) AM_READWRITE(pc_HDC1_r,				pc_HDC1_w)
 	AM_RANGE(0x0324, 0x0327) AM_READWRITE(pc_HDC2_r,				pc_HDC2_w)
 	AM_RANGE(0x0378, 0x037f) AM_READWRITE(pc_t1t_p37x_r,			pc_t1t_p37x_w)
 	AM_RANGE(0x03bc, 0x03be) AM_READWRITE(pc_parallelport0_r,		pc_parallelport0_w)
 	AM_RANGE(0x03d0, 0x03df) AM_READWRITE(pc_T1T_r,					pc_T1T_w)
 	AM_RANGE(0x03f0, 0x03f7) AM_READWRITE(pc_fdc_r,					pc_fdc_w)
-	AM_RANGE(0x03f8, 0x03ff) AM_READWRITE(pc_COM1_r,				pc_COM1_w)
+	AM_RANGE(0x03f8, 0x03ff) AM_READWRITE(uart8250_0_r,				uart8250_0_w)
 ADDRESS_MAP_END
 
 
@@ -210,15 +213,15 @@ static ADDRESS_MAP_START(pc200_io, ADDRESS_SPACE_IO, 8)
 	AM_RANGE(0x0080, 0x0087) AM_READWRITE(pc_page_r,				pc_page_w)
 	AM_RANGE(0x0200, 0x0207) AM_READWRITE(pc_JOY_r,					pc_JOY_w)
 	AM_RANGE(0x0278, 0x027b) AM_READWRITE(pc_parallelport2_r,		pc_parallelport2_w)
-	AM_RANGE(0x02e8, 0x02ef) AM_READWRITE(pc_COM4_r,				pc_COM4_w)
-	AM_RANGE(0x02f8, 0x02ff) AM_READWRITE(pc_COM2_r,				pc_COM2_w)
+	AM_RANGE(0x02e8, 0x02ef) AM_READWRITE(uart8250_3_r,				uart8250_3_w)
+	AM_RANGE(0x02f8, 0x02ff) AM_READWRITE(uart8250_1_r,				uart8250_1_w)
 	AM_RANGE(0x0320, 0x0323) AM_READWRITE(pc_HDC1_r,				pc_HDC1_w)
 	AM_RANGE(0x0324, 0x0327) AM_READWRITE(pc_HDC2_r,				pc_HDC2_w)
 	AM_RANGE(0x0378, 0x037b) AM_READWRITE(pc200_port378_r,			pc_parallelport1_w)
 	AM_RANGE(0x03bc, 0x03be) AM_READWRITE(pc_parallelport0_r,		pc_parallelport0_w)
-	AM_RANGE(0x03e8, 0x03ef) AM_READWRITE(pc_COM3_r,				pc_COM3_w)
+	AM_RANGE(0x03e8, 0x03ef) AM_READWRITE(uart8250_2_r,				uart8250_2_w)
 	AM_RANGE(0x03f0, 0x03f7) AM_READWRITE(pc_fdc_r,					pc_fdc_w)
-	AM_RANGE(0x03f8, 0x03ff) AM_READWRITE(pc_COM1_r,				pc_COM1_w)
+	AM_RANGE(0x03f8, 0x03ff) AM_READWRITE(uart8250_0_r,				uart8250_0_w)
 ADDRESS_MAP_END
 
 
@@ -244,15 +247,15 @@ static ADDRESS_MAP_START(pc1640_io, ADDRESS_SPACE_IO, 8)
 	AM_RANGE(0x0080, 0x0087) AM_READWRITE(pc_page_r,				pc_page_w)
 	AM_RANGE(0x0200, 0x0207) AM_READWRITE(pc_JOY_r,					pc_JOY_w)
 	AM_RANGE(0x0278, 0x027b) AM_READWRITE(pc_parallelport2_r,		pc_parallelport2_w)
-	AM_RANGE(0x02e8, 0x02ef) AM_READWRITE(pc_COM4_r,				pc_COM4_w)
-	AM_RANGE(0x02f8, 0x02ff) AM_READWRITE(pc_COM2_r,				pc_COM2_w)
+	AM_RANGE(0x02e8, 0x02ef) AM_READWRITE(uart8250_3_r,				uart8250_3_w)
+	AM_RANGE(0x02f8, 0x02ff) AM_READWRITE(uart8250_1_r,				uart8250_1_w)
 	AM_RANGE(0x0320, 0x0323) AM_READWRITE(pc_HDC1_r,				pc_HDC1_w)
 	AM_RANGE(0x0324, 0x0327) AM_READWRITE(pc_HDC2_r,				pc_HDC2_w)
 	AM_RANGE(0x0378, 0x037b) AM_READWRITE(pc1640_port378_r,			pc_parallelport1_w)
 	AM_RANGE(0x03bc, 0x03be) AM_READWRITE(pc_parallelport0_r,		pc_parallelport0_w)
-	AM_RANGE(0x03e8, 0x03ef) AM_READWRITE(pc_COM3_r,				pc_COM3_w)
+	AM_RANGE(0x03e8, 0x03ef) AM_READWRITE(uart8250_2_r,				uart8250_2_w)
 	AM_RANGE(0x03f0, 0x03f7) AM_READWRITE(pc_fdc_r,					pc_fdc_w)
-	AM_RANGE(0x03f8, 0x03ff) AM_READWRITE(pc_COM1_r,				pc_COM1_w)
+	AM_RANGE(0x03f8, 0x03ff) AM_READWRITE(uart8250_0_r,				uart8250_0_w)
 ADDRESS_MAP_END
 
 
@@ -1081,8 +1084,8 @@ static struct YM3812interface ym3812_interface =
 
 #define MDRV_CPU_PC(mem, port, type, clock, vblankfunc)	\
 	MDRV_CPU_ADD_TAG("main", type, clock)				\
-	MDRV_CPU_PROGRAM_MAP(mem##_map, mem##_map)			\
-	MDRV_CPU_IO_MAP(port##_io, port##_io)				\
+	MDRV_CPU_PROGRAM_MAP(mem##_map, 0)			\
+	MDRV_CPU_IO_MAP(port##_io, 0)				\
 	MDRV_CPU_VBLANK_INT(vblankfunc, 4)					\
 	MDRV_CPU_CONFIG(i86_address_mask)
 
@@ -1094,7 +1097,7 @@ static MACHINE_DRIVER_START( pcmda )
 	MDRV_FRAMES_PER_SECOND(60)
 	MDRV_VBLANK_DURATION(DEFAULT_REAL_60HZ_VBLANK_DURATION)
 
-	MDRV_MACHINE_INIT(pc_mda)
+	MDRV_MACHINE_RESET(pc_mda)
 
 	MDRV_VIDEO_ATTRIBUTES(VIDEO_TYPE_RASTER)
 	MDRV_SCREEN_SIZE(80*9, 25*14)
@@ -1133,7 +1136,7 @@ static MACHINE_DRIVER_START( pccga )
 	MDRV_FRAMES_PER_SECOND(60)
 	MDRV_VBLANK_DURATION(DEFAULT_REAL_60HZ_VBLANK_DURATION)
 
-	MDRV_MACHINE_INIT(pc_cga)
+	MDRV_MACHINE_RESET(pc_cga)
 
 	MDRV_IMPORT_FROM( pcvideo_cga )
 
@@ -1163,7 +1166,7 @@ static MACHINE_DRIVER_START( europc )
 	MDRV_FRAMES_PER_SECOND(60)
 	MDRV_VBLANK_DURATION(DEFAULT_REAL_60HZ_VBLANK_DURATION)
 
-	MDRV_MACHINE_INIT(pc_aga)
+	MDRV_MACHINE_RESET(pc_aga)
 
 	MDRV_VIDEO_ATTRIBUTES(VIDEO_TYPE_RASTER)
 	MDRV_SCREEN_SIZE(80*9, 25*14)
@@ -1198,7 +1201,7 @@ static MACHINE_DRIVER_START( xtcga )
 	MDRV_FRAMES_PER_SECOND(60)
 	MDRV_VBLANK_DURATION(DEFAULT_REAL_60HZ_VBLANK_DURATION)
 
-	MDRV_MACHINE_INIT(pc_cga)
+	MDRV_MACHINE_RESET(pc_cga)
 
 	MDRV_IMPORT_FROM( pcvideo_cga )
 
@@ -1228,7 +1231,7 @@ static MACHINE_DRIVER_START( pc200 )
 	MDRV_FRAMES_PER_SECOND(60)
 	MDRV_VBLANK_DURATION(DEFAULT_REAL_60HZ_VBLANK_DURATION)
 
-	MDRV_MACHINE_INIT(pc_aga)
+	MDRV_MACHINE_RESET(pc_aga)
 
 	MDRV_VIDEO_ATTRIBUTES(VIDEO_TYPE_RASTER)
 	MDRV_SCREEN_SIZE(80*8, 25*14)
@@ -1256,7 +1259,7 @@ static MACHINE_DRIVER_START( pc1512 )
 	MDRV_FRAMES_PER_SECOND(60)
 	MDRV_VBLANK_DURATION(DEFAULT_REAL_60HZ_VBLANK_DURATION)
 
-	MDRV_MACHINE_INIT(pc_aga)
+	MDRV_MACHINE_RESET(pc_aga)
 
 	MDRV_IMPORT_FROM( pcvideo_pc1512 )
 
@@ -1277,7 +1280,7 @@ static MACHINE_DRIVER_START( pc1640 )
 	MDRV_FRAMES_PER_SECOND(60)
 	MDRV_VBLANK_DURATION(DEFAULT_REAL_60HZ_VBLANK_DURATION)
 
-	MDRV_MACHINE_INIT(pc_vga)
+	MDRV_MACHINE_RESET(pc_vga)
 
 	MDRV_IMPORT_FROM(pcvideo_pc1640)
 
@@ -1298,7 +1301,7 @@ static MACHINE_DRIVER_START( xtvga )
 	MDRV_FRAMES_PER_SECOND(60)
 	MDRV_VBLANK_DURATION(DEFAULT_REAL_60HZ_VBLANK_DURATION)
 
-	MDRV_MACHINE_INIT(pc_vga)
+	MDRV_MACHINE_RESET(pc_vga)
 
 	MDRV_IMPORT_FROM( pcvideo_vga )
 
@@ -1328,7 +1331,7 @@ static MACHINE_DRIVER_START( t1000hx )
 	MDRV_FRAMES_PER_SECOND(60)
 	MDRV_VBLANK_DURATION(DEFAULT_REAL_60HZ_VBLANK_DURATION)
 
-	MDRV_MACHINE_INIT(pc_t1t)
+	MDRV_MACHINE_RESET(pc_t1t)
 
 	MDRV_IMPORT_FROM( pcvideo_t1000hx )
 
@@ -1409,59 +1412,59 @@ MACHINE_DRIVER_END
 
 ROM_START( ibmpc )
 	ROM_REGION(0x100000,REGION_CPU1, 0)
-    ROM_LOAD("wdbios.rom",  0xc8000, 0x02000, CRC(8e9e2bd4))
-    ROM_LOAD("basicc11.f6", 0xf6000, 0x2000, CRC(80d3cf5d))
-    ROM_LOAD("basicc11.f8", 0xf8000, 0x2000, CRC(673a4acc))
-    ROM_LOAD("basicc11.fa", 0xfa000, 0x2000, CRC(aac3fc37))
-    ROM_LOAD("basicc11.fc", 0xfc000, 0x2000, CRC(3062b3fc))
-    ROM_LOAD("pc102782.bin", 0xfe000, 0x2000, CRC(e88792b3))
+    ROM_LOAD("wdbios.rom",  0xc8000, 0x02000, CRC(8e9e2bd4) SHA1(601d7ceab282394ebab50763c267e915a6a2166a))
+    ROM_LOAD("basicc11.f6", 0xf6000, 0x2000, CRC(80d3cf5d) SHA1(64769b7a8b60ffeefa04e4afbec778069a2840c9))
+    ROM_LOAD("basicc11.f8", 0xf8000, 0x2000, CRC(673a4acc) SHA1(082ae803994048e225150f771794ca305f73d731))
+    ROM_LOAD("basicc11.fa", 0xfa000, 0x2000, CRC(aac3fc37) SHA1(c9e0529470edf04da093bb8c8ae2536c688c1a74))
+    ROM_LOAD("basicc11.fc", 0xfc000, 0x2000, CRC(3062b3fc) SHA1(5134dd64721cbf093d059ee5d3fd09c7f86604c7))
+    ROM_LOAD("pc102782.bin", 0xfe000, 0x2000, CRC(e88792b3) SHA1(40fce6a94dda4328a8b608c7ae2f39d1dc688af4))
 	ROM_REGION(0x08100,REGION_GFX1, 0)
-    ROM_LOAD("cga.chr",     0x00000, 0x01000, CRC(42009069))
+    ROM_LOAD("cga.chr",     0x00000, 0x01000, CRC(42009069) SHA1(ed08559ce2d7f97f68b9f540bddad5b6295294dd))
 ROM_END
 
 ROM_START( ibmpca )
 	ROM_REGION(0x100000,REGION_CPU1,0)
-    ROM_LOAD("wdbios.rom",  0xc8000, 0x02000, CRC(8e9e2bd4))
-    ROM_LOAD("basicc11.f6", 0xf6000, 0x2000, CRC(80d3cf5d))
-    ROM_LOAD("basicc11.f8", 0xf8000, 0x2000, CRC(673a4acc))
-    ROM_LOAD("basicc11.fa", 0xfa000, 0x2000, CRC(aac3fc37))
-    ROM_LOAD("basicc11.fc", 0xfc000, 0x2000, CRC(3062b3fc))
-    ROM_LOAD("pc081682.bin", 0xfe000, 0x2000, CRC(5c3f0256))
+    ROM_LOAD("wdbios.rom",  0xc8000, 0x02000, CRC(8e9e2bd4) SHA1(601d7ceab282394ebab50763c267e915a6a2166a))
+    ROM_LOAD("basicc11.f6", 0xf6000, 0x2000, CRC(80d3cf5d) SHA1(64769b7a8b60ffeefa04e4afbec778069a2840c9))
+    ROM_LOAD("basicc11.f8", 0xf8000, 0x2000, CRC(673a4acc) SHA1(082ae803994048e225150f771794ca305f73d731))
+    ROM_LOAD("basicc11.fa", 0xfa000, 0x2000, CRC(aac3fc37) SHA1(c9e0529470edf04da093bb8c8ae2536c688c1a74))
+    ROM_LOAD("basicc11.fc", 0xfc000, 0x2000, CRC(3062b3fc) SHA1(5134dd64721cbf093d059ee5d3fd09c7f86604c7))
+    ROM_LOAD("pc081682.bin", 0xfe000, 0x2000, CRC(5c3f0256) SHA1(b42c78abd0a9c630a2f972ad2bae46d83c3a2a09))
 	ROM_REGION(0x08100,REGION_GFX1, 0)
-    ROM_LOAD("cga.chr",     0x00000, 0x01000, CRC(42009069))
+    ROM_LOAD("cga.chr",     0x00000, 0x01000, CRC(42009069) SHA1(ed08559ce2d7f97f68b9f540bddad5b6295294dd))
 ROM_END
 
 ROM_START( bondwell )
 	ROM_REGION(0x100000,REGION_CPU1, 0)
-    ROM_LOAD("wdbios.rom",  0xc8000, 0x02000, CRC(8e9e2bd4)) /* taken from other machine */
+    ROM_LOAD("wdbios.rom",  0xc8000, 0x02000, CRC(8e9e2bd4) SHA1(601d7ceab282394ebab50763c267e915a6a2166a)) /* taken from other machine */
 	ROM_LOAD("bondwell.bin", 0xfe000, 0x2000, CRC(d435a405))
 	ROM_REGION(0x08100,REGION_GFX1, 0)
-    ROM_LOAD("cga.chr",     0x00000, 0x01000, CRC(42009069)) /* taken from cga */
+    ROM_LOAD("cga.chr",     0x00000, 0x01000, CRC(42009069) SHA1(ed08559ce2d7f97f68b9f540bddad5b6295294dd)) /* taken from cga */
 ROM_END
 
 ROM_START( pcmda )
     ROM_REGION(0x100000,REGION_CPU1, 0)
-    ROM_LOAD("wdbios.rom",  0xc8000, 0x02000, CRC(8e9e2bd4))
-    ROM_LOAD("pcxt.rom",    0xfe000, 0x02000, CRC(031aafad))
+    ROM_LOAD("wdbios.rom",  0xc8000, 0x02000, CRC(8e9e2bd4) SHA1(601d7ceab282394ebab50763c267e915a6a2166a))
+    ROM_LOAD("pcxt.rom",    0xfe000, 0x02000, CRC(031aafad) SHA1(a641b505bbac97b8775f91fe9b83d9afdf4d038f))
 	ROM_REGION(0x08100,REGION_GFX1, 0)
-    ROM_LOAD("mda.rom",     0x00000, 0x02000, CRC(0bf56d70)) /* taken from original IBM MDA */
+    ROM_LOAD("mda.rom",     0x00000, 0x02000, CRC(0bf56d70) SHA1(c2a8b10808bf51a3c123ba3eb1e9dd608231916f)) /* taken from original IBM MDA */
 ROM_END
 
 ROM_START( pc )
     ROM_REGION(0x100000,REGION_CPU1, 0)
-    ROM_LOAD("wdbios.rom",  0xc8000, 0x02000, CRC(8e9e2bd4))
+    ROM_LOAD("wdbios.rom",  0xc8000, 0x02000, CRC(8e9e2bd4) SHA1(601d7ceab282394ebab50763c267e915a6a2166a))
 /*    ROM_LOAD("xthdd.rom",  0xc8000, 0x02000, CRC(a96317da)) */
-    ROM_LOAD("pcxt.rom",    0xfe000, 0x02000, CRC(031aafad))
+    ROM_LOAD("pcxt.rom",    0xfe000, 0x02000, CRC(031aafad) SHA1(a641b505bbac97b8775f91fe9b83d9afdf4d038f))
 	ROM_REGION(0x08100,REGION_GFX1, 0)
-    ROM_LOAD("cga.chr",     0x00000, 0x01000, CRC(42009069))
+    ROM_LOAD("cga.chr",     0x00000, 0x01000, CRC(42009069) SHA1(ed08559ce2d7f97f68b9f540bddad5b6295294dd))
 ROM_END
 
 ROM_START( europc )
     ROM_REGION(0x100000,REGION_CPU1, 0)
 	/* hdd bios integrated! */
-    ROM_LOAD("50145", 0xf8000, 0x8000, CRC(1775a11d)) /* V2.07 */
+    ROM_LOAD("50145", 0xf8000, 0x8000, CRC(1775a11d) SHA1(54430d4d0462860860397487c9c109e6f70db8e3)) /* V2.07 */
 	ROM_REGION(0x08100,REGION_GFX1, 0)
-    ROM_LOAD("50146", 0x00000, 0x02000, CRC(1305dcf5)) /*D1.0 */
+    ROM_LOAD("50146", 0x00000, 0x02000, CRC(1305dcf5) SHA1(aca488a16ae4ff05a1f4d14574379ff49cd48343)) /*D1.0 */
 ROM_END
 
 
@@ -1474,149 +1477,167 @@ ROM_START( ibmpcjr )
     ROM_LOAD("bios.rom", 0xfe000, 0x2000, CRC(98463f95))
 #endif
 	ROM_REGION(0x08100,REGION_GFX1, 0)
-    ROM_LOAD("cga.chr",     0x00000, 0x01000, CRC(42009069))
+    ROM_LOAD("cga.chr",     0x00000, 0x01000, CRC(42009069) SHA1(ed08559ce2d7f97f68b9f540bddad5b6295294dd))
 ROM_END
 
 ROM_START( t1000hx )
 	ROM_REGION(0x100000,REGION_CPU1, 0)
-	ROM_LOAD("wdbios.rom",  0xc8000, 0x02000, CRC(8e9e2bd4))
+	ROM_LOAD("wdbios.rom",  0xc8000, 0x02000, CRC(8e9e2bd4) SHA1(601d7ceab282394ebab50763c267e915a6a2166a))
 	/* partlist says it has 1 128kbyte rom */
-	ROM_LOAD("t1000hx.e0", 0xe0000, 0x10000, CRC(61dbf242))
-	ROM_LOAD("tandy1t.rom", 0xf0000, 0x10000, CRC(d37a1d5f))
+	ROM_LOAD("t1000hx.e0", 0xe0000, 0x10000, CRC(61dbf242) SHA1(555b58d8aa8e0b0839259621c44b832d993beaef))
+	ROM_LOAD("tandy1t.rom", 0xf0000, 0x10000, CRC(d37a1d5f) SHA1(5ec031c31a7967cc3fd53a535d81833e4a1c385e))
 	ROM_REGION(0x08000,REGION_GFX1, 0)
 	/* expects 8x9 charset! */
-	ROM_LOAD("50146", 0x00000, 0x02000, BAD_DUMP CRC(1305dcf5)) /*taken from europc, 9th blank */
+	ROM_LOAD("50146", 0x00000, 0x02000, BAD_DUMP CRC(1305dcf5) SHA1(aca488a16ae4ff05a1f4d14574379ff49cd48343)) /*taken from europc, 9th blank */
 ROM_END
 
 ROM_START( t1000sx )
 	ROM_REGION(0x100000,REGION_CPU1, 0)
-	ROM_LOAD("wdbios.rom",  0xc8000, 0x02000, CRC(8e9e2bd4))
+	ROM_LOAD("wdbios.rom",  0xc8000, 0x02000, CRC(8e9e2bd4) SHA1(601d7ceab282394ebab50763c267e915a6a2166a))
 	/* partlist says it has 1 128kbyte rom */
-	ROM_LOAD("t1000hx.e0", 0xe0000, 0x10000, CRC(61dbf242))
+	ROM_LOAD("t1000hx.e0", 0xe0000, 0x10000, CRC(61dbf242) SHA1(555b58d8aa8e0b0839259621c44b832d993beaef))
 	ROM_LOAD("t1000sx.f0", 0xf0000, 0x10000, CRC(0e016ecf))
 	ROM_REGION(0x08000,REGION_GFX1, 0)
 	/* expects 8x9 charset! */
-	ROM_LOAD("50146", 0x00000, 0x02000, BAD_DUMP CRC(1305dcf5)) /*taken from europc, 9th blank */
+	ROM_LOAD("50146", 0x00000, 0x02000, BAD_DUMP CRC(1305dcf5) SHA1(aca488a16ae4ff05a1f4d14574379ff49cd48343)) /*taken from europc, 9th blank */
 ROM_END
 
 ROM_START( ibmxt )
 	ROM_REGION16_LE(0x100000,REGION_CPU1, 0)
-	ROM_LOAD("wdbios.rom",  0xc8000, 0x02000, CRC(8e9e2bd4))
-	ROM_LOAD16_BYTE("xt050986.0", 0xf0000, 0x8000, CRC(83727c42))
-	ROM_LOAD16_BYTE("xt050986.1", 0xf0001, 0x8000, CRC(2a629953))
+	ROM_LOAD("wdbios.rom",  0xc8000, 0x02000, CRC(8e9e2bd4) SHA1(601d7ceab282394ebab50763c267e915a6a2166a))
+	ROM_LOAD16_BYTE("xt050986.0", 0xf0000, 0x8000, CRC(83727c42) SHA1(1b218f96aa9570beef5c1f2d7b07433b21dc4599))
+	ROM_LOAD16_BYTE("xt050986.1", 0xf0001, 0x8000, CRC(2a629953) SHA1(048bb1a0b437ae7b93a4d71648cee12e5e37892c))
 	ROM_REGION(0x08100,REGION_GFX1, 0)
-	ROM_LOAD("cga.chr",     0x00000, 0x01000, CRC(42009069))
+	ROM_LOAD("cga.chr",     0x00000, 0x01000, CRC(42009069) SHA1(ed08559ce2d7f97f68b9f540bddad5b6295294dd))
 ROM_END
 
 ROM_START( xtvga )
     ROM_REGION(0x100000,REGION_CPU1, 0)
-    ROM_LOAD("et4000.bin", 0xc0000, 0x8000, CRC(f01e4be0))
-    ROM_LOAD("wdbios.rom",  0xc8000, 0x02000, CRC(8e9e2bd4))
-    ROM_LOAD("pcxt.rom",    0xfe000, 0x02000, CRC(031aafad))
+    ROM_LOAD("et4000.bin", 0xc0000, 0x8000, CRC(f01e4be0) SHA1(95d75ff41bcb765e50bd87a8da01835fd0aa01d5))
+    ROM_LOAD("wdbios.rom",  0xc8000, 0x02000, CRC(8e9e2bd4) SHA1(601d7ceab282394ebab50763c267e915a6a2166a))
+    ROM_LOAD("pcxt.rom",    0xfe000, 0x02000, CRC(031aafad) SHA1(a641b505bbac97b8775f91fe9b83d9afdf4d038f))
 ROM_END
 
 ROM_START( pc200 )
 /*    ROM_REGION(0x100000,REGION_CPU1, 0) */
     ROM_REGION16_LE(0x100000,REGION_CPU1, 0)
-    ROM_LOAD("wdbios.rom",  0xc8000, 0x02000, CRC(8e9e2bd4))
+    ROM_LOAD("wdbios.rom",  0xc8000, 0x02000, CRC(8e9e2bd4) SHA1(601d7ceab282394ebab50763c267e915a6a2166a))
 	/* special bios at 0xe0000 !? */
-    ROM_LOAD16_BYTE("pc20v2.0", 0xfc001, 0x2000, CRC(41302eb8)) /* v2 */
-    ROM_LOAD16_BYTE("pc20v2.1", 0xfc000, 0x2000, CRC(71b84616)) /* v2 */
+    ROM_LOAD16_BYTE("pc20v2.0", 0xfc001, 0x2000, CRC(41302eb8) SHA1(8b4b2afea543b96b45d6a30365281decc15f2932)) /* v2 */
+    ROM_LOAD16_BYTE("pc20v2.1", 0xfc000, 0x2000, CRC(71b84616) SHA1(4135102a491b25fc659d70b957e07649f3eacf24)) /* v2 */
 	/* also mapped to f0000, f4000, f8000 */
 	ROM_REGION(0x08100,REGION_GFX1, 0)
-    ROM_LOAD("40109.bin",     0x00000, 0x08000, CRC(a8b67639))
+    ROM_LOAD("40109.bin",     0x00000, 0x08000, CRC(a8b67639) SHA1(99663bfb61798526e092205575370c2ad34249a1))
 ROM_END
 
 ROM_START( pc20 )
 /*    ROM_REGION(0x100000,REGION_CPU1, 0) */
     ROM_REGION16_LE(0x100000,REGION_CPU1, 0)
-    ROM_LOAD("wdbios.rom",  0xc8000, 0x02000, CRC(8e9e2bd4))
+    ROM_LOAD("wdbios.rom",  0xc8000, 0x02000, CRC(8e9e2bd4) SHA1(601d7ceab282394ebab50763c267e915a6a2166a))
 
 	/* special bios at 0xe0000 !? */
 	/* This is probably referring to a check for the Amstrad RP5-2 diagnostic */
 	/* card, which can be plugged into an Amstrad XT for troubleshooting purposes. */
 	/* - John Elliott */
-    ROM_LOAD16_BYTE("pc20v2.0", 0xfc001, 0x2000, CRC(41302eb8)) /* v2 */
-    ROM_LOAD16_BYTE("pc20v2.1", 0xfc000, 0x2000, CRC(71b84616)) /* v2 */
+    ROM_LOAD16_BYTE("pc20v2.0", 0xfc001, 0x2000, CRC(41302eb8) SHA1(8b4b2afea543b96b45d6a30365281decc15f2932)) /* v2 */
+    ROM_LOAD16_BYTE("pc20v2.1", 0xfc000, 0x2000, CRC(71b84616) SHA1(4135102a491b25fc659d70b957e07649f3eacf24)) /* v2 */
 	/* also mapped to f0000, f4000, f8000 */
 	ROM_REGION(0x08100,REGION_GFX1, 0)
-    ROM_LOAD("40109.bin",     0x00000, 0x08000, CRC(a8b67639))
+    ROM_LOAD("40109.bin",     0x00000, 0x08000, CRC(a8b67639) SHA1(99663bfb61798526e092205575370c2ad34249a1))
 ROM_END
 
 ROM_START( ppc512 )
 /*    ROM_REGION(0x100000,REGION_CPU1, 0) */
     ROM_REGION16_LE(0x100000,REGION_CPU1, 0)
-    ROM_LOAD("wdbios.rom",  0xc8000, 0x02000, CRC(8e9e2bd4))
+    ROM_LOAD("wdbios.rom",  0xc8000, 0x02000, CRC(8e9e2bd4) SHA1(601d7ceab282394ebab50763c267e915a6a2166a))
 	/* special bios at 0xe0000 !? */
     ROM_LOAD16_BYTE("40107.v1", 0xfc001, 0x2000, CRC(4e37e769)) /* v1.9 */
     ROM_LOAD16_BYTE("40108.v1", 0xfc000, 0x2000, CRC(4f0302d9)) /* v1.9 */
 	/* also mapped to f0000, f4000, f8000 */
 	ROM_REGION(0x08100,REGION_GFX1, 0)
-    ROM_LOAD("40109.bin",     0x00000, 0x08000, CRC(a8b67639))
+    ROM_LOAD("40109.bin",     0x00000, 0x08000, CRC(a8b67639) SHA1(99663bfb61798526e092205575370c2ad34249a1))
 ROM_END
 
 ROM_START( ppc640 )
 /*    ROM_REGION(0x100000,REGION_CPU1, 0) */
     ROM_REGION16_LE(0x100000,REGION_CPU1, 0)
-    ROM_LOAD("wdbios.rom",  0xc8000, 0x02000, CRC(8e9e2bd4))
+    ROM_LOAD("wdbios.rom",  0xc8000, 0x02000, CRC(8e9e2bd4) SHA1(601d7ceab282394ebab50763c267e915a6a2166a))
 	/* special bios at 0xe0000 !? */
     ROM_LOAD16_BYTE("40107.v2", 0xfc001, 0x2000, CRC(0785b63e)) /* v2.1 */
     ROM_LOAD16_BYTE("40108.v2", 0xfc000, 0x2000, CRC(5351cf8c)) /* v2.1 */
 	/* also mapped to f0000, f4000, f8000 */
 	ROM_REGION(0x08100,REGION_GFX1, 0)
-    ROM_LOAD("40109.bin",     0x00000, 0x08000, CRC(a8b67639))
+    ROM_LOAD("40109.bin",     0x00000, 0x08000, CRC(a8b67639) SHA1(99663bfb61798526e092205575370c2ad34249a1))
 ROM_END
 
 ROM_START( pc1512 )
 /*    ROM_REGION(0x100000,REGION_CPU1, 0) */
     ROM_REGION16_LE(0x100000,REGION_CPU1, 0)
-    ROM_LOAD("wdbios.rom",  0xc8000, 0x02000, CRC(8e9e2bd4))
-    ROM_LOAD16_BYTE("40044.v1", 0xfc001, 0x2000, CRC(668fcc94)) /* v1 */
-    ROM_LOAD16_BYTE("40043.v1", 0xfc000, 0x2000, CRC(f72f1582)) /* v1 */
+    ROM_LOAD("wdbios.rom",  0xc8000, 0x02000, CRC(8e9e2bd4) SHA1(601d7ceab282394ebab50763c267e915a6a2166a))
+    ROM_LOAD16_BYTE("40044.v1", 0xfc001, 0x2000, CRC(668fcc94) SHA1(74002f5cc542df442eec9e2e7a18db3598d8c482)) /* v1 */
+    ROM_LOAD16_BYTE("40043.v1", 0xfc000, 0x2000, CRC(f72f1582) SHA1(7781d4717917262805d514b331ba113b1e05a247)) /* v1 */
 	ROM_REGION(0x08100,REGION_GFX1, 0)
-    ROM_LOAD("40045.bin",     0x00000, 0x02000, CRC(dd5e030f))
+    ROM_LOAD("40045.bin",     0x00000, 0x02000, CRC(dd5e030f) SHA1(7d858bbb2e8d6143aa67ab712edf5f753c2788a7))
 ROM_END
 
 ROM_START( pc1512v2 )
 /*    ROM_REGION(0x100000,REGION_CPU1, 0) */
     ROM_REGION16_LE(0x100000,REGION_CPU1, 0)
-    ROM_LOAD("wdbios.rom",  0xc8000, 0x02000, CRC(8e9e2bd4))
-    ROM_LOAD16_BYTE("40044.v2", 0xfc001, 0x2000, CRC(d2d4d2de)) /* v2 */
-    ROM_LOAD16_BYTE("40043.v2", 0xfc000, 0x2000, CRC(1aec54fa)) /* v2 */
+    ROM_LOAD("wdbios.rom",  0xc8000, 0x02000, CRC(8e9e2bd4) SHA1(601d7ceab282394ebab50763c267e915a6a2166a))
+    ROM_LOAD16_BYTE("40044.v2", 0xfc001, 0x2000, CRC(d2d4d2de) SHA1(c376fd1ad23025081ae16c7949e88eea7f56e1bb)) /* v2 */
+    ROM_LOAD16_BYTE("40043.v2", 0xfc000, 0x2000, CRC(1aec54fa) SHA1(b12fd73cfc35a240ed6da4dcc4b6c9910be611e0)) /* v2 */
 	ROM_REGION(0x08100,REGION_GFX1, 0)
-    ROM_LOAD("40078.bin",     0x00000, 0x02000, CRC(ae9c0d04))
+    ROM_LOAD("40078.bin",     0x00000, 0x02000, CRC(ae9c0d04) SHA1(bc8dc4dcedeea5bc1c04986b1f105ad93cb2ebcd))
 ROM_END
 
 ROM_START( pc1640 )
 /*    ROM_REGION(0x100000,REGION_CPU1, 0) */
     ROM_REGION16_LE(0x100000,REGION_CPU1, 0)
-    ROM_LOAD("40100", 0xc0000, 0x8000, CRC(d2d1f1ae)) /* this bios seams to be made for the amstrad pc */
-    ROM_LOAD("wdbios.rom",  0xc8000, 0x02000, CRC(8e9e2bd4))
-    ROM_LOAD16_BYTE("40043.v3", 0xfc001, 0x2000, CRC(e40a1513)) /* v3 */
-    ROM_LOAD16_BYTE("40044.v3", 0xfc000, 0x2000, CRC(f1c074f3))
+    ROM_LOAD("40100", 0xc0000, 0x8000, CRC(d2d1f1ae) SHA1(98302006ee38a17c09bd75504cc18c0649174e33)) /* this bios seams to be made for the amstrad pc */
+    ROM_LOAD("wdbios.rom",  0xc8000, 0x02000, CRC(8e9e2bd4) SHA1(601d7ceab282394ebab50763c267e915a6a2166a))
+    ROM_LOAD16_BYTE("40043.v3", 0xfc001, 0x2000, CRC(e40a1513) SHA1(447eff2057e682e51b1c7593cb6fad0e53879fa8)) /* v3 */
+    ROM_LOAD16_BYTE("40044.v3", 0xfc000, 0x2000, CRC(f1c074f3) SHA1(a055ea7e933d137623c22fe24004e870653c7952))
 	ROM_REGION(0x08100,REGION_GFX1, 0)
-    ROM_LOAD("40045.bin",     0x00000, 0x02000, CRC(dd5e030f))
+    ROM_LOAD("40045.bin",     0x00000, 0x02000, CRC(dd5e030f) SHA1(7d858bbb2e8d6143aa67ab712edf5f753c2788a7))
 ROM_END
 
-static void ibmpc_floppy_getinfo(struct IODevice *dev)
+static void ibmpc_floppy_getinfo(const device_class *devclass, UINT32 state, union devinfo *info)
 {
 	/* floppy */
-	floppy_device_getinfo(dev, floppyoptions_pc);
-	dev->count = 2;
+	switch(state)
+	{
+		/* --- the following bits of info are returned as 64-bit signed integers --- */
+		case DEVINFO_INT_COUNT:							info->i = 2; break;
+
+		/* --- the following bits of info are returned as pointers to data or functions --- */
+		case DEVINFO_PTR_FLOPPY_OPTIONS:				info->p = (void *) floppyoptions_pc; break;
+
+		default:										floppy_device_getinfo(devclass, state, info); break;
+	}
 }
 
-static void ibmpc_printer_getinfo(struct IODevice *dev)
+static void ibmpc_printer_getinfo(const device_class *devclass, UINT32 state, union devinfo *info)
 {
 	/* printer */
-	printer_device_getinfo(dev);
-	dev->count = 3;
+	switch(state)
+	{
+		/* --- the following bits of info are returned as 64-bit signed integers --- */
+		case DEVINFO_INT_COUNT:							info->i = 3; break;
+
+		default:										printer_device_getinfo(devclass, state, info); break;
+	}
 }
 
-static void ibmpc_harddisk_getinfo(struct IODevice *dev)
+static void ibmpc_harddisk_getinfo(const device_class *devclass, UINT32 state, union devinfo *info)
 {
 	/* harddisk */
-	harddisk_device_getinfo(dev);
-	dev->count = 4;
+	switch(state)
+	{
+		/* --- the following bits of info are returned as 64-bit signed integers --- */
+		case DEVINFO_INT_COUNT:							info->i = 4; break;
+
+		default:										harddisk_device_getinfo(devclass, state, info); break;
+	}
 }
 
 SYSTEM_CONFIG_START(ibmpc)
@@ -1624,9 +1645,6 @@ SYSTEM_CONFIG_START(ibmpc)
 	CONFIG_DEVICE(ibmpc_printer_getinfo)
 	CONFIG_DEVICE(ibmpc_floppy_getinfo)
 	CONFIG_DEVICE(ibmpc_harddisk_getinfo)
-	CONFIG_QUEUE_CHARS( at_keyboard )
-	CONFIG_ACCEPT_CHAR( at_keyboard )
-	CONFIG_CHARQUEUE_EMPTY( at_keyboard )
 SYSTEM_CONFIG_END
 
 /***************************************************************************
@@ -1636,27 +1654,27 @@ SYSTEM_CONFIG_END
 ***************************************************************************/
 
 /*	   YEAR		NAME		PARENT	COMPAT	MACHINE     INPUT	    INIT	    CONFIG   COMPANY	 FULLNAME */
-COMP(  1982,	ibmpc,		0,		0,		pccga,      pccga,	    pccga,	    ibmpc,   "International Business Machines",  "IBM PC 10/27/82" )
-COMP(  1982,	ibmpca,		ibmpc,	0,		pccga,      pccga,	    pccga,	    ibmpc,   "International Business Machines",  "IBM PC 08/16/82" )
-COMP(  1987,	pc,			ibmpc,	0,		pccga,      pccga,		pccga,	    ibmpc,   "",  "PC (CGA)" )
-COMPX( 1985,	bondwell,	ibmpc,	0,		pccga,		bondwell,   bondwell,	ibmpc,   "Bondwell Holding",  "BW230 (PRO28 Series)", GAME_NOT_WORKING )
-COMP(  1988,	europc,		ibmpc,	0,		europc,     europc,		europc,     ibmpc,   "Schneider Rdf. AG",  "EURO PC")
+COMP(  1982,	ibmpc,		0,		0,		pccga,      pccga,	    pccga,	    ibmpc,   "International Business Machines",  "IBM PC 10/27/82" , 0)
+COMP(  1982,	ibmpca,		ibmpc,	0,		pccga,      pccga,	    pccga,	    ibmpc,   "International Business Machines",  "IBM PC 08/16/82" , 0)
+COMP(  1987,	pc,			ibmpc,	0,		pccga,      pccga,		pccga,	    ibmpc,   "",  "PC (CGA)" , 0)
+COMP( 1985,	bondwell,	ibmpc,	0,		pccga,		bondwell,   bondwell,	ibmpc,   "Bondwell Holding",  "BW230 (PRO28 Series)", GAME_NOT_WORKING )
+COMP(  1988,	europc,		ibmpc,	0,		europc,     europc,		europc,     ibmpc,   "Schneider Rdf. AG",  "EURO PC", 0)
 
 /* pcjr (better graphics, better sound) */
-COMPX( 1983,	ibmpcjr,	ibmpc,	0,		t1000hx,    tandy1t,	t1000hx,    ibmpc,   "International Business Machines",  "IBM PC Jr", GAME_NOT_WORKING|GAME_IMPERFECT_COLORS )
-COMP(  1987,	t1000hx,	ibmpc,	0,		t1000hx,    tandy1t,	t1000hx,	ibmpc,   "Tandy Radio Shack",  "Tandy 1000HX")
-COMP(  1987,	t1000sx,	ibmpc,	0,		t1000sx,    tandy1t,	t1000hx,	ibmpc,   "Tandy Radio Shack",  "Tandy 1000SX")
+COMP( 1983,	ibmpcjr,	ibmpc,	0,		t1000hx,    tandy1t,	t1000hx,    ibmpc,   "International Business Machines",  "IBM PC Jr", GAME_NOT_WORKING|GAME_IMPERFECT_COLORS )
+COMP(  1987,	t1000hx,	ibmpc,	0,		t1000hx,    tandy1t,	t1000hx,	ibmpc,   "Tandy Radio Shack",  "Tandy 1000HX", 0)
+COMP(  1987,	t1000sx,	ibmpc,	0,		t1000sx,    tandy1t,	t1000hx,	ibmpc,   "Tandy Radio Shack",  "Tandy 1000SX", 0)
 
 /* xt class (pc but 8086) */
-COMP(  1986,	ibmxt,		ibmpc,	0,		xtcga,      xtcga,		pccga,		ibmpc,   "International Business Machines",  "IBM PC/XT (CGA)" )
-COMP(  1988,	pc200,		ibmpc,	0,		pc200,		pc200,		pc200,		ibmpc,   "Sinclair Research",  "PC200 Professional Series")
-COMP(  1988,	pc20,		ibmpc,	0,		pc200,		pc200,		pc200,		ibmpc,   "Amstrad plc",  "Amstrad PC20" )
-COMP(  1987,	ppc512,		ibmpc,	0,		pc200,		pc200,		pc200,		ibmpc,   "Amstrad plc",  "Amstrad PPC512")
-COMP(  1987,	ppc640,		ibmpc,	0,		pc200,		pc200,		pc200,		ibmpc,   "Amstrad plc",  "Amstrad PPC640")
-COMP(  1986,	pc1512,		ibmpc,	0,		pc1512,     pc1512,		pc1512,		ibmpc,   "Amstrad plc",  "Amstrad PC1512 (version 1)")
-COMP(  198?,	pc1512v2,	ibmpc,	0,		pc1512,     pc1512,		pc1512,		ibmpc,   "Amstrad plc",  "Amstrad PC1512 (version 2)")
-COMPX( 1987,	pc1640,		ibmpc,	0,		pc1640,     pc1640,		pc1640,		ibmpc,   "Amstrad plc",  "Amstrad PC1640 / PC6400 (US)", GAME_NOT_WORKING )
+COMP(  1986,	ibmxt,		ibmpc,	0,		xtcga,      xtcga,		pccga,		ibmpc,   "International Business Machines",  "IBM PC/XT (CGA)" , 0)
+COMP(  1988,	pc200,		ibmpc,	0,		pc200,		pc200,		pc200,		ibmpc,   "Sinclair Research",  "PC200 Professional Series", 0)
+COMP(  1988,	pc20,		ibmpc,	0,		pc200,		pc200,		pc200,		ibmpc,   "Amstrad plc",  "Amstrad PC20" , 0)
+COMP(  1987,	ppc512,		ibmpc,	0,		pc200,		pc200,		pc200,		ibmpc,   "Amstrad plc",  "Amstrad PPC512", 0)
+COMP(  1987,	ppc640,		ibmpc,	0,		pc200,		pc200,		pc200,		ibmpc,   "Amstrad plc",  "Amstrad PPC640", 0)
+COMP(  1986,	pc1512,		ibmpc,	0,		pc1512,     pc1512,		pc1512,		ibmpc,   "Amstrad plc",  "Amstrad PC1512 (version 1)", 0)
+COMP(  198?,	pc1512v2,	ibmpc,	0,		pc1512,     pc1512,		pc1512,		ibmpc,   "Amstrad plc",  "Amstrad PC1512 (version 2)", 0)
+COMP( 1987,	pc1640,		ibmpc,	0,		pc1640,     pc1640,		pc1640,		ibmpc,   "Amstrad plc",  "Amstrad PC1640 / PC6400 (US)", GAME_NOT_WORKING )
 /* pc2086 pc1512 with vga?? */
-COMP ( 1987,	pcmda,		ibmpc,	0,		pcmda,      pcmda,		pcmda,	    ibmpc,   "",  "PC (MDA)" )
-COMP ( 1987,	xtvga,		ibmpc,	0,		xtvga,      xtvga,		pc_vga,     ibmpc,   "",  "PC/XT (VGA, MF2 Keyboard)" )
+COMP ( 1987,	pcmda,		ibmpc,	0,		pcmda,      pcmda,		pcmda,	    ibmpc,   "",  "PC (MDA)" , 0)
+COMP ( 1987,	xtvga,		ibmpc,	0,		xtvga,      xtvga,		pc_vga,     ibmpc,   "",  "PC/XT (VGA, MF2 Keyboard)" , 0)
 
