@@ -93,14 +93,14 @@
 #include "includes/centroni.h" /* centronics printer handshake simulation */
 #include "devices/printer.h" /* printer device */
 /* PC-AT keyboard */
-#include "includes/pckeybrd.h"
+#include "machine/pckeybrd.h"
 /* change to superio later */
-#include "includes/pc_fdc_h.h"
+#include "machine/pc_fdc.h"
 /* for pc disk images */
 #include "devices/mflopimg.h"
 #include "formats/pc_dsk.h"
 /* for pc com port */
-#include "includes/uart8250.h"
+#include "machine/uart8250.h"
 /* for pc serial mouse */
 #include "includes/pc_mouse.h"
 /* pcw/pcw16 beeper */
@@ -108,6 +108,8 @@
 
 #include "includes/28f008sa.h"
 
+static void pcw16_machine_stop(void);
+
 /* interrupt counter */
 unsigned long pcw16_interrupt_counter;
 /* video control */
@@ -454,8 +456,8 @@ static void pcw16_update_bank(int bank)
 
 	mem_ptr = mem_ptr + ((bank_id - bank_offs)<<14);
 	pcw16_mem_ptr[bank] = (char*)mem_ptr;
-	cpu_setbank((bank+1), mem_ptr);
-	cpu_setbank((bank+5), mem_ptr);
+	memory_set_bankptr((bank+1), mem_ptr);
+	memory_set_bankptr((bank+5), mem_ptr);
 
 	if ((bank_id & 0x080)==0)
 	{
@@ -1200,8 +1202,9 @@ static void	pcw16_fdc_interrupt(int state)
 	pcw16_trigger_fdc_int();
 }
 
-pc_fdc_hw_interface pcw16_fdc_interface=
+static const struct pc_fdc_interface pcw16_fdc_interface=
 {
+	NEC765A,
 	pcw16_fdc_interrupt,
 	NULL
 };
@@ -1339,7 +1342,7 @@ static CENTRONICS_CONFIG cent_config =
 	pc_lpt_handshake_in
 };
 
-static MACHINE_INIT( pcw16 )
+static MACHINE_RESET( pcw16 )
 {
 	/* flash 0 */
 	flash_init(0);
@@ -1369,23 +1372,22 @@ static MACHINE_INIT( pcw16 )
 	pc_lpt_set_device(0, &CENTRONICS_PRINTER_DEVICE);
 
 	/* initialise mouse */
-	pc_mouse_set_protocol(TYPE_MOUSE_SYSTEMS);
-	pc_mouse_set_input_base(1);
 	pc_mouse_set_serial_port(0);
 	pc_mouse_initialise();
 
 	/* initialise keyboard */
 	at_keyboard_init(AT_KEYBOARD_TYPE_AT);
 	at_keyboard_set_scan_code_set(3);
-	at_keyboard_set_input_port_base(4);
 
 	pcw16_reset();
 
 	beep_set_state(0,0);
 	beep_set_frequency(0,3750);
+
+	add_exit_callback(pcw16_machine_stop);
 }
 
-static MACHINE_STOP( pcw16 )
+static void pcw16_machine_stop(void)
 {
 	/* flash 0 */
 	flash_store(0,"pcw16f1.nv");
@@ -1420,8 +1422,7 @@ static MACHINE_DRIVER_START( pcw16 )
 	MDRV_VBLANK_DURATION(DEFAULT_REAL_60HZ_VBLANK_DURATION)
 	MDRV_INTERLEAVE(1)
 
-	MDRV_MACHINE_INIT( pcw16 )
-	MDRV_MACHINE_STOP( pcw16 )
+	MDRV_MACHINE_RESET( pcw16 )
 
     /* video hardware */
 	MDRV_VIDEO_ATTRIBUTES(VIDEO_TYPE_RASTER)
@@ -1454,18 +1455,31 @@ ROM_START(pcw16)
 	ROM_LOAD("pcw045.sys",0x10000, 524288, CRC(c642f498))
 ROM_END
 
-static void pcw16_printer_getinfo(struct IODevice *dev)
+static void pcw16_printer_getinfo(const device_class *devclass, UINT32 state, union devinfo *info)
 {
 	/* printer */
-	printer_device_getinfo(dev);
-	dev->count = 1;
+	switch(state)
+	{
+		/* --- the following bits of info are returned as 64-bit signed integers --- */
+		case DEVINFO_INT_COUNT:							info->i = 1; break;
+
+		default:										printer_device_getinfo(devclass, state, info); break;
+	}
 }
 
-static void pcw16_floppy_getinfo(struct IODevice *dev)
+static void pcw16_floppy_getinfo(const device_class *devclass, UINT32 state, union devinfo *info)
 {
 	/* floppy */
-	floppy_device_getinfo(dev, floppyoptions_pc);
-	dev->count = 2;
+	switch(state)
+	{
+		/* --- the following bits of info are returned as 64-bit signed integers --- */
+		case DEVINFO_INT_COUNT:							info->i = 2; break;
+
+		/* --- the following bits of info are returned as pointers to data or functions --- */
+		case DEVINFO_PTR_FLOPPY_OPTIONS:				info->p = (void *) floppyoptions_pc; break;
+
+		default:										floppy_device_getinfo(devclass, state, info); break;
+	}
 }
 
 SYSTEM_CONFIG_START(pcw16)
@@ -1475,4 +1489,4 @@ SYSTEM_CONFIG_START(pcw16)
 SYSTEM_CONFIG_END
 
 /*     YEAR  NAME     PARENT	COMPAT	MACHINE    INPUT     INIT   CONFIG,  COMPANY          FULLNAME */
-COMP( 1995, pcw16,	  0,		0,		pcw16,	   pcw16,    0,	    pcw16,   "Amstrad plc",   "PCW16")
+COMP( 1995, pcw16,	  0,		0,		pcw16,	   pcw16,    0,	    pcw16,   "Amstrad plc",   "PCW16", 0)
