@@ -125,84 +125,43 @@ when problems start with -log and look into error.log file
 #include "includes/cbmieeeb.h"
 /*#include "includes/vc1541.h" */
 
-static ADDRESS_MAP_START( pet_readmem , ADDRESS_SPACE_PROGRAM, 8)
-	AM_RANGE(0x0000, 0x7fff) AM_READ( MRA8_RAM)
-	AM_RANGE(0x8000, 0x83ff) AM_READ( MRA8_RAM )
-	AM_RANGE(0xa000, 0xe7ff) AM_READ( MRA8_ROM )
-	AM_RANGE(0xe810, 0xe813) AM_READ( pia_0_r )
-	AM_RANGE(0xe820, 0xe823) AM_READ( pia_1_r )
-	AM_RANGE(0xe840, 0xe84f) AM_READ( via_0_r )
+static ADDRESS_MAP_START(pet_mem , ADDRESS_SPACE_PROGRAM, 8)
+	AM_RANGE(0x8000, 0x83ff) AM_RAM AM_BASE(&videoram) AM_SIZE(&videoram_size )
+	AM_RANGE(0xa000, 0xe7ff) AM_ROM
+	AM_RANGE(0xe810, 0xe813) AM_READWRITE(pia_0_r, pia_0_w)
+	AM_RANGE(0xe820, 0xe823) AM_READWRITE(pia_1_r, pia_1_w)
+	AM_RANGE(0xe840, 0xe84f) AM_READWRITE(via_0_r, via_0_w)
 /*	{0xe900, 0xe91f, cbm_ieee_state }, // for debugging */
-	AM_RANGE(0xf000, 0xffff) AM_READ( MRA8_ROM )
+	AM_RANGE(0xf000, 0xffff) AM_ROM
 ADDRESS_MAP_END
 
-static ADDRESS_MAP_START( pet_writemem , ADDRESS_SPACE_PROGRAM, 8)
-	AM_RANGE(0x0000, 0x7fff) AM_WRITE( MWA8_RAM) AM_BASE( &pet_memory)
-	AM_RANGE(0x8000, 0x83ff) AM_WRITE( videoram_w) AM_BASE( &videoram) AM_SIZE( &videoram_size )
-	AM_RANGE(0xa000, 0xe7ff) AM_WRITE( MWA8_ROM )
-	AM_RANGE(0xe810, 0xe813) AM_WRITE( pia_0_w )
-	AM_RANGE(0xe820, 0xe823) AM_WRITE( pia_1_w )
-	AM_RANGE(0xe840, 0xe84f) AM_WRITE( via_0_w )
-	AM_RANGE(0xf000, 0xffff) AM_WRITE( MWA8_ROM )
+static ADDRESS_MAP_START( pet40_mem , ADDRESS_SPACE_PROGRAM, 8)
+	AM_RANGE(0x8000, 0x83ff) AM_RAM AM_BASE(&videoram) AM_SIZE(&videoram_size )
+	AM_RANGE(0xa000, 0xe7ff) AM_ROM
+	AM_RANGE(0xe810, 0xe813) AM_READWRITE(pia_0_r, pia_0_w)
+	AM_RANGE(0xe820, 0xe823) AM_READWRITE(pia_1_r, pia_1_w)
+	AM_RANGE(0xe840, 0xe84f) AM_READWRITE(via_0_r, via_0_w)
+	AM_RANGE(0xe880, 0xe881) AM_READWRITE(crtc6845_0_port_r, crtc6845_0_port_w)
+	AM_RANGE(0xf000, 0xffff) AM_ROM
 ADDRESS_MAP_END
 
-static ADDRESS_MAP_START( pet40_readmem , ADDRESS_SPACE_PROGRAM, 8)
-	AM_RANGE(0x0000, 0x7fff) AM_READ( MRA8_RAM)
-	AM_RANGE(0x8000, 0x83ff) AM_READ( MRA8_RAM )
-	AM_RANGE(0xa000, 0xe7ff) AM_READ( MRA8_ROM )
-	AM_RANGE(0xe810, 0xe813) AM_READ( pia_0_r )
-	AM_RANGE(0xe820, 0xe823) AM_READ( pia_1_r )
-	AM_RANGE(0xe840, 0xe84f) AM_READ( via_0_r )
-	AM_RANGE(0xe880, 0xe881) AM_READ( crtc6845_0_port_r )
-	AM_RANGE(0xf000, 0xffff) AM_READ( MRA8_ROM )
-ADDRESS_MAP_END
-
-static ADDRESS_MAP_START( pet40_writemem , ADDRESS_SPACE_PROGRAM, 8)
-	AM_RANGE(0x0000, 0x7fff) AM_WRITE( MWA8_RAM) AM_BASE( &pet_memory)
-	AM_RANGE(0x8000, 0x83ff) AM_WRITE( videoram_w) AM_BASE( &videoram) AM_SIZE( &videoram_size )
-	AM_RANGE(0xa000, 0xe7ff) AM_WRITE( MWA8_ROM )
-	AM_RANGE(0xe810, 0xe813) AM_WRITE( pia_0_w )
-	AM_RANGE(0xe820, 0xe823) AM_WRITE( pia_1_w )
-	AM_RANGE(0xe840, 0xe84f) AM_WRITE( via_0_w )
-	AM_RANGE(0xe880, 0xe881) AM_WRITE( crtc6845_0_port_w )
-	AM_RANGE(0xf000, 0xffff) AM_WRITE( MWA8_ROM )
-ADDRESS_MAP_END
-
-static ADDRESS_MAP_START( pet80_readmem , ADDRESS_SPACE_PROGRAM, 8)
-	AM_RANGE(0x0000, 0x7fff) AM_READ( MRA8_RAM )
-	AM_RANGE(0x8000, 0x8fff) AM_READ( MRA8_BANK1 )
-	AM_RANGE(0x9000, 0x9fff) AM_READ( MRA8_BANK2 )
-	AM_RANGE(0xa000, 0xafff) AM_READ( MRA8_BANK3 )
-	AM_RANGE(0xb000, 0xbfff) AM_READ( MRA8_BANK4 )
-	AM_RANGE(0xc000, 0xe7ff) AM_READ( MRA8_BANK6 )
+static ADDRESS_MAP_START( pet80_mem , ADDRESS_SPACE_PROGRAM, 8)
+	AM_RANGE(0x8000, 0x8fff) AM_RAMBANK(1)
+	AM_RANGE(0x9000, 0x9fff) AM_RAMBANK(2)
+	AM_RANGE(0xa000, 0xafff) AM_RAMBANK(3)
+	AM_RANGE(0xb000, 0xbfff) AM_RAMBANK(4)
+	AM_RANGE(0xc000, 0xe7ff) AM_RAMBANK(6)
 #if 1
-	AM_RANGE(0xe800, 0xefff) AM_READ( MRA8_BANK7 )
+	AM_RANGE(0xe800, 0xefff) AM_RAMBANK(7)
 #else
-	AM_RANGE(0xe810, 0xe813) AM_READ( pia_0_r )
-	AM_RANGE(0xe820, 0xe823) AM_READ( pia_1_r )
-	AM_RANGE(0xe840, 0xe84f) AM_READ( via_0_r )
-	AM_RANGE(0xe880, 0xe881) AM_READ( crtc6845_0_port_r )
+	AM_RANGE(0xe810, 0xe813) AM_READWRITE(pia_0_r, pia_0_w)
+	AM_RANGE(0xe820, 0xe823) AM_READWRITE(pia_1_r, pia_1_w)
+	AM_RANGE(0xe840, 0xe84f) AM_READWRITE(via_0_r, via_0_w)
+	AM_RANGE(0xe880, 0xe881) AM_READWRITE(crtc6845_0_port_r, crtc6845_0_port_w)
 #endif
-	AM_RANGE(0xf000, 0xffff) AM_READ( MRA8_BANK8 )
-ADDRESS_MAP_END
-
-static ADDRESS_MAP_START( pet80_writemem , ADDRESS_SPACE_PROGRAM, 8)
-	AM_RANGE(0x0000, 0x7fff) AM_WRITE( MWA8_RAM) AM_BASE( &pet_memory)
-	AM_RANGE(0x8000, 0x8fff) AM_WRITE( MWA8_BANK1) AM_BASE( &videoram )
-	AM_RANGE(0x9000, 0x9fff) AM_WRITE( MWA8_BANK2 )
-	AM_RANGE(0xa000, 0xafff) AM_WRITE( MWA8_BANK3 )
-	AM_RANGE(0xb000, 0xbfff) AM_WRITE( MWA8_BANK4 )
-	AM_RANGE(0xc000, 0xe7ff) AM_WRITE( MWA8_BANK6 )
-#if 1
-	AM_RANGE(0xe800, 0xefff) AM_WRITE( MWA8_BANK7 )
-#else
-	AM_RANGE(0xe810, 0xe813) AM_WRITE( pia_0_w )
-	AM_RANGE(0xe820, 0xe823) AM_WRITE( pia_1_w )
-	AM_RANGE(0xe840, 0xe84f) AM_WRITE( via_0_w )
-	AM_RANGE(0xe880, 0xe881) AM_WRITE( crtc6845_0_port_w )
-#endif
-	AM_RANGE(0xf000, 0xffef) AM_WRITE( MWA8_BANK8 )
-    AM_RANGE(0xfff1, 0xffff) AM_WRITE( MWA8_BANK9 )
+	AM_RANGE(0xf000, 0xffff) AM_READ(MRA8_BANK8)
+	AM_RANGE(0xf000, 0xffef) AM_WRITE(MWA8_BANK8)
+	AM_RANGE(0xfff1, 0xffff) AM_WRITE(MWA8_BANK9)
 ADDRESS_MAP_END
 
 
@@ -221,56 +180,31 @@ ADDRESS_MAP_END
         bit 7    1=enable system latch
 
 */
-static ADDRESS_MAP_START( superpet_readmem , ADDRESS_SPACE_PROGRAM, 8)
-	AM_RANGE(0x0000, 0x7fff) AM_READ( MRA8_RAM)
-	AM_RANGE(0x8000, 0x87ff) AM_READ( MRA8_RAM )
-	AM_RANGE(0xa000, 0xe7ff) AM_READ( MRA8_ROM )
-	AM_RANGE(0xe810, 0xe813) AM_READ( pia_0_r )
-	AM_RANGE(0xe820, 0xe823) AM_READ( pia_1_r )
-	AM_RANGE(0xe840, 0xe84f) AM_READ( via_0_r )
-	AM_RANGE(0xe880, 0xe881) AM_READ( crtc6845_0_port_r )
+static ADDRESS_MAP_START( superpet_mem , ADDRESS_SPACE_PROGRAM, 8)
+	AM_RANGE(0x0000, 0x7fff) AM_RAM AM_SHARE(1) AM_BASE(&pet_memory)
+	AM_RANGE(0x8000, 0x87ff) AM_RAM AM_SHARE(2) AM_BASE(&videoram) AM_SIZE(&videoram_size)
+	AM_RANGE(0xa000, 0xe7ff) AM_ROM
+	AM_RANGE(0xe810, 0xe813) AM_READWRITE(pia_0_r, pia_0_w)
+	AM_RANGE(0xe820, 0xe823) AM_READWRITE(pia_1_r, pia_1_w)
+	AM_RANGE(0xe840, 0xe84f) AM_READWRITE(via_0_r, via_0_w)
+	AM_RANGE(0xe880, 0xe881) AM_READWRITE(crtc6845_0_port_r, crtc6845_0_port_w)
 	/* 0xefe0, 0xefe3, mos 6702 */
 	/* 0xeff0, 0xeff3, acia6551 */
-	AM_RANGE(0xeff8, 0xefff) AM_READ( superpet_r )
-	AM_RANGE(0xf000, 0xffff) AM_READ( MRA8_ROM )
+	AM_RANGE(0xeff8, 0xefff) AM_READWRITE(superpet_r, superpet_w)
+	AM_RANGE(0xf000, 0xffff) AM_ROM
 ADDRESS_MAP_END
 
-static ADDRESS_MAP_START( superpet_writemem , ADDRESS_SPACE_PROGRAM, 8)
-	AM_RANGE(0x0000, 0x7fff) AM_WRITE( MWA8_RAM) AM_BASE( &pet_memory)
-	AM_RANGE(0x8000, 0x87ff) AM_WRITE( videoram_w) AM_BASE( &videoram) AM_SIZE( &videoram_size )
-	AM_RANGE(0xa000, 0xe7ff) AM_WRITE( MWA8_ROM )
-	AM_RANGE(0xe810, 0xe813) AM_WRITE( pia_0_w )
-	AM_RANGE(0xe820, 0xe823) AM_WRITE( pia_1_w )
-	AM_RANGE(0xe840, 0xe84f) AM_WRITE( via_0_w )
-	AM_RANGE(0xe880, 0xe881) AM_WRITE( crtc6845_0_port_w )
-	AM_RANGE(0xeff8, 0xefff) AM_WRITE( superpet_w )
-	AM_RANGE(0xf000, 0xffff) AM_WRITE( MWA8_ROM )
-ADDRESS_MAP_END
-
-static ADDRESS_MAP_START( superpet_m6809_readmem, ADDRESS_SPACE_PROGRAM, 8)
-	AM_RANGE(0x0000, 0x7fff) AM_READ( MRA8_BANK1)
-	AM_RANGE(0x8000, 0x87ff) AM_READ( MRA8_BANK2 )
-    AM_RANGE(0x9000, 0x9fff) AM_READ( MRA8_BANK3 )
-	AM_RANGE(0xa000, 0xe7ff) AM_READ( MRA8_ROM )
-	AM_RANGE(0xe810, 0xe813) AM_READ( pia_0_r )
-	AM_RANGE(0xe820, 0xe823) AM_READ( pia_1_r )
-	AM_RANGE(0xe840, 0xe84f) AM_READ( via_0_r )
-	AM_RANGE(0xe880, 0xe881) AM_READ( crtc6845_0_port_r )
-	AM_RANGE(0xeff8, 0xefff) AM_READ( superpet_r )
-	AM_RANGE(0xf000, 0xffff) AM_READ( MRA8_ROM )
-ADDRESS_MAP_END
-
-static ADDRESS_MAP_START( superpet_m6809_writemem , ADDRESS_SPACE_PROGRAM, 8)
-	AM_RANGE(0x0000, 0x7fff) AM_WRITE( MWA8_BANK1 ) /* same memory as m6502 */
-	AM_RANGE(0x8000, 0x87ff) AM_WRITE( videoram_w ) /* same memory as m6502 */
-    AM_RANGE(0x9000, 0x9fff) AM_WRITE( MWA8_BANK3 ) /* 64 kbyte ram turned in */
-	AM_RANGE(0xa000, 0xe7ff) AM_WRITE( MWA8_ROM )
-	AM_RANGE(0xe810, 0xe813) AM_WRITE( pia_0_w )
-	AM_RANGE(0xe820, 0xe823) AM_WRITE( pia_1_w )
-	AM_RANGE(0xe840, 0xe84f) AM_WRITE( via_0_w )
-	AM_RANGE(0xe880, 0xe881) AM_WRITE( crtc6845_0_port_w )
-	AM_RANGE(0xeff8, 0xefff) AM_WRITE( superpet_w )
-	AM_RANGE(0xf000, 0xffff) AM_WRITE( MWA8_ROM )
+static ADDRESS_MAP_START( superpet_m6809_mem, ADDRESS_SPACE_PROGRAM, 8)
+	AM_RANGE(0x0000, 0x7fff) AM_RAM AM_SHARE(1)	/* same memory as m6502 */
+	AM_RANGE(0x8000, 0x87ff) AM_RAM AM_SHARE(2)	/* same memory as m6502 */
+    AM_RANGE(0x9000, 0x9fff) AM_RAMBANK(1)	/* 64 kbyte ram turned in */
+	AM_RANGE(0xa000, 0xe7ff) AM_ROM
+	AM_RANGE(0xe810, 0xe813) AM_READWRITE(pia_0_r, pia_0_w)
+	AM_RANGE(0xe820, 0xe823) AM_READWRITE(pia_1_r, pia_1_w)
+	AM_RANGE(0xe840, 0xe84f) AM_READWRITE(via_0_r, via_0_w)
+	AM_RANGE(0xe880, 0xe881) AM_READWRITE(crtc6845_0_port_r, crtc6845_0_port_w)
+	AM_RANGE(0xeff8, 0xefff) AM_READWRITE(superpet_r, superpet_w)
+	AM_RANGE(0xf000, 0xffff) AM_ROM
 ADDRESS_MAP_END
 
 #define DIPS_HELPER(bit, name, keycode) \
@@ -575,51 +509,54 @@ static unsigned short pet_colortable[][2] = {
 
 static gfx_layout pet_charlayout =
 {
-        8,8,
-        256,                                    /* 256 characters */
-        1,                      /* 1 bits per pixel */
-        { 0 },                  /* no bitplanes; 1 bit per pixel */
-        /* x offsets */
-        { 0,1,2,3,4,5,6,7 },
-        /* y offsets */
-        { 0*8, 1*8, 2*8, 3*8, 4*8, 5*8, 6*8, 7*8,
-        },
-        8*8
+	8,8,
+	256,                                    /* 256 characters */
+	1,                      /* 1 bits per pixel */
+	{ 0 },                  /* no bitplanes; 1 bit per pixel */
+	/* x offsets */
+	{ 0,1,2,3,4,5,6,7 },
+	/* y offsets */
+	{ 0*8, 1*8, 2*8, 3*8, 4*8, 5*8, 6*8, 7*8,
+	},
+	8*8
 };
 
 static gfx_layout pet80_charlayout =
 {
-        8,16,
-        256,                                    /* 256 characters */
-        1,                      /* 1 bits per pixel */
-        { 0 },                  /* no bitplanes; 1 bit per pixel */
-        /* x offsets */
-        { 0,1,2,3,4,5,6,7 },
-        /* y offsets */
-        {
-			0*8, 1*8, 2*8, 3*8, 4*8, 5*8, 6*8, 7*8,
-			8*8, 9*8, 10*8, 11*8, 12*8, 13*8, 14*8, 15*8
-        },
-        8*16
+	8,16,
+	256,                                    /* 256 characters */
+	1,                      /* 1 bits per pixel */
+	{ 0 },                  /* no bitplanes; 1 bit per pixel */
+	/* x offsets */
+	{ 0,1,2,3,4,5,6,7 },
+	/* y offsets */
+	{
+		0*8, 1*8, 2*8, 3*8, 4*8, 5*8, 6*8, 7*8,
+		8*8, 9*8, 10*8, 11*8, 12*8, 13*8, 14*8, 15*8
+	},
+	8*16
 };
 
-static gfx_decode pet_gfxdecodeinfo[] = {
-	{ 1, 0x0000, &pet_charlayout,                     0, 1 },
-	{ 1, 0x0800, &pet_charlayout,                     0, 1 },
+static gfx_decode pet_gfxdecodeinfo[] =
+{
+	{ REGION_GFX1, 0x0000, &pet_charlayout,                     0, 1 },
+	{ REGION_GFX1, 0x0800, &pet_charlayout,                     0, 1 },
     { -1 } /* end of array */
 };
 
-static gfx_decode pet80_gfxdecodeinfo[] = {
-	{ 1, 0x0000, &pet80_charlayout,                     0, 1 },
-	{ 1, 0x1000, &pet80_charlayout,                     0, 1 },
+static gfx_decode pet80_gfxdecodeinfo[] =
+{
+	{ REGION_GFX1, 0x0000, &pet80_charlayout,                     0, 1 },
+	{ REGION_GFX1, 0x1000, &pet80_charlayout,                     0, 1 },
     { -1 } /* end of array */
 };
 
-static gfx_decode superpet_gfxdecodeinfo[] = {
-	{ 2, 0x0000, &pet80_charlayout,                     0, 1 },
-	{ 2, 0x1000, &pet80_charlayout,                     0, 1 },
-	{ 2, 0x2000, &pet80_charlayout,                     0, 1 },
-	{ 2, 0x3000, &pet80_charlayout,                     0, 1 },
+static gfx_decode superpet_gfxdecodeinfo[] =
+{
+	{ REGION_GFX1, 0x0000, &pet80_charlayout,                     0, 1 },
+	{ REGION_GFX1, 0x1000, &pet80_charlayout,                     0, 1 },
+	{ REGION_GFX1, 0x2000, &pet80_charlayout,                     0, 1 },
+	{ REGION_GFX1, 0x3000, &pet80_charlayout,                     0, 1 },
     { -1 } /* end of array */
 };
 
@@ -632,154 +569,154 @@ static PALETTE_INIT( pet )
 /* basic 1 */
 ROM_START (pet)
 	ROM_REGION (0x10000, REGION_CPU1, 0)
-    ROM_LOAD ("901447.09", 0xc000, 0x800, CRC(03cf16d0))
-    ROM_LOAD ("901447.02", 0xc800, 0x800, CRC(69fd8a8f))
-    ROM_LOAD ("901447.03", 0xd000, 0x800, CRC(d349f2d4))
-    ROM_LOAD ("901447.04", 0xd800, 0x800, CRC(850544eb))
-    ROM_LOAD ("901447.05", 0xe000, 0x800, CRC(9e1c5cea))
-    ROM_LOAD ("901447.06", 0xf000, 0x800, CRC(661a814a))
-    ROM_LOAD ("901447.07", 0xf800, 0x800, CRC(c4f47ad1))
+    ROM_LOAD ("901447.09", 0xc000, 0x800, CRC(03cf16d0) SHA1(1330580c0614d3556a389da4649488ba04a60908))
+    ROM_LOAD ("901447.02", 0xc800, 0x800, CRC(69fd8a8f) SHA1(70c0f4fa67a70995b168668c957c3fcf2c8641bd))
+    ROM_LOAD ("901447.03", 0xd000, 0x800, CRC(d349f2d4) SHA1(4bf2c20c51a63d213886957485ebef336bb803d0))
+    ROM_LOAD ("901447.04", 0xd800, 0x800, CRC(850544eb) SHA1(d293972d529023d8fd1f493149e4777b5c253a69))
+    ROM_LOAD ("901447.05", 0xe000, 0x800, CRC(9e1c5cea) SHA1(f02f5fb492ba93dbbd390f24c10f7a832dec432a))
+    ROM_LOAD ("901447.06", 0xf000, 0x800, CRC(661a814a) SHA1(960717282878e7de893d87242ddf9d1512be162e))
+    ROM_LOAD ("901447.07", 0xf800, 0x800, CRC(c4f47ad1) SHA1(d440f2510bc52e20c3d6bc8b9ded9cea7f462a9c))
 	ROM_REGION (0x1000, REGION_GFX1, 0)
-    ROM_LOAD ("901447.08", 0x0000, 0x800, CRC(54f32f45))
+    ROM_LOAD ("901447.08", 0x0000, 0x800, CRC(54f32f45) SHA1(3e067cc621e4beafca2b90cb8f6dba975df2855b))
 ROM_END
 
 /* basic 2 */
 ROM_START (pet2)
 	ROM_REGION (0x10000, REGION_CPU1, 0)
-    ROM_LOAD ("901465.01", 0xc000, 0x1000, CRC(63a7fe4a))
-    ROM_LOAD ("901465.02", 0xd000, 0x1000, CRC(ae4cb035))
-    ROM_LOAD ("901447.24", 0xe000, 0x800, CRC(e459ab32))
-    ROM_LOAD ("901465.03", 0xf000, 0x1000, CRC(f02238e2))
+    ROM_LOAD ("901465.01", 0xc000, 0x1000, CRC(63a7fe4a) SHA1(3622111f486d0e137022523657394befa92bde44))
+    ROM_LOAD ("901465.02", 0xd000, 0x1000, CRC(ae4cb035) SHA1(1bc0ebf27c9bb62ad71bca40313e874234cab6ac))
+    ROM_LOAD ("901447.24", 0xe000, 0x800, CRC(e459ab32) SHA1(5e5502ce32f5a7e387d65efe058916282041e54b))
+    ROM_LOAD ("901465.03", 0xf000, 0x1000, CRC(f02238e2) SHA1(38742bdf449f629bcba6276ef24d3daeb7da6e84))
 	ROM_REGION (0x1000, REGION_GFX1, 0)
-    ROM_LOAD ("901447.08", 0x0000, 0x800, CRC(54f32f45))
+    ROM_LOAD ("901447.08", 0x0000, 0x800, CRC(54f32f45) SHA1(3e067cc621e4beafca2b90cb8f6dba975df2855b))
 ROM_END
 
 /* basic 2 business */
 ROM_START (pet2b)
 	ROM_REGION (0x10000, REGION_CPU1, 0)
-    ROM_LOAD ("901465.01", 0xc000, 0x1000, CRC(63a7fe4a))
-    ROM_LOAD ("901465.02", 0xd000, 0x1000, CRC(ae4cb035))
-    ROM_LOAD ("901474.01", 0xe000, 0x800, CRC(05db957e))
-    ROM_LOAD ("901465.03", 0xf000, 0x1000, CRC(f02238e2))
+    ROM_LOAD ("901465.01", 0xc000, 0x1000, CRC(63a7fe4a) SHA1(3622111f486d0e137022523657394befa92bde44))
+    ROM_LOAD ("901465.02", 0xd000, 0x1000, CRC(ae4cb035) SHA1(1bc0ebf27c9bb62ad71bca40313e874234cab6ac))
+    ROM_LOAD ("901474.01", 0xe000, 0x800, CRC(05db957e) SHA1(174ace3a8c0348cd21d39cc864e2adc58b0101a9))
+    ROM_LOAD ("901465.03", 0xf000, 0x1000, CRC(f02238e2) SHA1(38742bdf449f629bcba6276ef24d3daeb7da6e84))
 	ROM_REGION (0x1000, REGION_GFX1, 0)
-    ROM_LOAD ("901447.10", 0x0000, 0x800, CRC(d8408674))
+    ROM_LOAD ("901447.10", 0x0000, 0x800, CRC(d8408674) SHA1(0157a2d55b7ac4eaeb38475889ebeea52e2593db))
 ROM_END
 
 /* basic 4 business */
 ROM_START (pet4b)
 	ROM_REGION (0x10000, REGION_CPU1, 0)
-    ROM_LOAD ("901465.23", 0xb000, 0x1000, CRC(ae3deac0))
-    ROM_LOAD ("901465.20", 0xc000, 0x1000, CRC(0fc17b9c))
-    ROM_LOAD ("901465.21", 0xd000, 0x1000, CRC(36d91855))
-    ROM_LOAD ("901474.02", 0xe000, 0x800, CRC(75ff4af7))
-    ROM_LOAD ("901465.22", 0xf000, 0x1000, CRC(cc5298a1))
+    ROM_LOAD ("901465.23", 0xb000, 0x1000, CRC(ae3deac0) SHA1(975ee25e28ff302879424587e5fb4ba19f403adc))
+    ROM_LOAD ("901465.20", 0xc000, 0x1000, CRC(0fc17b9c) SHA1(242f98298931d21eaacb55fe635e44b7fc192b0a))
+    ROM_LOAD ("901465.21", 0xd000, 0x1000, CRC(36d91855) SHA1(1bb236c72c726e8fb029c68f9bfa5ee803faf0a8))
+    ROM_LOAD ("901474.02", 0xe000, 0x800, CRC(75ff4af7) SHA1(0ca5c4e8f532f914cb0bf86ea9900f20f0a655ce))
+    ROM_LOAD ("901465.22", 0xf000, 0x1000, CRC(cc5298a1) SHA1(96a0fa56e0c937da92971d9c99d504e44e898806))
 	ROM_REGION (0x1000, REGION_GFX1, 0)
-    ROM_LOAD ("901447.10", 0x0000, 0x800, CRC(d8408674))
+    ROM_LOAD ("901447.10", 0x0000, 0x800, CRC(d8408674) SHA1(0157a2d55b7ac4eaeb38475889ebeea52e2593db))
 ROM_END
 
 /* basic 4 crtc*/
 ROM_START (pet4)
 	ROM_REGION (0x10000, REGION_CPU1, 0)
-    ROM_LOAD ("901465.23", 0xb000, 0x1000, CRC(ae3deac0))
-    ROM_LOAD ("901465.20", 0xc000, 0x1000, CRC(0fc17b9c))
-    ROM_LOAD ("901465.21", 0xd000, 0x1000, CRC(36d91855))
-    ROM_LOAD ("901499.01", 0xe000, 0x800, CRC(5f85bdf8))
-    ROM_LOAD ("901465.22", 0xf000, 0x1000, CRC(cc5298a1))
+    ROM_LOAD ("901465.23", 0xb000, 0x1000, CRC(ae3deac0) SHA1(975ee25e28ff302879424587e5fb4ba19f403adc))
+    ROM_LOAD ("901465.20", 0xc000, 0x1000, CRC(0fc17b9c) SHA1(242f98298931d21eaacb55fe635e44b7fc192b0a))
+    ROM_LOAD ("901465.21", 0xd000, 0x1000, CRC(36d91855) SHA1(1bb236c72c726e8fb029c68f9bfa5ee803faf0a8))
+    ROM_LOAD ("901499.01", 0xe000, 0x800, CRC(5f85bdf8) SHA1(8cbf086c1ce4dfb2a2fe24c47476dfb878493dee))
+    ROM_LOAD ("901465.22", 0xf000, 0x1000, CRC(cc5298a1) SHA1(96a0fa56e0c937da92971d9c99d504e44e898806))
 	ROM_REGION (0x1000, REGION_GFX1, 0)
-    ROM_LOAD ("901447.08", 0x0000, 0x800, CRC(54f32f45))
+    ROM_LOAD ("901447.08", 0x0000, 0x800, CRC(54f32f45) SHA1(3e067cc621e4beafca2b90cb8f6dba975df2855b))
 ROM_END
 
 /* basic 4 crtc 50 hz */
 ROM_START (pet4pal)
 	ROM_REGION (0x10000, REGION_CPU1, 0)
-    ROM_LOAD ("901465.23", 0xb000, 0x1000, CRC(ae3deac0))
-    ROM_LOAD ("901465.20", 0xc000, 0x1000, CRC(0fc17b9c))
-    ROM_LOAD ("901465.21", 0xd000, 0x1000, CRC(36d91855))
-    ROM_LOAD ("901498.01", 0xe000, 0x800, CRC(3370e359))
-    ROM_LOAD ("901465.22", 0xf000, 0x1000, CRC(cc5298a1))
+    ROM_LOAD ("901465.23", 0xb000, 0x1000, CRC(ae3deac0) SHA1(975ee25e28ff302879424587e5fb4ba19f403adc))
+    ROM_LOAD ("901465.20", 0xc000, 0x1000, CRC(0fc17b9c) SHA1(242f98298931d21eaacb55fe635e44b7fc192b0a))
+    ROM_LOAD ("901465.21", 0xd000, 0x1000, CRC(36d91855) SHA1(1bb236c72c726e8fb029c68f9bfa5ee803faf0a8))
+    ROM_LOAD ("901498.01", 0xe000, 0x800, CRC(3370e359) SHA1(05af284c914d53a52987b5f602466de75765f650))
+    ROM_LOAD ("901465.22", 0xf000, 0x1000, CRC(cc5298a1) SHA1(96a0fa56e0c937da92971d9c99d504e44e898806))
 	ROM_REGION (0x1000, REGION_GFX1, 0)
-    ROM_LOAD ("901447.08", 0x0000, 0x800, CRC(54f32f45))
+    ROM_LOAD ("901447.08", 0x0000, 0x800, CRC(54f32f45) SHA1(3e067cc621e4beafca2b90cb8f6dba975df2855b))
 ROM_END
 
 /* basic 4 business 80 columns */
 ROM_START (pet80)
 	ROM_REGION (0x20000, REGION_CPU1, 0)
-    ROM_LOAD ("901465.23", 0xb000, 0x1000, CRC(ae3deac0))
-    ROM_LOAD ("901465.20", 0xc000, 0x1000, CRC(0fc17b9c))
-    ROM_LOAD ("901465.21", 0xd000, 0x1000, CRC(36d91855))
-    ROM_LOAD ("901474.03", 0xe000, 0x800, CRC(5674dd5e))
-    ROM_LOAD ("901465.22", 0xf000, 0x1000, CRC(cc5298a1))
+    ROM_LOAD ("901465.23", 0xb000, 0x1000, CRC(ae3deac0) SHA1(975ee25e28ff302879424587e5fb4ba19f403adc))
+    ROM_LOAD ("901465.20", 0xc000, 0x1000, CRC(0fc17b9c) SHA1(242f98298931d21eaacb55fe635e44b7fc192b0a))
+    ROM_LOAD ("901465.21", 0xd000, 0x1000, CRC(36d91855) SHA1(1bb236c72c726e8fb029c68f9bfa5ee803faf0a8))
+    ROM_LOAD ("901474.03", 0xe000, 0x800, CRC(5674dd5e) SHA1(c605fa343fd77c73cbe1e0e9567e2f014f6e7e30))
+    ROM_LOAD ("901465.22", 0xf000, 0x1000, CRC(cc5298a1) SHA1(96a0fa56e0c937da92971d9c99d504e44e898806))
 	ROM_REGION (0x2000, REGION_GFX1, 0)
-    ROM_LOAD ("901447.10", 0x0000, 0x800, CRC(d8408674))
+    ROM_LOAD ("901447.10", 0x0000, 0x800, CRC(d8408674) SHA1(0157a2d55b7ac4eaeb38475889ebeea52e2593db))
 ROM_END
 
 /* basic 4 business 80 columns 50 hz */
 ROM_START (pet80pal)
 	ROM_REGION (0x20000, REGION_CPU1, 0)
-    ROM_LOAD ("901465.23", 0xb000, 0x1000, CRC(ae3deac0))
-    ROM_LOAD ("901465.20", 0xc000, 0x1000, CRC(0fc17b9c))
-    ROM_LOAD ("901465.21", 0xd000, 0x1000, CRC(36d91855))
-    ROM_LOAD ("901474.04", 0xe000, 0x800, CRC(abb000e7))
-    ROM_LOAD ("901465.22", 0xf000, 0x1000, CRC(cc5298a1))
+    ROM_LOAD ("901465.23", 0xb000, 0x1000, CRC(ae3deac0) SHA1(975ee25e28ff302879424587e5fb4ba19f403adc))
+    ROM_LOAD ("901465.20", 0xc000, 0x1000, CRC(0fc17b9c) SHA1(242f98298931d21eaacb55fe635e44b7fc192b0a))
+    ROM_LOAD ("901465.21", 0xd000, 0x1000, CRC(36d91855) SHA1(1bb236c72c726e8fb029c68f9bfa5ee803faf0a8))
+    ROM_LOAD ("901474.04", 0xe000, 0x800, CRC(abb000e7) SHA1(66887061b6c4ebef7d6efb90af9afd5e2c3b08ba))
+    ROM_LOAD ("901465.22", 0xf000, 0x1000, CRC(cc5298a1) SHA1(96a0fa56e0c937da92971d9c99d504e44e898806))
 	ROM_REGION (0x2000, REGION_GFX1, 0)
-    ROM_LOAD ("901447.10", 0x0000, 0x800, CRC(d8408674))
+    ROM_LOAD ("901447.10", 0x0000, 0x800, CRC(d8408674) SHA1(0157a2d55b7ac4eaeb38475889ebeea52e2593db))
 ROM_END
 
 ROM_START (cbm80ger)
 	ROM_REGION (0x20000, REGION_CPU1, 0)
-	ROM_LOAD ("901465.23", 0xb000, 0x1000, CRC(ae3deac0))
-	ROM_LOAD ("901465.20", 0xc000, 0x1000, CRC(0fc17b9c))
-	ROM_LOAD ("901465.21", 0xd000, 0x1000, CRC(36d91855))
-	ROM_LOAD ("german.bin", 0xe000, 0x800, CRC(1c1e597d))
-	ROM_LOAD ("901465.22", 0xf000, 0x1000, CRC(cc5298a1))
+	ROM_LOAD ("901465.23", 0xb000, 0x1000, CRC(ae3deac0) SHA1(975ee25e28ff302879424587e5fb4ba19f403adc))
+	ROM_LOAD ("901465.20", 0xc000, 0x1000, CRC(0fc17b9c) SHA1(242f98298931d21eaacb55fe635e44b7fc192b0a))
+	ROM_LOAD ("901465.21", 0xd000, 0x1000, CRC(36d91855) SHA1(1bb236c72c726e8fb029c68f9bfa5ee803faf0a8))
+	ROM_LOAD ("german.bin", 0xe000, 0x800, CRC(1c1e597d) SHA1(7ac75ed73832847623c9f4f197fe7fb1a73bb41c))
+	ROM_LOAD ("901465.22", 0xf000, 0x1000, CRC(cc5298a1) SHA1(96a0fa56e0c937da92971d9c99d504e44e898806))
 	ROM_REGION (0x2000, REGION_GFX1, 0)
-	ROM_LOAD ("chargen.de", 0x0000, 0x800, CRC(3bb8cb87))
+	ROM_LOAD ("chargen.de", 0x0000, 0x800, CRC(3bb8cb87) SHA1(a4f0df13473d7f9cd31fd62cfcab11318e2fb1dc))
 ROM_END
 
 ROM_START (cbm80swe)
 	ROM_REGION (0x20000, REGION_CPU1, 0)
-    ROM_LOAD ("901465.23", 0xb000, 0x1000, CRC(ae3deac0))
-    ROM_LOAD ("901465.20", 0xc000, 0x1000, CRC(0fc17b9c))
-    ROM_LOAD ("901465.21", 0xd000, 0x1000, CRC(36d91855))
-    ROM_LOAD ("editswe.bin", 0xe000, 0x800, CRC(75901dd7))
-    ROM_LOAD ("901465.22", 0xf000, 0x1000, CRC(cc5298a1))
+    ROM_LOAD ("901465.23", 0xb000, 0x1000, CRC(ae3deac0) SHA1(975ee25e28ff302879424587e5fb4ba19f403adc))
+    ROM_LOAD ("901465.20", 0xc000, 0x1000, CRC(0fc17b9c) SHA1(242f98298931d21eaacb55fe635e44b7fc192b0a))
+    ROM_LOAD ("901465.21", 0xd000, 0x1000, CRC(36d91855) SHA1(1bb236c72c726e8fb029c68f9bfa5ee803faf0a8))
+    ROM_LOAD ("editswe.bin", 0xe000, 0x800, CRC(75901dd7) SHA1(2ead0d83255a344a42bb786428353ca48d446d03))
+    ROM_LOAD ("901465.22", 0xf000, 0x1000, CRC(cc5298a1) SHA1(96a0fa56e0c937da92971d9c99d504e44e898806))
 	ROM_REGION (0x2000, REGION_GFX1, 0)
-    ROM_LOAD ("901447.14", 0x0000, 0x800, CRC(48c77d29))
+    ROM_LOAD ("901447.14", 0x0000, 0x800, CRC(48c77d29) SHA1(aa7c8ff844d16ec05e2b32acc586c58d9e35388c))
 ROM_END
 
 ROM_START (superpet)
 	ROM_REGION (0x10000, REGION_CPU1, 0)
-    ROM_LOAD ("901465.23", 0xb000, 0x1000, CRC(ae3deac0))
-    ROM_LOAD ("901465.20", 0xc000, 0x1000, CRC(0fc17b9c))
-    ROM_LOAD ("901465.21", 0xd000, 0x1000, CRC(36d91855))
-    ROM_LOAD ("901474.04", 0xe000, 0x800, CRC(abb000e7))
-    ROM_LOAD ("901465.22", 0xf000, 0x1000, CRC(cc5298a1))
-	ROM_REGION (0x20000, REGION_CPU2, 0)
-    ROM_LOAD ("901898.01", 0xa000, 0x1000, CRC(728a998b))
-    ROM_LOAD ("901898.02", 0xb000, 0x1000, CRC(6beb7c62))
-    ROM_LOAD ("901898.03", 0xc000, 0x1000, CRC(5db4983d))
-    ROM_LOAD ("901898.04", 0xd000, 0x1000, CRC(f55fc559))
-    ROM_LOAD ("901897.01", 0xe000, 0x800, CRC(b2cee903))
-    ROM_LOAD ("901898.05", 0xf000, 0x1000, CRC(f42df0cb))
+    ROM_LOAD ("901465.23", 0xb000, 0x1000, CRC(ae3deac0) SHA1(975ee25e28ff302879424587e5fb4ba19f403adc))
+    ROM_LOAD ("901465.20", 0xc000, 0x1000, CRC(0fc17b9c) SHA1(242f98298931d21eaacb55fe635e44b7fc192b0a))
+    ROM_LOAD ("901465.21", 0xd000, 0x1000, CRC(36d91855) SHA1(1bb236c72c726e8fb029c68f9bfa5ee803faf0a8))
+    ROM_LOAD ("901474.04", 0xe000, 0x800, CRC(abb000e7) SHA1(66887061b6c4ebef7d6efb90af9afd5e2c3b08ba))
+    ROM_LOAD ("901465.22", 0xf000, 0x1000, CRC(cc5298a1) SHA1(96a0fa56e0c937da92971d9c99d504e44e898806))
+	ROM_REGION (0x10000, REGION_CPU2, 0)
+    ROM_LOAD ("901898.01", 0xa000, 0x1000, CRC(728a998b) SHA1(0414b3ab847c8977eb05c2fcc72efcf2f9d92871))
+    ROM_LOAD ("901898.02", 0xb000, 0x1000, CRC(6beb7c62) SHA1(df154939b934d0aeeb376813ec1ba0d43c2a3378))
+    ROM_LOAD ("901898.03", 0xc000, 0x1000, CRC(5db4983d) SHA1(6c5b0cce97068f8841112ba6d5cd8e568b562fa3))
+    ROM_LOAD ("901898.04", 0xd000, 0x1000, CRC(f55fc559) SHA1(b42a2050a319a1ffca7868a8d8d635fadd37ec37))
+    ROM_LOAD ("901897.01", 0xe000, 0x800, CRC(b2cee903) SHA1(e8ce8347451a001214a5e71a13081b38b4be23bc))
+    ROM_LOAD ("901898.05", 0xf000, 0x1000, CRC(f42df0cb) SHA1(9b4a5134d20345171e7303445f87c4e0b9addc96))
 	ROM_REGION (0x4000, REGION_GFX1, 0)
-    ROM_LOAD ("901640.01", 0x0000, 0x1000, CRC(ee8229c4))
+    ROM_LOAD ("901640.01", 0x0000, 0x1000, CRC(ee8229c4) SHA1(bf346f11595a3e65e55d6aeeaa2c0cec807b66c7))
 ROM_END
 
 /* swedish m6809 roms needed */
 ROM_START (mmf9000)
 	ROM_REGION (0x10000, REGION_CPU1, 0)
-    ROM_LOAD ("901465.23", 0xb000, 0x1000, CRC(ae3deac0))
-    ROM_LOAD ("901465.20", 0xc000, 0x1000, CRC(0fc17b9c))
-    ROM_LOAD ("901465.21", 0xd000, 0x1000, CRC(36d91855))
-    ROM_LOAD ("editswe.bin", 0xe000, 0x800, CRC(75901dd7))
-    ROM_LOAD ("901465.22", 0xf000, 0x1000, CRC(cc5298a1))
+    ROM_LOAD ("901465.23", 0xb000, 0x1000, CRC(ae3deac0) SHA1(975ee25e28ff302879424587e5fb4ba19f403adc))
+    ROM_LOAD ("901465.20", 0xc000, 0x1000, CRC(0fc17b9c) SHA1(242f98298931d21eaacb55fe635e44b7fc192b0a))
+    ROM_LOAD ("901465.21", 0xd000, 0x1000, CRC(36d91855) SHA1(1bb236c72c726e8fb029c68f9bfa5ee803faf0a8))
+    ROM_LOAD ("editswe.bin", 0xe000, 0x800, CRC(75901dd7) SHA1(2ead0d83255a344a42bb786428353ca48d446d03))
+    ROM_LOAD ("901465.22", 0xf000, 0x1000, CRC(cc5298a1) SHA1(96a0fa56e0c937da92971d9c99d504e44e898806))
 	ROM_REGION (0x20000, REGION_CPU2, 0)
-    ROM_LOAD ("901898.01", 0xa000, 0x1000, CRC(728a998b))
-    ROM_LOAD ("901898.02", 0xb000, 0x1000, CRC(6beb7c62))
-    ROM_LOAD ("901898.03", 0xc000, 0x1000, CRC(5db4983d))
-    ROM_LOAD ("901898.04", 0xd000, 0x1000, CRC(f55fc559))
-    ROM_LOAD ("901897.01", 0xe000, 0x800, CRC(b2cee903))
-    ROM_LOAD ("901898.05", 0xf000, 0x1000, CRC(f42df0cb))
+    ROM_LOAD ("901898.01", 0xa000, 0x1000, CRC(728a998b) SHA1(0414b3ab847c8977eb05c2fcc72efcf2f9d92871))
+    ROM_LOAD ("901898.02", 0xb000, 0x1000, CRC(6beb7c62) SHA1(df154939b934d0aeeb376813ec1ba0d43c2a3378))
+    ROM_LOAD ("901898.03", 0xc000, 0x1000, CRC(5db4983d) SHA1(6c5b0cce97068f8841112ba6d5cd8e568b562fa3))
+    ROM_LOAD ("901898.04", 0xd000, 0x1000, CRC(f55fc559) SHA1(b42a2050a319a1ffca7868a8d8d635fadd37ec37))
+    ROM_LOAD ("901897.01", 0xe000, 0x800, CRC(b2cee903) SHA1(e8ce8347451a001214a5e71a13081b38b4be23bc))
+    ROM_LOAD ("901898.05", 0xf000, 0x1000, CRC(f42df0cb) SHA1(9b4a5134d20345171e7303445f87c4e0b9addc96))
 	ROM_REGION (0x4000, REGION_GFX1, 0)
     ROM_LOAD("charswe.bin", 0x0000, 0x1000, CRC(da1cd630))
 ROM_END
@@ -885,13 +822,13 @@ ROM_END
 static MACHINE_DRIVER_START( pet )
 	/* basic machine hardware */
 	MDRV_CPU_ADD_TAG("main", M6502, 7833600)        /* 7.8336 Mhz */
-	MDRV_CPU_PROGRAM_MAP(pet_readmem, pet_writemem)
+	MDRV_CPU_PROGRAM_MAP(pet_mem, 0)
 	MDRV_CPU_VBLANK_INT(pet_frame_interrupt, 1)
 	MDRV_FRAMES_PER_SECOND(60)
 	MDRV_VBLANK_DURATION(DEFAULT_REAL_60HZ_VBLANK_DURATION)
 	MDRV_INTERLEAVE(0)
 
-	MDRV_MACHINE_INIT( pet )
+	MDRV_MACHINE_RESET( pet )
 
     /* video hardware */
 	MDRV_VIDEO_ATTRIBUTES(VIDEO_TYPE_RASTER)
@@ -910,7 +847,7 @@ MACHINE_DRIVER_END
 static MACHINE_DRIVER_START( pet40 )
 	MDRV_IMPORT_FROM( pet )
 	MDRV_CPU_MODIFY( "main" )
-	MDRV_CPU_PROGRAM_MAP( pet40_readmem, pet40_writemem )
+	MDRV_CPU_PROGRAM_MAP( pet40_mem, 0 )
 	MDRV_VIDEO_UPDATE( pet40 )
 MACHINE_DRIVER_END
 
@@ -924,7 +861,7 @@ MACHINE_DRIVER_END
 static MACHINE_DRIVER_START( pet80 )
 	MDRV_IMPORT_FROM( pet )
 	MDRV_CPU_MODIFY( "main" )
-	MDRV_CPU_PROGRAM_MAP( pet80_readmem, pet80_writemem )
+	MDRV_CPU_PROGRAM_MAP( pet80_mem, 0 )
 
     /* video hardware */
 #ifdef PET_TEST_CODE
@@ -948,11 +885,11 @@ MACHINE_DRIVER_END
 static MACHINE_DRIVER_START( superpet )
 	MDRV_IMPORT_FROM( pet80 )
 	MDRV_CPU_MODIFY( "main" )
-	MDRV_CPU_PROGRAM_MAP( superpet_readmem, superpet_writemem )
+	MDRV_CPU_PROGRAM_MAP( superpet_mem, 0 )
 
 	/* m6809 cpu */
 	MDRV_CPU_ADD_TAG("main", M6809, 1000000)
-	MDRV_CPU_PROGRAM_MAP(superpet_m6809_readmem, superpet_m6809_writemem)
+	MDRV_CPU_PROGRAM_MAP(superpet_m6809_mem, 0)
 	MDRV_CPU_VBLANK_INT(pet_frame_interrupt, 1)
 
 	MDRV_FRAMES_PER_SECOND(50)
@@ -961,12 +898,6 @@ static MACHINE_DRIVER_START( superpet )
 	MDRV_GFXDECODE( superpet_gfxdecodeinfo )
 MACHINE_DRIVER_END
 
-#define init_pet1 pet_basic1_driver_init
-#define init_pet pet_driver_init
-#define init_pet40 pet40_driver_init
-#define init_cbm80 cbm80_driver_init
-#define init_superpet superpet_driver_init
-
 #define rom_cbm30 rom_pet2
 #define rom_cbm30 rom_pet2
 #define rom_cbm30b rom_pet2b
@@ -976,60 +907,111 @@ MACHINE_DRIVER_END
 #define rom_cbm80 rom_pet80
 #define rom_cbm80pal rom_pet80pal
 
-static void pet_cbmcartslot_getinfo(struct IODevice *dev)
+static void pet_cbmcartslot_getinfo(const device_class *devclass, UINT32 state, union devinfo *info)
 {
-	cbmcartslot_device_getinfo(dev);
-	dev->file_extensions = "crt\0a0\0b0\0";
+	switch(state)
+	{
+		/* --- the following bits of info are returned as NULL-terminated strings --- */
+		case DEVINFO_STR_FILE_EXTENSIONS:				strcpy(info->s = device_temp_str(), "crt,a0,b0"); break;
+
+		default:										cbmcartslot_device_getinfo(devclass, state, info); break;
+	}
 }
 
-static void pet_quickload_getinfo(struct IODevice *dev)
+static void pet_quickload_getinfo(const device_class *devclass, UINT32 state, union devinfo *info)
 {
-	quickload_device_getinfo(dev, quickload_load_cbm_pet, CBM_QUICKLOAD_DELAY);
-	dev->file_extensions = "p00\0prg\0";
+	switch(state)
+	{
+		/* --- the following bits of info are returned as NULL-terminated strings --- */
+		case DEVINFO_STR_FILE_EXTENSIONS:				strcpy(info->s = device_temp_str(), "p00,prg"); break;
+
+		/* --- the following bits of info are returned as pointers to data or functions --- */
+		case DEVINFO_PTR_QUICKLOAD_LOAD:				info->f = (genf *) quickload_load_cbm_pet; break;
+
+		/* --- the following bits of info are returned as doubles --- */
+		case DEVINFO_FLOAT_QUICKLOAD_DELAY:				info->d = CBM_QUICKLOAD_DELAY; break;
+
+		default:										quickload_device_getinfo(devclass, state, info); break;
+	}
 }
 
-static void pet1_quickload_getinfo(struct IODevice *dev)
+static void pet1_quickload_getinfo(const device_class *devclass, UINT32 state, union devinfo *info)
 {
-	quickload_device_getinfo(dev, quickload_load_cbm_pet1, CBM_QUICKLOAD_DELAY);
-	dev->file_extensions = "p00\0prg\0";
+	switch(state)
+	{
+		/* --- the following bits of info are returned as NULL-terminated strings --- */
+		case DEVINFO_STR_FILE_EXTENSIONS:				strcpy(info->s = device_temp_str(), "p00,prg"); break;
+
+		/* --- the following bits of info are returned as pointers to data or functions --- */
+		case DEVINFO_PTR_QUICKLOAD_LOAD:				info->f = (genf *) quickload_load_cbm_pet1; break;
+
+		/* --- the following bits of info are returned as doubles --- */
+		case DEVINFO_FLOAT_QUICKLOAD_DELAY:				info->d = CBM_QUICKLOAD_DELAY; break;
+
+		default:										quickload_device_getinfo(devclass, state, info); break;
+	}
 }
 
 SYSTEM_CONFIG_START(pet)
 	CONFIG_DEVICE(pet_cbmcartslot_getinfo)
 	CONFIG_DEVICE(cbmfloppy_device_getinfo)
 	CONFIG_DEVICE(pet1_quickload_getinfo)
+	CONFIG_RAM(4 * 1024)
+	CONFIG_RAM(8 * 1024)
+	CONFIG_RAM(16 * 1024)
+	CONFIG_RAM_DEFAULT(32 * 1024)
 SYSTEM_CONFIG_END
 
 SYSTEM_CONFIG_START(pet2)
 	CONFIG_DEVICE(pet_cbmcartslot_getinfo)
 	CONFIG_DEVICE(cbmfloppy_device_getinfo)
 	CONFIG_DEVICE(pet_quickload_getinfo)
+	CONFIG_RAM(4 * 1024)
+	CONFIG_RAM(8 * 1024)
+	CONFIG_RAM(16 * 1024)
+	CONFIG_RAM_DEFAULT(32 * 1024)
 SYSTEM_CONFIG_END
 
-static void pet4_cbmcartslot_getinfo(struct IODevice *dev)
+static void pet4_cbmcartslot_getinfo(const device_class *devclass, UINT32 state, union devinfo *info)
 {
-	cbmcartslot_device_getinfo(dev);
-	dev->file_extensions = "crt\0a0\0";
+	switch(state)
+	{
+		/* --- the following bits of info are returned as NULL-terminated strings --- */
+		case DEVINFO_STR_FILE_EXTENSIONS:				strcpy(info->s = device_temp_str(), "crt,a0"); break;
+
+		default:										cbmcartslot_device_getinfo(devclass, state, info); break;
+	}
 }
 
 SYSTEM_CONFIG_START(pet4)
 	CONFIG_DEVICE(pet4_cbmcartslot_getinfo)
 	CONFIG_DEVICE(cbmfloppy_device_getinfo)
 	CONFIG_DEVICE(pet_quickload_getinfo)
+	CONFIG_RAM(4 * 1024)
+	CONFIG_RAM(8 * 1024)
+	CONFIG_RAM(16 * 1024)
+	CONFIG_RAM_DEFAULT(32 * 1024)
 SYSTEM_CONFIG_END
 
-/*	   YEAR 	NAME		COMPAT	PARENT	MACHINE 	INPUT	 INIT	  CONFIG	COMPANY							  FULLNAME */
-COMPX (1977,	pet,		0,		0,		pet,		pet,	 pet1,	  pet,		"Commodore Business Machines Co.",  "PET2001/CBM20xx Series (Basic 1)",            GAME_NO_SOUND)
-COMPX (1979,	cbm30,		0,		pet,	pet,		pet,	 pet,	  pet2,		"Commodore Business Machines Co.",  "Commodore 30xx (Basic 2)",                    GAME_NO_SOUND)
-COMPX (1979,	cbm30b, 	0,		pet,	pet,		petb,	 pet,	  pet2,		"Commodore Business Machines Co.",  "Commodore 30xx (Basic 2) (business keyboard)",GAME_NO_SOUND)
-COMPX (1982,	cbm40,		0,		pet,	pet40,		pet,	 pet40,   pet4,		"Commodore Business Machines Co.",  "Commodore 40xx FAT (CRTC) 60Hz",              GAME_NO_SOUND)
-COMPX (1982,	cbm40pal,	0,		pet,	pet40pal,	pet,	 pet40,   pet4,		"Commodore Business Machines Co.",  "Commodore 40xx FAT (CRTC) 50Hz",              GAME_NO_SOUND)
-COMPX (1979,	cbm40b, 	0,		pet,	pet,		petb,	 pet,	  pet4,		"Commodore Business Machines Co.",  "Commodore 40xx THIN (business keyboard)",     GAME_NO_SOUND)
-COMPX (1981,	cbm80,		0,		pet,	pet80,		cbm8096, cbm80,   pet4,		"Commodore Business Machines Co.",  "Commodore 80xx 60Hz",                         GAME_NO_SOUND)
-COMPX (1981,	cbm80pal,	0,		pet,	pet80pal,	cbm8096, cbm80,   pet4,		"Commodore Business Machines Co.",  "Commodore 80xx 50Hz",                         GAME_NO_SOUND)
-COMPX (1981,	cbm80ger,	0,		pet,	pet80pal,	cbm8096, cbm80,   pet4,		"Commodore Business Machines Co.",  "Commodore 80xx German (50Hz)",                GAME_NO_SOUND)
-COMPX (1981,	cbm80swe,	0,		pet,	pet80pal,	cbm8096, cbm80,   pet4,		"Commodore Business Machines Co.",  "Commodore 80xx Swedish (50Hz)",               GAME_NO_SOUND)
-COMPX (1981,	superpet,	0,		pet,	superpet,	superpet,superpet,pet4,		"Commodore Business Machines Co.",  "Commodore SP9000/MMF9000 (50Hz)",             GAME_NO_SOUND|GAME_NOT_WORKING)
+SYSTEM_CONFIG_START(pet4_32)
+	CONFIG_DEVICE(pet4_cbmcartslot_getinfo)
+	CONFIG_DEVICE(cbmfloppy_device_getinfo)
+	CONFIG_DEVICE(pet_quickload_getinfo)
+	CONFIG_RAM_DEFAULT(32 * 1024)
+SYSTEM_CONFIG_END
+
+/*    YEAR  NAME		COMPAT	PARENT	MACHINE 	INPUT	 INIT	  CONFIG	COMPANY							  FULLNAME */
+COMP (1977,	pet,		0,		0,		pet,		pet,	 pet1,	  pet,		"Commodore Business Machines Co.",  "PET2001/CBM20xx Series (Basic 1)",            GAME_NO_SOUND)
+COMP (1979,	cbm30,		0,		pet,	pet,		pet,	 pet,	  pet2,		"Commodore Business Machines Co.",  "Commodore 30xx (Basic 2)",                    GAME_NO_SOUND)
+COMP (1979,	cbm30b, 	0,		pet,	pet,		petb,	 pet,	  pet2,		"Commodore Business Machines Co.",  "Commodore 30xx (Basic 2) (business keyboard)",GAME_NO_SOUND)
+COMP (1982,	cbm40,		0,		pet,	pet40,		pet,	 pet40,   pet4,		"Commodore Business Machines Co.",  "Commodore 40xx FAT (CRTC) 60Hz",              GAME_NO_SOUND)
+COMP (1982,	cbm40pal,	0,		pet,	pet40pal,	pet,	 pet40,   pet4,		"Commodore Business Machines Co.",  "Commodore 40xx FAT (CRTC) 50Hz",              GAME_NO_SOUND)
+COMP (1979,	cbm40b, 	0,		pet,	pet,		petb,	 pet,	  pet4,		"Commodore Business Machines Co.",  "Commodore 40xx THIN (business keyboard)",     GAME_NO_SOUND)
+COMP (1981,	cbm80,		0,		pet,	pet80,		cbm8096, cbm80,   pet4_32,	"Commodore Business Machines Co.",  "Commodore 80xx 60Hz",                         GAME_NO_SOUND)
+COMP (1981,	cbm80pal,	0,		pet,	pet80pal,	cbm8096, cbm80,   pet4_32,	"Commodore Business Machines Co.",  "Commodore 80xx 50Hz",                         GAME_NO_SOUND)
+COMP (1981,	cbm80ger,	0,		pet,	pet80pal,	cbm8096, cbm80,   pet4_32,	"Commodore Business Machines Co.",  "Commodore 80xx German (50Hz)",                GAME_NO_SOUND)
+COMP (1981,	cbm80swe,	0,		pet,	pet80pal,	cbm8096, cbm80,   pet4_32,	"Commodore Business Machines Co.",  "Commodore 80xx Swedish (50Hz)",               GAME_NO_SOUND)
+COMP (1981,	superpet,	0,		pet,	superpet,	superpet,superpet,pet4_32,	"Commodore Business Machines Co.",  "Commodore SP9000/MMF9000 (50Hz)",             GAME_NO_SOUND|GAME_NOT_WORKING)
 
 /* please leave the following as testdriver only */
-COMP (198?, 	mmf9000,	0,		pet,	superpet,	superpet,superpet,pet4,		"Commodore Business Machines Co.",  "MMF9000 (50Hz) Swedish")
+COMP (198?, 	mmf9000,	0,		pet,	superpet,	superpet,superpet,pet4,		"Commodore Business Machines Co.",  "MMF9000 (50Hz) Swedish", 0)
