@@ -80,74 +80,37 @@
 /* special keys
    red c-ce and reset; warm boot, program NOT lost*/
 
-static ADDRESS_MAP_START( pc1401_readmem , ADDRESS_SPACE_PROGRAM, 8)
-	AM_RANGE( 0x0000, 0x1fff) AM_READ( MRA8_ROM )
+static ADDRESS_MAP_START( pc1401_mem , ADDRESS_SPACE_PROGRAM, 8)
+	AM_RANGE( 0x0000, 0x1fff) AM_ROM
 	AM_RANGE( 0x2000, 0x47ff) AM_READ( MRA8_RAM )
-/*	{ 0x5000, 0x57ff, ? }, */
-	AM_RANGE( 0x6000, 0x67ff) AM_READ( pc1401_lcd_read )
-	AM_RANGE( 0x7000, 0x77ff) AM_READ( pc1401_lcd_read )
-	AM_RANGE( 0x8000, 0xffff) AM_READ( MRA8_ROM )
-ADDRESS_MAP_END
-
-static ADDRESS_MAP_START( pc1401_writemem , ADDRESS_SPACE_PROGRAM, 8)
-	AM_RANGE( 0x0000, 0x1fff) AM_WRITE( MWA8_ROM )
 /*	{ 0x2000, 0x3fff, MWA8_RAM }, // done in pc1401_machine_init */
-	AM_RANGE( 0x4000, 0x47ff) AM_WRITE( MWA8_RAM )
 /*	{ 0x5000, 0x57ff, ? }, */
-	AM_RANGE( 0x6000, 0x67ff) AM_WRITE( pc1401_lcd_write )
-	AM_RANGE( 0x7000, 0x77ff) AM_WRITE( pc1401_lcd_write )
-	AM_RANGE( 0x8000, 0xffff) AM_WRITE( MWA8_ROM )
+	AM_RANGE( 0x6000, 0x67ff) AM_READWRITE( pc1401_lcd_read, pc1401_lcd_write ) AM_MIRROR(0x1000)
+	AM_RANGE( 0x8000, 0xffff) AM_ROM
 ADDRESS_MAP_END
 
-static ADDRESS_MAP_START( pc1251_readmem , ADDRESS_SPACE_PROGRAM, 8)
-	AM_RANGE( 0x0000, 0x1fff) AM_READ( MRA8_ROM )
+static ADDRESS_MAP_START( pc1251_mem , ADDRESS_SPACE_PROGRAM, 8)
+	AM_RANGE( 0x0000, 0x1fff) AM_ROM
 /*	{ 0x2000, 0x3fff, MRA8_RAM }, */
-	AM_RANGE( 0x4000, 0x7fff) AM_READ( MRA8_ROM )
-	AM_RANGE( 0xa000, 0xcbff) AM_READ( MRA8_ROM )
-	AM_RANGE( 0xf800, 0xf8ff) AM_READ( pc1251_lcd_read )
+	AM_RANGE( 0x4000, 0x7fff) AM_ROM
+	AM_RANGE( 0xa000, 0xcbff) AM_ROM
+	AM_RANGE( 0xf800, 0xf8ff) AM_READWRITE( pc1251_lcd_read, pc1251_lcd_write)
 ADDRESS_MAP_END
 
-static ADDRESS_MAP_START( pc1251_writemem , ADDRESS_SPACE_PROGRAM, 8)
-	AM_RANGE( 0x0000, 0x1fff) AM_WRITE( MWA8_ROM )
-	AM_RANGE( 0x4000, 0x7fff) AM_WRITE( MWA8_ROM )
-/*	{ 0xa000, 0xcbff, MWA8_ROM }, // c600 b800 b000 a000 tested */
-	AM_RANGE( 0xf800, 0xf8ff) AM_WRITE( pc1251_lcd_write )
+static ADDRESS_MAP_START( pc1350_mem , ADDRESS_SPACE_PROGRAM, 8)
+	AM_RANGE( 0x0000, 0x1fff) AM_ROM
+	AM_RANGE( 0x7000, 0x7eff) AM_READWRITE( pc1350_lcd_read, pc1350_lcd_write )
+	AM_RANGE( 0x8000, 0xffff) AM_ROM
 ADDRESS_MAP_END
 
-static ADDRESS_MAP_START( pc1350_readmem , ADDRESS_SPACE_PROGRAM, 8)
-	AM_RANGE( 0x0000, 0x1fff) AM_READ( MRA8_ROM )
-	AM_RANGE( 0x2000, 0x3fff) AM_READ( MRA8_RAM )
-	AM_RANGE( 0x4000, 0x5fff) AM_READ( MRA8_RAM )
-	AM_RANGE( 0x6000, 0x6fff) AM_READ( MRA8_RAM )
-	AM_RANGE( 0x7000, 0x7eff) AM_READ( pc1350_lcd_read )
-	AM_RANGE( 0x8000, 0xffff) AM_READ( MRA8_ROM )
+static ADDRESS_MAP_START( pc1403_mem , ADDRESS_SPACE_PROGRAM, 8)
+	AM_RANGE( 0x0000, 0x1fff) AM_ROM
+	AM_RANGE( 0x3000, 0x30bf) AM_READWRITE( pc1403_lcd_read, pc1403_lcd_write )  
+	AM_RANGE( 0x3800, 0x3fff) AM_READWRITE( pc1403_asic_read, pc1403_asic_write )    
+	AM_RANGE( 0x4000, 0x7fff) AM_ROMBANK(1)
+	AM_RANGE( 0xe000, 0xffff) AM_RAM
 ADDRESS_MAP_END
 
-static ADDRESS_MAP_START( pc1350_writemem , ADDRESS_SPACE_PROGRAM, 8)
-	AM_RANGE( 0x0000, 0x1fff) AM_WRITE( MWA8_ROM )
-	AM_RANGE( 0x2000, 0x3fff) AM_WRITE( MWA8_RAM ) /*ram card 16k */
-	AM_RANGE( 0x4000, 0x5fff) AM_WRITE( MWA8_RAM ) /*ram card 16k oder 8k */
-	AM_RANGE( 0x6000, 0x6fff) AM_WRITE( MWA8_RAM )
-	AM_RANGE( 0x7000, 0x7eff) AM_WRITE( pc1350_lcd_write )
-	AM_RANGE( 0x8000, 0xffff) AM_WRITE( MWA8_ROM )
-ADDRESS_MAP_END
-
-static ADDRESS_MAP_START( pc1403_readmem , ADDRESS_SPACE_PROGRAM, 8)
-	AM_RANGE( 0x0000, 0x1fff) AM_READ( MRA8_ROM )
-AM_RANGE( 0x3000, 0x30bf) AM_READ( pc1403_lcd_read )    
-AM_RANGE( 0x3800, 0x3fff) AM_READ( pc1403_asic_read )    
-AM_RANGE( 0x4000, 0x7fff) AM_READ( MRA8_BANK1 )
-AM_RANGE( 0xe000,0xffff) AM_READ( MRA8_RAM )
-ADDRESS_MAP_END
-
-static ADDRESS_MAP_START( pc1403_writemem , ADDRESS_SPACE_PROGRAM, 8)
-	AM_RANGE( 0x0000, 0x1fff) AM_WRITE( MWA8_ROM )
-AM_RANGE( 0x3000, 0x30bf) AM_WRITE( pc1403_lcd_write )    
-AM_RANGE( 0x3800, 0x3fff) AM_WRITE( pc1403_asic_write )    
-AM_RANGE( 0xe000,0xffff) AM_WRITE( MWA8_RAM )
-ADDRESS_MAP_END
-
-
 
 #if 0
 static ADDRESS_MAP_START( pc1421_readmem , ADDRESS_SPACE_PROGRAM, 8)
@@ -478,10 +441,6 @@ INPUT_PORTS_START( pc1350 )
 	DIPS_HELPER( 0x04, "SPC", KEYCODE_SPACE, CODE_NONE)
 	DIPS_HELPER( 0x02, "ENTER P<->NP", KEYCODE_ENTER, KEYCODE_ENTER_PAD)
 	PORT_START
-    PORT_DIPNAME   ( 0xc0, 0x80, "RAM")
-	PORT_DIPSETTING( 0x00, "4KB" )
-	PORT_DIPSETTING( 0x40, "12KB" )
-	PORT_DIPSETTING( 0x80, "20KB" )
     PORT_DIPNAME   ( 7, 2, "Contrast")
 	PORT_DIPSETTING( 0, "0/Low" )
 	PORT_DIPSETTING( 1, "1" )
@@ -493,74 +452,74 @@ INPUT_PORTS_START( pc1350 )
 	PORT_DIPSETTING( 7, "7/High" )
 INPUT_PORTS_END
 
-static struct GfxLayout pc1401_charlayout =
+static gfx_layout pc1401_charlayout =
 {
-        2,21,
-        128,                                    /* 256 characters */
-        1,                      /* 1 bits per pixel */
-        { 0,0 },                  /* no bitplanes; 1 bit per pixel */
-        /* x offsets */
-        { 0,0 },
-        /* y offsets */
-        {
-			7, 7, 7,
-			6, 6, 6,
-			5, 5, 5,
-			4, 4, 4,
-			3, 3, 3,
-			2, 2, 2,
-			1, 1, 1
-        },
-        1*8
+	2,21,
+	128,                                    /* 256 characters */
+	1,                      /* 1 bits per pixel */
+	{ 0,0 },                  /* no bitplanes; 1 bit per pixel */
+	/* x offsets */
+	{ 0,0 },
+	/* y offsets */
+	{
+		7, 7, 7,
+		6, 6, 6,
+		5, 5, 5,
+		4, 4, 4,
+		3, 3, 3,
+		2, 2, 2,
+		1, 1, 1
+	},
+	1*8
 };
 
-static struct GfxLayout pc1251_charlayout =
+static gfx_layout pc1251_charlayout =
 {
-        3,21,
-        128,                                    /* 256 characters */
-        1,                      /* 1 bits per pixel */
-        { 0, },                  /* no bitplanes; 1 bit per pixel */
-        /* x offsets */
-        { 0,0,0 },
-        /* y offsets */
-        {
-			7, 7, 7,
-			6, 6, 6,
-			5, 5, 5,
-			4, 4, 4,
-			3, 3, 3,
-			2, 2, 2,
-			1, 1, 1
-        },
-        1*8
+	3,21,
+	128,                                    /* 256 characters */
+	1,                      /* 1 bits per pixel */
+	{ 0, },                  /* no bitplanes; 1 bit per pixel */
+	/* x offsets */
+	{ 0,0,0 },
+	/* y offsets */
+	{
+		7, 7, 7,
+		6, 6, 6,
+		5, 5, 5,
+		4, 4, 4,
+		3, 3, 3,
+		2, 2, 2,
+		1, 1, 1
+	},
+	1*8
 };
 
-static struct GfxLayout pc1350_charlayout =
+static gfx_layout pc1350_charlayout =
 {
-        2,16,
-        256,                                    /* 256 characters */
-        1,                      /* 1 bits per pixel */
-        { 0,0 },                  /* no bitplanes; 1 bit per pixel */
-        /* x offsets */
-        { 0 },
-        /* y offsets */
-        {
-			7, 7, 6, 6, 5, 5, 4, 4, 3, 3, 2, 2, 1, 1, 0, 0
-        },
-        1*8
+	2,16,
+	256,                                    /* 256 characters */
+	1,                      /* 1 bits per pixel */
+	{ 0,0 },                  /* no bitplanes; 1 bit per pixel */
+	/* x offsets */
+	{ 0 },
+	/* y offsets */
+	{
+		7, 7, 6, 6, 5, 5, 4, 4, 3, 3, 2, 2, 1, 1, 0, 0
+	},
+	1*8
 };
 
-static struct GfxDecodeInfo pc1401_gfxdecodeinfo[] = {
+static gfx_decode pc1401_gfxdecodeinfo[] = {
 	{ REGION_GFX1, 0x0000, &pc1401_charlayout,                     0, 8 },
     { -1 } /* end of array */
 };
 
-static struct GfxDecodeInfo pc1251_gfxdecodeinfo[] = {
+static gfx_decode pc1251_gfxdecodeinfo[] = {
 	{ REGION_GFX1, 0x0000, &pc1251_charlayout,                     0, 8 },
     { -1 } /* end of array */
 };
 
-static struct GfxDecodeInfo pc1350_gfxdecodeinfo[] = {
+static gfx_decode pc1350_gfxdecodeinfo[] = {
 	{ REGION_GFX1, 0x0000, &pc1350_charlayout,                     0, 8 },
     { -1 } /* end of array */
 };
@@ -575,15 +534,14 @@ static SC61860_CONFIG config={
 static MACHINE_DRIVER_START( pc1401 )
 	/* basic machine hardware */
 	MDRV_CPU_ADD_TAG("main", SC61860, 192000)        /* 7.8336 Mhz */
-	MDRV_CPU_PROGRAM_MAP(pc1401_readmem,pc1401_writemem)
+	MDRV_CPU_PROGRAM_MAP(pc1401_mem, 0)
 	MDRV_CPU_CONFIG(config)
 
 	MDRV_FRAMES_PER_SECOND(20)	/* very early and slow lcd */
 	MDRV_VBLANK_DURATION(DEFAULT_REAL_60HZ_VBLANK_DURATION)
 	MDRV_INTERLEAVE(1)
 
-	MDRV_MACHINE_INIT( pc1401 )
-	MDRV_MACHINE_STOP( pc1401 )
+	MDRV_NVRAM_HANDLER( pc1401 )
 
 	/*
 	   aim: show sharp with keyboard
@@ -609,7 +567,8 @@ static MACHINE_DRIVER_START( pc1401 )
 MACHINE_DRIVER_END
 
 
-static SC61860_CONFIG pc1251_config={
+static SC61860_CONFIG pc1251_config =
+{
     NULL, pc1251_brk, NULL,
     pc1251_ina, pc1251_outa,
     pc1251_inb, pc1251_outb,
@@ -619,11 +578,10 @@ static SC61860_CONFIG pc1251_config={
 static MACHINE_DRIVER_START( pc1251 )
 	MDRV_IMPORT_FROM( pc1401 )
 	MDRV_CPU_MODIFY( "main" )
-	MDRV_CPU_PROGRAM_MAP( pc1251_readmem,pc1251_writemem )
+	MDRV_CPU_PROGRAM_MAP( pc1251_mem, 0 )
 	MDRV_CPU_CONFIG( pc1251_config )
 
-	MDRV_MACHINE_INIT( pc1251 )
-	MDRV_MACHINE_STOP( pc1251 )
+	MDRV_NVRAM_HANDLER( pc1251 )
 
 	/* video hardware */
 	MDRV_SCREEN_SIZE(608, 300)
@@ -636,7 +594,8 @@ static MACHINE_DRIVER_START( pc1251 )
 MACHINE_DRIVER_END
 
 
-static SC61860_CONFIG pc1350_config={
+static SC61860_CONFIG pc1350_config =
+{
     NULL, pc1350_brk,NULL,
     pc1350_ina, pc1350_outa,
     pc1350_inb, pc1350_outb,
@@ -646,11 +605,11 @@ static SC61860_CONFIG pc1350_config={
 static MACHINE_DRIVER_START( pc1350 )
 	MDRV_IMPORT_FROM( pc1401 )
 	MDRV_CPU_MODIFY( "main" )
-	MDRV_CPU_PROGRAM_MAP( pc1350_readmem,pc1350_writemem )
+	MDRV_CPU_PROGRAM_MAP( pc1350_mem, 0 )
 	MDRV_CPU_CONFIG( pc1350_config )
 
-	MDRV_MACHINE_INIT( pc1350 )
-	MDRV_MACHINE_STOP( pc1350 )
+	MDRV_MACHINE_START( pc1350 )
+	MDRV_NVRAM_HANDLER( pc1350 )
 
 	/*
 	   aim: show sharp with keyboard
@@ -667,7 +626,8 @@ static MACHINE_DRIVER_START( pc1350 )
 MACHINE_DRIVER_END
 
 
-static SC61860_CONFIG pc1403_config={
+static SC61860_CONFIG pc1403_config =
+{
     NULL, pc1403_brk, NULL,
     pc1403_ina, pc1403_outa,
     NULL,NULL,
@@ -677,11 +637,10 @@ static SC61860_CONFIG pc1403_config={
 static MACHINE_DRIVER_START( pc1403 )
 	MDRV_IMPORT_FROM( pc1401 )
 	MDRV_CPU_REPLACE( "main", SC61860, 256000 )
-	MDRV_CPU_PROGRAM_MAP( pc1403_readmem,pc1403_writemem )
+	MDRV_CPU_PROGRAM_MAP( pc1403_mem, 0 )
 	MDRV_CPU_CONFIG( pc1403_config )
 
-	MDRV_MACHINE_INIT( pc1403 )
-	MDRV_MACHINE_STOP( pc1403 )
+	MDRV_NVRAM_HANDLER( pc1403 )
 
 	/*
 	   aim: show sharp with keyboard
@@ -701,10 +660,10 @@ MACHINE_DRIVER_END
 ROM_START(pc1401)
 	ROM_REGION(0x10000,REGION_CPU1,0)
 	/* SC61860A08 5H 13LD cpu with integrated rom*/
-	ROM_LOAD("sc61860.a08", 0x0000, 0x2000, CRC(44bee438))
+	ROM_LOAD("sc61860.a08", 0x0000, 0x2000, CRC(44bee438) SHA1(c5106bc8d848be1b49494ace30a26eeb1cc5e504))
 /* 5S1 SC613256 D30
    or SC43536LD 5G 13 (LCD chip?) */
-	ROM_LOAD("sc613256.d30", 0x8000, 0x8000, CRC(69b9d587))
+	ROM_LOAD("sc613256.d30", 0x8000, 0x8000, CRC(69b9d587) SHA1(fa0602e7dfee548546f801fb4cca7d73da2d8f18))
 	ROM_REGION(0x80,REGION_GFX1,0)
 ROM_END
 
@@ -713,8 +672,8 @@ ROM_END
 ROM_START(pc1251)
 	ROM_REGION(0x10000,REGION_CPU1,0)
 	/* sc61860a13 6c 13 ld */
-	ROM_LOAD("cpu1251.rom", 0x0000, 0x2000, CRC(f7287aca))
-	ROM_LOAD("bas1251.rom", 0x4000, 0x4000, CRC(93ecb629))
+	ROM_LOAD("cpu1251.rom", 0x0000, 0x2000, CRC(f7287aca) SHA1(19bfa778e3e05ea06bdca15cd9dfbba9b971340e))
+	ROM_LOAD("bas1251.rom", 0x4000, 0x4000, CRC(93ecb629) SHA1(0fe0ad419053ee7814600b0be320dd2e8eb2ec92))
 	ROM_REGION(0x80,REGION_GFX1,0)
 ROM_END
 
@@ -723,19 +682,19 @@ ROM_END
 ROM_START(pc1350)
 	ROM_REGION(0x10000,REGION_CPU1,0)
 	/* sc61860a13 6c 13 ld */
-	ROM_LOAD("cpu.rom", 0x0000, 0x2000, CRC(79a924bc))
-	ROM_LOAD("basic.rom", 0x8000, 0x8000, CRC(158b28e2))
+	ROM_LOAD("cpu.rom", 0x0000, 0x2000, CRC(79a924bc) SHA1(2eaef0d53d85863ca70a41c8e1eddc5915136b99))
+	ROM_LOAD("basic.rom", 0x8000, 0x8000, CRC(158b28e2) SHA1(b63b37dd510b3c4d9f16d224f87ae2efb3bcc51f))
 	ROM_REGION(0x100,REGION_GFX1,0)
 ROM_END
 
 ROM_START(pc1403)
 	ROM_REGION(0x10000,REGION_CPU1,0)
-    ROM_LOAD("introm.bin", 0x0000, 0x2000, CRC(588c500b ))
+    ROM_LOAD("introm.bin", 0x0000, 0x2000, CRC(588c500b) SHA1(2fed9ebede27e20a8ee4b4b03b9f8cd7808ada5c))
 	ROM_REGION(0x10000,REGION_USER1,0)
-    ROM_LOAD("extrom08.bin", 0x0000, 0x4000, CRC(1fa65140 ))
-    ROM_LOAD("extrom09.bin", 0x4000, 0x4000, CRC(4a7da6ab ))
-    ROM_LOAD("extrom0a.bin", 0x8000, 0x4000, CRC(9925174f ))
-    ROM_LOAD("extrom0b.bin", 0xc000, 0x4000, CRC(fa5df9ec ))
+    ROM_LOAD("extrom08.bin", 0x0000, 0x4000, CRC(1fa65140) SHA1(f22a9f114486f69733fc43dfec26fb210643aeff))
+    ROM_LOAD("extrom09.bin", 0x4000, 0x4000, CRC(4a7da6ab) SHA1(b50fe8a4ca821244c119147b3ff04cee0fd6ad5c))
+    ROM_LOAD("extrom0a.bin", 0x8000, 0x4000, CRC(9925174f) SHA1(793a79142cd170ed7ac3f7ecb1b6e6f92c8fa4e0))
+    ROM_LOAD("extrom0b.bin", 0xc000, 0x4000, CRC(fa5df9ec) SHA1(6ff62c215f510a3a652d61823f54cd4018d6a771))
 	ROM_REGION(0x100,REGION_GFX1,0)
 ROM_END
 
@@ -749,6 +708,13 @@ SYSTEM_CONFIG_START(pocketc)
 /*	CONFIG_DEVICE_CASSETTE(1, "", mycas_init) */
 SYSTEM_CONFIG_END
 
+SYSTEM_CONFIG_START(pc1350)
+/*	CONFIG_DEVICE_CASSETTE(1, "", mycas_init) */
+	CONFIG_RAM_DEFAULT(4 * 1024)
+	CONFIG_RAM(12 * 1024)
+	CONFIG_RAM(20 * 1024)
+SYSTEM_CONFIG_END
+
 /*    YEAR  NAME      PARENT    MACHINE   INPUT     INIT      MONITOR	COMPANY   FULLNAME */
 
 /* cpu sc43177, sc43178 (4bit!)
@@ -763,16 +729,16 @@ SYSTEM_CONFIG_END
    pc1600
 */
 
-/*    YEAR  NAME		PARENT	COMPAT	MACHINE			INPUT		INIT	CONFIG		COMPANY		FULLNAME */
+/*    YEAR  NAME		PARENT	COMPAT	MACHINE	INPUT	INIT	CONFIG		COMPANY		FULLNAME */
 /* cpu sc61860 */
-COMPX( 1982, pc1251,	0, 		0,		pc1251,	pc1251,	pc1251,	pocketc,	"Sharp",  "Pocket Computer 1251", GAME_NOT_WORKING)
-COMPX( 198?, trs80pc3,	pc1251,	0,		pc1251,	pc1251,	pc1251,	pocketc,	"Tandy",  "TRS80 PC-3", GAME_NOT_WORKING)
+COMP( 1982, pc1251,		0, 		0,		pc1251,	pc1251,	pc1251,	pocketc,	"Sharp",	"Pocket Computer 1251", GAME_NOT_WORKING)
+COMP( 198?, trs80pc3,	pc1251,	0,		pc1251,	pc1251,	pc1251,	pocketc,	"Tandy",	"TRS80 PC-3", GAME_NOT_WORKING)
 
 /* pc1261/pc1262 */
-COMPX( 1984, pc1350,	0, 		0,		pc1350,	pc1350,	pc1350,	pocketc,	"Sharp",  "Pocket Computer 1350", GAME_NOT_WORKING)
-COMPX( 1983, pc1401,	0, 		0,		pc1401,	pc1401,	pc1401,	pocketc,	"Sharp",  "Pocket Computer 1401", GAME_NOT_WORKING)
-COMPX( 1984, pc1402,	pc1401,	0,		pc1401,	pc1401,	pc1401,	pocketc,	"Sharp",  "Pocket Computer 1402", GAME_NOT_WORKING)
+COMP( 1984, pc1350,		0, 		0,		pc1350,	pc1350,	0,		pc1350,		"Sharp",	"Pocket Computer 1350", GAME_NOT_WORKING)
+COMP( 1983, pc1401,		0, 		0,		pc1401,	pc1401,	pc1401,	pocketc,	"Sharp",	"Pocket Computer 1401", GAME_NOT_WORKING)
+COMP( 1984, pc1402,		pc1401,	0,		pc1401,	pc1401,	pc1401,	pocketc,	"Sharp",	"Pocket Computer 1402", GAME_NOT_WORKING)
 
 /* 72kb rom, 32kb ram, cpu? pc1360 */
-COMPX( 198?, pc1403,	0,		0,		pc1403,	pc1403,	pc1403,	pocketc,	"Sharp", "Pocket Computer 1403", GAME_NOT_WORKING)
-COMPX( 198?, pc1403h,	pc1403,	0,		pc1403,	pc1403,	pc1403,	pocketc,	"Sharp", "Pocket Computer 1403H", GAME_NOT_WORKING)
+COMP( 198?, pc1403,		0,		0,		pc1403,	pc1403,	pc1403,	pocketc,	"Sharp",	"Pocket Computer 1403", GAME_NOT_WORKING)
+COMP( 198?, pc1403h,	pc1403,	0,		pc1403,	pc1403,	pc1403,	pocketc,	"Sharp",	"Pocket Computer 1403H", GAME_NOT_WORKING)
