@@ -12,7 +12,6 @@
 	TODO:
 
 	- everything
-	- get a dump of the i8049 MCU, some versions of the QL have it on a separate EPROM
 
 */
 
@@ -236,7 +235,7 @@ static ADDRESS_MAP_START( ql_map, ADDRESS_SPACE_PROGRAM, 8 )
 	AM_RANGE(0x0e0000, 0x0fffff) AM_ROM	/* add-on ROM */
 ADDRESS_MAP_END
 
-static ADDRESS_MAP_START( mcu_map, ADDRESS_SPACE_PROGRAM, 8 )
+static ADDRESS_MAP_START( ipc_map, ADDRESS_SPACE_PROGRAM, 8 )
 	AM_RANGE(0x000, 0x7ff) AM_ROM
 ADDRESS_MAP_END
 
@@ -341,8 +340,8 @@ static MACHINE_DRIVER_START( ql )
 	MDRV_CPU_ADD(M68008, 15000000/2)	/* 7.5 MHz */
 	MDRV_CPU_PROGRAM_MAP(ql_map, 0)
 
-	/*MDRV_CPU_ADD(I8039, 11000000)		// 11 MHz (i8049 MCU) */
-	/*MDRV_CPU_PROGRAM_MAP(mcu_map, 0) */
+	MDRV_CPU_ADD(I8039, 11000000)		/* 11 MHz (i8049 IPC) */
+	MDRV_CPU_PROGRAM_MAP(ipc_map, 0)
 
 	MDRV_FRAMES_PER_SECOND(50)
 	MDRV_VBLANK_DURATION(DEFAULT_REAL_60HZ_VBLANK_DURATION)
@@ -378,7 +377,7 @@ ROM_START( ql )
     ROM_LOAD16_WORD_SWAP( "ah.ic34",   0x008000, 0x004000, CRC(61259d4c) SHA1(bdd10d111e7ba488551a27c8d3b2743917ff1307) )
 
 	ROM_REGION( 0x800, REGION_CPU2, 0 )
-	ROM_LOAD( "mcu", 0x0000, 0x0800, NO_DUMP )
+	ROM_LOAD( "ipc8049.ic24", 0x0000, 0x0800, CRC(6a0d1f20) SHA1(fcb1c97ee7c66e5b6d8fbb57c06fd2f6509f2e1b) )
 ROM_END
 
 ROM_START( ql_jm )
@@ -387,7 +386,7 @@ ROM_START( ql_jm )
     ROM_LOAD16_WORD_SWAP( "jm.ic34", 0x008000, 0x004000, CRC(9168a2e9) SHA1(1e7c47a59fc40bd96dfefc2f4d86827c15f0199e) )
 
 	ROM_REGION( 0x800, REGION_CPU2, 0 )
-	ROM_LOAD( "mcu", 0x0000, 0x0800, NO_DUMP )
+	ROM_LOAD( "ipc8049.ic24", 0x0000, 0x0800, CRC(6a0d1f20) SHA1(fcb1c97ee7c66e5b6d8fbb57c06fd2f6509f2e1b) )
 ROM_END
 
 ROM_START( ql_tb )
@@ -396,7 +395,7 @@ ROM_START( ql_tb )
     ROM_LOAD16_WORD_SWAP( "tb.ic34", 0x008000, 0x004000, CRC(de7f9669) SHA1(9d6bc0b794541a4cec2203256ae92c7e68d1011d) )
 
 	ROM_REGION( 0x800, REGION_CPU2, 0 )
-	ROM_LOAD( "mcu", 0x0000, 0x0800, NO_DUMP )
+	ROM_LOAD( "ipc8049.ic24", 0x0000, 0x0800, CRC(6a0d1f20) SHA1(fcb1c97ee7c66e5b6d8fbb57c06fd2f6509f2e1b) )
 ROM_END
 
 ROM_START( ql_js )
@@ -405,7 +404,7 @@ ROM_START( ql_js )
     ROM_LOAD16_WORD_SWAP( "js.ic34", 0x008000, 0x004000, CRC(c970800e) SHA1(b8c9203026a7de6a44bd0942ec9343e8b222cb41) )
 
 	ROM_REGION( 0x800, REGION_CPU2, 0 )
-	ROM_LOAD( "mcu", 0x0000, 0x0800, NO_DUMP )
+	ROM_LOAD( "ipc8049.ic24", 0x0000, 0x0800, CRC(6a0d1f20) SHA1(fcb1c97ee7c66e5b6d8fbb57c06fd2f6509f2e1b) )
 ROM_END
 
 ROM_START( ql_jsu )
@@ -414,7 +413,7 @@ ROM_START( ql_jsu )
     ROM_LOAD16_WORD_SWAP( "jsu.ic34", 0x008000, 0x004000, CRC(3debbacc) SHA1(9fbc3e42ec463fa42f9c535d63780ff53a9313ec) )
 
 	ROM_REGION( 0x800, REGION_CPU2, 0 )
-	ROM_LOAD( "mcu", 0x0000, 0x0800, NO_DUMP )
+	ROM_LOAD( "ipc8049.ic24", 0x0000, 0x0800, CRC(6a0d1f20) SHA1(fcb1c97ee7c66e5b6d8fbb57c06fd2f6509f2e1b) )
 ROM_END
 
 ROM_START( ql_mge )
@@ -423,7 +422,7 @@ ROM_START( ql_mge )
     ROM_LOAD16_WORD_SWAP( "mge.ic34", 0x008000, 0x004000, CRC(a694f8d7) SHA1(bd2868656008de85d7c191598588017ae8aa3339) )
 
 	ROM_REGION( 0x800, REGION_CPU2, 0 )
-	ROM_LOAD( "mcu", 0x0000, 0x0800, NO_DUMP )
+	ROM_LOAD( "ipc8049.ic24", 0x0000, 0x0800, CRC(6a0d1f20) SHA1(fcb1c97ee7c66e5b6d8fbb57c06fd2f6509f2e1b) )
 ROM_END
 
 ROM_START( ql_mgf )
@@ -432,7 +431,7 @@ ROM_START( ql_mgf )
     ROM_LOAD16_WORD_SWAP( "mgf.ic34", 0x008000, 0x004000, NO_DUMP )
 
 	ROM_REGION( 0x800, REGION_CPU2, 0 )
-	ROM_LOAD( "mcu", 0x0000, 0x0800, NO_DUMP )
+	ROM_LOAD( "ipc8049.ic24", 0x0000, 0x0800, CRC(6a0d1f20) SHA1(fcb1c97ee7c66e5b6d8fbb57c06fd2f6509f2e1b) )
 ROM_END
 
 ROM_START( ql_mgg )
@@ -441,7 +440,7 @@ ROM_START( ql_mgg )
     ROM_LOAD16_WORD_SWAP( "mgg.ic34", 0x008000, 0x004000, CRC(54959d40) SHA1(ffc0be9649f26019d7be82925c18dc699259877f) )
 
 	ROM_REGION( 0x800, REGION_CPU2, 0 )
-	ROM_LOAD( "mcu", 0x0000, 0x0800, NO_DUMP )
+	ROM_LOAD( "ipc8049.ic24", 0x0000, 0x0800, CRC(6a0d1f20) SHA1(fcb1c97ee7c66e5b6d8fbb57c06fd2f6509f2e1b) )
 ROM_END
 
 ROM_START( ql_mgi )
@@ -450,7 +449,7 @@ ROM_START( ql_mgi )
     ROM_LOAD16_WORD_SWAP( "mgi.ic34", 0x008000, 0x004000, CRC(a2fdfb83) SHA1(162b1052737500f3c13497cdf0f813ba006bdae9) )
 
 	ROM_REGION( 0x800, REGION_CPU2, 0 )
-	ROM_LOAD( "mcu", 0x0000, 0x0800, NO_DUMP )
+	ROM_LOAD( "ipc8049.ic24", 0x0000, 0x0800, CRC(6a0d1f20) SHA1(fcb1c97ee7c66e5b6d8fbb57c06fd2f6509f2e1b) )
 ROM_END
 
 ROM_START( ql_mgs )
@@ -459,7 +458,7 @@ ROM_START( ql_mgs )
     ROM_LOAD16_WORD_SWAP( "mgs.ic34", 0x008000, 0x004000, NO_DUMP )
 
 	ROM_REGION( 0x800, REGION_CPU2, 0 )
-	ROM_LOAD( "mcu", 0x0000, 0x0800, NO_DUMP )
+	ROM_LOAD( "ipc8049.ic24", 0x0000, 0x0800, CRC(6a0d1f20) SHA1(fcb1c97ee7c66e5b6d8fbb57c06fd2f6509f2e1b) )
 ROM_END
 
 ROM_START( ql_efp )
@@ -468,7 +467,7 @@ ROM_START( ql_efp )
     ROM_LOAD16_WORD_SWAP( "efp.ic34", 0x008000, 0x004000, NO_DUMP )
 
 	ROM_REGION( 0x800, REGION_CPU2, 0 )
-	ROM_LOAD( "mcu", 0x0000, 0x0800, NO_DUMP )
+	ROM_LOAD( "ipc8049.ic24", 0x0000, 0x0800, CRC(6a0d1f20) SHA1(fcb1c97ee7c66e5b6d8fbb57c06fd2f6509f2e1b) )
 ROM_END
 
 /* System Configuration */
@@ -481,16 +480,16 @@ SYSTEM_CONFIG_END
 /* Computer Drivers */
 
 /*     YEAR  NAME      PARENT	COMPAT	MACHINE   INPUT     INIT  CONFIG	COMPANY	FULLNAME */
-/*COMPX( 1984, ql_fb,  0,  0, ql, ql, 0, ql, "Sinclair Research Ltd", "QL (v1.00, FB)", GAME_NOT_WORKING ) */
-/*COMPX( 1984, ql_pm,  0,  0, ql, ql, 0, ql, "Sinclair Research Ltd", "QL (v1.01, PM)", GAME_NOT_WORKING ) */
-COMPX( 1984, ql,     0,  0, ql, ql, 0, ql, "Sinclair Research Ltd", "QL (v1.02, AH)", GAME_NOT_WORKING )
-COMPX( 1984, ql_jm,  ql, 0, ql, ql, 0, ql, "Sinclair Research Ltd", "QL (v1.03, JM)", GAME_NOT_WORKING )
-COMPX( 1984, ql_tb,  ql, 0, ql, ql, 0, ql, "Sinclair Research Ltd", "QL (v1.0?, TB)", GAME_NOT_WORKING )
-COMPX( 1985, ql_js,  ql, 0, ql, ql, 0, ql, "Sinclair Research Ltd", "QL (v1.10, JS)", GAME_NOT_WORKING )
-COMPX( 1985, ql_jsu, ql, 0, ql_ntsc, ql, 0, ql, "Sinclair Research Ltd", "QL (v1.10, JSU) (NTSC)", GAME_NOT_WORKING )
-COMPX( 1985, ql_mge, ql, 0, ql, ql, 0, ql, "Sinclair Research Ltd", "QL (v1.13, MGE) (Spain)", GAME_NOT_WORKING )
-COMPX( 1985, ql_mgf, ql, 0, ql, ql, 0, ql, "Sinclair Research Ltd", "QL (v1.13, MGF) (France)", GAME_NOT_WORKING )
-COMPX( 1985, ql_mgg, ql, 0, ql, ql, 0, ql, "Sinclair Research Ltd", "QL (v1.13, MGG) (Germany)", GAME_NOT_WORKING )
-COMPX( 1985, ql_mgi, ql, 0, ql, ql, 0, ql, "Sinclair Research Ltd", "QL (v1.13, MGI) (Italy)", GAME_NOT_WORKING )
-COMPX( 1985, ql_mgs, ql, 0, ql, ql, 0, ql, "Sinclair Research Ltd", "QL (v1.13, MGS) (Sweden)", GAME_NOT_WORKING )
-COMPX( 1985, ql_efp, ql, 0, ql, ql, 0, ql, "Sinclair Research Ltd", "QL (v1.13, EFP) (Mexico)", GAME_NOT_WORKING )
+/*COMP( 1984, ql_fb,  0,  0, ql, ql, 0, ql, "Sinclair Research Ltd", "QL (v1.00, FB)", GAME_NOT_WORKING ) */
+/*COMP( 1984, ql_pm,  0,  0, ql, ql, 0, ql, "Sinclair Research Ltd", "QL (v1.01, PM)", GAME_NOT_WORKING ) */
+COMP( 1984, ql,     0,  0, ql, ql, 0, ql, "Sinclair Research Ltd", "QL (v1.02, AH)", GAME_NOT_WORKING )
+COMP( 1984, ql_jm,  ql, 0, ql, ql, 0, ql, "Sinclair Research Ltd", "QL (v1.03, JM)", GAME_NOT_WORKING )
+COMP( 1984, ql_tb,  ql, 0, ql, ql, 0, ql, "Sinclair Research Ltd", "QL (v1.0?, TB)", GAME_NOT_WORKING )
+COMP( 1985, ql_js,  ql, 0, ql, ql, 0, ql, "Sinclair Research Ltd", "QL (v1.10, JS)", GAME_NOT_WORKING )
+COMP( 1985, ql_jsu, ql, 0, ql_ntsc, ql, 0, ql, "Sinclair Research Ltd", "QL (v1.10, JSU) (NTSC)", GAME_NOT_WORKING )
+COMP( 1985, ql_mge, ql, 0, ql, ql, 0, ql, "Sinclair Research Ltd", "QL (v1.13, MGE) (Spain)", GAME_NOT_WORKING )
+COMP( 1985, ql_mgf, ql, 0, ql, ql, 0, ql, "Sinclair Research Ltd", "QL (v1.13, MGF) (France)", GAME_NOT_WORKING )
+COMP( 1985, ql_mgg, ql, 0, ql, ql, 0, ql, "Sinclair Research Ltd", "QL (v1.13, MGG) (Germany)", GAME_NOT_WORKING )
+COMP( 1985, ql_mgi, ql, 0, ql, ql, 0, ql, "Sinclair Research Ltd", "QL (v1.13, MGI) (Italy)", GAME_NOT_WORKING )
+COMP( 1985, ql_mgs, ql, 0, ql, ql, 0, ql, "Sinclair Research Ltd", "QL (v1.13, MGS) (Sweden)", GAME_NOT_WORKING )
+COMP( 1985, ql_efp, ql, 0, ql, ql, 0, ql, "Sinclair Research Ltd", "QL (v1.13, EFP) (Mexico)", GAME_NOT_WORKING )
