@@ -22,9 +22,12 @@
 #include "vidhrdw/tms9928a.h"
 #include "sound/sn76496.h"
 #include "cpu/z80/z80.h"
+#include "cpu/z80/z80daisy.h"
 #include "includes/centroni.h"
 #include "devices/printer.h"
-#include "machine/z80fmly.h"
+#include "machine/z80ctc.h"
+#include "machine/z80pio.h"
+#include "machine/z80sio.h"
 #include "machine/8255ppi.h"
 #include "devices/cartslot.h"
 #include "devices/cassette.h"
@@ -44,25 +47,20 @@
 /* - IRQ of NEC765 is connected to INT of Z80 */
 /* PI-5 interface is required. mode 2 of the 8255 is used to communicate with the FD-5 */
 
-#include "includes/nec765.h"
+#include "machine/nec765.h"
 #include "devices/cassette.h"
 #include "image.h"
 
-static MACHINE_INIT( sord_m5 );
+static MACHINE_RESET( sord_m5 );
 
 static unsigned char fd5_databus;
 
-ADDRESS_MAP_START( readmem_sord_fd5 , ADDRESS_SPACE_PROGRAM, 8)
-	AM_RANGE(0x0000, 0x03fff) AM_READ( MRA8_ROM)	/* internal rom */
-	AM_RANGE(0x4000, 0x0ffff) AM_READ( MRA8_RAM)
+ADDRESS_MAP_START( sord_fd5_mem , ADDRESS_SPACE_PROGRAM, 8)
+	AM_RANGE(0x0000, 0x03fff) AM_ROM	/* internal rom */
+	AM_RANGE(0x4000, 0x0ffff) AM_RAM
 ADDRESS_MAP_END
 
 
-ADDRESS_MAP_START( writemem_sord_fd5 , ADDRESS_SPACE_PROGRAM, 8)
-	AM_RANGE(0x0000, 0x03fff) AM_WRITE( MWA8_ROM) /* internal rom */
-	AM_RANGE(0x4000, 0x0ffff) AM_WRITE( MWA8_RAM)
-ADDRESS_MAP_END
-
 static int obfa,ibfa, intra;
 static int fd5_port_0x020_data;
 
@@ -99,9 +97,9 @@ static  READ8_HANDLER(fd5_data_r)
 	logerror("fd5 0x010 r: %02x %04x\n",fd5_databus,activecpu_get_pc());
 #endif
 	
-	ppi8255_set_input_acka(0,1);
-	ppi8255_set_input_acka(0,0);
-	ppi8255_set_input_acka(0,1);
+	ppi8255_set_portC(0, 0x50);
+	ppi8255_set_portC(0, 0x10);
+	ppi8255_set_portC(0, 0x50);
 
 	return fd5_databus;
 }
@@ -115,9 +113,9 @@ static WRITE8_HANDLER(fd5_data_w)
 	fd5_databus = data;
 
 	/* set stb on data write */
-	ppi8255_set_input_stba(0,1);
-	ppi8255_set_input_stba(0,0);
-	ppi8255_set_input_stba(0,1);
+	ppi8255_set_portC(0, 0x50);
+	ppi8255_set_portC(0, 0x40);
+	ppi8255_set_portC(0, 0x50);
 
 	cpu_yield();
 }
@@ -192,14 +190,13 @@ static void sord_fd5_init(void)
 	nec765_init(&sord_fd5_nec765_interface,NEC765A);
 }
 
-static MACHINE_INIT( sord_m5_fd5 )
+static MACHINE_RESET( sord_m5_fd5 )
 {
 	floppy_drive_set_geometry(image_from_devtype_and_index(IO_FLOPPY, 0), FLOPPY_DRIVE_SS_40);
 	floppy_drive_set_geometry(image_from_devtype_and_index(IO_FLOPPY, 1), FLOPPY_DRIVE_SS_40);
 	sord_fd5_init();
-	machine_init_sord_m5();
-	ppi8255_set_input_acka(0,1);
-	ppi8255_set_input_stba(0,1);
+	machine_reset_sord_m5();
+	ppi8255_set_portC(0, 0x50);
 }
 
 
@@ -295,40 +292,16 @@ static WRITE8_HANDLER(sord_ppi_portb_w)
 
 static WRITE8_HANDLER(sord_ppi_portc_w)
 {
+	obfa = (data & 0x80) ? 1 : 0;
+	intra = (data & 0x08) ? 1 : 0;
+	ibfa = (data & 0x20) ? 1 : 0;
+
 	cpu_yield();
 #ifdef SORD_DEBUG
 	logerror("m5 write to pi5 port c: %02x %04x\n",data,activecpu_get_pc());
 #endif
 }
 
-static WRITE8_HANDLER(sord_ppi_obfa_write)
-{
-/*	logerror("ppi obfa write %02x %04x\n",data,activecpu_get_pc()); */
-	obfa = data & 0x01;
-	cpu_yield();
-}
-
-static WRITE8_HANDLER(sord_ppi_intra_write)
-{
-/*	logerror("ppi intra write %02x %04x\n",data,activecpu_get_pc()); */
-	intra = data & 0x01;
-	cpu_yield();
-}
-
-static WRITE8_HANDLER(sord_ppi_ibfa_write)
-{
-/*	logerror("ppi ibfa write %02x %04x\n",data,activecpu_get_pc()); */
-	ibfa = data & 0x01;
-	cpu_yield();
-}
-
-static ppi8255_mode2_interface sord_ppi8255_mode2_interface = 
-{
-	{sord_ppi_obfa_write},
-	{sord_ppi_intra_write},
-	{sord_ppi_ibfa_write}
-};
-
 static ppi8255_interface sord_ppi8255_interface =
 {
 	1,
@@ -343,48 +316,36 @@ static ppi8255_interface sord_ppi8255_interface =
 /*********************************************************************************************/
 
 
-static DEVICE_LOAD( sord_cartslot )
-{
-	return cartslot_load_generic(file, REGION_USER1, 0, 1, 0x5000, 0);
-}
-
 static void sord_m5_ctc_interrupt(int state)
 {
 	/*logerror("interrupting ctc %02x\r\n ",state); */
-	cpunum_set_input_line_and_vector( 0, 0, HOLD_LINE, Z80_VECTOR( 0, state));
+	cpunum_set_input_line(0, 0, state);
 }
 
 static z80ctc_interface	sord_m5_ctc_intf =
 {
-	1,
-	{3800000},
-	{0},
-	{sord_m5_ctc_interrupt},
-	{0},
-	{0},
-    {0}
+	3800000,
+	0,
+	sord_m5_ctc_interrupt,
+	0,
+	0,
+    0
 };
 
-static  READ8_HANDLER ( sord_keyboard_r )
+static READ8_HANDLER ( sord_keyboard_r )
 {
 	return readinputport(offset);
 }
 
-ADDRESS_MAP_START( readmem_sord_m5 , ADDRESS_SPACE_PROGRAM, 8)
-	AM_RANGE(0x0000, 0x01fff) AM_READ( MRA8_ROM)	/* internal rom */
-	AM_RANGE(0x2000, 0x06fff) AM_READ( MRA8_BANK1)
-	AM_RANGE(0x7000, 0x0ffff) AM_READ( MRA8_RAM)
+ADDRESS_MAP_START( sord_m5_mem , ADDRESS_SPACE_PROGRAM, 8)
+	AM_RANGE(0x0000, 0x01fff) AM_ROM	/* internal rom */
+	AM_RANGE(0x2000, 0x06fff) AM_ROMBANK(1)
+	AM_RANGE(0x7000, 0x0ffff) AM_RAM
 ADDRESS_MAP_END
 
 
 
-ADDRESS_MAP_START( writemem_sord_m5 , ADDRESS_SPACE_PROGRAM, 8)
-	AM_RANGE(0x0000, 0x01fff) AM_WRITE( MWA8_ROM) /* internal rom */
-	AM_RANGE(0x02000, 0x06fff) AM_WRITE( MWA8_NOP)	
-	AM_RANGE(0x7000, 0x0ffff) AM_WRITE( MWA8_RAM)
-ADDRESS_MAP_END
-
-static  READ8_HANDLER(sord_ctc_r)
+static READ8_HANDLER(sord_ctc_r)
 {
 	unsigned char data;
 
@@ -469,6 +430,7 @@ static WRITE8_HANDLER(sord_printer_w)
 }
 
 ADDRESS_MAP_START( sord_m5_io , ADDRESS_SPACE_IO, 8)
+	ADDRESS_MAP_FLAGS( AMEF_ABITS(8) )
 	AM_RANGE(0x00, 0x0f)					AM_READWRITE(sord_ctc_r,			sord_ctc_w)
 	AM_RANGE(0x10, 0x10) AM_MIRROR(0x0e)	AM_READWRITE(TMS9928A_vram_r,		TMS9928A_vram_w)
 	AM_RANGE(0x11, 0x11) AM_MIRROR(0x0e)	AM_READWRITE(TMS9928A_register_r,	TMS9928A_register_w)
@@ -479,6 +441,7 @@ ADDRESS_MAP_START( sord_m5_io , ADDRESS_SPACE_IO, 8)
 ADDRESS_MAP_END
 
 ADDRESS_MAP_START( srdm5fd5_io , ADDRESS_SPACE_IO, 8)
+	ADDRESS_MAP_FLAGS( AMEF_ABITS(8) )
 	AM_RANGE(0x00, 0x0f)					AM_READWRITE(sord_ctc_r,			sord_ctc_w)
 	AM_RANGE(0x10, 0x10) AM_MIRROR(0x0e)	AM_READWRITE(TMS9928A_vram_r,		TMS9928A_vram_w)
 	AM_RANGE(0x11, 0x11) AM_MIRROR(0x0e)	AM_READWRITE(TMS9928A_register_r,	TMS9928A_register_w)
@@ -508,20 +471,19 @@ static void sordm5_video_interrupt_callback(int state)
 	}
 }
 
-static MACHINE_INIT( sord_m5 )
+static MACHINE_RESET( sord_m5 )
 {
-	z80ctc_init(&sord_m5_ctc_intf);
+	z80ctc_init(0, &sord_m5_ctc_intf);
 
 	/* PI-5 interface connected to Sord M5 */
 	ppi8255_init(&sord_ppi8255_interface);
-	ppi8255_set_mode2_interface(&sord_ppi8255_mode2_interface);
 
 /*	cassette_timer = timer_pulse(TIME_IN_HZ(11025), 0, cassette_timer_callback); */
 	TMS9928A_reset ();
 	z80ctc_reset(0);
 
 	/* should be done in a special callback to work properly! */
-	cpu_setbank(1, memory_region(REGION_USER1));
+	memory_set_bankptr(1, memory_region(REGION_USER1));
 
 	centronics_config(0, sordm5_cent_config);
 	/* assumption: select is tied low */
@@ -648,10 +610,10 @@ INPUT_PORTS_START(sord_m5)
 INPUT_PORTS_END
 
 
-static Z80_DaisyChain sord_m5_daisy_chain[] =
+static struct z80_irq_daisy_chain sord_m5_daisy_chain[] =
 {
-	{z80ctc_reset, z80ctc_interrupt, z80ctc_reti, 0},
-	{0,0,0,-1}
+	{z80ctc_reset, z80ctc_irq_state, z80ctc_irq_ack, z80ctc_irq_reti, 0},
+	{0,0,0,0,-1}
 };
 
 
@@ -672,7 +634,7 @@ static const TMS9928a_interface tms9928a_interface =
 static MACHINE_DRIVER_START( sord_m5 )
 	/* basic machine hardware */
 	MDRV_CPU_ADD_TAG("main", Z80, 3800000)
-	MDRV_CPU_PROGRAM_MAP(readmem_sord_m5,writemem_sord_m5)
+	MDRV_CPU_PROGRAM_MAP(sord_m5_mem, 0)
 	MDRV_CPU_IO_MAP(sord_m5_io, 0)
 	MDRV_CPU_VBLANK_INT(sord_interrupt, 1)
 	MDRV_CPU_CONFIG( sord_m5_daisy_chain )
@@ -680,7 +642,7 @@ static MACHINE_DRIVER_START( sord_m5 )
 	MDRV_VBLANK_DURATION(DEFAULT_REAL_60HZ_VBLANK_DURATION)
 	MDRV_INTERLEAVE(1)
 
-	MDRV_MACHINE_INIT( sord_m5 )
+	MDRV_MACHINE_RESET( sord_m5 )
 
 	/* video hardware */
 	MDRV_TMS9928A( &tms9928a_interface )
@@ -699,11 +661,11 @@ static MACHINE_DRIVER_START( sord_m5_fd5 )
 	MDRV_CPU_IO_MAP(srdm5fd5_io, 0)
 
 	MDRV_CPU_ADD(Z80, 3800000)
-	MDRV_CPU_PROGRAM_MAP(readmem_sord_fd5,writemem_sord_fd5)
+	MDRV_CPU_PROGRAM_MAP(sord_fd5_mem, 0)
 	MDRV_CPU_IO_MAP(readport_sord_fd5,writeport_sord_fd5)
 
 	MDRV_INTERLEAVE(20)
-	MDRV_MACHINE_INIT( sord_m5_fd5 )
+	MDRV_MACHINE_RESET( sord_m5_fd5 )
 MACHINE_DRIVER_END
 
 
@@ -715,14 +677,15 @@ MACHINE_DRIVER_END
 
 ROM_START(sordm5)
 	ROM_REGION(0x010000, REGION_CPU1, 0)
-	ROM_LOAD("sordint.rom",0x0000, 0x02000, CRC(78848d39))
+	ROM_LOAD("sordint.rom",0x0000, 0x02000, CRC(78848d39) SHA1(ac042c4ae8272ad6abe09ae83492ef9a0026d0b2))
 	ROM_REGION(0x5000, REGION_USER1, 0)
+	ROM_CART_LOAD(0, "rom\0", 0x0000, 0x5000, ROM_NOMIRROR)
 ROM_END
 
 
 ROM_START(srdm5fd5)
 	ROM_REGION(0x10000, REGION_CPU1, 0)
-	ROM_LOAD("sordint.rom",0x0000, 0x02000, CRC(78848d39))
+	ROM_LOAD("sordint.rom",0x0000, 0x02000, CRC(78848d39) SHA1(ac042c4ae8272ad6abe09ae83492ef9a0026d0b2))
 	ROM_REGION(0x10000, REGION_CPU2, 0)
 	ROM_LOAD("sordfd5.rom",0x0000, 0x04000, NO_DUMP)
 	ROM_REGION(0x5000, REGION_USER1, 0)
@@ -737,42 +700,53 @@ static FLOPPY_OPTIONS_START( sordm5 )
 		FIRST_SECTOR_ID([1]))
 FLOPPY_OPTIONS_END
 
-static void sordm5_printer_getinfo(struct IODevice *dev)
+static void sordm5_printer_getinfo(const device_class *devclass, UINT32 state, union devinfo *info)
 {
 	/* printer */
-	printer_device_getinfo(dev);
-	dev->count = 1;
+	switch(state)
+	{
+		/* --- the following bits of info are returned as 64-bit signed integers --- */
+		case DEVINFO_INT_COUNT:							info->i = 1; break;
+
+		default:										printer_device_getinfo(devclass, state, info); break;
+	}
 }
 
-static void sordm5_cassette_getinfo(struct IODevice *dev)
+static void sordm5_cassette_getinfo(const device_class *devclass, UINT32 state, union devinfo *info)
 {
 	/* cassette */
-	cassette_device_getinfo(dev, sordm5_cassette_formats, NULL, (cassette_state) -1);
-	dev->count = 1;
-}
+	switch(state)
+	{
+		/* --- the following bits of info are returned as 64-bit signed integers --- */
+		case DEVINFO_INT_COUNT:							info->i = 1; break;
 
-static void sordm5_cartslot_getinfo(struct IODevice *dev)
-{
-	/* cartslot */
-	cartslot_device_getinfo(dev);
-	dev->count = 1;
-	dev->file_extensions = "rom\0";
-	dev->must_be_loaded = 1;
-	dev->load = device_load_sord_cartslot;
+		/* --- the following bits of info are returned as pointers to data or functions --- */
+		case DEVINFO_PTR_CASSETTE_FORMATS:				info->p = (void *) sordm5_cassette_formats; break;
+
+		default:										cassette_device_getinfo(devclass, state, info); break;
+	}
 }
 
 SYSTEM_CONFIG_START(sordm5)
 	CONFIG_RAM_DEFAULT(64 * 1024)
 	CONFIG_DEVICE(sordm5_printer_getinfo)
 	CONFIG_DEVICE(sordm5_cassette_getinfo)
-	CONFIG_DEVICE(sordm5_cartslot_getinfo)
+	CONFIG_DEVICE(cartslot_device_getinfo)
 SYSTEM_CONFIG_END
 
-static void srdm5fd5_floppy_getinfo(struct IODevice *dev)
+static void srdm5fd5_floppy_getinfo(const device_class *devclass, UINT32 state, union devinfo *info)
 {
 	/* floppy */
-	floppy_device_getinfo(dev, floppyoptions_sordm5);
-	dev->count = 4;
+	switch(state)
+	{
+		/* --- the following bits of info are returned as 64-bit signed integers --- */
+		case DEVINFO_INT_COUNT:							info->i = 4; break;
+
+		/* --- the following bits of info are returned as pointers to data or functions --- */
+		case DEVINFO_PTR_FLOPPY_OPTIONS:				info->p = (void *) floppyoptions_sordm5; break;
+
+		default:										floppy_device_getinfo(devclass, state, info); break;
+	}
 }
 
 SYSTEM_CONFIG_START(srdm5fd5)
@@ -781,5 +755,5 @@ SYSTEM_CONFIG_START(srdm5fd5)
 SYSTEM_CONFIG_END
 
 /*    YEAR  NAME		PARENT	COMPAT	MACHINE			INPUT		INIT	CONFIG		COMPANY		FULLNAME */
-COMP( 1983, sordm5,		0,		0,		sord_m5,		sord_m5,	0,		sordm5,		"Sord",		"Sord M5")
-COMPX(1983, srdm5fd5,	0,		0,		sord_m5_fd5,	sord_m5,	0,		srdm5fd5,	"Sord",		"Sord M5 + PI5 + FD5", GAME_NOT_WORKING)
+COMP( 1983, sordm5,		0,		0,		sord_m5,		sord_m5,	0,		sordm5,		"Sord",		"Sord M5", 0)
+COMP(1983, srdm5fd5,	0,		0,		sord_m5_fd5,	sord_m5,	0,		srdm5fd5,	"Sord",		"Sord M5 + PI5 + FD5", GAME_NOT_WORKING)
