@@ -12,6 +12,8 @@
 #include "inputx.h"
 #include "sound/beep.h"
 
+#define ST2_HEADER_SIZE		256
+
 extern  READ8_HANDLER( cdp1861_video_enable_r );
 
 static UINT8 keylatch;
@@ -88,15 +90,15 @@ INPUT_PORTS_START( studio2 )
 
 	PORT_START
 	PORT_BIT( 0x001, IP_ACTIVE_HIGH, IPT_KEYBOARD) PORT_NAME("Player 2/Right 0") PORT_CODE(KEYCODE_0_PAD)
-	PORT_BIT( 0x002, IP_ACTIVE_HIGH, IPT_KEYBOARD) PORT_NAME("Player 2/Right 1") PORT_CODE(KEYCODE_1_PAD)
-	PORT_BIT( 0x004, IP_ACTIVE_HIGH, IPT_KEYBOARD) PORT_NAME("Player 2/Right 2") PORT_CODE(KEYCODE_2_PAD) PORT_CODE(KEYCODE_UP)
-	PORT_BIT( 0x008, IP_ACTIVE_HIGH, IPT_KEYBOARD) PORT_NAME("Player 2/Right 3") PORT_CODE(KEYCODE_3_PAD)
+	PORT_BIT( 0x002, IP_ACTIVE_HIGH, IPT_KEYBOARD) PORT_NAME("Player 2/Right 1") PORT_CODE(KEYCODE_7_PAD)
+	PORT_BIT( 0x004, IP_ACTIVE_HIGH, IPT_KEYBOARD) PORT_NAME("Player 2/Right 2") PORT_CODE(KEYCODE_8_PAD) PORT_CODE(KEYCODE_UP)
+	PORT_BIT( 0x008, IP_ACTIVE_HIGH, IPT_KEYBOARD) PORT_NAME("Player 2/Right 3") PORT_CODE(KEYCODE_9_PAD)
 	PORT_BIT( 0x010, IP_ACTIVE_HIGH, IPT_KEYBOARD) PORT_NAME("Player 2/Right 4") PORT_CODE(KEYCODE_4_PAD) PORT_CODE(KEYCODE_LEFT)
 	PORT_BIT( 0x020, IP_ACTIVE_HIGH, IPT_KEYBOARD) PORT_NAME("Player 2/Right 5") PORT_CODE(KEYCODE_5_PAD)
 	PORT_BIT( 0x040, IP_ACTIVE_HIGH, IPT_KEYBOARD) PORT_NAME("Player 2/Right 6") PORT_CODE(KEYCODE_6_PAD) PORT_CODE(KEYCODE_RIGHT)
-	PORT_BIT( 0x080, IP_ACTIVE_HIGH, IPT_KEYBOARD) PORT_NAME("Player 2/Right 7") PORT_CODE(KEYCODE_7_PAD)
-	PORT_BIT( 0x100, IP_ACTIVE_HIGH, IPT_KEYBOARD) PORT_NAME("Player 2/Right 8") PORT_CODE(KEYCODE_8_PAD) PORT_CODE(KEYCODE_DOWN)
-	PORT_BIT( 0x200, IP_ACTIVE_HIGH, IPT_KEYBOARD) PORT_NAME("Player 2/Right 9") PORT_CODE(KEYCODE_9_PAD)
+	PORT_BIT( 0x080, IP_ACTIVE_HIGH, IPT_KEYBOARD) PORT_NAME("Player 2/Right 7") PORT_CODE(KEYCODE_1_PAD)
+	PORT_BIT( 0x100, IP_ACTIVE_HIGH, IPT_KEYBOARD) PORT_NAME("Player 2/Right 8") PORT_CODE(KEYCODE_2_PAD) PORT_CODE(KEYCODE_DOWN)
+	PORT_BIT( 0x200, IP_ACTIVE_HIGH, IPT_KEYBOARD) PORT_NAME("Player 2/Right 9") PORT_CODE(KEYCODE_3_PAD)
 INPUT_PORTS_END
 
 INPUT_PORTS_START( vip )
@@ -219,11 +221,11 @@ static CDP1802_CONFIG vip_config={
 
 /* Machine Initialization */
 
-static MACHINE_INIT( studio2 )
+static MACHINE_RESET( studio2 )
 {
 }
 
-static MACHINE_INIT( vip )
+static MACHINE_RESET( vip )
 {
 	memory_set_bankptr(1,memory_region(REGION_CPU1)+0x8000);
 }
@@ -241,7 +243,7 @@ static MACHINE_DRIVER_START( studio2 )
 	MDRV_VBLANK_DURATION(DEFAULT_REAL_60HZ_VBLANK_DURATION)
 	MDRV_INTERLEAVE(1)
 
-	MDRV_MACHINE_INIT( studio2 )
+	MDRV_MACHINE_RESET( studio2 )
 
     /* video hardware */
 	MDRV_VIDEO_ATTRIBUTES(VIDEO_TYPE_RASTER)
@@ -267,38 +269,68 @@ static MACHINE_DRIVER_START( vip )
 	MDRV_CPU_PROGRAM_MAP(vip_map, 0)
 	MDRV_CPU_IO_MAP(vip_io_map, 0)
 	MDRV_CPU_CONFIG( vip_config )
-	MDRV_MACHINE_INIT( vip )
+	MDRV_MACHINE_RESET( vip )
 MACHINE_DRIVER_END
 
 /* ROMs */
 
 ROM_START(studio2)
 	ROM_REGION(0x10000,REGION_CPU1, 0)
-	ROM_LOAD("studio2.rom", 0x0000, 0x800, CRC(a494b339))
+	ROM_LOAD("studio2.rom", 0x0000, 0x800, CRC(a494b339) SHA1(f2650dacc9daab06b9fdf0e7748e977b2907010c))
+/*	ROM_CART_LOAD(0, "st2,bin\0", 0x0400, 0xfc00, ROM_NOCLEAR | ROM_NOMIRROR | ROM_OPTIONAL ) */
 	ROM_REGION(0x100,REGION_GFX1, 0)
 ROM_END
 
 ROM_START(vip)
 	ROM_REGION(0x10000,REGION_CPU1, 0)
-	ROM_LOAD("monitor.rom", 0x8000, 0x200, CRC(5be0a51f))
-	ROM_LOAD("chip8.rom", 0x8200, 0x200, CRC(3e0f50f0))
+	ROM_LOAD("monitor.rom", 0x8000, 0x200, CRC(5be0a51f) SHA1(40266e6d13e3340607f8b3dcc4e91d7584287c06))
+	ROM_LOAD("chip8.rom", 0x8200, 0x200, CRC(3e0f50f0) SHA1(4a9759035f99d125859cdf6ad71b8728637dcf4f))
 	ROM_REGION(0x100,REGION_GFX1, 0)
 ROM_END
 
 /* System Configuration */
 
-static DEVICE_LOAD( studio2_cart )
-{
-	return cartslot_load_generic(file, REGION_CPU1, 0x0400, 0x0001, 0xfc00, 0);
+DEVICE_LOAD( studio2_cart ) {
+	UINT8	*ptr = NULL;
+	UINT8	header[ST2_HEADER_SIZE];
+	int	filesize;
+
+	filesize = image_length( image );
+	if ( filesize <= ST2_HEADER_SIZE ) {
+		logerror( "Error loading cartridge: Invalid ROM file: %s.\n", image_filename( image ) );
+		return INIT_FAIL;
+	}
+
+	/* read ST2 header */
+	if ( mame_fread( file, header, ST2_HEADER_SIZE ) != ST2_HEADER_SIZE ) {
+		logerror( "Error loading cartridge: Unable to read header from file: %s.\n", image_filename( image ) );
+		return INIT_FAIL;
+	}
+	filesize -= ST2_HEADER_SIZE;
+	/* Read ST2 cartridge contents */
+	ptr = ((UINT8 *)memory_region( REGION_CPU1 ) ) + 0x0400;
+	if ( mame_fread( file, ptr, filesize ) != filesize ) {
+		logerror( "Error loading cartridge: Unable to read contents from file: %s.\n", image_filename( image ) );
+		return INIT_FAIL;
+	}
+	return INIT_PASS;
 }
 
-static void studio2_cartslot_getinfo(struct IODevice *dev)
-{
-	/* cartslot */
-	cartslot_device_getinfo(dev);
-	dev->count = 1;
-	dev->file_extensions = "bin\0";
-	dev->load = device_load_studio2_cart;
+static void studio2_cartslot_getinfo( const device_class *devclass, UINT32 state, union devinfo *info ) {
+	switch( state ) {
+	case DEVINFO_INT_COUNT:
+		info->i = 1;
+		break;
+	case DEVINFO_PTR_LOAD:
+		info->load = device_load_studio2_cart;
+		break;
+	case DEVINFO_STR_FILE_EXTENSIONS:
+		strcpy(info->s = device_temp_str(), "st2");
+		break;
+	default:
+		cartslot_device_getinfo( devclass, state, info );
+		break;
+	}
 }
 
 SYSTEM_CONFIG_START(studio2)
@@ -310,13 +342,18 @@ SYSTEM_CONFIG_END
 
 /* Driver Initialization */
 
+static void setup_beep(int dummy) {
+	beep_set_state( 0, 0 );
+	beep_set_frequency( 0, 300 );
+}
+
 static DRIVER_INIT( studio2 )
 {
 	int i;
 	UINT8 *gfx = memory_region(REGION_GFX1);
 	for (i=0; i<256; i++)
 		gfx[i]=i;
-	beep_set_frequency(0, 300);
+	timer_set(0.0, 0, setup_beep);
 }
 
 static DRIVER_INIT( vip )
@@ -325,8 +362,8 @@ static DRIVER_INIT( vip )
 	UINT8 *gfx = memory_region(REGION_GFX1);
 	for (i=0; i<256; i++)
 		gfx[i]=i;
-	beep_set_frequency(0, 300);
 	memory_region(REGION_CPU1)[0x8022] = 0x3e; /*bn3, default monitor */
+	timer_set(0.0, 0, setup_beep);
 }
 
 /* Game Drivers */
@@ -334,7 +371,7 @@ static DRIVER_INIT( vip )
 /*    YEAR	NAME		PARENT	COMPAT	MACHINE		INPUT		INIT		CONFIG      COMPANY   FULLNAME */
 /* rca cosmac elf development board (2 7segment leds, some switches/keys) */
 /* rca cosmac elf2 16 key keyblock */
-CONSX(1977,	vip,		0,		0,		vip,		vip,		vip,		studio2,	"RCA",		"COSMAC VIP", GAME_NOT_WORKING )
-CONSX(1976,	studio2,	0,		0,		studio2,	studio2,	studio2,	studio2,	"RCA",		"Studio II", GAME_NOT_WORKING )
+CONS(1977,	vip,		0,		0,		vip,		vip,		vip,		studio2,	"RCA",		"COSMAC VIP", GAME_NOT_WORKING )
+CONS(1976,	studio2,	0,		0,		studio2,	studio2,	studio2,	studio2,	"RCA",		"Studio II", 0 )
 /* hanimex mpt-02 */
 /* colour studio 2 (m1200) with little color capability */
