@@ -20,8 +20,11 @@
 
 #include <math.h>
 #include "driver.h"
-#include "machine/z80fmly.h"
+#include "machine/z80ctc.h"
+#include "machine/z80pio.h"
+#include "machine/z80sio.h"
 #include "vidhrdw/generic.h"
+#include "cpu/z80/z80daisy.h"
 
 static void pio_interrupt(int state);
 
@@ -30,21 +33,14 @@ static int charset;
 
 static z80pio_interface z80pio_intf =
 {
-	1,
-	{
-		pio_interrupt
-	},
-	{
-		NULL
-	},
-	{
-		NULL
-	}
+	pio_interrupt
+	NULL,
+	NULL
 };
 
 static void pio_interrupt(int state)
 {
-	cpunum_set_input_line_and_vector(0, 0, HOLD_LINE, Z80_VECTOR(0, state));
+	cpunum_set_input_line(0, 0, state);
 }
 
 static void keyboard_scan(void)
@@ -67,10 +63,10 @@ static void reset_timer_callback(int dummy)
 	memory_set_bankptr(1, memory_region(REGION_CPU1) + 0x0000);
 }
 
-static void machine_init_super80(void)
+static MACHINE_RESET( super8 )
 {
 	/* reset PIO */
-	z80pio_init(&z80pio_intf);
+	z80pio_init(0, &z80pio_intf);
 	z80pio_reset(0);
 	keyboard_scan();
 	/* enable ROM in base >0000, and re-enable RAM shortly thereafter */
@@ -162,6 +158,11 @@ static ADDRESS_MAP_START(super80_mem, ADDRESS_SPACE_PROGRAM, 8)
 	AM_RANGE(0xf000, 0xffff) AM_RAM
 ADDRESS_MAP_END
 
+static READ8_HANDLER( pio_0_r )
+{
+	return (offset & 2) ? z80pio_c_r(0, offset & 1) : z80pio_d_r(0, offset & 1);
+}
+
 static ADDRESS_MAP_START(super80_ports, ADDRESS_SPACE_IO, 8)
 	/*AM_RANGE(0xdc, 0xdc) AM_READWRITE(super80_parallel_r, super80_parallel_w) */
 	/*AM_RANGE(0xdd, 0xdd) AM_READWRITE(super80_serial0_r, super80_serial0_w) */
@@ -169,7 +170,7 @@ static ADDRESS_MAP_START(super80_ports, ADDRESS_SPACE_IO, 8)
 	AM_RANGE(0xf0, 0xf0) AM_WRITE(super80_gpo_w)
 	AM_RANGE(0xf1, 0xf1) AM_WRITE(super80_vidpg_w)
 	AM_RANGE(0xf2, 0xf2) AM_READ(super80_gpi_r)
-	AM_RANGE(0xf8, 0xfb) AM_READWRITE(z80pio_0_r, super80_z80pio_w)
+	AM_RANGE(0xf8, 0xfb) AM_READWRITE(pio_0_r, super80_z80pio_w)
 ADDRESS_MAP_END
 
 static INPUT_PORTS_START( super80 )
@@ -247,7 +248,7 @@ static INPUT_PORTS_START( super80 )
 	PORT_BIT(0x80, IP_ACTIVE_LOW, IPT_UNUSED)
 INPUT_PORTS_END
 
-struct GfxLayout super80_elg4_charlayout =
+gfx_layout super80_elg4_charlayout =
 {
 	8,10,					/* 8 x 10 characters */
 	256,					/* 256 characters */
@@ -261,7 +262,7 @@ struct GfxLayout super80_elg4_charlayout =
 	8*16					/* every char takes 16 bytes */
 };
 
-struct GfxLayout super80_dslc_charlayout =
+gfx_layout super80_dslc_charlayout =
 {
 	8,10,					/* 8 x 10 characters */
 	128,					/* 128 characters */
@@ -275,7 +276,7 @@ struct GfxLayout super80_dslc_charlayout =
 	8*16					/* every char takes 16 bytes */
 };
 
-static struct GfxDecodeInfo super80_gfxdecodeinfo[] =
+static gfx_decode super80_gfxdecodeinfo[] =
 {
 	{ REGION_GFX1, 0x0000, &super80_elg4_charlayout, 0, 2},
 	{ REGION_GFX1, 0x1000, &super80_dslc_charlayout, 0, 2},
@@ -300,7 +301,7 @@ static PALETTE_INIT( super80_bw )
 	memcpy(colortable, & bw_colortable, sizeof(bw_colortable));
 }
 
-static Z80_DaisyChain super80_daisy_chain[] =
+static struct z80_irq_daisy_chain super80_daisy_chain[] =
 {
 	{z80pio_reset, z80pio_interrupt, z80pio_reti, 0},
 	{0,0,0,-1}
@@ -319,7 +320,7 @@ static MACHINE_DRIVER_START( super80 )
 	/*MDRV_VBLANK_DURATION(2500) */
 	MDRV_INTERLEAVE(1)
 
-	MDRV_MACHINE_INIT( super80 )
+	MDRV_MACHINE_RESET( super80 )
 
 	MDRV_GFXDECODE(super80_gfxdecodeinfo)
 	MDRV_VIDEO_ATTRIBUTES(VIDEO_TYPE_RASTER)
@@ -363,4 +364,4 @@ SYSTEM_CONFIG_START(super80)
 SYSTEM_CONFIG_END
 
 /*    YEAR  NAME      PARENT	COMPAT	MACHINE   INPUT     INIT      CONFIG	COMPANY   FULLNAME */
-COMP( 1981, super80,  0,		0,		super80,  super80,  0,        super80,	"Dick Smith",  "Super-80" )
+COMP( 1981, super80,  0,		0,		super80,  super80,  0,        super80,	"Dick Smith",  "Super-80" , 0)
