@@ -217,20 +217,13 @@ static WRITE8_HANDLER(svision_w)
 	}
 }
 
-static ADDRESS_MAP_START( readmem , ADDRESS_SPACE_PROGRAM, 8)
-    AM_RANGE( 0x0000, 0x1fff) AM_READ( MRA8_RAM )
-    AM_RANGE( 0x2000, 0x3fff) AM_READ( svision_r )
-    AM_RANGE( 0x4000, 0x5fff) AM_READ( MRA8_RAM ) /*? */
-	AM_RANGE( 0x6000, 0x7fff) AM_READ( MRA8_ROM )
-	AM_RANGE( 0x8000, 0xbfff) AM_READ( MRA8_BANK1 )
-	AM_RANGE( 0xc000, 0xffff) AM_READ( MRA8_BANK2 )
-ADDRESS_MAP_END
-
-static ADDRESS_MAP_START( writemem , ADDRESS_SPACE_PROGRAM, 8)
-	AM_RANGE( 0x0000, 0x1fff) AM_WRITE( MWA8_RAM )
-    AM_RANGE( 0x2000, 0x3fff) AM_WRITE( svision_w) AM_BASE( &svision_reg )
-	AM_RANGE( 0x4000, 0x5fff) AM_WRITE( MWA8_RAM )
-	AM_RANGE( 0x6000, 0xffff) AM_WRITE( MWA8_ROM )
+static ADDRESS_MAP_START( svision_mem , ADDRESS_SPACE_PROGRAM, 8)
+    AM_RANGE( 0x0000, 0x1fff) AM_RAM
+    AM_RANGE( 0x2000, 0x3fff) AM_READWRITE(svision_r, svision_w) AM_BASE(&svision_reg)
+    AM_RANGE( 0x4000, 0x5fff) AM_RAM AM_BASE(&videoram)
+	AM_RANGE( 0x6000, 0x7fff) AM_ROM
+	AM_RANGE( 0x8000, 0xbfff) AM_ROMBANK(1)
+	AM_RANGE( 0xc000, 0xffff) AM_ROMBANK(2)
 ADDRESS_MAP_END
 
 INPUT_PORTS_START( svision )
@@ -279,7 +272,7 @@ static PALETTE_INIT( svision )
 static VIDEO_UPDATE( svision )
 {
 	int x, y;
-	UINT8 *vram = memory_region(REGION_CPU1) + 0x4000 + (svision_reg[2] / 4);
+	UINT8 *vram = videoram + (svision_reg[2] / 4);
 	UINT8 *vram_line;
 	UINT16 *line;
 	UINT8 b;
@@ -311,7 +304,7 @@ static DRIVER_INIT( svision )
 	svision.timer1 = timer_alloc(svision_timer);
 }
 
-static MACHINE_INIT( svision )
+static MACHINE_RESET( svision )
 {
     svision.timer1_shot = FALSE;
 	svision_update_banks();
@@ -326,13 +319,13 @@ struct CustomSound_interface svision_sound_interface =
 static MACHINE_DRIVER_START( svision )
 	/* basic machine hardware */
 	MDRV_CPU_ADD(M65C02, 4000000)        /* ? stz used! speed? */
-	MDRV_CPU_PROGRAM_MAP(readmem, writemem)
+	MDRV_CPU_PROGRAM_MAP(svision_mem, 0)
 	MDRV_CPU_VBLANK_INT(svision_frame_int, 1)
 	MDRV_FRAMES_PER_SECOND(60)
 	MDRV_VBLANK_DURATION(DEFAULT_REAL_60HZ_VBLANK_DURATION)
 	MDRV_INTERLEAVE(1)
 
-	MDRV_MACHINE_INIT( svision )
+	MDRV_MACHINE_RESET( svision )
 
     /* video hardware */
 	MDRV_VIDEO_ATTRIBUTES(VIDEO_TYPE_RASTER)	/* lcd */
@@ -354,7 +347,9 @@ MACHINE_DRIVER_END
 
 ROM_START(svision)
 	ROM_REGION( 0x8000, REGION_CPU1, 0)
+
 	ROM_REGION(0x10000, REGION_USER1, 0)
+	ROM_CART_LOAD(0, "bin\0ws\0sv\0", 0x0000, 0x10000, ROM_MIRROR)
 ROM_END
 
 /* deltahero
@@ -374,23 +369,8 @@ ROM_END
  dd6a clear 0x2000 at ($57/58) (0x4000)
  */
 
-static DEVICE_LOAD( svision_cart )
-{
-	return cartslot_load_generic(file, REGION_USER1, 0, 1, 0x10000, CARTLOAD_MUSTBEPOWEROFTWO);
-}
-
-static void svision_cartslot_getinfo(struct IODevice *dev)
-{
-	/* cartslot */
-	cartslot_device_getinfo(dev);
-	dev->count = 1;
-	dev->file_extensions = "bin\0ws\0sv\0";
-	dev->must_be_loaded = 1;
-	dev->load = device_load_svision_cart;
-}
-
 SYSTEM_CONFIG_START(svision)
-	CONFIG_DEVICE(svision_cartslot_getinfo)
+	CONFIG_DEVICE(cartslot_device_getinfo)
 SYSTEM_CONFIG_END
 
 /***************************************************************************
@@ -400,6 +380,6 @@ SYSTEM_CONFIG_END
 ***************************************************************************/
 
 /*    YEAR  NAME		PARENT	COMPAT	MACHINE		INPUT		INIT		CONFIG		COMPANY		FULLNAME */
-CONSX(1992,	svision,	0,		0,		svision,	svision,	svision,	svision,	"Watara",	"Super Vision", GAME_IMPERFECT_SOUND)
+CONS(1992,	svision,	0,		0,		svision,	svision,	svision,	svision,	"Watara",	"Supervision", GAME_IMPERFECT_SOUND)
 /* marketed under a ton of firms and names */
 
