@@ -257,14 +257,14 @@ static WRITE8_HANDLER( tmc2000_bankswitch_w )
 		/* enable Color RAM */
 		memory_install_read8_handler(  0, ADDRESS_SPACE_PROGRAM, 0x8000, 0x81ff, 0, 0, MRA8_RAM );
 		memory_install_write8_handler( 0, ADDRESS_SPACE_PROGRAM, 0x8000, 0x81ff, 0, 0, MWA8_RAM );
-		cpu_setbank(1, &colorram);
+		memory_set_bankptr(1, &colorram);
 	}
 	else
 	{
 		/* enable ROM */
 		memory_install_read8_handler(  0, ADDRESS_SPACE_PROGRAM, 0x8000, 0x81ff, 0, 0, MRA8_ROM );
 		memory_install_write8_handler( 0, ADDRESS_SPACE_PROGRAM, 0x8000, 0x81ff, 0, 0, MWA8_ROM );
-		cpu_setbank(1, memory_region(REGION_CPU1) + 0x8000);
+		memory_set_bankptr(1, memory_region(REGION_CPU1) + 0x8000);
 	}
 
 	cdp1864_tone_divisor_latch_w(0, data);
@@ -514,7 +514,7 @@ INPUT_PORTS_END
 
 /* Graphics Layouts */
 
-static struct GfxLayout charlayout_normal_size =
+static gfx_layout charlayout_normal_size =
 {
 	CDP1869_CHAR_WIDTH, CDP1869_CHAR_HEIGHT_PAL,
 	256,
@@ -525,7 +525,7 @@ static struct GfxLayout charlayout_normal_size =
 	8*8
 };
 
-static struct GfxLayout charlayout_double_size =
+static gfx_layout charlayout_double_size =
 {
 	CDP1869_CHAR_WIDTH*2, CDP1869_CHAR_HEIGHT_PAL*2,
 	256,
@@ -538,7 +538,7 @@ static struct GfxLayout charlayout_double_size =
 
 /* Graphics Decode Information */
 
-static struct GfxDecodeInfo gfxdecodeinfo[] =
+static gfx_decode gfxdecodeinfo[] =
 {
 	{ REGION_GFX1, 0, &charlayout_normal_size, 0, 128 },
 	{ REGION_GFX1, 0, &charlayout_double_size, 0, 128 },
@@ -702,12 +702,12 @@ static INTERRUPT_GEN( telmac_frame_int )
 
 /* Machine Initialization */
 
-static MACHINE_INIT( tmc2000 )
+static MACHINE_RESET( tmc2000 )
 {
 	/* set program counter to 0x8000 */
 }
 
-static MACHINE_INIT( tmc2000e )
+static MACHINE_RESET( tmc2000e )
 {
 	/* set program counter to selected value */
 }
@@ -737,7 +737,7 @@ static MACHINE_DRIVER_START( tmc2000 )
 	MDRV_CPU_VBLANK_INT(telmac_frame_int, 1)
 	MDRV_CPU_CONFIG(tmc2000_config)
 
-	MDRV_MACHINE_INIT(tmc2000)
+	MDRV_MACHINE_RESET(tmc2000)
 
 	MDRV_FRAMES_PER_SECOND(CDP1864_FPS)	/* 50.08 Hz */
 	MDRV_VBLANK_DURATION(DEFAULT_60HZ_VBLANK_DURATION)
@@ -770,7 +770,7 @@ MACHINE_DRIVER_END
 static MACHINE_DRIVER_START( tmc2000e )
 	MDRV_IMPORT_FROM(tmc2000)
 
-	MDRV_MACHINE_INIT(tmc2000e)
+	MDRV_MACHINE_RESET(tmc2000e)
 
 	/* basic system hardware */
 	MDRV_CPU_MODIFY("main")
@@ -900,11 +900,16 @@ logerror("memwrite ok\n");
 	return INIT_PASS;
 }
 
-static void tmc1800_cassette_getinfo(struct IODevice *dev)
+static void tmc1800_cassette_getinfo(const device_class *devclass, UINT32 state, union devinfo *info)
 {
 	/* cassette */
-	cassette_device_getinfo(dev, NULL, NULL, (cassette_state) -1);
-	dev->count = 1;
+	switch(state)
+	{
+		/* --- the following bits of info are returned as 64-bit signed integers --- */
+		case DEVINFO_INT_COUNT:							info->i = 1; break;
+
+		default:										cassette_device_getinfo(devclass, state, info); break;
+	}
 }
 
 SYSTEM_CONFIG_START( tmc1800 )
@@ -913,11 +918,16 @@ SYSTEM_CONFIG_START( tmc1800 )
 	CONFIG_DEVICE(tmc1800_cassette_getinfo)
 SYSTEM_CONFIG_END
 
-static void tmc2000_cassette_getinfo(struct IODevice *dev)
+static void tmc2000_cassette_getinfo(const device_class *devclass, UINT32 state, union devinfo *info)
 {
 	/* cassette */
-	cassette_device_getinfo(dev, NULL, NULL, (cassette_state) -1);
-	dev->count = 1;
+	switch(state)
+	{
+		/* --- the following bits of info are returned as 64-bit signed integers --- */
+		case DEVINFO_INT_COUNT:							info->i = 1; break;
+
+		default:										cassette_device_getinfo(devclass, state, info); break;
+	}
 }
 
 SYSTEM_CONFIG_START( tmc2000 )
@@ -926,11 +936,16 @@ SYSTEM_CONFIG_START( tmc2000 )
 	CONFIG_DEVICE(tmc2000_cassette_getinfo)
 SYSTEM_CONFIG_END
 
-static void tmc2000e_cassette_getinfo(struct IODevice *dev)
+static void tmc2000e_cassette_getinfo(const device_class *devclass, UINT32 state, union devinfo *info)
 {
 	/* cassette */
-	cassette_device_getinfo(dev, NULL, NULL, (cassette_state) -1);
-	dev->count = 1;
+	switch(state)
+	{
+		/* --- the following bits of info are returned as 64-bit signed integers --- */
+		case DEVINFO_INT_COUNT:							info->i = 1; break;
+
+		default:										cassette_device_getinfo(devclass, state, info); break;
+	}
 }
 
 SYSTEM_CONFIG_START( tmc2000e )
@@ -938,34 +953,61 @@ SYSTEM_CONFIG_START( tmc2000e )
 	CONFIG_DEVICE(tmc2000e_cassette_getinfo)
 SYSTEM_CONFIG_END
 
-static void tmc600_cassette_getinfo(struct IODevice *dev)
+static void tmc600_cassette_getinfo(const device_class *devclass, UINT32 state, union devinfo *info)
 {
 	/* cassette */
-	cassette_device_getinfo(dev, NULL, NULL, (cassette_state) -1);
-	dev->count = 1;
+	switch(state)
+	{
+		/* --- the following bits of info are returned as 64-bit signed integers --- */
+		case DEVINFO_INT_COUNT:							info->i = 1; break;
+
+		default:										cassette_device_getinfo(devclass, state, info); break;
+	}
 }
 
-static void tmc600_floppy_getinfo(struct IODevice *dev)
+static void tmc600_floppy_getinfo(const device_class *devclass, UINT32 state, union devinfo *info)
 {
 	/* floppy */
-	legacybasicdsk_device_getinfo(dev);
-	dev->count = 4;
-	dev->file_extensions = "dsk\0";
-	dev->load = device_load_basicdsk_floppy;
+	switch(state)
+	{
+		/* --- the following bits of info are returned as 64-bit signed integers --- */
+		case DEVINFO_INT_COUNT:							info->i = 4; break;
+
+		/* --- the following bits of info are returned as pointers to data or functions --- */
+		case DEVINFO_PTR_LOAD:							info->load = device_load_basicdsk_floppy; break;
+
+		/* --- the following bits of info are returned as NULL-terminated strings --- */
+		case DEVINFO_STR_FILE_EXTENSIONS:				strcpy(info->s = device_temp_str(), "dsk"); break;
+
+		default:										legacybasicdsk_device_getinfo(devclass, state, info); break;
+	}
 }
 
-static void tmc600_printer_getinfo(struct IODevice *dev)
+static void tmc600_printer_getinfo(const device_class *devclass, UINT32 state, union devinfo *info)
 {
 	/* printer */
-	printer_device_getinfo(dev);
-	dev->count = 1;
+	switch(state)
+	{
+		/* --- the following bits of info are returned as 64-bit signed integers --- */
+		case DEVINFO_INT_COUNT:							info->i = 1; break;
+
+		default:										printer_device_getinfo(devclass, state, info); break;
+	}
 }
 
-static void tmc600_quickload_getinfo(struct IODevice *dev)
+static void tmc600_quickload_getinfo(const device_class *devclass, UINT32 state, union devinfo *info)
 {
 	/* quickload */
-	quickload_device_getinfo(dev, quickload_load_tmc600, 0.0);
-	dev->file_extensions = "sbp\0";
+	switch(state)
+	{
+		/* --- the following bits of info are returned as NULL-terminated strings --- */
+		case DEVINFO_STR_FILE_EXTENSIONS:				strcpy(info->s = device_temp_str(), "sbp"); break;
+
+		/* --- the following bits of info are returned as pointers to data or functions --- */
+		case DEVINFO_PTR_QUICKLOAD_LOAD:				info->f = (genf *) quickload_load_tmc600; break;
+
+		default:										quickload_device_getinfo(devclass, state, info); break;
+	}
 }
 
 SYSTEM_CONFIG_START( tmc600 )
@@ -993,10 +1035,10 @@ static DRIVER_INIT( telmac )
 /* System Drivers */
 
 /*     YEAR  NAME 	   PARENT   COMPAT   MACHINE   INPUT     INIT	 CONFIG    COMPANY 	      FULLNAME */
-COMPX( 1977, tmc1800,  0,       0,	     tmc1800,  tmc1800,  telmac, tmc1800,  "Telercas Oy", "Telmac 1800", GAME_NOT_WORKING )
-COMPX( 1980, tmc2000,  0,       tmc1800, tmc2000,  tmc1800,  telmac, tmc2000,  "Telercas Oy", "Telmac 2000", GAME_NOT_WORKING )
-COMPX( 1980, tmc2000t, tmc2000, tmc1800, tmc2000t, tmc1800,  telmac, tmc2000,  "Telercas Oy", "Telmac 2000 (TOOL-2000)", GAME_NOT_WORKING )
-COMPX( 1980, tmc2000e, 0,       0,	     tmc2000e, tmc2000e, telmac, tmc2000e, "Telercas Oy", "Telmac 2000E", GAME_NOT_WORKING )
-COMPX( 1982, tmc600,   0,       0,	     tmc600,   tmc600,   telmac, tmc600,   "Telercas Oy", "Telmac TMC-600 (Series I)", GAME_NOT_WORKING )
-COMPX( 1982, tmc600a,  tmc600,  0,	     tmc600,   tmc600,   telmac, tmc600,   "Telercas Oy", "Telmac TMC-600 (Series II)", GAME_IMPERFECT_GRAPHICS | GAME_IMPERFECT_SOUND )
-COMPX( 1982, tmc600as, tmc600,  0,	     tmc600,   tmc600,   telmac, tmc600,   "Telercas Oy", "Telmac TMC-600 AS", GAME_NOT_WORKING )
+COMP( 1977, tmc1800,  0,       0,	     tmc1800,  tmc1800,  telmac, tmc1800,  "Telercas Oy", "Telmac 1800", GAME_NOT_WORKING )
+COMP( 1980, tmc2000,  0,       tmc1800, tmc2000,  tmc1800,  telmac, tmc2000,  "Telercas Oy", "Telmac 2000", GAME_NOT_WORKING )
+COMP( 1980, tmc2000t, tmc2000, tmc1800, tmc2000t, tmc1800,  telmac, tmc2000,  "Telercas Oy", "Telmac 2000 (TOOL-2000)", GAME_NOT_WORKING )
+COMP( 1980, tmc2000e, 0,       0,	     tmc2000e, tmc2000e, telmac, tmc2000e, "Telercas Oy", "Telmac 2000E", GAME_NOT_WORKING )
+COMP( 1982, tmc600,   0,       0,	     tmc600,   tmc600,   telmac, tmc600,   "Telercas Oy", "Telmac TMC-600 (Series I)", GAME_NOT_WORKING )
+COMP( 1982, tmc600a,  tmc600,  0,	     tmc600,   tmc600,   telmac, tmc600,   "Telercas Oy", "Telmac TMC-600 (Series II)", GAME_IMPERFECT_GRAPHICS | GAME_IMPERFECT_SOUND )
+COMP( 1982, tmc600as, tmc600,  0,	     tmc600,   tmc600,   telmac, tmc600,   "Telercas Oy", "Telmac TMC-600 AS", GAME_NOT_WORKING )
