@@ -101,12 +101,20 @@ enum
 };
 
 
-static void machine_init_tutor(void)
+static DRIVER_INIT(tutor)
+{
+	tape_interrupt_timer = timer_alloc(tape_interrupt_handler);
+
+	memory_configure_bank(1, 0, 1, memory_region(REGION_CPU1) + basic_base, 0);
+	memory_configure_bank(1, 1, 1, memory_region(REGION_CPU1) + cartridge_base, 0);
+	memory_set_bank(1, 0);
+}
+
+static MACHINE_RESET(tutor)
 {
 	cartridge_enable = 0;
 
 	tape_interrupt_enable = 0;
-	tape_interrupt_timer = timer_alloc(tape_interrupt_handler);
 
 	printer_data = 0;
 	printer_strobe = 0;
@@ -132,21 +140,21 @@ static void tutor_vblank_interrupt(void)
 	mapped to both a keyboard key and a joystick switch.
 */
 
-static  READ8_HANDLER(read_keyboard)
+static READ8_HANDLER(read_keyboard)
 {
 	return readinputport(offset);
 }
 
-static DEVICE_LOAD(tutor_cart)
+static int device_load_tutor_cart(mess_image *image, mame_file *file)
 {
 	mame_fread(file, memory_region(REGION_CPU1) + cartridge_base, 0x6000);
 
 	return INIT_PASS;
 }
 
-static DEVICE_UNLOAD(tutor_cart)
+static void device_unload_tutor_cart(mess_image *image)
 {
-	memset(memory_region(REGION_CPU1) + cartridge_base, 0x6000, 0);
+	memset(memory_region(REGION_CPU1) + cartridge_base, 0, 0x6000);
 }
 
 /*
@@ -194,13 +202,13 @@ static WRITE8_HANDLER(tutor_mapper_w)
 	case 0x08:
 		/* disable cartridge ROM, enable BASIC ROM at base >8000 */
 		cartridge_enable = 0;
-		cpu_setbank(1, memory_region(REGION_CPU1) + basic_base);
+		memory_set_bank(1, 0);
 		break;
 
 	case 0x0c:
 		/* enable cartridge ROM, disable BASIC ROM at base >8000 */
 		cartridge_enable = 1;
-		cpu_setbank(1, memory_region(REGION_CPU1) + cartridge_base);
+		memory_set_bank(1, 1);
 		break;
 
 	default:
@@ -284,14 +292,14 @@ static WRITE8_HANDLER(tutor_cassette_w)
 	}
 }
 
-static DEVICE_LOAD(tutor_printer)
+static int device_load_tutor_printer(mess_image *image, mame_file *file)
 {
 	printer_fp = file;
 
 	return INIT_PASS;
 }
 
-static DEVICE_UNLOAD(tutor_printer)
+static void device_unload_tutor_printer(mess_image *image)
 {
 	printer_fp = NULL;
 }
@@ -390,9 +398,9 @@ static WRITE8_HANDLER(tutor_printer_w)
 
 static ADDRESS_MAP_START(tutor_memmap, ADDRESS_SPACE_PROGRAM, 8)
 
-	AM_RANGE(0x0000, 0x7fff) AM_READWRITE(MRA8_ROM, MWA8_ROM)	/*system ROM*/
-	AM_RANGE(0x8000, 0xbfff) AM_READWRITE(MRA8_BANK1, MWA8_ROM)	/*BASIC ROM & cartridge ROM*/
-	AM_RANGE(0xc000, 0xdfff) AM_READWRITE(MRA8_NOP, MWA8_NOP)	/*free for expansion, or cartridge ROM?*/
+	AM_RANGE(0x0000, 0x7fff) AM_ROM	/*system ROM*/
+	AM_RANGE(0x8000, 0xbfff) AM_ROMBANK(1)	/*BASIC ROM & cartridge ROM*/
+	AM_RANGE(0xc000, 0xdfff) AM_NOP	/*free for expansion, or cartridge ROM?*/
 
 	AM_RANGE(0xe000, 0xe000) AM_READWRITE(TMS9928A_vram_r, TMS9928A_vram_w)	/*VDP data*/
 	AM_RANGE(0xe002, 0xe002) AM_READWRITE(TMS9928A_register_r, TMS9928A_register_w)/*VDP status*/
@@ -401,7 +409,7 @@ static ADDRESS_MAP_START(tutor_memmap, ADDRESS_SPACE_PROGRAM, 8)
 	AM_RANGE(0xe800, 0xe8ff) AM_READWRITE(tutor_printer_r, tutor_printer_w)	/*printer*/
 	AM_RANGE(0xee00, 0xeeff) AM_READWRITE(MRA8_NOP, tutor_cassette_w)		/*cassette interface*/
 
-	AM_RANGE(0xf000, 0xffff) AM_READWRITE(MRA8_NOP, MWA8_NOP)	/*free for expansion (and internal processor RAM)*/
+	AM_RANGE(0xf000, 0xffff) AM_NOP	/*free for expansion (and internal processor RAM)*/
 
 ADDRESS_MAP_END
 
@@ -570,7 +578,7 @@ static MACHINE_DRIVER_START(tutor)
 	MDRV_VBLANK_DURATION(DEFAULT_REAL_60HZ_VBLANK_DURATION)
 	/*MDRV_INTERLEAVE(interleave)*/
 
-	MDRV_MACHINE_INIT( tutor )
+	MDRV_MACHINE_RESET( tutor )
 	/*MDRV_NVRAM_HANDLER( NULL )*/
 
 	/* video hardware */
@@ -591,38 +599,60 @@ MACHINE_DRIVER_END
 ROM_START(tutor)
 	/*CPU memory space*/
 	ROM_REGION(0x14000,REGION_CPU1,0)
-	ROM_LOAD("tutor1.bin", 0x0000, 0x8000, CRC(702c38ba))      /* system ROM */
-	ROM_LOAD("tutor2.bin", 0x8000, 0x4000, CRC(05f228f5))      /* BASIC ROM */
+	ROM_LOAD("tutor1.bin", 0x0000, 0x8000, CRC(702c38ba) SHA1(ce60607c3038895e31915d41bb5cf71cb8522d7a))      /* system ROM */
+	ROM_LOAD("tutor2.bin", 0x8000, 0x4000, CRC(05f228f5) SHA1(46a14a45f6f9e2c30663a2b87ce60c42768a78d0))      /* BASIC ROM */
 ROM_END
 
-static void tutor_cartslot_getinfo(struct IODevice *dev)
+static void tutor_cartslot_getinfo(const device_class *devclass, UINT32 state, union devinfo *info)
 {
 	/* cartslot */
-	cartslot_device_getinfo(dev);
-	dev->count = 1;
-	dev->file_extensions = "\0";
-	dev->load = device_load_tutor_cart;
-	dev->unload = device_unload_tutor_cart;
+	switch(state)
+	{
+		/* --- the following bits of info are returned as 64-bit signed integers --- */
+		case DEVINFO_INT_COUNT:							info->i = 1; break;
+
+		/* --- the following bits of info are returned as pointers to data or functions --- */
+		case DEVINFO_PTR_LOAD:							info->load = device_load_tutor_cart; break;
+		case DEVINFO_PTR_UNLOAD:						info->unload = device_unload_tutor_cart; break;
+
+		/* --- the following bits of info are returned as NULL-terminated strings --- */
+		case DEVINFO_STR_FILE_EXTENSIONS:				strcpy(info->s = device_temp_str(), ""); break;
+
+		default:										cartslot_device_getinfo(devclass, state, info); break;
+	}
 }
 
-static void tutor_cassette_getinfo(struct IODevice *dev)
+static void tutor_cassette_getinfo(const device_class *devclass, UINT32 state, union devinfo *info)
 {
 	/* cassette */
-	cassette_device_getinfo(dev, NULL, NULL, (cassette_state) -1);
-	dev->count = 1;
+	switch(state)
+	{
+		/* --- the following bits of info are returned as 64-bit signed integers --- */
+		case DEVINFO_INT_COUNT:							info->i = 1; break;
+
+		default:										cassette_device_getinfo(devclass, state, info); break;
+	}
 }
 
-static void tutor_parallel_getinfo(struct IODevice *dev)
+static void tutor_parallel_getinfo(const device_class *devclass, UINT32 state, union devinfo *info)
 {
 	/* parallel */
-	dev->type = IO_PARALLEL;
-	dev->file_extensions = "\0";
-	dev->count = 1;
-	dev->readable = 0;
-	dev->writeable = 1;
-	dev->creatable = 1;
-	dev->load = device_load_tutor_printer;
-	dev->unload = device_unload_tutor_printer;
+	switch(state)
+	{
+		/* --- the following bits of info are returned as 64-bit signed integers --- */
+		case DEVINFO_INT_TYPE:							info->i = IO_PARALLEL; break;
+		case DEVINFO_INT_READABLE:						info->i = 0; break;
+		case DEVINFO_INT_WRITEABLE:						info->i = 1; break;
+		case DEVINFO_INT_CREATABLE:						info->i = 1; break;
+		case DEVINFO_INT_COUNT:							info->i = 1; break;
+
+		/* --- the following bits of info are returned as pointers to data or functions --- */
+		case DEVINFO_PTR_LOAD:							info->load = device_load_tutor_printer; break;
+		case DEVINFO_PTR_UNLOAD:						info->unload = device_unload_tutor_printer; break;
+
+		/* --- the following bits of info are returned as NULL-terminated strings --- */
+		case DEVINFO_STR_FILE_EXTENSIONS:				strcpy(info->s = device_temp_str(), ""); break;
+	}
 }
 
 SYSTEM_CONFIG_START(tutor)
@@ -635,4 +665,4 @@ SYSTEM_CONFIG_START(tutor)
 SYSTEM_CONFIG_END
 
 /*		YEAR	NAME	PARENT		COMPAT	MACHINE		INPUT	INIT	CONFIG		COMPANY		FULLNAME */
-COMP(	1983?,	tutor,	0,			0,		tutor,		tutor,	NULL,	tutor,		"Tomy",		"Tomy Tutor" )
+COMP(	1983?,	tutor,	0,			0,		tutor,		tutor,	tutor,	tutor,		"Tomy",		"Tomy Tutor" , 0)
