@@ -163,81 +163,52 @@ when problems start with -log and look into error.log file
 #include "includes/vic6560.h"
 #include "devices/cartslot.h"
 
-static ADDRESS_MAP_START( vc20_readmem , ADDRESS_SPACE_PROGRAM, 8)
-	AM_RANGE(0x0000, 0x03ff) AM_READ( MRA8_RAM)
+static ADDRESS_MAP_START( vc20_mem , ADDRESS_SPACE_PROGRAM, 8)
+	AM_RANGE(0x0000, 0x03ff) AM_RAM AM_BASE(&vc20_memory)
 #if 0
-	AM_RANGE(0x0400, 0x0fff) AM_READ( MRA8_RAM)		   /* ram, rom or nothing; I think read 0xff! */
+	AM_RANGE(0x0400, 0x0fff) AM_READ(MRA8_RAM)	/* ram, rom or nothing; I think read 0xff! */
 #endif
-	AM_RANGE(0x1000, 0x1fff) AM_READ( MRA8_RAM)
+	AM_RANGE(0x1000, 0x1fff) AM_RAM
 #if 0
-	AM_RANGE(0x2000, 0x3fff) AM_READ( MRA8_RAM)		   /* ram, rom or nothing */
-	AM_RANGE(0x4000, 0x5fff) AM_READ( MRA8_RAM)		   /* ram, rom or nothing */
-	AM_RANGE(0x6000, 0x7fff) AM_READ( MRA8_RAM)		   /* ram, rom or nothing */
+	AM_RANGE(0x2000, 0x3fff) AM_READ(MRA8_RAM)	/* ram, rom or nothing */
+	AM_RANGE(0x4000, 0x5fff) AM_READ(MRA8_RAM)	/* ram, rom or nothing */
+	AM_RANGE(0x6000, 0x7fff) AM_READ(MRA8_RAM)	/* ram, rom or nothing */
 #endif
-	AM_RANGE(0x8000, 0x8fff) AM_READ( MRA8_ROM)
-	AM_RANGE(0x9000, 0x900f) AM_READ( vic6560_port_r)
-	AM_RANGE(0x9010, 0x910f) AM_READ( MRA8_NOP)
-	AM_RANGE(0x9110, 0x911f) AM_READ( via_0_r)
-	AM_RANGE(0x9120, 0x912f) AM_READ( via_1_r)
-	AM_RANGE(0x9130, 0x93ff) AM_READ( MRA8_NOP)
-	AM_RANGE(0x9400, 0x97ff) AM_READ( MRA8_RAM)		   /*color ram 4 bit */
-	AM_RANGE(0x9800, 0x9fff) AM_READ( MRA8_NOP)
+	AM_RANGE(0x8000, 0x8fff) AM_ROM
+	AM_RANGE(0x9000, 0x900f) AM_READWRITE( vic6560_port_r, vic6560_port_w )
+	AM_RANGE(0x9010, 0x910f) AM_NOP
+	AM_RANGE(0x9110, 0x911f) AM_READWRITE( via_0_r, via_0_w )
+	AM_RANGE(0x9120, 0x912f) AM_READWRITE( via_1_r, via_1_w )
+	AM_RANGE(0x9130, 0x93ff) AM_NOP
+	AM_RANGE(0x9400, 0x97ff) AM_READWRITE(MRA8_RAM, vc20_write_9400) AM_BASE(&vc20_memory_9400)	/*color ram 4 bit */
+	AM_RANGE(0x9800, 0x9fff) AM_NOP
 #if 0
-	AM_RANGE(0xa000, 0xbfff) AM_READ( MRA8_RAM)		   /* or nothing */
+	AM_RANGE(0xa000, 0xbfff) AM_ROM		   /* or nothing */
 #endif
-	AM_RANGE(0xc000, 0xffff) AM_READ( MRA8_ROM)
+	AM_RANGE(0xc000, 0xffff) AM_ROM
 ADDRESS_MAP_END
 
-static ADDRESS_MAP_START( vc20_writemem , ADDRESS_SPACE_PROGRAM, 8)
-	AM_RANGE(0x0000, 0x03ff) AM_WRITE( MWA8_RAM) AM_BASE( &vc20_memory)
-	AM_RANGE(0x1000, 0x1fff) AM_WRITE( MWA8_RAM)
-	AM_RANGE(0x8000, 0x8fff) AM_WRITE( MWA8_ROM)
-	AM_RANGE(0x9000, 0x900f) AM_WRITE( vic6560_port_w)
-	AM_RANGE(0x9010, 0x910f) AM_WRITE( MWA8_NOP)
-	AM_RANGE(0x9110, 0x911f) AM_WRITE( via_0_w)
-	AM_RANGE(0x9120, 0x912f) AM_WRITE( via_1_w)
-	AM_RANGE(0x9130, 0x93ff) AM_WRITE( MWA8_NOP)
-	AM_RANGE(0x9400, 0x97ff) AM_WRITE( vc20_write_9400) AM_BASE( &vc20_memory_9400)
-	AM_RANGE(0x9800, 0x9fff) AM_WRITE( MWA8_NOP)
-	AM_RANGE(0xc000, 0xffff) AM_WRITE( MWA8_NOP)		   /* MWA8_ROM , but logfile */
-ADDRESS_MAP_END
-
-static ADDRESS_MAP_START( vc20i_readmem , ADDRESS_SPACE_PROGRAM, 8)
-	AM_RANGE(0x0000, 0x03ff) AM_READ( MRA8_RAM)
+static ADDRESS_MAP_START( vc20i_mem , ADDRESS_SPACE_PROGRAM, 8)
+	AM_RANGE(0x0000, 0x03ff) AM_RAM AM_BASE(&vc20_memory)
 #if 0
-	AM_RANGE(0x0400, 0x0fff) AM_READ( MRA8_RAM)		   /* ram, rom or nothing; I think read 0xff! */
+	AM_RANGE(0x0400, 0x0fff) AM_READ(MRA8_RAM)	/* ram, rom or nothing; I think read 0xff! */
 #endif
-	AM_RANGE(0x1000, 0x1fff) AM_READ( MRA8_RAM)
+	AM_RANGE(0x1000, 0x1fff) AM_RAM
 #if 0
-	AM_RANGE(0x2000, 0x3fff) AM_READ( MRA8_RAM)		   /* ram, rom or nothing */
-	AM_RANGE(0x4000, 0x5fff) AM_READ( MRA8_RAM)		   /* ram, rom or nothing */
-	AM_RANGE(0x6000, 0x7fff) AM_READ( MRA8_RAM)		   /* ram, rom or nothing */
+	AM_RANGE(0x2000, 0x3fff) AM_READ(MRA8_RAM)	/* ram, rom or nothing */
+	AM_RANGE(0x4000, 0x5fff) AM_READ(MRA8_RAM)	/* ram, rom or nothing */
+	AM_RANGE(0x6000, 0x7fff) AM_READ(MRA8_RAM)	/* ram, rom or nothing */
 #endif
-	AM_RANGE(0x8000, 0x8fff) AM_READ( MRA8_ROM)
-	AM_RANGE(0x9000, 0x900f) AM_READ( vic6560_port_r)
-	AM_RANGE(0x9010, 0x910f) AM_READ( MRA8_NOP)
-	AM_RANGE(0x9110, 0x911f) AM_READ( via_0_r)
-	AM_RANGE(0x9120, 0x912f) AM_READ( via_1_r)
-	AM_RANGE(0x9400, 0x97ff) AM_READ( MRA8_RAM)		   /*color ram 4 bit */
-	AM_RANGE(0x9800, 0x980f) AM_READ( via_4_r)
-	AM_RANGE(0x9810, 0x981f) AM_READ( via_5_r)
-	AM_RANGE(0xa000, 0xbfff) AM_READ( MRA8_ROM)
-	AM_RANGE(0xc000, 0xffff) AM_READ( MRA8_ROM)
-ADDRESS_MAP_END
-
-static ADDRESS_MAP_START( vc20i_writemem , ADDRESS_SPACE_PROGRAM, 8)
-	AM_RANGE(0x0000, 0x03ff) AM_WRITE( MWA8_RAM) AM_BASE( &vc20_memory)
-	AM_RANGE(0x1000, 0x1fff) AM_WRITE( MWA8_RAM)
-	AM_RANGE(0x8000, 0x8fff) AM_WRITE( MWA8_ROM)
-	AM_RANGE(0x9000, 0x900f) AM_WRITE( vic6560_port_w)
-	AM_RANGE(0x9010, 0x910f) AM_WRITE( MWA8_NOP)
-	AM_RANGE(0x9110, 0x911f) AM_WRITE( via_0_w)
-	AM_RANGE(0x9120, 0x912f) AM_WRITE( via_1_w)
-	AM_RANGE(0x9400, 0x97ff) AM_WRITE( vc20_write_9400) AM_BASE( &vc20_memory_9400)
-	AM_RANGE(0x9800, 0x980f) AM_WRITE( via_4_w)
-	AM_RANGE(0x9810, 0x981f) AM_WRITE( via_5_w)
-	AM_RANGE(0xa000, 0xbfff) AM_WRITE( MWA8_ROM)
-	AM_RANGE(0xc000, 0xffff) AM_WRITE( MWA8_NOP)		   /* MWA8_ROM, but logfile */
+	AM_RANGE(0x8000, 0x8fff) AM_ROM
+	AM_RANGE(0x9000, 0x900f) AM_READWRITE( vic6560_port_r, vic6560_port_w )
+	AM_RANGE(0x9010, 0x910f) AM_NOP
+	AM_RANGE(0x9110, 0x911f) AM_READWRITE( via_0_r, via_0_w )
+	AM_RANGE(0x9120, 0x912f) AM_READWRITE( via_1_r, via_1_w )
+	AM_RANGE(0x9400, 0x97ff) AM_READWRITE( MRA8_RAM, vc20_write_9400) AM_BASE(&vc20_memory_9400)	/* color ram 4 bit */
+	AM_RANGE(0x9800, 0x980f) AM_READWRITE( via_4_r, via_4_w )
+	AM_RANGE(0x9810, 0x981f) AM_READWRITE( via_5_r, via_5_w )
+	AM_RANGE(0xa000, 0xbfff) AM_ROM
+	AM_RANGE(0xc000, 0xffff) AM_ROM
 ADDRESS_MAP_END
 
 #define DIPS_HELPER(bit, name, keycode) \
@@ -675,68 +646,68 @@ static PALETTE_INIT( vc20 )
 
 ROM_START (vic20)
 	ROM_REGION (0x10000, REGION_CPU1,0)
-	ROM_LOAD ("901460.03", 0x8000, 0x1000, CRC(83e032a6))
-	ROM_LOAD ("901486.01", 0xc000, 0x2000, CRC(db4c43c1))
-	ROM_LOAD ("901486.06", 0xe000, 0x2000, CRC(e5e7c174))
+	ROM_LOAD ("901460.03", 0x8000, 0x1000, CRC(83e032a6) SHA1(4fd85ab6647ee2ac7ba40f729323f2472d35b9b4))
+	ROM_LOAD ("901486.01", 0xc000, 0x2000, CRC(db4c43c1) SHA1(587d1e90950675ab6b12d91248a3f0d640d02e8d))
+	ROM_LOAD ("901486.06", 0xe000, 0x2000, CRC(e5e7c174) SHA1(06de7ec017a5e78bd6746d89c2ecebb646efeb19))
 ROM_END
 
 ROM_START (vic1001)
 	ROM_REGION (0x10000, REGION_CPU1,0)
-	ROM_LOAD ("901460.02", 0x8000, 0x1000, CRC(fcfd8a4b))
-	ROM_LOAD ("901486.01", 0xc000, 0x2000, CRC(db4c43c1))
-	ROM_LOAD ("901486.02", 0xe000, 0x2000, CRC(336900d7))
+	ROM_LOAD ("901460.02", 0x8000, 0x1000, CRC(fcfd8a4b) SHA1(dae61ac03065aa2904af5c123ce821855898c555))
+	ROM_LOAD ("901486.01", 0xc000, 0x2000, CRC(db4c43c1) SHA1(587d1e90950675ab6b12d91248a3f0d640d02e8d))
+	ROM_LOAD ("901486.02", 0xe000, 0x2000, CRC(336900d7) SHA1(c9ead45e6674d1042ca6199160e8583c23aeac22))
 ROM_END
 
 ROM_START (vic20swe)
 	ROM_REGION (0x10000, REGION_CPU1,0)
-	ROM_LOAD ("nec22101.207", 0x8000, 0x1000, CRC(d808551d))
-	ROM_LOAD ("901486.01", 0xc000, 0x2000, CRC(db4c43c1))
-	ROM_LOAD ("nec22081.206", 0xe000, 0x2000, CRC(b2a60662))
+	ROM_LOAD ("nec22101.207", 0x8000, 0x1000, CRC(d808551d) SHA1(f403f0b0ce5922bd61bbd768bdd6f0b38e648c9f))
+	ROM_LOAD ("901486.01", 0xc000, 0x2000, CRC(db4c43c1) SHA1(587d1e90950675ab6b12d91248a3f0d640d02e8d))
+	ROM_LOAD ("nec22081.206", 0xe000, 0x2000, CRC(b2a60662) SHA1(cb3e2f6e661ea7f567977751846ce9ad524651a3))
 ROM_END
 
 ROM_START (vic20v)
 	ROM_REGION (0x10000, REGION_CPU1,0)
-	ROM_LOAD ("901460.03", 0x8000, 0x1000, CRC(83e032a6))
-	ROM_LOAD ("901486.01", 0xc000, 0x2000, CRC(db4c43c1))
-	ROM_LOAD ("901486.06", 0xe000, 0x2000, CRC(e5e7c174))
+	ROM_LOAD ("901460.03", 0x8000, 0x1000, CRC(83e032a6) SHA1(4fd85ab6647ee2ac7ba40f729323f2472d35b9b4))
+	ROM_LOAD ("901486.01", 0xc000, 0x2000, CRC(db4c43c1) SHA1(587d1e90950675ab6b12d91248a3f0d640d02e8d))
+	ROM_LOAD ("901486.06", 0xe000, 0x2000, CRC(e5e7c174) SHA1(06de7ec017a5e78bd6746d89c2ecebb646efeb19))
 	VC1540_ROM (REGION_CPU2)
 ROM_END
 
 ROM_START (vic20i)
 	ROM_REGION (0x10000, REGION_CPU1,0)
-	ROM_LOAD ("901460.03", 0x8000, 0x1000, CRC(83e032a6))
-	ROM_LOAD ("325329.04", 0xb000, 0x800, CRC(d37b6335))
-	ROM_LOAD ("901486.01", 0xc000, 0x2000, CRC(db4c43c1))
-	ROM_LOAD ("901486.06", 0xe000, 0x2000, CRC(e5e7c174))
+	ROM_LOAD ("901460.03", 0x8000, 0x1000, CRC(83e032a6) SHA1(4fd85ab6647ee2ac7ba40f729323f2472d35b9b4))
+	ROM_LOAD ("325329.04", 0xb000, 0x800, CRC(d37b6335) SHA1(828c965829d21c60e8c2d083caee045c639a270f))
+	ROM_LOAD ("901486.01", 0xc000, 0x2000, CRC(db4c43c1) SHA1(587d1e90950675ab6b12d91248a3f0d640d02e8d))
+	ROM_LOAD ("901486.06", 0xe000, 0x2000, CRC(e5e7c174) SHA1(06de7ec017a5e78bd6746d89c2ecebb646efeb19))
 /*	C2031_ROM (REGION_CPU2) */
 ROM_END
 
 ROM_START (vc20)
 	ROM_REGION (0x10000, REGION_CPU1,0)
-	ROM_LOAD ("901460.03", 0x8000, 0x1000, CRC(83e032a6))
-	ROM_LOAD ("901486.01", 0xc000, 0x2000, CRC(db4c43c1))
-	ROM_LOAD ("901486.07", 0xe000, 0x2000, CRC(4be07cb4))
+	ROM_LOAD ("901460.03", 0x8000, 0x1000, CRC(83e032a6) SHA1(4fd85ab6647ee2ac7ba40f729323f2472d35b9b4))
+	ROM_LOAD ("901486.01", 0xc000, 0x2000, CRC(db4c43c1) SHA1(587d1e90950675ab6b12d91248a3f0d640d02e8d))
+	ROM_LOAD ("901486.07", 0xe000, 0x2000, CRC(4be07cb4) SHA1(ce0137ed69f003a299f43538fa9eee27898e621e))
 ROM_END
 
 ROM_START (vc20v)
 	ROM_REGION (0x10000, REGION_CPU1,0)
-	ROM_LOAD ("901460.03", 0x8000, 0x1000, CRC(83e032a6))
-	ROM_LOAD ("901486.01", 0xc000, 0x2000, CRC(db4c43c1))
-	ROM_LOAD ("901486.07", 0xe000, 0x2000, CRC(4be07cb4))
+	ROM_LOAD ("901460.03", 0x8000, 0x1000, CRC(83e032a6) SHA1(4fd85ab6647ee2ac7ba40f729323f2472d35b9b4))
+	ROM_LOAD ("901486.01", 0xc000, 0x2000, CRC(db4c43c1) SHA1(587d1e90950675ab6b12d91248a3f0d640d02e8d))
+	ROM_LOAD ("901486.07", 0xe000, 0x2000, CRC(4be07cb4) SHA1(ce0137ed69f003a299f43538fa9eee27898e621e))
 	VC1541_ROM (REGION_CPU2)
 ROM_END
 
 static MACHINE_DRIVER_START( vic20 )
 	/* basic machine hardware */
 	MDRV_CPU_ADD_TAG("main", M6502, VIC6560_CLOCK)        /* 7.8336 Mhz */
-	MDRV_CPU_PROGRAM_MAP(vc20_readmem, vc20_writemem)
+	MDRV_CPU_PROGRAM_MAP(vc20_mem, 0)
 	MDRV_CPU_VBLANK_INT(vc20_frame_interrupt, 1)
-	MDRV_CPU_PERIODIC_INT(vic656x_raster_interrupt, VIC656X_HRETRACERATE)
+	MDRV_CPU_PERIODIC_INT(vic656x_raster_interrupt, TIME_IN_HZ(VIC656X_HRETRACERATE))
 	MDRV_FRAMES_PER_SECOND(VIC6560_VRETRACERATE)
 	MDRV_VBLANK_DURATION(DEFAULT_REAL_60HZ_VBLANK_DURATION)
 	MDRV_INTERLEAVE(0)
 
-	MDRV_MACHINE_INIT( vc20 )
+	MDRV_MACHINE_RESET( vc20 )
 
     /* video hardware */
 	MDRV_VIDEO_ATTRIBUTES(VIDEO_TYPE_RASTER)
@@ -746,7 +717,6 @@ static MACHINE_DRIVER_START( vic20 )
 	MDRV_PALETTE_INIT( vc20 )
 
 	MDRV_VIDEO_START( vic6560 )
-	MDRV_VIDEO_STOP( vic6560 )
 	MDRV_VIDEO_UPDATE( vic6560 )
 
 	/* sound hardware */
@@ -780,7 +750,7 @@ static MACHINE_DRIVER_START( vic20i )
 #endif
 
 	MDRV_CPU_MODIFY( "main" )
-	MDRV_CPU_PROGRAM_MAP( vc20i_readmem, vc20i_writemem )
+	MDRV_CPU_PROGRAM_MAP( vc20i_mem, 0 )
 MACHINE_DRIVER_END
 
 
@@ -788,7 +758,7 @@ static MACHINE_DRIVER_START( vc20 )
 	MDRV_IMPORT_FROM( vic20 )
 
 	MDRV_CPU_REPLACE( "main", M6502, VIC6561_CLOCK )
-	MDRV_CPU_PROGRAM_MAP( vc20i_readmem, vc20i_writemem )
+	MDRV_CPU_PROGRAM_MAP( vc20i_mem, 0 )
 
 	MDRV_FRAMES_PER_SECOND(VIC6561_VRETRACERATE)
 	MDRV_SCREEN_SIZE((VIC6561_XSIZE + 7) & ~7, VIC6561_YSIZE)
@@ -806,24 +776,39 @@ static MACHINE_DRIVER_START( vc20v )
 #endif
 MACHINE_DRIVER_END
 
-#define init_vc20		vc20_driver_init
-#define init_vic20		vic20_driver_init
-#define init_vic1001	vic20_driver_init
-#define init_vic20i 	vic20ieee_driver_init
-
-static void cbmvc20_cartslot_getinfo(struct IODevice *dev)
+static void cbmvc20_cartslot_getinfo(const device_class *devclass, UINT32 state, union devinfo *info)
 {
-	cartslot_device_getinfo(dev);
-	dev->count = 2;
-	dev->file_extensions = "a0\00020\00040\00060\0rom\0bin\0";
-	dev->init = device_init_vc20_rom;
-	dev->load = device_load_vc20_rom;
+	switch(state)
+	{
+		/* --- the following bits of info are returned as 64-bit signed integers --- */
+		case DEVINFO_INT_COUNT:							info->i = 2; break;
+
+		/* --- the following bits of info are returned as pointers to data or functions --- */
+		case DEVINFO_PTR_INIT:							info->init = device_init_vc20_rom; break;
+		case DEVINFO_PTR_LOAD:							info->load = device_load_vc20_rom; break;
+
+		/* --- the following bits of info are returned as NULL-terminated strings --- */
+		case DEVINFO_STR_FILE_EXTENSIONS:				strcpy(info->s = device_temp_str(), "a0,20,40,60,rom,bin"); break;
+
+		default:										cartslot_device_getinfo(devclass, state, info); break;
+	}
 }
 
-static void vc20_quickload_getinfo(struct IODevice *dev)
+static void vc20_quickload_getinfo(const device_class *devclass, UINT32 state, union devinfo *info)
 {
-	quickload_device_getinfo(dev, quickload_load_cbm_vc20, CBM_QUICKLOAD_DELAY);
-	dev->file_extensions = "p00\0prg\0";
+	switch(state)
+	{
+		/* --- the following bits of info are returned as NULL-terminated strings --- */
+		case DEVINFO_STR_FILE_EXTENSIONS:				strcpy(info->s = device_temp_str(), "p00,prg"); break;
+
+		/* --- the following bits of info are returned as pointers to data or functions --- */
+		case DEVINFO_PTR_QUICKLOAD_LOAD:				info->f = (genf *) quickload_load_cbm_vc20; break;
+
+		/* --- the following bits of info are returned as doubles --- */
+		case DEVINFO_FLOAT_QUICKLOAD_DELAY:				info->d = CBM_QUICKLOAD_DELAY; break;
+
+		default:										quickload_device_getinfo(devclass, state, info); break;
+	}
 }
 
 SYSTEM_CONFIG_START(vc20)
@@ -850,11 +835,11 @@ SYSTEM_CONFIG_END
 #endif
 
 /*		YEAR	NAME		PARENT	COMPAT	MACHINE INPUT		INIT	CONFIG     COMPANY 							FULLNAME */
-COMPX ( 1981,	vic20,		0,		0,		vic20,	vic20,		vic20,	vc20,      "Commodore Business Machines Co.",  "VIC20 (NTSC)", GAME_IMPERFECT_SOUND)
-COMPX ( 1981,	vic20i, 	vic20,	0,		vic20i, vic20i, 	vic20i, vc20,      "Commodore Business Machines Co.",  "VIC20 (NTSC), IEEE488 Interface (SYS45065)",   GAME_IMPERFECT_SOUND)
-COMPX ( 1981,	vic1001,	vic20,	0,		vic20,	vic1001,	vic20,	vc20,      "Commodore Business Machines Co.",  "VIC1001 (NTSC)", GAME_IMPERFECT_SOUND)
-COMPX ( 1981,	vc20,		vic20,	0,		vc20,	vc20,		vc20,	vc20,      "Commodore Business Machines Co.",  "VIC20/VC20(German) PAL",       GAME_IMPERFECT_SOUND)
-COMPX ( 1981,	vic20swe,	vic20,	0,		vc20,	vic20swe,	vc20,	vc20,      "Commodore Business Machines Co.",  "VIC20 PAL, Swedish Expansion Kit", GAME_IMPERFECT_SOUND)
+COMP ( 1981,	vic20,		0,		0,		vic20,	vic20,		vic20,	vc20,      "Commodore Business Machines Co.",  "VIC20 (NTSC)", GAME_IMPERFECT_SOUND)
+COMP ( 1981,	vic20i, 	vic20,	0,		vic20i, vic20i, 	vic20i, vc20,      "Commodore Business Machines Co.",  "VIC20 (NTSC), IEEE488 Interface (SYS45065)",   GAME_IMPERFECT_SOUND)
+COMP ( 1981,	vic1001,	vic20,	0,		vic20,	vic1001,	vic20,	vc20,      "Commodore Business Machines Co.",  "VIC1001 (NTSC)", GAME_IMPERFECT_SOUND)
+COMP ( 1981,	vc20,		vic20,	0,		vc20,	vc20,		vc20,	vc20,      "Commodore Business Machines Co.",  "VIC20/VC20(German) PAL",       GAME_IMPERFECT_SOUND)
+COMP ( 1981,	vic20swe,	vic20,	0,		vc20,	vic20swe,	vc20,	vc20,      "Commodore Business Machines Co.",  "VIC20 PAL, Swedish Expansion Kit", GAME_IMPERFECT_SOUND)
 /* please leave the following as testdriver only */
-COMPX ( 1981,	vic20v, 	vic20,	0,		vic20v, vic20,		vic20,	vc20v,     "Commodore Business Machines Co.",  "VIC20 (NTSC), VC1540", GAME_IMPERFECT_SOUND)
-COMPX ( 1981,	vc20v,		vic20,	0,		vc20v,	vic20,		vc20,	vc20v,     "Commodore Business Machines Co.",  "VC20 (PAL), VC1541", GAME_IMPERFECT_SOUND)
+COMP ( 1981,	vic20v, 	vic20,	0,		vic20v, vic20,		vic20,	vc20v,     "Commodore Business Machines Co.",  "VIC20 (NTSC), VC1540", GAME_IMPERFECT_SOUND | GAME_NOT_WORKING )
+COMP ( 1981,	vc20v,		vic20,	0,		vc20v,	vic20,		vc20,	vc20v,     "Commodore Business Machines Co.",  "VC20 (PAL), VC1541", GAME_IMPERFECT_SOUND | GAME_NOT_WORKING )
