@@ -186,9 +186,9 @@ static void z88_install_memory_handler_pair(offs_t start, offs_t size, int bank_
 	memory_install_write8_handler(0, ADDRESS_SPACE_PROGRAM, start, start + size - 1, 0, 0, write_handler);
 
 	if (read_addr)
-		cpu_setbank(bank_base + 0, read_addr);
+		memory_set_bankptr(bank_base + 0, read_addr);
 	if (write_addr)
-		cpu_setbank(bank_base + 1, write_addr);
+		memory_set_bankptr(bank_base + 1, write_addr);
 }
 
 
@@ -274,7 +274,7 @@ static void z88_refresh_memory_bank(int bank)
 	}
 }
 
-static MACHINE_INIT( z88 )
+static MACHINE_RESET( z88 )
 {
 	memset(mess_ram, 0x0ff, mess_ram_size);
 
@@ -602,7 +602,7 @@ static  READ8_HANDLER(z88_port_r)
 
 
 static ADDRESS_MAP_START( z88_io, ADDRESS_SPACE_IO, 8)
-	ADDRESS_MAP_FLAGS( AMEF_ABITS(8) ) 
+	ADDRESS_MAP_FLAGS( AMEF_ABITS(16) ) 
 	AM_RANGE(0x0000, 0x0ffff) AM_READWRITE(z88_port_r, z88_port_w)
 ADDRESS_MAP_END
 
@@ -716,7 +716,7 @@ static MACHINE_DRIVER_START( z88 )
 	MDRV_VBLANK_DURATION(DEFAULT_60HZ_VBLANK_DURATION)
 	MDRV_INTERLEAVE(1)
 
-	MDRV_MACHINE_INIT( z88 )
+	MDRV_MACHINE_RESET( z88 )
 
 	/* video hardware */
 	MDRV_VIDEO_ATTRIBUTES(VIDEO_TYPE_RASTER)
@@ -744,7 +744,7 @@ MACHINE_DRIVER_END
 
 ROM_START(z88)
     ROM_REGION(((64*1024)+(128*1024)), REGION_CPU1,0)
-    ROM_LOAD("z88v400.rom", 0x010000, 0x020000, CRC(1356d440))
+    ROM_LOAD("z88v400.rom", 0x010000, 0x020000, CRC(1356d440) SHA1(23c63ceced72d0a9031cba08d2ebc72ca336921d))
 ROM_END
 
 SYSTEM_CONFIG_START( z88 )
@@ -753,5 +753,5 @@ SYSTEM_CONFIG_END
 
 
 /*	   YEAR	    NAME	PARENT	COMPAT	MACHINE		INPUT		INIT	CONFIG	COMPANY					FULLNAME */
-COMPX( 1988,	z88,	0,		0,		z88,		z88,		0,		z88,	"Cambridge Computers",	"Z88",GAME_NOT_WORKING)
+COMP( 1988,	z88,	0,		0,		z88,		z88,		0,		z88,	"Cambridge Computers",	"Z88",GAME_NOT_WORKING)
 
