@@ -10,6 +10,7 @@
 #include <assert.h>
 #include <string.h>
 
+#include "osdepend.h"
 #include "library.h"
 #include "pool.h"
 
@@ -54,7 +55,7 @@ const struct ImageModule *imgtool_library_unlink(imgtool_library *library,
 
 	for (m = library->first; m; m = m->next)
 	{
-		if (!stricmp(m->name, module))
+		if (!mame_stricmp(m->name, module))
 		{
 			previous = m->previous ? &m->previous->next : &library->first;
 			next = m->next ? &m->next->previous : &library->last;
@@ -80,7 +81,7 @@ static int module_compare(const struct ImageModule *m1,
 			rc = strcmp(m1->name, m2->name);
 			break;
 		case ITLS_DESCRIPTION:
-			rc = stricmp(m1->name, m2->name);
+			rc = mame_stricmp(m1->name, m2->name);
 			break;
 	}
 	return rc;
@@ -176,18 +177,16 @@ const struct ImageModule *imgtool_library_findmodule(
 
 
 
-const struct ImageModule *imgtool_library_iterate(
-	imgtool_library *library, const struct ImageModule *module)
+struct ImageModule *imgtool_library_iterate(imgtool_library *library, const struct ImageModule *module)
 {
 	return module ? module->next : library->first;
 }
 
 
 
-const struct ImageModule *imgtool_library_index(
-	imgtool_library *library, int i)
+struct ImageModule *imgtool_library_index(imgtool_library *library, int i)
 {
-	const struct ImageModule *module;
+	struct ImageModule *module;
 	module = library->first;
 	while(module && i--)
 		module = module->next;
@@ -205,7 +204,7 @@ void *imgtool_library_alloc(imgtool_library *library, size_t mem)
 
 char *imgtool_library_strdup(imgtool_library *library, const char *s)
 {
-	return pool_strdup(&library->pool, s);
+	return s ? pool_strdup(&library->pool, s) : NULL;
 }
 
 
