@@ -10,16 +10,17 @@
 #include <string.h>
 #include <zlib.h>
 #include <assert.h>
+
 #include "unzip.h"
 #include "osdepend.h"
 #include "imgtool.h"
 #include "utils.h"
+#include "osd_tool.h"
 
 typedef enum
 {
 	IMG_FILE,
-	IMG_MEM,
-	IMG_FILTER
+	IMG_MEM
 } imgtype_t;
 
 struct _imgtool_stream
@@ -27,38 +28,26 @@ struct _imgtool_stream
 	imgtype_t imgtype;
 	int write_protect;
 	const char *name; /* needed for clear */
-	union {
-		FILE *f;
-		struct {
+	INT64 position;
+
+	union
+	{
+		osd_tool_file *f;
+		struct
+		{
 			char *buf;
 			size_t bufsz;
-			size_t pos;
 		} m;
-		struct {
-			imgtool_stream *s;
-			imgtool_filter *f;
-			size_t totalread;
-		} filt;
 	} u;
 };
 
-static size_t fsize(FILE *f)
-{
-	long l, sz;
-	l = ftell(f);
-	if (fseek(f, 0, SEEK_END))
-		return (size_t) -1;
-	sz = ftell(f);
-	if (fseek(f, l, SEEK_SET))
-		return (size_t) -1;
-	return (size_t) sz;
-}
+
 
 static imgtool_stream *stream_open_zip(const char *zipname, const char *subname, int read_or_write)
 {
 	imgtool_stream *imgfile = NULL;
-	ZIP *z = NULL;
-	struct zipent *zipent;
+	zip_file *z = NULL;
+	zip_entry *zipent;
 	FILE *f;
 
 	if (read_or_write)
@@ -77,7 +66,7 @@ static imgtool_stream *stream_open_zip(const char *zipname, const char *subname,
 	memset(imgfile, 0, sizeof(*imgfile));
 	imgfile->imgtype = IMG_MEM;
 	imgfile->write_protect = 1;
-	imgfile->u.m.pos = 0;
+	imgfile->position = 0;
 
 	z = openzip(0, 0, zipname);
 	if (!z)
@@ -114,12 +103,14 @@ error:
 	return NULL;
 }
 
+
+
 imgtool_stream *stream_open(const char *fname, int read_or_write)
 {
 	const char *ext;
 	imgtool_stream *imgfile = NULL;
-	static const char *write_modes[] = {"rb", "wb", "r+b", "w+b"};
-	FILE *f = NULL;
+	static const char *write_modes[] = {"rb", "wb", "rb+", "wb+"};
+	osd_tool_file *f = NULL;
 	char *buf = NULL;
 	int len, i;
 	imgtool_stream *s = NULL;
@@ -127,10 +118,10 @@ imgtool_stream *stream_open(const char *fname, int read_or_write)
 
 	/* maybe we are just a ZIP? */
 	ext = strrchr(fname, '.');
-	if (ext && !stricmp(ext, ".zip"))
+	if (ext && !mame_stricmp(ext, ".zip"))
 		return stream_open_zip(fname, NULL, read_or_write);
 
-	f = fopen(fname, write_modes[read_or_write]);
+	f = osd_tool_fopen(fname, write_modes[read_or_write]);
 	if (!f)
 	{
 		if (!read_or_write)
@@ -171,6 +162,7 @@ imgtool_stream *stream_open(const char *fname, int read_or_write)
 	/* Normal file */
 	memset(imgfile, 0, sizeof(*imgfile));
 	imgfile->imgtype = IMG_FILE;
+	imgfile->position = 0;
 	imgfile->write_protect = read_or_write ? 0 : 1;
 	imgfile->u.f = f;
 	imgfile->name = fname;
@@ -180,7 +172,7 @@ error:
 	if (imgfile)
 		free((void *) imgfile);
 	if (f)
-		fclose(f);
+		osd_tool_fclose(f);
 	if (buf)
 		free(buf);
 	return (imgtool_stream *) NULL;
@@ -198,7 +190,7 @@ imgtool_stream *stream_open_write_stream(int size)
 
 	imgfile->imgtype = IMG_MEM;
 	imgfile->write_protect = 0;
-	imgfile->u.m.pos = 0;
+	imgfile->position = 0;
 
 	imgfile->u.m.bufsz = size;
 	imgfile->u.m.buf = malloc(size);
@@ -222,9 +214,10 @@ imgtool_stream *stream_open_mem(void *buf, size_t sz)
 	if (!imgfile)
 		return NULL;
 
+	memset(imgfile, 0, sizeof(*imgfile));
 	imgfile->imgtype = IMG_MEM;
+	imgfile->position = 0;
 	imgfile->write_protect = 0;
-	imgfile->u.m.pos = 0;
 
 	imgfile->u.m.bufsz = sz;
 	imgfile->u.m.buf = buf;
@@ -233,23 +226,6 @@ imgtool_stream *stream_open_mem(void *buf, size_t sz)
 
 
 
-imgtool_stream *stream_open_filter(imgtool_stream *s, imgtool_filter *f)
-{
-	imgtool_stream *imgfile;
-
-	imgfile = malloc(sizeof(struct _imgtool_stream));
-	if (!imgfile)
-		return NULL;
-
-	imgfile->imgtype = IMG_FILTER;
-	imgfile->u.filt.s = s;
-	imgfile->u.filt.f = f;
-	imgfile->u.filt.totalread = 0;
-	return imgfile;
-}
-
-
-
 void stream_close(imgtool_stream *s)
 {
 	assert(s);
@@ -257,17 +233,13 @@ void stream_close(imgtool_stream *s)
 	switch(s->imgtype)
 	{
 		case IMG_FILE:
-			fclose(s->u.f);
+			osd_tool_fclose(s->u.f);
 			break;
 
 		case IMG_MEM:
 			free(s->u.m.buf);
 			break;
 
-		case IMG_FILTER:
-			filter_term(s->u.filt.f);
-			break;
-
 		default:
 			assert(0);
 			break;
@@ -284,27 +256,22 @@ size_t stream_read(imgtool_stream *s, void *buf, size_t sz)
 	switch(s->imgtype)
 	{
 		case IMG_FILE:
-			result = fread(buf, 1, sz, s->u.f);
+			result = osd_tool_fread(s->u.f, s->position, sz, buf);
 			break;
 
 		case IMG_MEM:
-			if ((s->u.m.pos + sz) > s->u.m.bufsz)
-				result = s->u.m.bufsz - s->u.m.pos;
+			if ((s->position + sz) > s->u.m.bufsz)
+				result = s->u.m.bufsz - s->position;
 			else
 				result = sz;
-			memcpy(buf, s->u.m.buf + s->u.m.pos, result);
-			s->u.m.pos += result;
-			break;
-
-		case IMG_FILTER:
-			result = filter_readfromstream(s->u.filt.f, s->u.filt.s, buf, sz);
-			s->u.filt.totalread += result;
+			memcpy(buf, s->u.m.buf + s->position, result);
 			break;
 
 		default:
 			assert(0);
 			break;
 	}
+	s->position += result;
 	return result;
 }
 
@@ -319,29 +286,25 @@ size_t stream_write(imgtool_stream *s, const void *buf, size_t sz)
 		case IMG_MEM:
 			if (!s->write_protect)
 			{
-				if (s->u.m.bufsz < s->u.m.pos + sz)
+				if (s->u.m.bufsz < s->position + sz)
 				{
-					s->u.m.buf = realloc(s->u.m.buf, s->u.m.pos + sz);
-					s->u.m.bufsz = s->u.m.pos+sz;
+					s->u.m.buf = realloc(s->u.m.buf, s->position + sz);
+					s->u.m.bufsz = s->position + sz;
 				}
-				memcpy(s->u.m.buf + s->u.m.pos, buf, sz);
-				s->u.m.pos += sz;
+				memcpy(s->u.m.buf + s->position, buf, sz);
 				result = sz;
 			}
 			break;
 
 		case IMG_FILE:
-			result = fwrite(buf, 1, sz, s->u.f);
-			break;
-
-		case IMG_FILTER:
-			result = filter_writetostream(s->u.filt.f, s->u.filt.s, buf, sz);
+			result = osd_tool_fwrite(s->u.f, s->position, sz, buf);
 			break;
 
 		default:
 			assert(0);
 			break;
 	}
+	s->position += result;
 	return result;
 }
 
@@ -354,18 +317,13 @@ UINT64 stream_size(imgtool_stream *s)
 	switch(s->imgtype)
 	{
 		case IMG_FILE:
-			result = fsize(s->u.f);
+			result = osd_tool_flength(s->u.f);
 			break;
 
 		case IMG_MEM:
 			result = s->u.m.bufsz;
 			break;
 
-		case IMG_FILTER:
-			s->u.filt.totalread += filter_readintobuffer(s->u.filt.f, s->u.filt.s);
-			result = s->u.filt.totalread;
-			break;
-
 		default:
 			assert(0);
 			break;
@@ -394,64 +352,38 @@ void *stream_getptr(imgtool_stream *f)
 
 
 
-int stream_seek(imgtool_stream *s, size_t pos, int where)
+int stream_seek(imgtool_stream *s, INT64 pos, int where)
 {
-	int result = 0;
+	UINT64 size;
 
-	switch(s->imgtype)
+	size = stream_size(s);
+
+	switch(where)
 	{
-		case IMG_FILE:
-			result = fseek(s->u.f, pos, where);
+		case SEEK_CUR:
+			pos += s->position;
 			break;
-
-		case IMG_MEM:
-			switch(where)
-			{
-				case SEEK_CUR:
-					pos += s->u.m.pos;
-					break;
-				case SEEK_END:
-					pos += s->u.m.bufsz;
-					break;
-			}
-			if ((pos > s->u.m.bufsz) || (pos < 0))
-			{
-				result = -1;
-			}
-			else
-			{
-				s->u.m.pos = pos;
-			}
-			break;
-
-		default:
-			assert(0);
+		case SEEK_END:
+			pos += size;
 			break;
 	}
-	return result;
+
+	if (pos < 0)
+		s->position = 0;
+	else
+		s->position = MIN(size, pos);
+
+	if (s->position < pos)
+		stream_fill(s, '\0', pos - s->position);
+
+	return 0;
 }
 
 
 
 size_t stream_tell(imgtool_stream *s)
 {
-	int result = 0;
-
-	switch(s->imgtype)
-	{
-		case IMG_FILE:
-			result = ftell(s->u.f);
-			break;
-
-		case IMG_MEM:
-			result = s->u.m.pos;
-			break;
-
-		default:
-			assert(0);
-			break;
-	}
-	return result;
+	return (size_t) s->position;
 }
 
 
@@ -522,7 +454,7 @@ int file_crc(const char *fname,  unsigned long *result)
 	return err;
 }
 
-size_t stream_fill(imgtool_stream *f, unsigned char b, size_t sz)
+size_t stream_fill(imgtool_stream *f, unsigned char b, UINT64 sz)
 {
 	size_t outsz;
 	char buf[1024];
@@ -530,13 +462,16 @@ size_t stream_fill(imgtool_stream *f, unsigned char b, size_t sz)
 	outsz = 0;
 	memset(buf, b, MIN(sz, sizeof(buf)));
 
-	while(sz) {
+	while(sz)
+	{
 		outsz += stream_write(f, buf, MIN(sz, sizeof(buf)));
 		sz -= MIN(sz, sizeof(buf));
 	}
 	return outsz;
 }
 
+
+
 void stream_clear(imgtool_stream *s)
 {
 	switch(s->imgtype)
@@ -544,10 +479,10 @@ void stream_clear(imgtool_stream *s)
 		case IMG_FILE:
 			if (!s->write_protect)
 			{
-				fclose(s->u.f);
-				s->u.f = fopen(s->name, "wb+");
-				fclose(s->u.f);
-				s->u.f = fopen(s->name, "wb");
+				osd_tool_fclose(s->u.f);
+				s->u.f = osd_tool_fopen(s->name, "wb+");
+				osd_tool_fclose(s->u.f);
+				s->u.f = osd_tool_fopen(s->name, "wb");
 			}
 			break;
 
@@ -565,3 +500,32 @@ int stream_isreadonly(imgtool_stream *s)
 	return s->write_protect;
 }
 
+
+
+size_t stream_putc(imgtool_stream *stream, char c)
+{
+	return stream_write(stream, &c, 1);
+}
+
+
+
+size_t stream_puts(imgtool_stream *stream, const char *s)
+{
+	return stream_write(stream, s, strlen(s));
+}
+
+
+
+size_t stream_printf(imgtool_stream *stream, const char *fmt, ...)
+{
+	va_list va;
+	char buf[256];
+
+	va_start(va, fmt);
+	vsprintf(buf, fmt, va);
+	va_end(va);
+
+	return stream_puts(stream, buf);
+}
+
+
