@@ -136,13 +136,13 @@ typedef struct ti990_sc0
 	UINT16BE	ilf;			/* intermediate loader flag */
 	char		din[8];			/* diagnostic file name */
 	UINT16BE	dif;			/* diagnostic flag */
-	UINT16BE	drs;			/* "DBUILD DETERMINES DEFAULT PRS" (whatever it means) */
+	UINT16BE	drs;			/* default physical record size "DBUILD DETERMINES DEFAULT PRS" (whatever it means) */
 	UINT16BE	bal;			/* starting sector of bad ADU list */
 	UINT16BE	spr;			/* track 0 sectors per record */
 	char		wf1[8];			/* WCS primary microcode file */
 	char		wf2[8];			/* WCS secondary microcode file */
 	UINT16BE	wff;			/* WCS flag switch */
-	UINT16BE	vif;			/* track 1 select flag (whatever it means) */
+	UINT16BE	vif;			/* track 1 select flag (whatever it means) volume information copied flag */
 	UINT16BE	sta;			/* state of disk: */
 									/*	1 = disk surface has not been tested for defects */
 									/*	2 = disk surface has been tested, but no file system has been installed */
@@ -164,7 +164,7 @@ typedef struct ti990_dor
 	char dnm[8];				/* directory file name (VCATALOG for root) */
 	UINT16BE lvl;				/* level # of directory (0 for root, 1 for children of root, 2 for grandchildren, etc) */
 	char pnm[8];				/* name of parent directory (VCATALOG for root, even though it makes little sense) */
-	UINT16BE prs;				/* "default physical record lenght (used for file creation)" */
+	UINT16BE prs;				/* "default physical record length (used for file creation)" */
 	/* DORSIZ = >1C */
 } ti990_dor;
 
@@ -211,8 +211,8 @@ typedef struct ti990_ace
 */
 typedef struct ti990_fdr
 {
-	UINT16BE	hkc;			/* hask key count */
-	UINT16BE	hkv;			/* hask key value */
+	UINT16BE	hkc;			/* hask key count: the number of file descriptor records that are present in the directory that hashed to this record number */
+	UINT16BE	hkv;			/* hask key value: the result of the hash algorithm for the file name actually covered in this record */
 	char		fnm[8];			/* file name */
 	UINT8		rsv[2];			/* reserved */
 	UINT16BE	fl1;			/* flags word 1 */
@@ -222,7 +222,7 @@ typedef struct ti990_fdr
 	UINT16BE	pas;			/* primary allocation size: # of ADUs allocated in primary allocation block? */
 	UINT16BE	paa;			/* primary allocation address: first ADU of primary allocation block? */
 	UINT16BE	sas;			/* secondary allocation size: used to determinate the # of blocks allocated per secondary allocation */
-	UINT16BE	saa;			/* offset of secondary table: ???? */
+	UINT16BE	saa;			/* offset of secondary table: ???? "offset into this FDR of the secondary allocation table, if any.  No secondary allocation table is denoted by 0.  Secondary allocations are present only for unbounded files." */
 	UINT16BE	rfa;			/* record number of first alias */
 	UINT32BE	eom;			/* end of medium record number */
 	UINT32BE	bkm;			/* end of medium block number */
@@ -237,7 +237,7 @@ typedef struct ti990_fdr
 	UINT8		apb;			/* ADU's per block */
 	UINT8		bpa;			/* blocks per ADU */
 	UINT16BE	mrs;			/* minimumu KIF record size */
-	UINT8		sat[64];		/* secondary allocation table: 16-entry table (format unknown) */
+	UINT8		sat[64];		/* secondary allocation table: 16 2-word entries.  The first word of an entry contains the size, in ADUs, of the secondary allocation.  The second word contains the starting ADU of the allocation. */
 
 /* bytes >86 to >100 are optional */
 	UINT8		res[10];		/* reserved: seem to be actually meaningful (at least under DX10 3.6.x) */
@@ -509,6 +509,11 @@ static void fname_to_str(char *dst, const char src[8], int n)
 	dst[last_nonspace+1] = '\0';
 }
 
+#if 0
+#pragma mark -
+#pragma mark DISK ROUTINES
+#endif
+
 /*
 	Convert physical sector address to offset
 */
@@ -687,6 +692,11 @@ static int write_sector_logical(imgtool_stream *file_handle, int secnum, const t
 	return write_sector_logical_len(file_handle, secnum, geometry, src, geometry->bytes_per_sector);
 }
 
+#if 0
+#pragma mark -
+#pragma mark CATALOG FILE ROUTINES
+#endif
+
 /*
 	Find the catalog entry and fdr record associated with a file name
 
@@ -1095,13 +1105,11 @@ static int qsort_catalog_compare(const void *p1, const void *p2)
 */
 static imgtoolerr_t ti990_image_init(imgtool_image *img, imgtool_stream *f)
 {
-	ti990_image *image;
+	ti990_image *image = (ti990_image *) img_extrabytes(img);
 	disk_image_header header;
 	int reply;
 	unsigned totsecs;
 
-	image = (ti990_image *) img_extrabytes(img);
-
 	image->file_handle = f;
 	reply = stream_read(f, &header, sizeof(header));
 	if (reply != sizeof(header))
@@ -1164,7 +1172,7 @@ static void ti990_image_exit(imgtool_image *img)
 */
 static void ti990_image_info(imgtool_image *img, char *string, size_t len)
 {
-	ti990_image *image = (ti990_image *) img;
+	ti990_image *image = (ti990_image *) img_extrabytes(img);
 	char vol_name[9];
 
 	fname_to_str(vol_name, image->sec0.vnm, 9);
@@ -1177,14 +1185,11 @@ static void ti990_image_info(imgtool_image *img, char *string, size_t len)
 */
 static imgtoolerr_t ti990_image_beginenum(imgtool_imageenum *enumeration, const char *path)
 {
-	ti990_image *image;
-	ti990_iterator *iter;
+	ti990_image *image = (ti990_image *) img_extrabytes(img_enum_image(enumeration));
+	ti990_iterator *iter = (ti990_iterator *) img_enum_extrabytes(enumeration);
 	ti990_dor dor;
 	int reply;
 
-	iter = (ti990_iterator *) img_enum_extrabytes(enumeration);
-	image = (ti990_image *) img_extrabytes(img_enum_image(enumeration));
-
 	iter->image = image;
 
 	reply = read_sector_logical_len(iter->image->file_handle,
@@ -1206,7 +1211,7 @@ static imgtoolerr_t ti990_image_beginenum(imgtool_imageenum *enumeration, const
 */
 static imgtoolerr_t ti990_image_nextenum(imgtool_imageenum *enumeration, imgtool_dirent *ent)
 {
-	ti990_iterator *iter = (ti990_iterator*) enumeration;
+	ti990_iterator *iter = (ti990_iterator *) img_enum_extrabytes(enumeration);
 	int flag;
 	int reply = 0;
 
@@ -1247,11 +1252,11 @@ static imgtoolerr_t ti990_image_nextenum(imgtool_imageenum *enumeration, imgtool
 			for (i=0; i<iter->level; i++)
 			{
 				fname_to_str(buf, iter->xdr[i].fdr.fnm, 9);
-				strncat(ent->filename, buf, sizeof(ent->filename) / sizeof(ent->filename[0]));
-				strncat(ent->filename, ".", sizeof(ent->filename) / sizeof(ent->filename[0]));
+				strncat(ent->filename, buf, sizeof(ent->filename) / sizeof(ent->filename[0]) - 1);
+				strncat(ent->filename, ".", sizeof(ent->filename) / sizeof(ent->filename[0]) - 1);
 			}
 			fname_to_str(buf, iter->xdr[iter->level].fdr.fnm, 9);
-			strncat(ent->filename, buf, sizeof(ent->filename) / sizeof(ent->filename[0]));
+			strncat(ent->filename, buf, sizeof(ent->filename) / sizeof(ent->filename[0]) - 1);
 		}
 #endif
 
@@ -1405,7 +1410,7 @@ static void ti990_image_closeenum(imgtool_imageenum *enumeration)
 */
 static imgtoolerr_t ti990_image_freespace(imgtool_image *img, UINT64 *size)
 {
-	ti990_image *image = (ti990_image*) img;
+	ti990_image *image = (ti990_image *) img_extrabytes(img);
 	int totadus = get_UINT16BE(image->sec0.tna);
 	int adu, record, sub_adu;
 	char buf[256];
@@ -1443,7 +1448,7 @@ static imgtoolerr_t ti990_image_freespace(imgtool_image *img, UINT64 *size)
 */
 static imgtoolerr_t ti990_image_readfile(imgtool_image *img, const char *fpath, imgtool_stream *destf)
 {
-	ti990_image *image = (ti990_image*) img;
+	ti990_image *image = (ti990_image *) img_extrabytes(img);
 	int catalog_index, fdr_secnum, parent_fdr_secnum;
 	imgtoolerr_t reply;
 
@@ -1539,7 +1544,7 @@ static imgtoolerr_t ti990_image_readfile(imgtool_image *img, const char *fpath,
 */
 static imgtoolerr_t ti990_image_writefile(imgtool_image *img, const char *fpath, imgtool_stream *sourcef, option_resolution *writeoptions)
 {
-	ti990_image *image = (ti990_image*) img;
+	ti990_image *image = (ti990_image *) img_extrabytes(img);
 	int catalog_index, fdr_secnum, parent_fdr_secnum;
 	imgtoolerr_t reply;
 
@@ -1662,7 +1667,7 @@ static imgtoolerr_t ti990_image_writefile(imgtool_image *img, const char *fpath,
 */
 static imgtoolerr_t ti990_image_deletefile(imgtool_image *img, const char *fpath)
 {
-	ti990_image *image = (ti990_image*) img;
+	ti990_image *image = (ti990_image *) img_extrabytes(img);
 	int catalog_index, fdr_secnum, parent_fdr_secnum;
 	imgtoolerr_t reply;
 
