@@ -15,16 +15,25 @@
 #include "pile.h"
 #include "pool.h"
 #include "sound/wavwrite.h"
+#include "vidhrdw/generic.h"
 
-enum messtest_running_state
+#ifdef WIN32
+#include "windows/parallel.h"
+#endif
+
+#if defined(MAME_DEBUG) && defined(NEW_DEBUGGER)
+#include "debug/debugcpu.h"
+#endif
+
+typedef enum
 {
 	STATE_READY,
 	STATE_INCOMMAND,
 	STATE_ABORTED,
 	STATE_DONE
-};
+} messtest_running_state_t;
 
-enum messtest_command_type
+typedef enum
 {
 	MESSTEST_COMMAND_END,
 	MESSTEST_COMMAND_WAIT,
@@ -32,17 +41,19 @@ enum messtest_command_type
 	MESSTEST_COMMAND_RAWINPUT,
 	MESSTEST_COMMAND_SWITCH,
 	MESSTEST_COMMAND_SCREENSHOT,
+	MESSTEST_COMMAND_CHECKBLANK,
 	MESSTEST_COMMAND_IMAGE_CREATE,
 	MESSTEST_COMMAND_IMAGE_LOAD,
 	MESSTEST_COMMAND_IMAGE_PRECREATE,
 	MESSTEST_COMMAND_IMAGE_PRELOAD,
 	MESSTEST_COMMAND_VERIFY_MEMORY,
-	MESSTEST_COMMAND_VERIFY_IMAGE
-};
+	MESSTEST_COMMAND_VERIFY_IMAGE,
+	MESSTEST_COMMAND_TRACE
+} messtest_command_type_t;
 
 struct messtest_command
 {
-	enum messtest_command_type command_type;
+	messtest_command_type_t command_type;
 	union
 	{
 		double wait_time;
@@ -67,6 +78,7 @@ struct messtest_command
 			const char *format;
 			iodevice_t device_type;
 			int device_slot;
+			const char *device_tag;
 		} image_args;
 		struct
 		{
@@ -95,16 +107,16 @@ struct messtest_specific_state
 	struct messtest_command current_command;
 };
 
-enum messtest_result
+typedef enum
 {
 	MESSTEST_RESULT_SUCCESS,
 	MESSTEST_RESULT_STARTFAILURE,
 	MESSTEST_RESULT_RUNTIMEFAILURE
-};
+} messtest_result_t;
 
 struct messtest_results
 {
-	enum messtest_result rc;
+	messtest_result_t rc;
 	UINT64 runtime_hash;	/* A value that is a hash taken from certain runtime parameters; used to detect different execution paths */
 };
 
@@ -113,7 +125,8 @@ struct messtest_results
 #define MESSTEST_ALWAYS_DUMP_SCREENSHOT		1
 
 
-static enum messtest_running_state state;
+static messtest_running_state_t state;
+static int had_failure;
 static double wait_target;
 static double final_time;
 static const struct messtest_command *current_command;
@@ -123,7 +136,7 @@ static int format_index;
 static UINT64 runtime_hash;
 static void *wavptr;
 static UINT32 samples_this_frame;
-static jmp_buf die_jmpbuf;
+static int seen_first_update;
 
 /* command list */
 static mess_pile command_pile;
@@ -135,32 +148,37 @@ static struct messtest_testcase current_testcase;
 
 
 
-static void dump_screenshot(void)
+static void dump_screenshot(int write_file)
 {
 	mame_file *fp;
 	char buf[128];
 	mame_bitmap *bitmap;
 	int x, y, is_blank;
 	pen_t color;
+	extern mame_bitmap *scrbitmap[8];
 
 	bitmap = artwork_get_ui_bitmap();
 
-	/* dump a screenshot */
-	snprintf(buf, sizeof(buf) / sizeof(buf[0]),
-		(screenshot_num >= 0) ? "_%s_%d.png" : "_%s.png",
-		current_testcase.name, screenshot_num);
-	fp = mame_fopen(Machine->gamedrv->name, buf, FILETYPE_SCREENSHOT, 1);
-	if (fp)
+	if (write_file)
 	{
-		save_screen_snapshot_as(fp, bitmap);
-		mame_fclose(fp);
-		report_message(MSG_INFO, "Saved screenshot as %s", buf);
+		/* dump a screenshot */
+		snprintf(buf, sizeof(buf) / sizeof(buf[0]),
+			(screenshot_num >= 0) ? "_%s_%d.png" : "_%s.png",
+			current_testcase.name, screenshot_num);
+		fp = mame_fopen(Machine->gamedrv->name, buf, FILETYPE_SCREENSHOT, 1);
+		if (fp)
+		{
+			save_screen_snapshot_as(fp, bitmap);
+			mame_fclose(fp);
+			report_message(MSG_INFO, "Saved screenshot as %s", buf);
+		}
+
+		if (screenshot_num >= 0)
+			screenshot_num++;
 	}
 
-	if (screenshot_num >= 0)
-		screenshot_num++;
-
 	/* check to see if bitmap is blank */
+	bitmap = scrbitmap[0];
 	is_blank = 1;
 	color = bitmap->read(bitmap, 0, 0);
 	for (y = 0; is_blank && (y < bitmap->height); y++)
@@ -172,46 +190,25 @@ static void dump_screenshot(void)
 		}
 	}
 	if (is_blank)
+	{
+		had_failure = TRUE;
 		report_message(MSG_FAILURE, "Screenshot is blank");
+	}
 }
 
 
 
-void CLIB_DECL osd_die(const char *text,...)
-{
-	va_list va;
-	char buf[256];
-	char *s;
-
-	/* format the die message */
-	va_start(va, text);
-	vsnprintf(buf, sizeof(buf) / sizeof(buf[0]), text, va);
-	va_end(va);
-
-	/* strip out \n */
-	s = strchr(buf, '\n');
-	if (s)
-		*s = '\0';
-
-	/* report the failure */
-	report_message(MSG_FAILURE, "Die: %s", buf);
-	state = STATE_ABORTED;
-	longjmp(die_jmpbuf, -1);
-}
-
-
-
-static enum messtest_result run_test(int flags, struct messtest_results *results)
+static messtest_result_t run_test(int flags, struct messtest_results *results)
 {
 	int driver_num;
-	enum messtest_result rc;
+	messtest_result_t rc;
 	clock_t begin_time;
 	double real_run_time;
 
 	/* lookup driver */
 	for (driver_num = 0; drivers[driver_num]; driver_num++)
 	{
-		if (!strcmpi(current_testcase.driver, drivers[driver_num]->name))
+		if (!mame_stricmp(current_testcase.driver, drivers[driver_num]->name))
 			break;
 	}
 
@@ -228,6 +225,11 @@ static enum messtest_result run_test(int flags, struct messtest_results *results
 	test_flags = flags;
 	screenshot_num = 0;
 	runtime_hash = 0;
+	had_failure = FALSE;
+	seen_first_update = FALSE;
+	videoram = NULL;
+	videoram_size = 0;
+	dirtybuffer = NULL;
 
 	/* set up options */
 	memset(&options, 0, sizeof(options));
@@ -239,12 +241,14 @@ static enum messtest_result run_test(int flags, struct messtest_results *results
 	options.vector_intensity = 1.5;
 	options.use_artwork = 1;
 	options.samplerate = 44100;
+	options.mame_debug = 1;
 
 	/* preload any needed images */
 	while(current_command->command_type == MESSTEST_COMMAND_IMAGE_PRELOAD)
 	{
 		options.image_files[options.image_count].name = current_command->u.image_args.filename;
-		options.image_files[options.image_count].type = current_command->u.image_args.device_type;
+		options.image_files[options.image_count].device_type = current_command->u.image_args.device_type;
+		options.image_files[options.image_count].device_index = -1;
 		options.image_count++;
 		current_command++;
 	}
@@ -252,8 +256,7 @@ static enum messtest_result run_test(int flags, struct messtest_results *results
 	/* perform the test */
 	report_message(MSG_INFO, "Beginning test (driver '%s')", current_testcase.driver);
 	begin_time = clock();
-	if (setjmp(die_jmpbuf) == 0)
-		run_game(driver_num);
+	run_game(driver_num);
 	real_run_time = ((double) (clock() - begin_time)) / CLOCKS_PER_SEC;
 
 	/* what happened? */
@@ -265,9 +268,18 @@ static enum messtest_result run_test(int flags, struct messtest_results *results
 			break;
 
 		case STATE_DONE:
-			report_message(MSG_INFO, "Test succeeded (real time %.2f; emu time %.2f [%i%%])",
-				real_run_time, final_time, (int) ((final_time / real_run_time) * 100));
-			rc = MESSTEST_RESULT_SUCCESS;
+			if (had_failure)
+			{
+				report_message(MSG_FAILURE, "Test failed (real time %.2f; emu time %.2f [%i%%])",
+					real_run_time, final_time, (int) ((final_time / real_run_time) * 100));
+				rc = MESSTEST_RESULT_RUNTIMEFAILURE;
+			}
+			else
+			{
+				report_message(MSG_INFO, "Test succeeded (real time %.2f; emu time %.2f [%i%%])",
+					real_run_time, final_time, (int) ((final_time / real_run_time) * 100));
+				rc = MESSTEST_RESULT_SUCCESS;
+			}
 			break;
 
 		default:
@@ -287,13 +299,6 @@ static enum messtest_result run_test(int flags, struct messtest_results *results
 
 
 
-int osd_trying_to_quit(void)
-{
-	return (state == STATE_ABORTED) || (state == STATE_DONE);
-}
-
-
-
 int osd_start_audio_stream(int stereo)
 {
 	char buf[256];
@@ -347,7 +352,7 @@ static void find_switch(const char *switch_name, const char *switch_setting,
 	while(in->type != IPT_END)
 	{
 		if (in->type == switch_type && input_port_active(in)
-			&& input_port_name(in) && !stricmp(input_port_name(in), switch_name))
+			&& input_port_name(in) && !mame_stricmp(input_port_name(in), switch_name))
 			break;
 		in++;
 	}
@@ -359,7 +364,7 @@ static void find_switch(const char *switch_name, const char *switch_setting,
 	in++;
 	while(in->type == switch_setting_type)
 	{
-		if (input_port_active(in) && input_port_name(in) && !stricmp(input_port_name(in), switch_setting))
+		if (input_port_active(in) && input_port_name(in) && !mame_stricmp(input_port_name(in), switch_setting))
 			break;
 		in++;
 	}
@@ -470,7 +475,14 @@ static void command_rawinput(void)
 
 static void command_screenshot(void)
 {
-	dump_screenshot();
+	dump_screenshot(TRUE);
+}
+
+
+
+static void command_checkblank(void)
+{
+	dump_screenshot(FALSE);
 }
 
 
@@ -520,6 +532,7 @@ static void command_image_loadcreate(void)
 	mess_image *image;
 	int device_type;
 	int device_slot;
+	const char *device_tag;
 	int i, format_index = 0;
 	const char *filename;
 	const char *format;
@@ -529,9 +542,13 @@ static void command_image_loadcreate(void)
 
 	device_slot = current_command->u.image_args.device_slot;
 	device_type = current_command->u.image_args.device_type;
+	device_tag = current_command->u.image_args.device_tag;
 
 	/* look up the image slot */
-	image = image_from_devtype_and_index(device_type, device_slot);
+	if (device_tag)
+		image = image_from_devtag_and_index(device_tag, device_slot);
+	else
+		image = image_from_devtype_and_index(device_type, device_slot);
 	if (!image)
 	{
 		state = STATE_ABORTED;
@@ -613,7 +630,7 @@ static void command_image_loadcreate(void)
 
 
 
-static void command_image_verify_memory(void)
+static void command_verify_memory(void)
 {
 	int i = 0;
 	offs_t offset, offset_start, offset_end;
@@ -678,7 +695,7 @@ static void command_image_verify_memory(void)
 
 
 
-static void command_image_verify_image(void)
+static void command_verify_image(void)
 {
 	const UINT8 *verify_data;
 	size_t verify_data_size;
@@ -736,11 +753,41 @@ static void command_image_verify_image(void)
 
 
 
+static void command_trace(void)
+{
+#if defined(MAME_DEBUG) && defined(NEW_DEBUGGER)
+	int cpunum;
+	FILE *file;
+	char filename[256];
+
+	for (cpunum = 0; cpunum < cpu_gettotalcpu(); cpunum++)
+	{
+		if (cpu_gettotalcpu() == 1)
+			snprintf(filename, sizeof(filename) / sizeof(filename[0]), "_%s.tr", current_testcase.name);
+		else
+			snprintf(filename, sizeof(filename) / sizeof(filename[0]), "_%s.%d.tr", current_testcase.name, cpunum);
+
+		file = fopen(filename, "w");
+		if (file)
+		{
+			report_message(MSG_INFO, "Tracing CPU #%d: %s", cpunum, filename);
+			debug_cpu_trace(cpunum, file, FALSE, NULL);
+		}
+	}
+#else
+	state = STATE_ABORTED;
+	report_message(MSG_FAILURE, "Cannot trace; debugger not present");
+#endif
+}
+
+
+
 static void command_end(void)
 {
 	/* at the end of our test */
 	state = STATE_DONE;
 	final_time = timer_get_time();
+	mame_schedule_exit();
 }
 
 
@@ -749,7 +796,7 @@ static void command_end(void)
 
 struct command_procmap_entry
 {
-	enum messtest_command_type command_type;
+	messtest_command_type_t command_type;
 	void (*proc)(void);
 };
 
@@ -759,12 +806,14 @@ static const struct command_procmap_entry commands[] =
 	{ MESSTEST_COMMAND_INPUT,			command_input },
 	{ MESSTEST_COMMAND_RAWINPUT,		command_rawinput },
 	{ MESSTEST_COMMAND_SCREENSHOT,		command_screenshot },
+	{ MESSTEST_COMMAND_CHECKBLANK,		command_checkblank },
 	{ MESSTEST_COMMAND_SWITCH,			command_switch },
 	{ MESSTEST_COMMAND_IMAGE_PRELOAD,	command_image_preload },
 	{ MESSTEST_COMMAND_IMAGE_LOAD,		command_image_loadcreate },
 	{ MESSTEST_COMMAND_IMAGE_CREATE,	command_image_loadcreate },
-	{ MESSTEST_COMMAND_VERIFY_MEMORY,	command_image_verify_memory },
-	{ MESSTEST_COMMAND_VERIFY_IMAGE,	command_image_verify_image },
+	{ MESSTEST_COMMAND_VERIFY_MEMORY,	command_verify_memory },
+	{ MESSTEST_COMMAND_VERIFY_IMAGE,	command_verify_image },
+	{ MESSTEST_COMMAND_TRACE,			command_trace },
 	{ MESSTEST_COMMAND_END,				command_end }
 };
 
@@ -782,6 +831,13 @@ void osd_update_video_and_audio(mame_display *display)
 			display->game_visible_area.max_x, display->game_visible_area.max_y);
 	}
 
+	/* is this the first update?  if so, eat it */
+	if (!seen_first_update)
+	{
+		seen_first_update = TRUE;
+		return;
+	}
+
 	/* if we have already aborted or completed, our work is done */
 	if ((state == STATE_ABORTED) || (state == STATE_DONE))
 		return;
@@ -826,7 +882,7 @@ void osd_update_video_and_audio(mame_display *display)
 			(current_command[0].command_type != MESSTEST_COMMAND_SCREENSHOT) &&
 			(current_command[1].command_type == MESSTEST_COMMAND_END))
 		{
-			dump_screenshot();
+			dump_screenshot(TRUE);
 		}
 
 		current_command++;
@@ -844,8 +900,6 @@ const struct KeyboardInfo *osd_get_key_list(void)
 	if (!ki)
 	{
 		ki = auto_malloc((__code_key_last - __code_key_first + 1) * sizeof(struct KeyboardInfo));
-		if (!ki)
-			return NULL;
 
 		for (i = __code_key_first; i <= __code_key_last; i++)
 		{
@@ -864,8 +918,6 @@ const struct JoystickInfo *osd_get_joy_list(void)
 	if (!ji)
 	{
 		ji = auto_malloc((__code_joy_last - __code_joy_first + 1) * sizeof(struct JoystickInfo));
-		if (!ji)
-			return NULL;
 
 		for (i = __code_joy_first; i <= __code_joy_last; i++)
 		{
@@ -1036,13 +1088,25 @@ static void node_screenshot(xml_data_node *node)
 
 
 
-static void node_image(xml_data_node *node, enum messtest_command_type command)
+static void node_checkblank(xml_data_node *node)
+{
+	/* <checkblank> - checks to see if the screen is blank */
+	memset(&new_command, 0, sizeof(new_command));
+	new_command.command_type = MESSTEST_COMMAND_CHECKBLANK;
+
+	if (!append_command())
+	{
+		error_outofmemory();
+		return;
+	}
+}
+
+
+
+static void node_image(xml_data_node *node, messtest_command_type_t command)
 {
 	xml_attribute_node *attr_node;
-	const char *s1;
 	const char *s2;
-	const char *s3;
-	const char *s4;
 	int preload, device_type;
 
 	memset(&new_command, 0, sizeof(new_command));
@@ -1056,7 +1120,7 @@ static void node_image(xml_data_node *node, enum messtest_command_type command)
 
 	/* 'filename' attribute */
 	attr_node = xml_get_attribute(node, "filename");
-	s1 = attr_node ? attr_node->value : NULL;
+	new_command.u.image_args.filename = attr_node ? attr_node->value : NULL;
 
 	/* 'type' attribute */
 	attr_node = xml_get_attribute(node, "type");
@@ -1073,20 +1137,20 @@ static void node_image(xml_data_node *node, enum messtest_command_type command)
 		error_baddevicetype(s2);
 		return;
 	}
+	new_command.u.image_args.device_type = device_type;
 	
 	/* 'slot' attribute */
 	attr_node = xml_get_attribute(node, "slot");
-	s3 = attr_node ? attr_node->value : NULL;
+	new_command.u.image_args.device_slot = attr_node ? atoi(attr_node->value) : 0;
 
 	/* 'format' attribute */
 	format_index = 0;
 	attr_node = xml_get_attribute(node, "format");
-	s4 = attr_node ? attr_node->value : NULL;
+	new_command.u.image_args.format = attr_node ? attr_node->value : NULL;
 
-	new_command.u.image_args.filename = s1;
-	new_command.u.image_args.device_type = device_type;
-	new_command.u.image_args.device_slot = s3 ? atoi(s3) : 0;
-	new_command.u.image_args.format = s4;
+	/* 'tag' attribute */
+	attr_node = xml_get_attribute(node, "tag");
+	new_command.u.image_args.device_tag = attr_node ? attr_node->value : NULL;
 
 	if (!append_command())
 	{
@@ -1236,6 +1300,21 @@ static void verify_end_handler(const void *buffer, size_t size)
 
 
 
+static void node_trace(xml_data_node *node)
+{
+	/* <trace> - emit a trace file */
+	memset(&new_command, 0, sizeof(new_command));
+	new_command.command_type = MESSTEST_COMMAND_TRACE;
+
+	if (!append_command())
+	{
+		error_outofmemory();
+		return;
+	}
+}
+
+
+
 void node_testmess(xml_data_node *node)
 {
 	xml_data_node *child_node;
@@ -1285,6 +1364,8 @@ void node_testmess(xml_data_node *node)
 			node_switch(child_node);
 		else if (!strcmp(child_node->name, "screenshot"))
 			node_screenshot(child_node);
+		else if (!strcmp(child_node->name, "checkblank"))
+			node_checkblank(child_node);
 		else if (!strcmp(child_node->name, "imagecreate"))
 			node_imagecreate(child_node);
 		else if (!strcmp(child_node->name, "imageload"))
@@ -1293,6 +1374,8 @@ void node_testmess(xml_data_node *node)
 			node_memverify(child_node);
 		else if (!strcmp(child_node->name, "imageverify"))
 			node_imageverify(child_node);
+		else if (!strcmp(child_node->name, "trace"))
+			node_trace(child_node);
 	}
 
 	memset(&new_command, 0, sizeof(new_command));
