@@ -1,18 +1,19 @@
 #include <stdlib.h>
 #include "mame.h"
+
 #ifdef WIN32
 #include <windows.h>
 #endif
 
+#if defined(MAME_DEBUG) && defined(NEW_DEBUGGER)
+#include "debug/debugcpu.h"
+#endif
+
 int osd_init(void)
 {
 	return 0;
 }
 
-void osd_exit(void)
-{
-}
-
 int osd_create_display(const osd_create_params *params, UINT32 *rgb_components)
 {
 	rgb_components[0] = 0xff0000;
@@ -123,11 +124,7 @@ int osd_display_loading_rom_message(const char *name, rom_load_data *romdata)
 	return 0;
 }
 
-void osd_pause(int paused)
-{
-}
-
-void CLIB_DECL logerror(const char *text,...)
+void osd_logerror(const char *text)
 {
 }
 
@@ -149,13 +146,14 @@ void osd_image_load_status_changed(mess_image *img, int is_final_unload)
 {
 }
 
-#ifdef NEW_DEBUGGER
+#if defined(MAME_DEBUG) && defined(NEW_DEBUGGER)
 void osd_wait_for_debugger(void)
 {
+	debug_cpu_go(~0);
 }
 #endif
 
-int win_mess_validitychecks(void)
+int win_mess_config_init(void)
 {
 	return 0;
 }
