@@ -81,8 +81,6 @@ VIDEO_START( aim65 )
 {
     videoram_size = 6 * 2 + 24;
     videoram = (UINT8*)auto_malloc (videoram_size);
-	if (!videoram)
-        return 1;
 
 #if 0
 	{
@@ -93,10 +91,7 @@ VIDEO_START( aim65 )
 	}
 #endif
     
-	if (video_start_generic () != 0)
-        return 1;
-
-    return 0;
+	return video_start_generic();
 }
 
 static const char led[] = {
