@@ -402,7 +402,7 @@ sprite x position
 */
 
 
-static UINT8 rectangle[0x40][8];
+static UINT8 arcadia_rectangle[0x40][8];
 static UINT8 chars[0x40][8]={
     /* read from the screen generated from a palladium */
     { 0,0,0,0,0,0,0,0 },			/* 00 (space) */
@@ -506,28 +506,31 @@ static struct {
 	    UINT8 ram3[3][16];
 	} d;
     } reg;
+	mame_bitmap *bitmap;
 } arcadia_video={ 0 };
 
 VIDEO_START( arcadia )
 {
 	int i;
-	for (i=0; i<0x40; i++) {
-		rectangle[i][0]=0;
-		rectangle[i][4]=0;
-		if (i&1) rectangle[i][0]|=3;
-		if (i&2) rectangle[i][0]|=0x1c;
-		if (i&4) rectangle[i][0]|=0xe0;
-		if (i&8) rectangle[i][4]|=3;
-		if (i&0x10) rectangle[i][4]|=0x1c;
-		if (i&0x20) rectangle[i][4]|=0xe0;
-		rectangle[i][1]=rectangle[i][2]=rectangle[i][3]=rectangle[i][0];
-		rectangle[i][5]=rectangle[i][6]=rectangle[i][7]=rectangle[i][4];
+	for (i=0; i<0x40; i++)
+	{
+		arcadia_rectangle[i][0]=0;
+		arcadia_rectangle[i][4]=0;
+		if (i&1) arcadia_rectangle[i][0]|=3;
+		if (i&2) arcadia_rectangle[i][0]|=0x1c;
+		if (i&4) arcadia_rectangle[i][0]|=0xe0;
+		if (i&8) arcadia_rectangle[i][4]|=3;
+		if (i&0x10) arcadia_rectangle[i][4]|=0x1c;
+		if (i&0x20) arcadia_rectangle[i][4]|=0xe0;
+		arcadia_rectangle[i][1]=arcadia_rectangle[i][2]=arcadia_rectangle[i][3]=arcadia_rectangle[i][0];
+		arcadia_rectangle[i][5]=arcadia_rectangle[i][6]=arcadia_rectangle[i][7]=arcadia_rectangle[i][4];
 	}
 
+	arcadia_video.bitmap = auto_bitmap_alloc(Machine->drv->screen_width, Machine->drv->screen_height);
 	return 0;
 }
 
- READ8_HANDLER(arcadia_video_r)
+READ8_HANDLER(arcadia_video_r)
 {
     UINT8 data=0;
     switch (offset) {
@@ -578,15 +581,8 @@ VIDEO_START( arcadia )
     return data;
 }
 
-#if arcadia_DEBUG
-static int _y;
-#endif
-
 WRITE8_HANDLER(arcadia_video_w)
 {
-#if arcadia_DEBUG
-    char str[40];
-#endif
     switch (offset) {
     case 0xfc:
 	arcadia_video.reg.data[offset]=data;
@@ -605,22 +601,10 @@ WRITE8_HANDLER(arcadia_video_w)
     case 0xf0: case 0xf2: case 0xf4: case 0xf6:
 	arcadia_video.reg.data[offset]=data;
 	arcadia_video.pos[(offset>>1)&3].y=(data^0xff)+1;
-#if arcadia_DEBUG
-	snprintf(str, sizeof(str), "y %d %d",(offset>>1)&3,
-		 arcadia_video.reg.d.pos[(offset>>1)&3].y );
-	ui_text(Machine->scrbitmap, str, 120, _y);
-	_y+=8;
-#endif
 	break;
     case 0xf1: case 0xf3: case 0xf5: case 0xf7:
 	arcadia_video.reg.data[offset]=data;
 	arcadia_video.pos[(offset>>1)&3].x=data-43;
-#if arcadia_DEBUG
-	snprintf(str, sizeof(str), "x %d %d",(offset>>1)&3,
-		 arcadia_video.reg.d.pos[(offset>>1)&3].x );
-	ui_text(Machine->scrbitmap, str, 120, _y);
-	_y+=8;
-#endif
 	break;
     case 0x180: case 0x181: case 0x182: case 0x183: case 0x184: case 0x185: case 0x186: case 0x187:
     case 0x188: case 0x189: case 0x18a: case 0x18b: case 0x18c: case 0x18d: case 0x18e: case 0x18f:
@@ -648,7 +632,7 @@ WRITE8_HANDLER(arcadia_video_w)
     }
 }
 
-INLINE void arcadia_draw_char(struct mame_bitmap *bitmap, UINT8 *ch, int color,
+INLINE void arcadia_draw_char(mame_bitmap *bitmap, UINT8 *ch, int color,
 			      int y, int x)
 {
     int k,b;
@@ -672,20 +656,24 @@ INLINE void arcadia_draw_char(struct mame_bitmap *bitmap, UINT8 *ch, int color,
 	    b=ch[k];
 	    arcadia_video.bg[y][x>>3]|=b>>(x&7);
 	    arcadia_video.bg[y][(x>>3)+1]|=b<<(8-(x&7));
-	    arcadia_video.bg[y+1][x>>3]|=b>>(x&7);
-	    arcadia_video.bg[y+1][(x>>3)+1]|=b<<(8-(x&7));
-	    drawgfx(bitmap, Machine->gfx[0], b,0,
-		    0,0,x,y,
-		    0, TRANSPARENCY_NONE,0);
-	    drawgfx(bitmap, Machine->gfx[0], b,0,
-		    0,0,x,y+1,
-		    0, TRANSPARENCY_NONE,0);
+
+            if (y+1<bitmap->height) {
+                arcadia_video.bg[y+1][x>>3]|=b>>(x&7);
+                arcadia_video.bg[y+1][(x>>3)+1]|=b<<(8-(x&7));
+                drawgfx(bitmap, Machine->gfx[0], b,0,
+                        0,0,x,y,
+                        0, TRANSPARENCY_NONE,0);
+                drawgfx(bitmap, Machine->gfx[0], b,0,
+                        0,0,x,y+1,
+                        0, TRANSPARENCY_NONE,0);
+            }
 	}
     } else {
 	for (k=0; (k<8)&&(y<bitmap->height); k++, y++) {
 	    b=ch[k];
-	    arcadia_video.bg[y][x>>3]|=b>>(x&7);
+            arcadia_video.bg[y][x>>3]|=b>>(x&7);
 	    arcadia_video.bg[y][(x>>3)+1]|=b<<(8-(x&7));
+
 	    drawgfx(bitmap, Machine->gfx[0], b,0,
 		    0,0,x,y,
 		    0, TRANSPARENCY_NONE,0);
@@ -693,7 +681,7 @@ INLINE void arcadia_draw_char(struct mame_bitmap *bitmap, UINT8 *ch, int color,
     }
 }
 
-INLINE void arcadia_vh_draw_line(struct mame_bitmap *bitmap,
+INLINE void arcadia_vh_draw_line(mame_bitmap *bitmap,
 				 int y, UINT8 chars1[16])
 {
     int x, ch, j, h;
@@ -709,21 +697,21 @@ INLINE void arcadia_vh_draw_line(struct mame_bitmap *bitmap,
 	/* alien invaders shield lines start with 0xc0 */
 	if ((ch&0x3f)==0) {
 	    switch (ch) {
-		case 0xc0: graphics=true;break;
-		case 0x40: graphics=false;break;
+		case 0xc0: graphics=TRUE;break;
+		case 0x40: graphics=FALSE;break;
 /*		case 0x80: */
 /*			alien invaders shields are empty 0x80 */
-/*		    usrintf_showmessage_secs(5, "graphics code 0x80 used"); */
+/*		    ui_popup(5, "graphics code 0x80 used"); */
 	    }
 	}
 	if (graphics)
-	    arcadia_draw_char(bitmap, rectangle[ch&0x3f], ch, y, x);
+	    arcadia_draw_char(bitmap, arcadia_rectangle[ch&0x3f], ch, y, x);
 	else
 	    arcadia_draw_char(bitmap, chars[ch&0x3f], ch, y, x);
     }
 }
 
-static bool arcadia_sprite_collision(int n1, int n2)
+static int arcadia_sprite_collision(int n1, int n2)
 {
     int k, b1, b2, x;
     if (arcadia_video.pos[n1].x+8<=arcadia_video.pos[n2].x) return FALSE;
@@ -741,7 +729,7 @@ static bool arcadia_sprite_collision(int n1, int n2)
     return FALSE;
 }
 
-static void arcadia_draw_sprites(struct mame_bitmap *bitmap)
+static void arcadia_draw_sprites(mame_bitmap *bitmap)
 {
     int i, k, x, y;
     UINT8 b;
@@ -749,7 +737,7 @@ static void arcadia_draw_sprites(struct mame_bitmap *bitmap)
     arcadia_video.reg.d.collision_bg|=0xf;
     arcadia_video.reg.d.collision_sprite|=0x3f;
     for (i=0; i<4; i++) {
-	bool doublescan = false;
+	bool doublescan = FALSE;
 	if (arcadia_video.pos[i].y<=-YPOS) continue;
 	if (arcadia_video.pos[i].y>=bitmap->height-YPOS-8) continue;
 	if (arcadia_video.pos[i].x<=-XPOS) continue;
@@ -758,19 +746,19 @@ static void arcadia_draw_sprites(struct mame_bitmap *bitmap)
 	switch (i) {
 	case 0:
 	    Machine->gfx[0]->colortable[1]=Machine->pens[(arcadia_video.reg.d.pal[3]>>3)&7];
-	    doublescan=arcadia_video.reg.d.pal[3]&0x80?false:true;
+	    doublescan=arcadia_video.reg.d.pal[3]&0x80?FALSE:TRUE;
 	    break;
 	case 1:
 	    Machine->gfx[0]->colortable[1]=Machine->pens[arcadia_video.reg.d.pal[3]&7];
-	    doublescan=arcadia_video.reg.d.pal[3]&0x40?false:true;
+	    doublescan=arcadia_video.reg.d.pal[3]&0x40?FALSE:TRUE;
 	    break;
 	case 2:
 	    Machine->gfx[0]->colortable[1]=Machine->pens[(arcadia_video.reg.d.pal[2]>>3)&7];
-	    doublescan=arcadia_video.reg.d.pal[2]&0x80?false:true;
+	    doublescan=arcadia_video.reg.d.pal[2]&0x80?FALSE:TRUE;
 	    break;
 	case 3:
 	    Machine->gfx[0]->colortable[1]=Machine->pens[arcadia_video.reg.d.pal[2]&7];
-	    doublescan=arcadia_video.reg.d.pal[2]&0x40?false:true;
+	    doublescan=arcadia_video.reg.d.pal[2]&0x40?FALSE:TRUE;
 	    break;
 	}
 	for (k=0; k<8; k++) {
@@ -813,9 +801,6 @@ INTERRUPT_GEN( arcadia_video_line )
 
 	arcadia_video.line++;
 	arcadia_video.line%=262;
-#if arcadia_DEBUG
-	if (arcadia_video.line==0) _y=0;
-#endif
 	/* unbelievable, reflects only charline, but alien invaders uses it for */
 	/* alien scrolling */
 
@@ -823,7 +808,7 @@ INTERRUPT_GEN( arcadia_video_line )
 
 	if (arcadia_video.line<arcadia_video.ypos)
 	{
-		plot_box(Machine->scrbitmap, 0, arcadia_video.line, Machine->scrbitmap->width, 1, Machine->gfx[0]->colortable[0]);
+		plot_box(arcadia_video.bitmap, 0, arcadia_video.line, Machine->drv->screen_width, 1, Machine->gfx[0]->colortable[0]);
 		memset(arcadia_video.bg[arcadia_video.line], 0, sizeof(arcadia_video.bg[0]));
 	}
 	else
@@ -835,7 +820,7 @@ INTERRUPT_GEN( arcadia_video_line )
 		if (arcadia_video.charline<13)
 		{
 			if (((arcadia_video.line-arcadia_video.ypos)&(h-1))==0) {
-				arcadia_vh_draw_line(Machine->scrbitmap, arcadia_video.charline*h+arcadia_video.ypos,
+				arcadia_vh_draw_line(arcadia_video.bitmap, arcadia_video.charline*h+arcadia_video.ypos,
 					arcadia_video.reg.d.chars1[arcadia_video.charline]);
 			}
 		}
@@ -843,7 +828,7 @@ INTERRUPT_GEN( arcadia_video_line )
 		{
 			if (((arcadia_video.line-arcadia_video.ypos)&(h-1))==0)
 			{
-				arcadia_vh_draw_line(Machine->scrbitmap, arcadia_video.charline*h+arcadia_video.ypos,
+				arcadia_vh_draw_line(arcadia_video.bitmap, arcadia_video.charline*h+arcadia_video.ypos,
 					arcadia_video.reg.d.chars2[arcadia_video.charline-13]);
 			}
 			arcadia_video.charline-=13;
@@ -851,56 +836,20 @@ INTERRUPT_GEN( arcadia_video_line )
 		else
 		{
 			arcadia_video.charline=0xd;
-			plot_box(Machine->scrbitmap, 0, arcadia_video.line, Machine->scrbitmap->width, 1, Machine->gfx[0]->colortable[0]);
+			plot_box(arcadia_video.bitmap, 0, arcadia_video.line, Machine->drv->screen_width, 1, Machine->gfx[0]->colortable[0]);
 			memset(arcadia_video.bg[arcadia_video.line], 0, sizeof(arcadia_video.bg[0]));
 		}
 	}
 	if (arcadia_video.line==261)
-		arcadia_draw_sprites(Machine->scrbitmap);
+		arcadia_draw_sprites(arcadia_video.bitmap);
 }
 
- READ8_HANDLER(arcadia_vsync_r)
+READ8_HANDLER(arcadia_vsync_r)
 {
     return arcadia_video.line>=216?0x80:0;
 }
 
 VIDEO_UPDATE( arcadia )
 {
-#if arcadia_DEBUG
-{
-    char str[0x40];
-/*    snprintf(str, sizeof(str), "%.2x %.2x %.2x %.2x", */
-/*	     input_port_7_r(0), input_port_8_r(0), */
-/*	     input_port_9_r(0), input_port_10_r(0)); */
-
-/*    snprintf(str, sizeof(str), "%.2x %.2x %.2x", */
-/*	     arcadia_video.reg.d.control, arcadia_video.reg.d.sound1, arcadia_video.reg.d.sound2); */
-    snprintf(str, sizeof(str), "%.2x:%.2x %.2x:%.2x %.2x:%.2x %.2x:%.2x",
-	     arcadia_video.reg.d.pos[0].x,
-	     arcadia_video.reg.d.pos[0].y,
-	     arcadia_video.reg.d.pos[1].x,
-	     arcadia_video.reg.d.pos[1].y,
-	     arcadia_video.reg.d.pos[2].x,
-	     arcadia_video.reg.d.pos[2].y,
-	     arcadia_video.reg.d.pos[3].x,
-	     arcadia_video.reg.d.pos[3].y );
-    ui_text(bitmap, str, 0, 0);
-    snprintf(str, sizeof(str), "%.2x:%.2x %.2x:%.2x %.2x:%.2x %.2x:%.2x",
-	     arcadia_video.pos[0].x,
-	     arcadia_video.pos[0].y,
-	     arcadia_video.pos[1].x,
-	     arcadia_video.pos[1].y,
-	     arcadia_video.pos[2].x,
-	     arcadia_video.pos[2].y,
-	     arcadia_video.pos[3].x,
-	     arcadia_video.pos[3].y );
-    ui_text(bitmap, str, 0, 8);
-    snprintf(str, sizeof(str), "%.2x %.2x %.2x %.2x",
-	     arcadia_video.reg.d.pal[0],
-	     arcadia_video.reg.d.pal[1],
-	     arcadia_video.reg.d.pal[2],
-	     arcadia_video.reg.d.pal[3] );
-    ui_text(bitmap, str, 0, 16);
-}
-#endif
+	copybitmap(bitmap, arcadia_video.bitmap, 0, 0, 0, 0, cliprect, TRANSPARENCY_NONE, 0);
 }
