@@ -1,4 +1,4 @@
 int video_start_crt(int num_levels, int offset_x, int offset_y, int width, int height);
 void crt_plot(int x, int y);
 VIDEO_EOF( crt );
-void video_update_crt(struct mame_bitmap *bitmap);
+void video_update_crt(mame_bitmap *bitmap);
