@@ -935,7 +935,7 @@ void	Nick_reg_w(int RegIndex, int Data)
   }
 }
 
-void    Nick_DoScreen(struct mame_bitmap *bm)
+void    Nick_DoScreen(mame_bitmap *bm)
 {
   int line = 0;
 
