@@ -126,7 +126,7 @@ typedef struct
 	UINT16	vramsize;		/* Size in words   */
 	UINT8	mode;			/* Resolution mode */
 	UINT8   dirty;
-	struct mame_bitmap *tmpbmp;
+	mame_bitmap *tmpbmp;
 } TYP_GDC_MESS;
 
 static TYP_GDC_MESS gdc_mess;
@@ -1423,13 +1423,11 @@ static int compis_gdc_start (const compis_gdc_interface *intf)
 
 	/* Video RAM */
 	gdc_mess.vram = (UINT16*)auto_malloc (gdc_mess.vramsize * sizeof(UINT16) );
-	if (!gdc_mess.vram)
-		return 1;
 	memset (gdc_mess.vram, 0, gdc_mess.vramsize*sizeof(UINT16) );
 
 	/* back bitmap */
 
-	gdc_mess.tmpbmp    = auto_bitmap_alloc (640, 400);
+	gdc_mess.tmpbmp = auto_bitmap_alloc (640, 400);
 	if (!gdc_mess.tmpbmp ) {
 		return 1;
 	}
@@ -1468,7 +1466,7 @@ VIDEO_START ( compis_gdc )
 	return compis_gdc_start(&sIntf);
 }
 
-void mdrv_compisgdc(struct InternalMachineDriver *machine,
+void mdrv_compisgdc(machine_config *machine,
                     const compis_gdc_interface *intf)
 
 {
