@@ -220,7 +220,7 @@ static void render_sprites(void)
     }
 }
 
-static void render_line(struct mame_bitmap *bitmap, UINT8 nextByte, UINT16 x, UINT16 y,
+static void render_line(mame_bitmap *bitmap, UINT8 nextByte, UINT16 x, UINT16 y,
         UINT8 fgcolor, UINT8 bgcolor)
 {
     UINT32 color = (nextByte & 0x80 ? Machine->pens[fgcolor]
@@ -280,7 +280,7 @@ static void render_line(struct mame_bitmap *bitmap, UINT8 nextByte, UINT16 x, UI
     plot_pixel(bitmap, x+15, y+1, color);
 }
 
-static void render_colored_squares(struct mame_bitmap *bitmap, UINT16 x, UINT16 y,
+static void render_colored_squares(mame_bitmap *bitmap, UINT16 x, UINT16 y,
         UINT8 color0, UINT8 color1, UINT8 color2, UINT8 color3)
 {
     plot_box(bitmap, x, y, 8, 8, Machine->pens[color0]);
@@ -289,7 +289,7 @@ static void render_colored_squares(struct mame_bitmap *bitmap, UINT16 x, UINT16
     plot_box(bitmap, x+8, y+8, 8, 8, Machine->pens[color3]);
 }
 
-static void render_color_stack_mode(struct mame_bitmap *bitmap)
+static void render_color_stack_mode(mame_bitmap *bitmap)
 {
     UINT8 h, csPtr = 0, nexty = 0;
     UINT16 nextCard, nextx = 0;
@@ -348,7 +348,7 @@ static void render_color_stack_mode(struct mame_bitmap *bitmap)
     }
 }
 
-static void render_fg_bg_mode(struct mame_bitmap *bitmap)
+static void render_fg_bg_mode(mame_bitmap *bitmap)
 {
     UINT8 i, j, isGrom, fgcolor, bgcolor, nexty = 0;
     UINT16 nextCard, memoryLocation, nextx = 0;
@@ -384,7 +384,7 @@ static void render_fg_bg_mode(struct mame_bitmap *bitmap)
     }
 }
 
-static void copy_sprites_to_background(struct mame_bitmap *bitmap)
+static void copy_sprites_to_background(mame_bitmap *bitmap)
 {
     UINT8 width, currentPixel;
     UINT8 borderCollision, foregroundCollision;
@@ -453,7 +453,7 @@ static void copy_sprites_to_background(struct mame_bitmap *bitmap)
     }
 }
 
-static void render_background(struct mame_bitmap *bitmap)
+static void render_background(mame_bitmap *bitmap)
 {
 	if (intv_color_stack_mode)
         render_color_stack_mode(bitmap);
@@ -462,7 +462,7 @@ static void render_background(struct mame_bitmap *bitmap)
 }
 
 /*
-static void draw_background(struct mame_bitmap *bitmap, int transparency)
+static void draw_background(mame_bitmap *bitmap, int transparency)
 {
 	// First, draw the background
 	int offs = 0;
@@ -614,7 +614,7 @@ static void draw_background(struct mame_bitmap *bitmap, int transparency)
 
 /* TBD: need to handle sprites behind foreground? */
 /*
-static void draw_sprites(struct mame_bitmap *bitmap, int behind_foreground)
+static void draw_sprites(mame_bitmap *bitmap, int behind_foreground)
 {
 	int i;
 	int code;
@@ -715,7 +715,7 @@ static void draw_sprites(struct mame_bitmap *bitmap, int behind_foreground)
 }
 */
 
-static void draw_borders(struct mame_bitmap *bm)
+static void draw_borders(mame_bitmap *bm)
 {
 	if (intv_left_edge_inhibit)
 	{
@@ -840,7 +840,7 @@ VIDEO_UPDATE( intvkbd )
 /*	char c; */
 
 	/* Draw the underlying INTV screen first */
-	video_update_intv(bitmap, cliprect, do_skip);
+	video_update_intv(screen, bitmap, cliprect, do_skip);
 
 	/* if the intvkbd text is not blanked, overlay it */
 	if (!intvkbd_text_blanked)
