@@ -54,7 +54,7 @@ int mbee_frame_counter;
 UINT8 *pcgram;
 
 /* from mess/systems/microbee.c */
-extern struct GfxLayout mbee_charlayout;
+extern gfx_layout mbee_charlayout;
 
 
 WRITE8_HANDLER ( mbee_pcg_color_latch_w )
@@ -498,9 +498,8 @@ VIDEO_START( mbee )
 {
     if( video_start_generic() )
 		return 1;
-	pcgram = memory_region(REGION_CPU1)+0xf000;
-	videoram = memory_region(REGION_GFX1)+0x0000;
-	colorram = memory_region(REGION_GFX1)+0x0800;
+	videoram = auto_malloc(0x800);
+	colorram = auto_malloc(0x800);
     memset(dirtybuffer, 1, videoram_size);
 
     return 0;
@@ -508,7 +507,7 @@ VIDEO_START( mbee )
 
 VIDEO_UPDATE( mbee )
 {
-	int offs, cursor, screen;
+	int offs, cursor, screen_;
 	int full_refresh = 1;
 
 	if( mbee_frame_counter > 0 )
@@ -517,12 +516,7 @@ VIDEO_UPDATE( mbee )
 			full_refresh = 1;
 		else
 		{
-			/* I know this is ugly, but it happens only once
-			 * after a new message is sprintf()ed into the string :)
-			 */
-            while( strlen(mbee_frame_message) < 128 )
-				strcat(mbee_frame_message, " ");
-			ui_text(bitmap, mbee_frame_message, 0, Machine->uiheight - 10);
+			ui_popup("%s", mbee_frame_message);
 		}
     }
 
@@ -537,14 +531,14 @@ VIDEO_UPDATE( mbee )
 	framecnt++;
 
 	cursor = crt.cursor_address_hi * 256 + crt.cursor_address_lo;
-	screen = crt.screen_address_hi * 256 + crt.screen_address_lo;
-	for( offs = screen; offs < crt.horizontal_displayed * crt.vertical_displayed + screen; offs++ )
+	screen_ = crt.screen_address_hi * 256 + crt.screen_address_lo;
+	for( offs = screen_; offs < crt.horizontal_displayed * crt.vertical_displayed + screen_; offs++ )
 	{
 		if( dirtybuffer[offs] )
 		{
 			int sx, sy, code, color;
-			sy = off_y + ((offs - screen) / crt.horizontal_displayed) * (crt.scan_lines + 1);
-			sx = (off_x + ((offs - screen) % crt.horizontal_displayed)) * 8;
+			sy = off_y + ((offs - screen_) / crt.horizontal_displayed) * (crt.scan_lines + 1);
+			sx = (off_x + ((offs - screen_) % crt.horizontal_displayed)) * 8;
 			code = videoram[offs];
 			color = colorram[offs];
 			drawgfx( bitmap,Machine->gfx[0],code,color,0,0,sx,sy,
