@@ -1,6 +1,6 @@
 /***************************************************************************
 
-  $Id: pc8801.c,v 1.13 2004/06/12 21:05:39 npwoods Exp $
+  $Id: pc8801.c,v 1.16 2006/02/27 23:58:00 npwoods Exp $
 
 ***************************************************************************/
 
@@ -75,7 +75,7 @@ static int disp_plane[3];
 
 static char *graph_dirty=NULL;
 static unsigned short *attr_tmp=NULL,*attr_old=NULL,*text_old=NULL;
-static struct mame_bitmap *wbm1,*wbm2;
+static mame_bitmap *wbm1,*wbm2;
 
 #define TRAM(x,y) (pc88sr_is_highspeed ? \
 	pc88sr_textRAM[(dmac_addr[2]+(x)+(y)*120)&0xfff] : \
@@ -106,7 +106,7 @@ void pc8801_video_init (int hireso)
 	text_old = auto_malloc(sizeof(unsigned short)*80*100);
 	graph_dirty = auto_malloc(80*100);
 
-	if (!wbm1 || !wbm2 || !gVRAM || !pc88sr_textRAM || !attr_tmp || !attr_old || !text_old || !graph_dirty)
+	if (!wbm1 || !wbm2)
 	{
 		logerror ("pc8801: out of memory!\n");
 		return;
@@ -276,8 +276,8 @@ int is_pc8801_vram_select(void)
       rh6 = MRA8_BANK6; \
       wh5 = write_gvram##n##_bank5; \
       wh6 = write_gvram##n##_bank6; \
-      cpu_setbank(5, gVRAM + 0x4000*n ); \
-      cpu_setbank(6, gVRAM + 0x4000*n + 0x3000 ); \
+      memory_set_bankptr(5, gVRAM + 0x4000*n ); \
+      memory_set_bankptr(6, gVRAM + 0x4000*n + 0x3000 ); \
       return 1;
 
       VVV
