@@ -52,9 +52,10 @@
 #include "state.h"
 
 #include "includes/crtc6845.h"
-#include "includes/pc_cga.h"
-#include "includes/pc_video.h"
+#include "vidhrdw/pc_cga.h"
+#include "vidhrdw/pc_video.h"
 #include "mscommon.h"
+#include "memconv.h"
 
 #define VERBOSE_CGA 0		/* CGA (Color Graphics Adapter) */
 
@@ -147,29 +148,29 @@ unsigned short cga_colortable[] =
      12,11,12,15, 13,11,12,15, 14,11,12,15, 15,11,12,15,
 };
 
-struct GfxLayout CGA_charlayout =
+gfx_layout CGA_charlayout =
 {
 	8,16,					/* 8 x 16 characters */
-    256,                    /* 256 characters */
-    1,                      /* 1 bits per pixel */
-    { 0 },                  /* no bitplanes; 1 bit per pixel */
-    /* x offsets */
-    { 0,1,2,3,4,5,6,7 },
-    /* y offsets */
+	256,                    /* 256 characters */
+	1,                      /* 1 bits per pixel */
+	{ 0 },                  /* no bitplanes; 1 bit per pixel */
+	/* x offsets */
+	{ 0,1,2,3,4,5,6,7 },
+	/* y offsets */
 	{ 0*8,1*8,2*8,3*8,
-	  4*8,5*8,6*8,7*8,
-	  0*8,1*8,2*8,3*8,
-	  4*8,5*8,6*8,7*8 },
-    8*8                     /* every char takes 8 bytes */
+		4*8,5*8,6*8,7*8,
+		0*8,1*8,2*8,3*8,
+		4*8,5*8,6*8,7*8 },
+	8*8                     /* every char takes 8 bytes */
 };
 
-static struct GfxDecodeInfo CGA_gfxdecodeinfo[] =
+static gfx_decode CGA_gfxdecodeinfo[] =
 {
 /* Support up to four CGA fonts */
-	{ 1, 0x0000, &CGA_charlayout,              0, 256 },   /* Font 0 */
-	{ 1, 0x0800, &CGA_charlayout,              0, 256 },   /* Font 1 */
-	{ 1, 0x1000, &CGA_charlayout,              0, 256 },   /* Font 2 */
-	{ 1, 0x1800, &CGA_charlayout,              0, 256 },   /* Font 3*/
+	{ REGION_GFX1, 0x0000, &CGA_charlayout,              0, 256 },   /* Font 0 */
+	{ REGION_GFX1, 0x0800, &CGA_charlayout,              0, 256 },   /* Font 1 */
+	{ REGION_GFX1, 0x1000, &CGA_charlayout,              0, 256 },   /* Font 2 */
+	{ REGION_GFX1, 0x1800, &CGA_charlayout,              0, 256 },   /* Font 3*/
     { -1 } /* end of array */
 };
 
@@ -271,10 +272,10 @@ static int internal_pc_cga_video_start(int personality)
 	if (!pc_video_start(&config, pc_cga_choosevideomode, 0x8000))
 		return 1;
 
-	state_save_register_UINT8("pccga", 0, "mode_control",	&cga.mode_control, 1);
-	state_save_register_UINT8("pccga", 0, "color_select",	&cga.color_select, 1);
-	state_save_register_UINT8("pccga", 0, "status",			&cga.status, 1);
-	state_save_register_UINT8("pccga", 0, "plantronics",	&cga.plantronics, 1);
+	state_save_register_item("pccga", 0, cga.mode_control);
+	state_save_register_item("pccga", 0, cga.color_select);
+	state_save_register_item("pccga", 0, cga.status);
+	state_save_register_item("pccga", 0, cga.plantronics);
 
 	timer_pulse(TIME_IN_SEC(32.0/240.0), 0, cga_timerproc);
 	return 0;
@@ -291,28 +292,33 @@ static VIDEO_START( pc_cga )
 	 * TODO: Cards which don't support Plantronics should repeat at 
 	 * BC000h */
 	buswidth = cputype_databus_width(Machine->drv->cpu[0].cpu_type, ADDRESS_SPACE_PROGRAM);
-	switch(buswidth) {
-	case 8:
-		memory_install_read8_handler(0, ADDRESS_SPACE_PROGRAM, 0xb8000, 0xbffff, 0, 0, MRA8_RAM );
-		memory_install_write8_handler(0, ADDRESS_SPACE_PROGRAM, 0xb8000, 0xbffff, 0, 0, pc_video_videoram_w );
-		memory_install_read8_handler(0, ADDRESS_SPACE_IO, 0x3d0, 0x3df, 0, 0, pc_cga8_r );
-		memory_install_write8_handler(0, ADDRESS_SPACE_IO, 0x3d0, 0x3df, 0, 0, pc_cga8_w );
-		break;
+	switch(buswidth)
+	{
+		case 8:
+			memory_install_read8_handler(0, ADDRESS_SPACE_PROGRAM, 0xb8000, 0xbffff, 0, 0, MRA8_BANK11 );
+			memory_install_write8_handler(0, ADDRESS_SPACE_PROGRAM, 0xb8000, 0xbffff, 0, 0, pc_video_videoram_w );
+			memory_install_read8_handler(0, ADDRESS_SPACE_IO, 0x3d0, 0x3df, 0, 0, pc_cga8_r );
+			memory_install_write8_handler(0, ADDRESS_SPACE_IO, 0x3d0, 0x3df, 0, 0, pc_cga8_w );
+			break;
 
-	case 32:
-		memory_install_read32_handler(0, ADDRESS_SPACE_PROGRAM, 0xb8000, 0xbffff, 0, 0, MRA32_RAM );
-		memory_install_write32_handler(0, ADDRESS_SPACE_PROGRAM, 0xb8000, 0xbffff, 0, 0, pc_video_videoram32_w );
-		memory_install_read32_handler(0, ADDRESS_SPACE_IO, 0x3d0, 0x3df, 0, 0, pc_cga32_r );
-		memory_install_write32_handler(0, ADDRESS_SPACE_IO, 0x3d0, 0x3df, 0, 0, pc_cga32_w );
-		break;
+		case 32:
+			memory_install_read32_handler(0, ADDRESS_SPACE_PROGRAM, 0xb8000, 0xbffff, 0, 0, MRA32_BANK11 );
+			memory_install_write32_handler(0, ADDRESS_SPACE_PROGRAM, 0xb8000, 0xbffff, 0, 0, pc_video_videoram32_w );
+			memory_install_read32_handler(0, ADDRESS_SPACE_IO, 0x3d0, 0x3df, 0, 0, pc_cga32_r );
+			memory_install_write32_handler(0, ADDRESS_SPACE_IO, 0x3d0, 0x3df, 0, 0, pc_cga32_w );
+			break;
 
-	default:
-		osd_die("CGA:  Bus width %d not supported\n", buswidth);
-		break;
+		default:
+			fatalerror("CGA:  Bus width %d not supported\n", buswidth);
+			break;
 	}
 
-	videoram = memory_region(REGION_CPU1)+0xb8000;
-	videoram_size = 0x4000;
+	if (videoram_size == 0)
+		videoram_size = 0x8000;
+	if (!videoram)
+		videoram = auto_malloc(videoram_size);
+	memory_set_bankptr(11, videoram);
+
 	return internal_pc_cga_video_start(M6845_PERSONALITY_GENUINE);
 }
 
@@ -502,14 +508,14 @@ WRITE8_HANDLER( pc_cga8_w )
 
 READ32_HANDLER( pc_cga32_r )
 {
-	return read32_with_read8_handler(pc_cga8_r, offset, mem_mask);
+	return read32le_with_read8_handler(pc_cga8_r, offset, mem_mask);
 }
 
 
 
 WRITE32_HANDLER( pc_cga32_w )
 {
-	write32_with_write8_handler(pc_cga8_w, offset, data, mem_mask);
+	write32le_with_write8_handler(pc_cga8_w, offset, data, mem_mask);
 }
 
 
@@ -519,14 +525,14 @@ WRITE32_HANDLER( pc_cga32_w )
   The character cell size is 16x8
 ***************************************************************************/
 
-static void cga_text_inten(struct mame_bitmap *bitmap, struct crtc6845 *crtc)
+static void cga_text_inten(mame_bitmap *bitmap, struct crtc6845 *crtc)
 {
 	int sx, sy;
 	int	offs = crtc6845_get_start(crtc) * 2;
 	int lines = crtc6845_get_char_lines(crtc);
 	int height = crtc6845_get_char_height(crtc);
 	int columns = crtc6845_get_char_columns(crtc);
-	struct rectangle r;
+	rectangle r;
 	struct crtc6845_cursor cursor;
 
 	crtc6845_time(crtc);
@@ -535,7 +541,7 @@ static void cga_text_inten(struct mame_bitmap *bitmap, struct crtc6845 *crtc)
 
 	for (sy=0, r.min_y=0, r.max_y=height-1; sy<lines; sy++, r.min_y+=height,r.max_y+=height)
 	{
-		if (r.min_y >= Machine->scrbitmap->height)
+		if (r.min_y >= Machine->drv->screen_height)
 			break;
 		for (sx=0, r.min_x=0, r.max_x=7; sx<columns; 
 			 sx++, offs=(offs+2)&0x3fff, r.min_x+=8, r.max_x+=8)
@@ -579,14 +585,14 @@ static void cga_text_inten(struct mame_bitmap *bitmap, struct crtc6845 *crtc)
   The character cell size is 16x8
 ***************************************************************************/
 
-static void cga_text_inten_alt(struct mame_bitmap *bitmap, struct crtc6845 *crtc)
+static void cga_text_inten_alt(mame_bitmap *bitmap, struct crtc6845 *crtc)
 {
 	int sx, sy;
 	int	offs = crtc6845_get_start(crtc) * 2;
 	int lines = crtc6845_get_char_lines(crtc);
 	int height = crtc6845_get_char_height(crtc);
 	int columns = crtc6845_get_char_columns(crtc);
-	struct rectangle r;
+	rectangle r;
 	struct crtc6845_cursor cursor;
 
 	if (CGA_CHIPSET != CGA_CHIPSET_PC200) 
@@ -634,14 +640,14 @@ static void cga_text_inten_alt(struct mame_bitmap *bitmap, struct crtc6845 *crtc
   Draw text mode with 40x25 characters (default) and blinking colors.
   The character cell size is 16x8
 ***************************************************************************/
-static void cga_text_blink(struct mame_bitmap *bitmap, struct crtc6845 *crtc)
+static void cga_text_blink(mame_bitmap *bitmap, struct crtc6845 *crtc)
 {
 	int sx, sy;
 	int	offs = crtc6845_get_start(crtc)*2;
 	int lines = crtc6845_get_char_lines(crtc);
 	int height = crtc6845_get_char_height(crtc);
 	int columns = crtc6845_get_char_columns(crtc);
-	struct rectangle r;
+	rectangle r;
 	struct crtc6845_cursor cursor;
 
 	crtc6845_time(crtc);
@@ -650,7 +656,7 @@ static void cga_text_blink(struct mame_bitmap *bitmap, struct crtc6845 *crtc)
 
 	for (sy=0, r.min_y=0, r.max_y=height-1; sy<lines; sy++, r.min_y+=height,r.max_y+=height)
 	{
-		if (r.min_y >= Machine->scrbitmap->height)
+		if (r.min_y >= Machine->drv->screen_height)
 			break;
 
 		for (sx=0, r.min_x=0, r.max_x=7; sx<columns; 
@@ -706,14 +712,14 @@ static void cga_text_blink(struct mame_bitmap *bitmap, struct crtc6845 *crtc)
   The character cell size is 16x8
 ***************************************************************************/
 
-static void cga_text_blink_alt(struct mame_bitmap *bitmap, struct crtc6845 *crtc)
+static void cga_text_blink_alt(mame_bitmap *bitmap, struct crtc6845 *crtc)
 {
 	int sx, sy;
 	int	offs = crtc6845_get_start(crtc)*2;
 	int lines = crtc6845_get_char_lines(crtc);
 	int height = crtc6845_get_char_height(crtc);
 	int columns = crtc6845_get_char_columns(crtc);
-	struct rectangle r;
+	rectangle r;
 	struct crtc6845_cursor cursor;
 	
 	if (CGA_CHIPSET != CGA_CHIPSET_PC200) 
@@ -728,7 +734,7 @@ static void cga_text_blink_alt(struct mame_bitmap *bitmap, struct crtc6845 *crtc
 
 	for (sy=0, r.min_y=0, r.max_y=height-1; sy<lines; sy++, r.min_y+=height,r.max_y+=height)
 	{
-		if (r.min_y >= Machine->scrbitmap->height)
+		if (r.min_y >= Machine->drv->screen_height)
 			break;
 
 		for (sx=0, r.min_x=0, r.max_x=7; sx<columns; 
@@ -775,7 +781,7 @@ static void cga_text_blink_alt(struct mame_bitmap *bitmap, struct crtc6845 *crtc
   cga fetches 2 byte per crtc6845 access (not modeled here)!
 ***************************************************************************/
 
-static void cga_gfx_2bpp(struct mame_bitmap *bitmap, struct crtc6845 *crtc)
+static void cga_gfx_2bpp(mame_bitmap *bitmap, struct crtc6845 *crtc)
 {
 	const UINT16 *palette;
 	int colorset = cga.color_select & 0x3F;
@@ -817,7 +823,7 @@ static void cga_gfx_2bpp(struct mame_bitmap *bitmap, struct crtc6845 *crtc)
   Even scanlines are from CGA_base + 0x0000, odd from CGA_base + 0x2000
 ***************************************************************************/
 
-static void cga_gfx_1bpp(struct mame_bitmap *bitmap, struct crtc6845 *crtc)
+static void cga_gfx_1bpp(mame_bitmap *bitmap, struct crtc6845 *crtc)
 {
 	const UINT16 *palette;
 
@@ -833,7 +839,7 @@ static void cga_gfx_1bpp(struct mame_bitmap *bitmap, struct crtc6845 *crtc)
 
 
 
-INLINE void cga_plot_unit_4bpp(struct mame_bitmap *bitmap, 
+INLINE void cga_plot_unit_4bpp(mame_bitmap *bitmap, 
 				 int x, int y, int offs, int scale)
 {
 	int color;
@@ -846,7 +852,7 @@ INLINE void cga_plot_unit_4bpp(struct mame_bitmap *bitmap,
 }
 
 
-static void cga_gfx_4bpp(struct mame_bitmap *bitmap, struct crtc6845 *crtc, int scale)
+static void cga_gfx_4bpp(mame_bitmap *bitmap, struct crtc6845 *crtc, int scale)
 {
 	int i, sx, sy, sh;
 	int	offs = crtc6845_get_start(crtc)*2;
@@ -895,7 +901,7 @@ static void cga_gfx_4bpp(struct mame_bitmap *bitmap, struct crtc6845 *crtc, int
  * The different scaling factors mean that the '160x200' versions of screens
  * are the same size as the normal colour ones.
  */ 
-static void cga_gfx_4bpph(struct mame_bitmap *bitmap, struct crtc6845 *crtc)
+static void cga_gfx_4bpph(mame_bitmap *bitmap, struct crtc6845 *crtc)
 {
 	pc_cga_check_palette();
 	cga_gfx_4bpp(bitmap, crtc, 8);
@@ -903,7 +909,7 @@ static void cga_gfx_4bpph(struct mame_bitmap *bitmap, struct crtc6845 *crtc)
 
 	
 /* The lo-res graphics mode on a colour composite monitor */
-static void cga_gfx_4bppl(struct mame_bitmap *bitmap, struct crtc6845 *crtc)
+static void cga_gfx_4bppl(mame_bitmap *bitmap, struct crtc6845 *crtc)
 {
 	pc_cga_check_palette();
 	cga_gfx_4bpp(bitmap, crtc, 4);
@@ -912,7 +918,7 @@ static void cga_gfx_4bppl(struct mame_bitmap *bitmap, struct crtc6845 *crtc)
 
 
 
-INLINE void pgfx_plot_unit_4bpp(struct mame_bitmap *bitmap, 
+INLINE void pgfx_plot_unit_4bpp(mame_bitmap *bitmap, 
 							 int x, int y, int offs)
 {
 	int color, values[2];
@@ -947,7 +953,7 @@ INLINE void pgfx_plot_unit_4bpp(struct mame_bitmap *bitmap,
   Second plane at CGA_base + 0x4000 / 0x6000 
 ***************************************************************************/
 
-static void cga_pgfx_4bpp(struct mame_bitmap *bitmap, struct crtc6845 *crtc)
+static void cga_pgfx_4bpp(mame_bitmap *bitmap, struct crtc6845 *crtc)
 {
 	int i, sx, sy, sh;
 	int	offs = crtc6845_get_start(crtc)*2;
@@ -990,7 +996,7 @@ static void cga_pgfx_4bpp(struct mame_bitmap *bitmap, struct crtc6845 *crtc)
 
 
 
-INLINE void pgfx_plot_unit_2bpp(struct mame_bitmap *bitmap, 
+INLINE void pgfx_plot_unit_2bpp(mame_bitmap *bitmap, 
 					 int x, int y, const UINT16 *palette, int offs)
 {
 	int i;
@@ -1037,7 +1043,7 @@ INLINE void pgfx_plot_unit_2bpp(struct mame_bitmap *bitmap,
   cga fetches 2 byte per crtc6845 access (not modeled here)!
 ***************************************************************************/
 
-static void cga_pgfx_2bpp(struct mame_bitmap *bitmap, struct crtc6845 *crtc)
+static void cga_pgfx_2bpp(mame_bitmap *bitmap, struct crtc6845 *crtc)
 {
 	int i, sx, sy, sh;
 	int	offs = crtc6845_get_start(crtc)*2;
@@ -1111,7 +1117,7 @@ static void cga_pgfx_2bpp(struct mame_bitmap *bitmap, struct crtc6845 *crtc)
 /* mapping of the 4 planes into videoram */
 /* (text data should be readable at videoram+0) */
 static const int videoram_offset[4]= { 0xc000, 0x8000, 0x4000, 0 };
-INLINE void pc1512_plot_unit(struct mame_bitmap *bitmap, 
+INLINE void pc1512_plot_unit(mame_bitmap *bitmap, 
 							 int x, int y, int offs)
 {
 	int color, values[4];
@@ -1143,7 +1149,7 @@ INLINE void pc1512_plot_unit(struct mame_bitmap *bitmap,
   Even scanlines are from CGA_base + 0x0000, odd from CGA_base + 0x2000
 ***************************************************************************/
 
-static void pc1512_gfx_4bpp(struct mame_bitmap *bitmap, struct crtc6845 *crtc)
+static void pc1512_gfx_4bpp(mame_bitmap *bitmap, struct crtc6845 *crtc)
 {
 	int i, sx, sy, sh;
 	int	offs = crtc6845_get_start(crtc)*2;
@@ -1338,7 +1344,7 @@ WRITE8_HANDLER ( pc1512_w )
 
 	case 0xe:
 		pc1512.read = data;
-		cpu_setbank(1, videoram + videoram_offset[data & 3]);
+		memory_set_bankptr(1, videoram + videoram_offset[data & 3]);
 		break;
 
 	/* The PC1512 doesn't have a full 6845; writes to the first 9 6845
@@ -1375,7 +1381,7 @@ WRITE8_HANDLER ( pc1512_w )
 
  READ8_HANDLER ( pc1512_r )
 {
-	data8_t data;
+	UINT8 data;
 
 	switch (offset) {
 	case 0xd:
@@ -1414,11 +1420,8 @@ WRITE8_HANDLER ( pc1512_videoram_w )
 VIDEO_START( pc1512 )
 {
 	videoram = (UINT8*) auto_malloc(0x10000);
-	if (videoram == 0)
-		return 1;
-
 	videoram_size = 0x4000; /*! used in cga this way, size of plain memory in 1 bank */
-	cpu_setbank(1,videoram + videoram_offset[0]);
+	memory_set_bankptr(1,videoram + videoram_offset[0]);
 	pc1512.write = 0xf;
 	pc1512.read = 0;
 	
