@@ -1,13 +1,14 @@
 /***************************************************************************
 
-  IBM PC junior
-  Tandy 1000 Graphics Adapter (T1T) section
+	IBM PC junior
+	Tandy 1000 Graphics Adapter (T1T) section
 
-  Note that in the IBM PC Junior world, the term 'vga' is not the 'vga' that
-  most people think of
+	Note that in the IBM PC Junior world, the term 'vga' is not the 'vga' that
+	most people think of
 
 ***************************************************************************/
 
+#include "driver.h"
 #include "vidhrdw/generic.h"
 
 #include "includes/crtc6845.h"
@@ -101,7 +102,7 @@ static gfx_decode t1000hx_gfxdecodeinfo[] =
 {
 	{ 0, 0xffa6e, &t1t_charlayout,			0,				128 },	/* single width */
 	{ 0, 0xfc0a8, &t1t_charlayout,			0,				128 },	/* single width */
-	{ 1,  0x1000, &t1t_gfxlayout_4bpp,		256*2+16*2+2*4,	16 },	/* 160x200 4bpp gfx */
+	{ REGION_GFX1,  0x1000, &t1t_gfxlayout_4bpp,		256*2+16*2+2*4,	16 },	/* 160x200 4bpp gfx */
     { -1 } /* end of array */
 };
 
@@ -109,7 +110,7 @@ static gfx_decode t1000sx_gfxdecodeinfo[] =
 {
 	{ 0, 0xffa6e, &t1t_charlayout,			0,				128 },	/* single width */
 	{ 0, 0xf40a3, &t1t_charlayout,			0,				128 },	/* single width */
-	{ 1,  0x1000, &t1t_gfxlayout_4bpp,		256*2+16*2+2*4,	16 },	/* 160x200 4bpp gfx */
+	{ REGION_GFX1,  0x1000, &t1t_gfxlayout_4bpp,		256*2+16*2+2*4,	16 },	/* 160x200 4bpp gfx */
     { -1 } /* end of array */
 };
 
