@@ -8,6 +8,17 @@
 	This code takes care of installing the various VGA memory and port
 	handlers
 
+	The VGA standard is compatible with MDA, CGA, Hercules, EGA
+	(mda, cga, hercules not real register compatible)
+	several vga cards drive also mda, cga, ega monitors
+	some vga cards have register compatible mda, cga, hercules modes
+
+	ega/vga
+	64k (early ega 16k) words of 32 bit memory
+
+
+	ROM declarations:
+
 	(oti 037 chip)
     ROM_LOAD("oakvga.bin", 0xc0000, 0x8000, 0x318c5f43)
 	(tseng labs famous et4000 isa vga card (oem))
@@ -20,9 +31,11 @@
 #include "driver.h"
 
 #include "includes/crtc6845.h"
-#include "includes/pc_vga.h"
-#include "includes/pc_video.h"
+#include "vidhrdw/pc_vga.h"
+#include "vidhrdw/pc_video.h"
 #include "mscommon.h"
+#include "mess.h"
+#include "memconv.h"
 
 /***************************************************************************
 
@@ -30,29 +43,16 @@
 
 ***************************************************************************/
 
-#define DBG_LOG(n,m,a)
-
-#ifdef MAME_DEBUG
-#define LOG(x)	logerror x
-#else
-#define LOG(x)
-#endif
-
-/* vga
- standard compatible to mda, cga, hercules?, ega
- (mda, cga, hercules not real register compatible)
- several vga cards drive also mda, cga, ega monitors
- some vga cards have register compatible mda, cga, hercules modes
-
- ega/vga
- 64k (early ega 16k) words of 32 bit memory
- */
-
+#define LOG_ACCESSES	0
+#define LOG_REGISTERS	1
 
 static PALETTE_INIT( ega );
 static PALETTE_INIT( vga );
 static VIDEO_START( ega );
 static VIDEO_START( vga );
+static VIDEO_RESET( ega );
+static VIDEO_RESET( vga );
+
 static pc_video_update_proc pc_vga_choosevideomode(int *width, int *height, struct crtc6845 *crtc);
 static pc_video_update_proc pc_ega_choosevideomode(int *width, int *height, struct crtc6845 *crtc);
 
@@ -161,6 +161,7 @@ MACHINE_DRIVER_START( pcvideo_vga )
 	MDRV_PALETTE_INIT(vga)
 
 	MDRV_VIDEO_START(vga)
+	MDRV_VIDEO_RESET(vga)
 	MDRV_VIDEO_UPDATE(pc_video)
 MACHINE_DRIVER_END
 
@@ -173,6 +174,7 @@ MACHINE_DRIVER_START( pcvideo_pc1640 )
 	MDRV_PALETTE_INIT(ega)
 
 	MDRV_VIDEO_START(ega)
+	MDRV_VIDEO_RESET(ega)
 	MDRV_VIDEO_UPDATE(pc_video)
 MACHINE_DRIVER_END
 
@@ -193,22 +195,36 @@ static PALETTE_INIT( vga )
 	memcpy(colortable, vga_colortable,0x200);
 }
 
-static UINT8 rotate_right[8][256];
 static UINT8 color_bitplane_to_packed[4/*plane*/][8/*pixel*/][256];
 
-static struct {
-	read8_handler read_dipswitch;
+static struct
+{
+	struct pc_vga_interface vga_intf;
+	struct pc_svga_interface svga_intf;
 
 	UINT8 *memory;
-	UINT8 *dirty;
 	UINT8 *fontdirty;
 	UINT16 pens[16]; /* the current 16 pens */
 
 	UINT8 miscellaneous_output;
 	UINT8 feature_control;
-	struct { UINT8 index, data[5]; } sequencer;
-	struct { UINT8 index, data[0x19]; } crtc;
-	struct { UINT8 index, data[9]; UINT8 latch[4]; } gc;
+
+	struct
+	{
+		UINT8 index;
+		UINT8 *data;
+	} sequencer;
+	struct
+	{
+		UINT8 index;
+		UINT8 *data;
+	} crtc;
+	struct
+	{
+		UINT8 index;
+		UINT8 *data;
+		UINT8 latch[4];
+	} gc;
 	struct { UINT8 index, data[0x15]; bool state; } attribute;
 
 
@@ -288,6 +304,13 @@ static struct {
 #define FONT2 ( ((vga.sequencer.data[3]&c)>>2)|((vga.sequencer.data[3]&0x20)<<3))*0x2000)
 
 
+INLINE UINT8 rotate_right(UINT8 val, UINT8 rot)
+{
+	return (val >> rot) | (val << (8 - rot));
+}
+
+
+
 static int ega_get_clock(void)
 {
 	int clck=0;
@@ -367,19 +390,14 @@ static int vga_get_crtc_sync_columns(void)
 
 INLINE WRITE8_HANDLER(vga_dirty_w)
 {
-	if (vga.memory[offset]!=data)
-	{
-		vga.memory[offset]=data;
-		vga.dirty[offset]=1;
-	}
+	vga.memory[offset] = data;
 }
 
 INLINE WRITE8_HANDLER(vga_dirty_font_w)
 {
-	if (vga.memory[offset]!=data)
+	if (vga.memory[offset] != data)
 	{
-		vga.memory[offset]=data;
-		vga.dirty[offset]=1;
+		vga.memory[offset] = data;
 		if ((offset&3)==2)
 			vga.fontdirty[offset>>7]=1;
 	}
@@ -432,16 +450,16 @@ static  READ8_HANDLER(vga_ega_r)
 
 INLINE UINT8 vga_latch_helper(UINT8 cpu, UINT8 latch, UINT8 mask)
 {
-	switch (vga.gc.data[3]&0x18) {
-	case 0:
-		return rotate_right[vga.gc.data[3]&7][(cpu&mask)|(latch&~mask)];
-	case 8:
-		return rotate_right[vga.gc.data[3]&7][((cpu&latch)&mask)|(latch&~mask)];
-	case 0x10:
-		return rotate_right[vga.gc.data[3]&7][((cpu|latch)&mask)|(latch&~mask)];
-	case 0x18:
-		return rotate_right[vga.gc.data[3]&7][((cpu^latch)&mask)|(latch&~mask)];
-;
+	switch (vga.gc.data[3] & 0x18)
+	{
+		case 0x00:
+			return rotate_right((cpu&mask)|(latch&~mask), vga.gc.data[3] & 0x07);
+		case 0x08:
+			return rotate_right(((cpu&latch)&mask)|(latch&~mask), vga.gc.data[3] & 0x07);
+		case 0x10:
+			return rotate_right(((cpu|latch)&mask)|(latch&~mask), vga.gc.data[3] & 0x07);
+		case 0x18:
+			return rotate_right(((cpu^latch)&mask)|(latch&~mask), vga.gc.data[3] & 0x07);
 	}
 	return 0; /* must not be reached, suppress compiler warning */
 }
@@ -509,7 +527,8 @@ static void vga_cpu_interface(void)
 	static int sequencer, gc;
 	read8_handler read_handler;
 	write8_handler write_handler;
-	data8_t sel;
+	UINT8 sel;
+	int buswidth;
 
 	if ((gc==vga.gc.data[6])&&(sequencer==vga.sequencer.data[4])) return;
 
@@ -520,53 +539,92 @@ static void vga_cpu_interface(void)
 	{
 		read_handler = vga_vga_r;
 		write_handler = vga_vga_w;
-		DBG_LOG(1,"vga memory",("vga\n"));
 	}
 	else if (vga.sequencer.data[4] & 4)
 	{
 		read_handler = vga_ega_r;
 		write_handler = vga_ega_w;
-		DBG_LOG(1,"vga memory",("ega\n"));
 	}
 	else
 	{
 		read_handler = vga_text_r;
 		write_handler = vga_text_w;
-		DBG_LOG(1,"vga memory",("text\n"));
 	}
 
-	sel = vga.gc.data[6] & 0x0c;
-	if (sel)
+	/* remap the VGA memory */
+	if (vga.vga_intf.map_vga_memory)
 	{
-		memory_install_read8_handler(0, ADDRESS_SPACE_PROGRAM,  0xa0000, 0xaffff, 0, 0, (sel == 0x04) ? read_handler  : MRA8_NOP);
-		memory_install_read8_handler(0, ADDRESS_SPACE_PROGRAM,  0xb0000, 0xb7fff, 0, 0, (sel == 0x08) ? read_handler  : MRA8_NOP);
-		memory_install_read8_handler(0, ADDRESS_SPACE_PROGRAM,  0xb8000, 0xbffff, 0, 0, (sel == 0x0C) ? read_handler  : MRA8_NOP);
-		memory_install_write8_handler(0, ADDRESS_SPACE_PROGRAM, 0xa0000, 0xaffff, 0, 0, (sel == 0x04) ? write_handler : MWA8_NOP);
-		memory_install_write8_handler(0, ADDRESS_SPACE_PROGRAM, 0xb0000, 0xb7fff, 0, 0, (sel == 0x08) ? write_handler : MWA8_NOP);
-		memory_install_write8_handler(0, ADDRESS_SPACE_PROGRAM, 0xb8000, 0xbffff, 0, 0, (sel == 0x0C) ? write_handler : MWA8_NOP);
+		sel = vga.gc.data[6] & 0x0c;
+
+		switch(sel)
+		{
+			case 0x00:
+				if (vga.vga_intf.vga_memory_bank != 0)
+				{
+					read_handler = (read8_handler) vga.vga_intf.vga_memory_bank;
+					write_handler = (write8_handler) vga.vga_intf.vga_memory_bank;
+				}
+				else
+				{
+					read_handler = MRA8_NOP;
+					write_handler = MWA8_NOP;
+				}
+				vga.vga_intf.map_vga_memory(0xA0000, 0xBFFFF, read_handler, write_handler);
+
+				if (vga.vga_intf.vga_memory_bank != 0)
+					memory_set_bankptr(vga.vga_intf.vga_memory_bank, vga.memory);
+				break;
+			case 0x04:
+				vga.vga_intf.map_vga_memory(0xA0000, 0xAFFFF, read_handler, write_handler);
+				break;
+			case 0x08:
+				vga.vga_intf.map_vga_memory(0xB0000, 0xB7FFF, read_handler, write_handler);
+				break;
+			case 0x0C:
+				vga.vga_intf.map_vga_memory(0xB8000, 0xBFFFF, read_handler, write_handler);
+				break;
+		}
 	}
-	else
+
+	buswidth = cputype_databus_width(Machine->drv->cpu[0].cpu_type, ADDRESS_SPACE_PROGRAM);
+	switch(buswidth)
 	{
-		cpu_setbank(1, vga.memory);
-		memory_install_read8_handler(0, ADDRESS_SPACE_PROGRAM,  0xa0000, 0xbffff, 0, 0, MRA8_BANK1 );
-		memory_install_write8_handler(0, ADDRESS_SPACE_PROGRAM, 0xa0000, 0xbffff, 0, 0, MWA8_BANK1 );
+		case 8:
+			sel = vga.gc.data[6] & 0x0c;
+			if (sel)
+			{
+				memory_install_read8_handler(0, ADDRESS_SPACE_PROGRAM,  0xa0000, 0xaffff, 0, 0, (sel == 0x04) ? read_handler  : MRA8_NOP);
+				memory_install_read8_handler(0, ADDRESS_SPACE_PROGRAM,  0xb0000, 0xb7fff, 0, 0, (sel == 0x08) ? read_handler  : MRA8_NOP);
+				memory_install_read8_handler(0, ADDRESS_SPACE_PROGRAM,  0xb8000, 0xbffff, 0, 0, (sel == 0x0C) ? read_handler  : MRA8_NOP);
+				memory_install_write8_handler(0, ADDRESS_SPACE_PROGRAM, 0xa0000, 0xaffff, 0, 0, (sel == 0x04) ? write_handler : MWA8_NOP);
+				memory_install_write8_handler(0, ADDRESS_SPACE_PROGRAM, 0xb0000, 0xb7fff, 0, 0, (sel == 0x08) ? write_handler : MWA8_NOP);
+				memory_install_write8_handler(0, ADDRESS_SPACE_PROGRAM, 0xb8000, 0xbffff, 0, 0, (sel == 0x0C) ? write_handler : MWA8_NOP);
+			}
+			else
+			{
+				memory_set_bankptr(1, vga.memory);
+				memory_install_read8_handler(0, ADDRESS_SPACE_PROGRAM,  0xa0000, 0xbffff, 0, 0, MRA8_BANK1 );
+				memory_install_write8_handler(0, ADDRESS_SPACE_PROGRAM, 0xa0000, 0xbffff, 0, 0, MWA8_BANK1 );
+			}
+			break;
 	}
 }
 
-static  READ8_HANDLER(vga_crtc_r)
+static READ8_HANDLER(vga_crtc_r)
 {
-	int data=0xff;
+	UINT8 data = 0xff;
 
 	switch (offset) {
-	case 4: data=vga.crtc.index;break;
+	case 4:
+		data = vga.crtc.index;
+		break;
 	case 5:
-		if (vga.crtc.index<sizeof(vga.crtc.data))
-			data=vga.crtc.data[vga.crtc.index];
-		DBG_LOG(1,"vga crtc read",("%.2x %.2x\n",vga.crtc.index,data));
+		if (vga.crtc.index < vga.svga_intf.crtc_regcount)
+			data = vga.crtc.data[vga.crtc.index];
 		break;
 	case 0xa:
-		vga.attribute.state=0;
-		data=0;/*4; */
+		vga.attribute.state = 0;
+		data = 0;/*4; */
 #if 0 /* slow */
 		{
 			int clock=vga.monitor.get_clock();
@@ -608,255 +666,264 @@ static  READ8_HANDLER(vga_crtc_r)
 			data|=(vga.attribute.data[0x11]&0xc0)>>2;
 			break;
 		}
-
-		/*DBG_LOG(1,"vga crtc 0x3[bd]a",("%.2x %.2x\n",offset,data)); */
 		break;
 	case 0xf:
 		/* oak test */
 		data=0;
 		/* pega bios on/off */
 		data=0x80;
-		DBG_LOG(1,"0x3[bd]0 read",("%.2x %.2x\n",offset,data));
 		break;
-	default:
-		DBG_LOG(1,"0x3[bd]0 read",("%.2x %.2x\n",offset,data));
 	}
 	return data;
 }
 
 static WRITE8_HANDLER(vga_crtc_w)
 {
-	switch (offset) {
-	case 0xa:
-		DBG_LOG(1,"vga feature control write",("%.2x %.2x\n",offset,data));
-		vga.feature_control=data;
-		break;
+	switch (offset)
+	{
+		case 0xa:
+			vga.feature_control = data;
+			break;
 
-	case 4:
-		vga.crtc.index = data;
-		break;
+		case 4:
+			vga.crtc.index = data;
+			break;
 
-	case 5:
-		DBG_LOG(1,"vga crtc write",("%.2x %.2x\n",vga.crtc.index,data));
-		if (vga.crtc.index<sizeof(vga.crtc.data))
-		{
-			switch (vga.crtc.index) {
-			case 0xa:case 0xb: case 0xe: case 0xf:
-				vga.dirty[CRTC6845_CURSOR_POS<<2]=1;
-				break;
+		case 5:
+			if (LOG_REGISTERS)
+			{
+				logerror("vga_crtc_w(): CRTC[0x%02X%s] = 0x%02X\n",
+					vga.crtc.index,
+					(vga.crtc.index < vga.svga_intf.crtc_regcount) ? "" : "?",
+					data);
 			}
-			vga.crtc.data[vga.crtc.index]=data;
-		}
-		break;
 
-	default:
-		DBG_LOG(1,"0x3[bd]0 write",("%.2x %.2x\n",offset,data));
-		break;
+			if (vga.crtc.index < vga.svga_intf.crtc_regcount)
+				vga.crtc.data[vga.crtc.index] = data;
+			break;
 	}
 }
 
- READ8_HANDLER( vga_port_03b0_r )
+
+
+READ8_HANDLER( vga_port_03b0_r )
 {
-	int data=0xff;
+	UINT8 data = 0xff;
 	if (CRTC_PORT_ADDR==0x3b0)
 		data=vga_crtc_r(offset);
-	/*DBG_LOG(1,"vga 0x3b0 read",("%.2x %.2x\n", offset, data)); */
 	return data;
 }
 
- READ8_HANDLER( ega_port_03c0_r)
+
+
+READ8_HANDLER( ega_port_03c0_r)
 {
-	int data=0xff;
+	UINT8 data = 0xff;
 	switch (offset) {
 	case 2: data=0xff;/*!*/break;
 	}
-	DBG_LOG(1,"ega 0x3c0 read",("%.2x %.2x\n", offset, data));
 	return data;
 }
 
- READ8_HANDLER( vga_port_03c0_r )
+READ8_HANDLER( vga_port_03c0_r )
 {
-	int data=0xff;
-	switch (offset) {
-	case 1:
-		if (vga.attribute.state==0) {
-			data=vga.attribute.index;
-			DBG_LOG(2,"vga attr index read",("%.2x %.2x\n",offset,data));
-		} else {
-			if ((vga.attribute.index&0x1f)<sizeof(vga.attribute.data))
-				data=vga.attribute.data[vga.attribute.index&0x1f];
-			DBG_LOG(1,"vga attr read",("%.2x %.2x\n",vga.attribute.index&0x1f,data));
-		}
-		break;
-	case 2:
-		data=0;
-		switch ((vga.miscellaneous_output>>2)&3) {
-		case 3:
-			if (vga.read_dipswitch(0)&1) data|=0x10;
-			break;
-		case 2:
-			if (vga.read_dipswitch(0)&2) data|=0x10;
-			break;
+	UINT8 data = 0xff;
+
+	switch (offset)
+	{
 		case 1:
-			if (vga.read_dipswitch(0)&4) data|=0x10;
-			break;
-		case 0:
-			if (vga.read_dipswitch(0)&8) data|=0x10;
-			break;
-		}
-		DBG_LOG(1,"vga dipswitch read",("%.2x %.2x\n",offset,data));
-		break;
-	case 3: data=vga.oak.reg;break;
-	case 4:
-		data=vga.sequencer.index;
-		DBG_LOG(2,"vga sequencer index read",("%.2x %.2x\n",offset,data));
-		break;
-	case 5:
-		if (vga.sequencer.index<sizeof(vga.sequencer.data))
-			data=vga.sequencer.data[vga.sequencer.index];
-		DBG_LOG(1,"vga sequencer read",("%.2x %.2x\n",vga.sequencer.index,data));
-		break;
-	case 6:
-		data=vga.dac.mask;
-		DBG_LOG(3,"vga dac mask read",("%.2x %.2x\n",offset,data));
-		break;
-	case 7:
-		if (vga.dac.read) data=0;
-		else data=3;
-		DBG_LOG(3,"vga dac status read",("%.2x %.2x\n",offset,data));
-		break;
-	case 8:
-		data=vga.dac.write_index;
-		DBG_LOG(3,"vga dac writeindex read",("%.2x %.2x\n",offset,data));
-		break;
-	case 9:
-		if (vga.dac.read) {
-			switch (vga.dac.state++) {
-			case 0:
-				data=vga.dac.color[vga.dac.read_index].red;
-				DBG_LOG(3,"vga dac red read",("%.2x %.2x\n",offset,data));
-				break;
-			case 1:
-				data=vga.dac.color[vga.dac.read_index].green;
-				DBG_LOG(3,"vga dac green read",("%.2x %.2x\n",offset,data));
-				break;
-			case 2:
-				data=vga.dac.color[vga.dac.read_index].blue;
-				DBG_LOG(3,"vga dac blue read",("%.2x %.2x\n",offset,data));
-				break;
+			if (vga.attribute.state==0)
+			{
+				data = vga.attribute.index;
 			}
-			if (vga.dac.state==3) {
-				vga.dac.state=0; vga.dac.read_index++;
+			else
+			{
+				if ((vga.attribute.index&0x1f)<sizeof(vga.attribute.data))
+					data=vga.attribute.data[vga.attribute.index&0x1f];
 			}
-		} else {
-			DBG_LOG(1,"vga dac color read",("%.2x %.2x\n",offset,data));
-		}
-		break;
-	case 0xa:
-		data=vga.feature_control;
-		DBG_LOG(1,"vga feature control read",("%.2x %.2x\n",offset,data));
-		break;
-	case 0xc:
-		data=vga.miscellaneous_output;
-		DBG_LOG(1,"vga miscellaneous read",("%.2x %.2x\n",offset,data));
-		break;
-	case 0xe:
-		data=vga.gc.index;
-		DBG_LOG(2,"vga gc index read",("%.2x %.2x\n",offset,data));
-		break;
-	case 0xf:
-		if (vga.gc.index<sizeof(vga.gc.data)) {
-			data=vga.gc.data[vga.gc.index];
-		}
-		DBG_LOG(1,"vga gc read",("%.2x %.2x\n",vga.gc.index,data));
-		break;
-	default:
-		DBG_LOG(1,"03c0 read",("%.2x %.2x\n",offset,data));
+			break;
+
+		case 2:
+			data = 0;
+			switch ((vga.miscellaneous_output>>2)&3)
+			{
+				case 3:
+					if (vga.vga_intf.read_dipswitch && vga.vga_intf.read_dipswitch(0) & 0x01)
+						data |= 0x10;
+					break;
+				case 2:
+					if (vga.vga_intf.read_dipswitch && vga.vga_intf.read_dipswitch(0) & 0x02)
+						data |= 0x10;
+					break;
+				case 1:
+					if (vga.vga_intf.read_dipswitch && vga.vga_intf.read_dipswitch(0) & 0x04)
+						data |= 0x10;
+					break;
+				case 0:
+					if (vga.vga_intf.read_dipswitch && vga.vga_intf.read_dipswitch(0) & 0x08)
+						data |= 0x10;
+					break;
+			}
+			break;
+
+		case 3:
+			data = vga.oak.reg;
+			break;
+
+		case 4:
+			data = vga.sequencer.index;
+			break;
+
+		case 5:
+			if (vga.sequencer.index < vga.svga_intf.seq_regcount)
+				data = vga.sequencer.data[vga.sequencer.index];
+			break;
+
+		case 6:
+			data = vga.dac.mask;
+			break;
+
+		case 7:
+			if (vga.dac.read)
+				data = 0;
+			else
+				data = 3;
+			break;
+
+		case 8:
+			data = vga.dac.write_index;
+			break;
+
+		case 9:
+			if (vga.dac.read)
+			{
+				switch (vga.dac.state++)
+				{
+					case 0:
+						data = vga.dac.color[vga.dac.read_index].red;
+						break;
+					case 1:
+						data = vga.dac.color[vga.dac.read_index].green;
+						break;
+					case 2:
+						data = vga.dac.color[vga.dac.read_index].blue;
+						break;
+				}
+
+				if (vga.dac.state==3)
+				{
+					vga.dac.state = 0;
+					vga.dac.read_index++;
+				}
+			}
+			break;
+
+		case 0xa:
+			data = vga.feature_control;
+			break;
+
+		case 0xc:
+			data = vga.miscellaneous_output;
+			break;
+
+		case 0xe:
+			data = vga.gc.index;
+			break;
+
+		case 0xf:
+			if (vga.gc.index < vga.svga_intf.gc_regcount)
+				data = vga.gc.data[vga.gc.index];
+			break;
 	}
 	return data;
 }
 
- READ8_HANDLER(vga_port_03d0_r)
+READ8_HANDLER(vga_port_03d0_r)
 {
-	int data=0xff;
-	if (CRTC_PORT_ADDR==0x3d0)
-		data=vga_crtc_r(offset);
-	/*DBG_LOG(1,"vga 0x3d0 read",("%.2x %.2x\n", offset, data)); */
+	UINT8 data = 0xff;
+	if (CRTC_PORT_ADDR == 0x3d0)
+		data = vga_crtc_r(offset);
 	return data;
 }
 
 WRITE8_HANDLER( vga_port_03b0_w )
 {
-	LOG(("vga_port_03b0_w(): port=0x%04x data=0x%02x\n", offset + 0x3b0, data));
+	if (LOG_ACCESSES)
+		logerror("vga_port_03b0_w(): port=0x%04x data=0x%02x\n", offset + 0x3b0, data);
 
-	if (CRTC_PORT_ADDR!=0x3b0) return;
-	vga_crtc_w(offset, data);
+	if (CRTC_PORT_ADDR == 0x3b0)
+		vga_crtc_w(offset, data);
 }
 
 WRITE8_HANDLER(vga_port_03c0_w)
 {
-	LOG(("vga_port_03c0_w(): port=0x%04x data=0x%02x\n", offset + 0x3c0, data));
+	if (LOG_ACCESSES)
+		logerror("vga_port_03c0_w(): port=0x%04x data=0x%02x\n", offset + 0x3c0, data);
 
 	switch (offset) {
 	case 0:
-		if (vga.attribute.state==0) {
+		if (vga.attribute.state==0)
+		{
 			vga.attribute.index=data;
-			DBG_LOG(2,"vga attr index write",("%.2x %.2x\n",offset,data));
-		} else {
+		}
+		else
+		{
 			if ((vga.attribute.index&0x1f)<sizeof(vga.attribute.data))
 				vga.attribute.data[vga.attribute.index&0x1f]=data;
-			DBG_LOG(1,"vga attr write",("%.2x %.2x\n",vga.attribute.index,data));
 		}
 		vga.attribute.state=!vga.attribute.state;
 		break;
 	case 2:
 		vga.miscellaneous_output=data;
-		DBG_LOG(1,"vga miscellaneous write",("%.2x %.2x\n",offset,data));
 		break;
 	case 3:
-		vga.oak.reg=data;
+		vga.oak.reg = data;
 		break;
 	case 4:
-		vga.sequencer.index=data;
-		DBG_LOG(2,"vga sequencer index write",("%.2x %.2x\n",offset,data));
+		vga.sequencer.index = data;
 		break;
 	case 5:
-		if (vga.sequencer.index<sizeof(vga.sequencer.data))
-			vga.sequencer.data[vga.sequencer.index]=data;
-		vga_cpu_interface();
-		if (vga.sequencer.index==0) vga.monitor.start_time=timer_get_time();
-		DBG_LOG(1,"vga sequencer write",("%.2x %.2x\n",vga.sequencer.index,data));
+		if (LOG_REGISTERS)
+		{
+			logerror("vga_port_03c0_w(): SEQ[0x%02X%s] = 0x%02X\n",
+				vga.sequencer.index,
+				(vga.sequencer.index < vga.svga_intf.seq_regcount) ? "" : "?",
+				data);
+		}
+		if (vga.sequencer.index < vga.svga_intf.seq_regcount)
+		{
+			vga.sequencer.data[vga.sequencer.index] = data;
+			vga_cpu_interface();
+	
+			if (vga.sequencer.index == 0)
+				vga.monitor.start_time = timer_get_time();
+		}
 		break;
 	case 6:
 		vga.dac.mask=data;
-		DBG_LOG(3,"vga dac mask write",("%.2x %.2x\n",offset,data));
 		break;
 	case 7:
 		vga.dac.read_index=data;
 		vga.dac.state=0;
 		vga.dac.read=1;
-		DBG_LOG(3,"vga dac readindex write",("%.2x %.2x\n",offset,data));
 		break;
 	case 8:
 		vga.dac.write_index=data;
 		vga.dac.state=0;
 		vga.dac.read=0;
-		DBG_LOG(3,"vga dac writeindex write",("%.2x %.2x\n",offset,data));
 		break;
 	case 9:
-		if (!vga.dac.read) {
+		if (!vga.dac.read)
+		{
 			switch (vga.dac.state++) {
 			case 0:
 				vga.dac.color[vga.dac.write_index].red=data;
-				DBG_LOG(3,"vga dac red write",("%.2x %.2x\n",offset,data));
 				break;
 			case 1:
 				vga.dac.color[vga.dac.write_index].green=data;
-				DBG_LOG(3,"vga dac green write",("%.2x %.2x\n",offset,data));
 				break;
 			case 2:
 				vga.dac.color[vga.dac.write_index].blue=data;
-				DBG_LOG(3,"vga dac blue write",("%.2x %.2x\n",offset,data));
 				break;
 			}
 			vga.dac.dirty=1;
@@ -875,83 +942,104 @@ WRITE8_HANDLER(vga_port_03c0_w)
 				}
 #endif
 			}
-		} else {
-			DBG_LOG(1,"vga dac color write",("%.2x %.2x\n",offset,data));
 		}
 		break;
 	case 0xe:
 		vga.gc.index=data;
-		DBG_LOG(2,"vga gc index write",("%.2x %.2x\n",offset,data));
 		break;
 	case 0xf:
-		if (vga.gc.index<sizeof(vga.gc.data))
-			vga.gc.data[vga.gc.index]=data;
-		vga_cpu_interface();
-		DBG_LOG(1,"vga gc data write",("%.2x %.2x\n",vga.gc.index,data));
+		if (LOG_REGISTERS)
+		{
+			logerror("vga_port_03c0_w(): GC[0x%02X%s] = 0x%02X\n",
+				vga.gc.index,
+				(vga.gc.index < vga.svga_intf.gc_regcount) ? "" : "?",
+				data);
+		}
+		if (vga.gc.index < vga.svga_intf.gc_regcount)
+		{
+			vga.gc.data[vga.gc.index] = data;
+			vga_cpu_interface();
+		}
 		break;
-	default:
-		DBG_LOG(1,"vga write",("%.3x %.2x\n",0x3c0+offset,data));
 	}
 }
 
+
+
 WRITE8_HANDLER(vga_port_03d0_w)
 {
-	LOG(("vga_port_03d0_w(): port=0x%04x data=0x%02x\n", offset + 0x3d0, data));
+	if (LOG_ACCESSES)
+		logerror("vga_port_03d0_w(): port=0x%04x data=0x%02x\n", offset + 0x3d0, data);
 
-	if (CRTC_PORT_ADDR==0x3d0)
+	if (CRTC_PORT_ADDR == 0x3d0)
 		vga_crtc_w(offset,data);
 }
 
- READ8_HANDLER( paradise_ega_03c0_r )
+
+
+READ8_HANDLER( paradise_ega_03c0_r )
 {
-	int data=vga_port_03c0_r(offset);
-	if (offset==2) {
+	UINT8 data = vga_port_03c0_r(offset);
+
+	if (offset == 2)
+	{
 		if ( (vga.feature_control&3)==2 ) {
-			data=(data&~0x60)|((vga.read_dipswitch(0)&0xc0)>>1);
+			data=(data&~0x60)|((vga.vga_intf.read_dipswitch(0)&0xc0)>>1);
 		} else if ((vga.feature_control&3)==1 ) {
-			data=(data&~0x60)|((vga.read_dipswitch(0)&0x30)<<1);
+			data=(data&~0x60)|((vga.vga_intf.read_dipswitch(0)&0x30)<<1);
 		}
 	}
 	return data;
 }
 
+
+
 void pc_vga_reset(void)
 {
-	UINT8 *memory=vga.memory, *dirty=vga.dirty, *fontdirty=vga.fontdirty;
+	/* clear out the VGA structure */
+	memset(vga.pens, 0, sizeof(vga.pens));
+	vga.miscellaneous_output = 0;
+	vga.feature_control = 0;
+	vga.sequencer.index = 0;
+	memset(vga.sequencer.data, 0, vga.svga_intf.seq_regcount * sizeof(*vga.sequencer.data));
+	vga.crtc.index = 0;
+	memset(vga.crtc.data, 0, vga.svga_intf.crtc_regcount * sizeof(*vga.crtc.data));
+	vga.gc.index = 0;
+	memset(vga.gc.data, 0, vga.svga_intf.gc_regcount * sizeof(*vga.gc.data));
+	memset(vga.gc.latch, 0, sizeof(vga.gc.latch));
+	memset(&vga.attribute, 0, sizeof(vga.attribute));
+	memset(&vga.dac, 0, sizeof(vga.dac));
+	memset(&vga.cursor, 0, sizeof(vga.cursor));
+	memset(&vga.monitor, 0, sizeof(vga.monitor));
+	memset(&vga.oak, 0, sizeof(vga.oak));
+	vga.log = 0;
 
-    read8_handler read_dipswitch=vga.read_dipswitch;
-
-	memset(&vga,0, sizeof(vga));
-
-	vga.memory=memory;
-	vga.dirty=dirty;
-	vga.fontdirty=fontdirty;
-
-	vga.read_dipswitch=read_dipswitch;
-	vga.log=0;
-	vga.gc.data[6]=0xc; /* prevent xtbios excepting vga ram as system ram */
+	vga.gc.data[6] = 0xc; /* prevent xtbios excepting vga ram as system ram */
 /* amstrad pc1640 bios relies on the position of
    the video memory area,
    so I introduced the reset to switch to b8000 area */
-	vga.sequencer.data[4]=0;
+	vga.sequencer.data[4] = 0;
 	vga_cpu_interface();
 }
 
-void pc_vga_init(read8_handler read_dipswitch)
+
+
+static READ64_HANDLER( vga_port64be_03b0_r ) { return read64be_with_read8_handler(vga_port_03b0_r, offset, mem_mask); }
+static READ64_HANDLER( vga_port64be_03c0_r ) { return read64be_with_read8_handler(vga_port_03c0_r, offset, mem_mask); }
+static READ64_HANDLER( vga_port64be_03d0_r ) { return read64be_with_read8_handler(vga_port_03d0_r, offset, mem_mask); }
+
+static WRITE64_HANDLER( vga_port64be_03b0_w ) { write64be_with_write8_handler(vga_port_03b0_w, offset, data, mem_mask); }
+static WRITE64_HANDLER( vga_port64be_03c0_w ) { write64be_with_write8_handler(vga_port_03c0_w, offset, data, mem_mask); }
+static WRITE64_HANDLER( vga_port64be_03d0_w ) { write64be_with_write8_handler(vga_port_03d0_w, offset, data, mem_mask); }
+
+
+
+void pc_vga_init(const struct pc_vga_interface *vga_intf, const struct pc_svga_interface *svga_intf)
 {
-	int i, j, k, mask;
+	int i, j, k, mask, buswidth;
 
 	memset(&vga, 0, sizeof(vga));
 
-	for (j=0; j<8; j++)
-	{
-		for (i=0; i<256; i++)
-		{
-			rotate_right[j][i]=i>>j;
-			rotate_right[j][i]|=i<<(8-j);
-		}
-	}
-
 	for (k=0;k<4;k++)
 	{
 		for (mask=0x80, j=0; j<8; j++, mask>>=1)
@@ -961,28 +1049,64 @@ void pc_vga_init(read8_handler read_dipswitch)
 		}
 	}
 
-	vga.read_dipswitch = read_dipswitch;
-	vga.memory =	(UINT8*) auto_malloc(0x40000);
-	vga.dirty =		(UINT8*) auto_malloc(0x40000);
-	vga.fontdirty =	(UINT8*) auto_malloc(0x800);
+	/* copy over interfaces */
+	vga.vga_intf = *vga_intf;
+	if (svga_intf)
+	{
+		vga.svga_intf = *svga_intf;
 
-	memory_install_read8_handler(0, ADDRESS_SPACE_PROGRAM, 0xa0000, 0xaffff, 0, 0, MRA8_BANK1 );
-	memory_install_read8_handler(0, ADDRESS_SPACE_PROGRAM, 0xb0000, 0xb7fff, 0, 0, MRA8_BANK2 );
-	memory_install_read8_handler(0, ADDRESS_SPACE_PROGRAM, 0xb8000, 0xbffff, 0, 0, MRA8_BANK3 );
-	memory_install_read8_handler(0, ADDRESS_SPACE_PROGRAM, 0xc0000, 0xc7fff, 0, 0, MRA8_ROM );
+		if (vga.svga_intf.seq_regcount < 0x05)
+			fatalerror("Invalid SVGA sequencer register count");
+		if (vga.svga_intf.gc_regcount < 0x09)
+			fatalerror("Invalid SVGA GC register count");
+		if (vga.svga_intf.crtc_regcount < 0x19)
+			fatalerror("Invalid SVGA CRTC register count");
+	}
+	else
+	{
+		vga.svga_intf.vram_size = 0x40000;
+		vga.svga_intf.seq_regcount = 0x05;
+		vga.svga_intf.gc_regcount = 0x09;
+		vga.svga_intf.crtc_regcount = 0x19;
+	}
 
-	memory_install_write8_handler(0, ADDRESS_SPACE_PROGRAM, 0xa0000, 0xaffff, 0, 0, MWA8_BANK1 );
-	memory_install_write8_handler(0, ADDRESS_SPACE_PROGRAM, 0xb0000, 0xb7fff, 0, 0, MWA8_BANK2 );
-	memory_install_write8_handler(0, ADDRESS_SPACE_PROGRAM, 0xb8000, 0xbffff, 0, 0, MWA8_BANK3 );
-	memory_install_write8_handler(0, ADDRESS_SPACE_PROGRAM, 0xc0000, 0xc7fff, 0, 0, MWA8_ROM );
+	vga.memory			= (UINT8 *) auto_malloc(vga.svga_intf.vram_size);
+	vga.fontdirty		= (UINT8 *) auto_malloc(0x800);
+	vga.sequencer.data	= (UINT8 *) auto_malloc(vga.svga_intf.seq_regcount);
+	vga.crtc.data		= (UINT8 *) auto_malloc(vga.svga_intf.crtc_regcount);
+	vga.gc.data			= (UINT8 *) auto_malloc(vga.svga_intf.gc_regcount);
+	memset(vga.memory, '\0', vga.svga_intf.vram_size);
+	memset(vga.fontdirty, '\0', 0x800);
+	memset(vga.sequencer.data, '\0', vga.svga_intf.seq_regcount);
+	memset(vga.crtc.data, '\0', vga.svga_intf.crtc_regcount);
+	memset(vga.gc.data, '\0', vga.svga_intf.gc_regcount);
 
-	memory_install_read8_handler(0, ADDRESS_SPACE_IO, 0x3b0, 0x3bf, 0, 0, vga_port_03b0_r );
-	memory_install_read8_handler(0, ADDRESS_SPACE_IO, 0x3c0, 0x3cf, 0, 0, vga_port_03c0_r );
-	memory_install_read8_handler(0, ADDRESS_SPACE_IO, 0x3d0, 0x3df, 0, 0, vga_port_03d0_r );
+	buswidth = cputype_databus_width(Machine->drv->cpu[0].cpu_type, ADDRESS_SPACE_PROGRAM);
+	switch(buswidth)
+	{
+		case 8:
+			memory_install_read8_handler(0, ADDRESS_SPACE_PROGRAM, 0xc0000, 0xc7fff, 0, 0, MRA8_ROM );
+			memory_install_write8_handler(0, ADDRESS_SPACE_PROGRAM, 0xc0000, 0xc7fff, 0, 0, MWA8_ROM );
 
-	memory_install_write8_handler(0, ADDRESS_SPACE_IO, 0x3b0, 0x3bf, 0, 0, vga_port_03b0_w );
-	memory_install_write8_handler(0, ADDRESS_SPACE_IO, 0x3c0, 0x3cf, 0, 0, vga_port_03c0_w );
-	memory_install_write8_handler(0, ADDRESS_SPACE_IO, 0x3d0, 0x3df, 0, 0, vga_port_03d0_w );
+			memory_install_read8_handler(0, vga.vga_intf.port_addressspace, vga.vga_intf.port_offset + 0x3b0, vga.vga_intf.port_offset + 0x3bf, 0, 0, vga_port_03b0_r );
+			memory_install_read8_handler(0, vga.vga_intf.port_addressspace, vga.vga_intf.port_offset + 0x3c0, vga.vga_intf.port_offset + 0x3cf, 0, 0, vga_port_03c0_r );
+			memory_install_read8_handler(0, vga.vga_intf.port_addressspace, vga.vga_intf.port_offset + 0x3d0, vga.vga_intf.port_offset + 0x3df, 0, 0, vga_port_03d0_r );
+
+			memory_install_write8_handler(0, vga.vga_intf.port_addressspace, vga.vga_intf.port_offset + 0x3b0, vga.vga_intf.port_offset + 0x3bf, 0, 0, vga_port_03b0_w );
+			memory_install_write8_handler(0, vga.vga_intf.port_addressspace, vga.vga_intf.port_offset + 0x3c0, vga.vga_intf.port_offset + 0x3cf, 0, 0, vga_port_03c0_w );
+			memory_install_write8_handler(0, vga.vga_intf.port_addressspace, vga.vga_intf.port_offset + 0x3d0, vga.vga_intf.port_offset + 0x3df, 0, 0, vga_port_03d0_w );
+			break;
+
+		case 64:
+			memory_install_read64_handler(0, vga.vga_intf.port_addressspace, vga.vga_intf.port_offset + 0x3b0, vga.vga_intf.port_offset + 0x3bf, 0, 0, vga_port64be_03b0_r );
+			memory_install_read64_handler(0, vga.vga_intf.port_addressspace, vga.vga_intf.port_offset + 0x3c0, vga.vga_intf.port_offset + 0x3cf, 0, 0, vga_port64be_03c0_r );
+			memory_install_read64_handler(0, vga.vga_intf.port_addressspace, vga.vga_intf.port_offset + 0x3d0, vga.vga_intf.port_offset + 0x3df, 0, 0, vga_port64be_03d0_r );
+
+			memory_install_write64_handler(0, vga.vga_intf.port_addressspace, vga.vga_intf.port_offset + 0x3b0, vga.vga_intf.port_offset + 0x3bf, 0, 0, vga_port64be_03b0_w );
+			memory_install_write64_handler(0, vga.vga_intf.port_addressspace, vga.vga_intf.port_offset + 0x3c0, vga.vga_intf.port_offset + 0x3cf, 0, 0, vga_port64be_03c0_w );
+			memory_install_write64_handler(0, vga.vga_intf.port_addressspace, vga.vga_intf.port_offset + 0x3d0, vga.vga_intf.port_offset + 0x3df, 0, 0, vga_port64be_03d0_w );
+			break;
+	}		
 
 	pc_vga_reset();
 }
@@ -992,7 +1116,7 @@ static void vga_timer(int param)
 	vga.monitor.retrace=1;
 }
 
-VIDEO_START( ega )
+static VIDEO_START( ega )
 {
 	vga.monitor.get_clock = ega_get_clock;
 	vga.monitor.get_lines = ega_get_crtc_lines;
@@ -1004,7 +1128,11 @@ VIDEO_START( ega )
 	return 0;
 }
 
-VIDEO_START( vga )
+static VIDEO_RESET( ega )
+{
+}
+
+static VIDEO_START( vga )
 {
 	vga.monitor.get_clock=vga_get_clock;
 	vga.monitor.get_lines=vga_get_crtc_lines;
@@ -1016,10 +1144,12 @@ VIDEO_START( vga )
 	return 0;
 }
 
-#define myMIN(a, b) ((a) < (b) ? (a) : (b))
-#define myMAX(a, b) ((a) > (b) ? (a) : (b))
+static VIDEO_RESET( vga )
+{
+	pc_vga_reset();
+}
 
-static void vga_vh_text(struct mame_bitmap *bitmap, struct crtc6845 *crtc)
+static void vga_vh_text(mame_bitmap *bitmap, struct crtc6845 *crtc)
 {
 	UINT8 ch, attr;
 	UINT8 bits;
@@ -1047,7 +1177,7 @@ static void vga_vh_text(struct mame_bitmap *bitmap, struct crtc6845 *crtc)
 			attr = vga.memory[(pos<<2) + 1];
 			font = vga.memory+2+(ch<<(5+2))+FONT1;
 
-			for (h = myMAX(-line, 0); (h < height) && (line+h < myMIN(TEXT_LINES, bitmap->height)); h++)
+			for (h = MAX(-line, 0); (h < height) && (line+h < MIN(TEXT_LINES, bitmap->height)); h++)
 			{
 				bitmapline = (UINT16 *) bitmap->line[line+h];
 				bits = font[h<<2];
@@ -1086,7 +1216,7 @@ static void vga_vh_text(struct mame_bitmap *bitmap, struct crtc6845 *crtc)
 	}
 }
 
-static void vga_vh_ega(struct mame_bitmap *bitmap, struct crtc6845 *crtc)
+static void vga_vh_ega(mame_bitmap *bitmap, struct crtc6845 *crtc)
 {
 	int pos, line, column, c, addr, i;
 	int height = CRTC6845_CHAR_HEIGHT;
@@ -1097,7 +1227,7 @@ static void vga_vh_ega(struct mame_bitmap *bitmap, struct crtc6845 *crtc)
 	for (addr=EGA_START_ADDRESS, pos=0, line=0; line<LINES;
 		 line += height, addr=(addr+EGA_LINE_LENGTH)&0x3ffff)
 	{
-		bitmapline = (UINT16 *) Machine->scrbitmap->line[line];
+		bitmapline = (UINT16 *) bitmap->line[line];
 
 		for (pos=addr, c=0, column=0; column<EGA_COLUMNS; column++, c+=8, pos=(pos+4)&0x3ffff)
 		{
@@ -1125,38 +1255,32 @@ static void vga_vh_ega(struct mame_bitmap *bitmap, struct crtc6845 *crtc)
 			if (line + i >= LINES)
 				break;
 
-			newbitmapline = (UINT16 *) Machine->scrbitmap->line[line+i];
+			newbitmapline = (UINT16 *) bitmap->line[line+i];
 			memcpy(newbitmapline, bitmapline, EGA_COLUMNS * 8 * sizeof(UINT16));
 		}
 	}
 }
 
-static void vga_vh_vga(struct mame_bitmap *bitmap, struct crtc6845 *crtc)
+static void vga_vh_vga(mame_bitmap *bitmap, struct crtc6845 *crtc)
 {
 	int pos, line, column, c, addr;
 	UINT16 *bitmapline;
 
-	for (addr=VGA_START_ADDRESS, line=0; line<LINES; line++, addr+=VGA_LINE_LENGTH)
+	for (addr = VGA_START_ADDRESS, line=0; line<LINES; line++, addr+=VGA_LINE_LENGTH)
 	{
 		bitmapline = (UINT16 *) bitmap->line[line];
+		addr %= vga.svga_intf.vram_size;
+
 		for (pos=addr, c=0, column=0; column<VGA_COLUMNS; column++, c+=8, pos+=0x20)
 		{
-			/*if (*(UINT32*)(vga.dirty+pos)) */
-			{
-				bitmapline[c+0] = vga.memory[pos+0];
-				bitmapline[c+1] = vga.memory[pos+1];
-				bitmapline[c+2] = vga.memory[pos+2];
-				bitmapline[c+3] = vga.memory[pos+3];
-				/**(UINT32*)(vga.dirty+pos)=0; */
-			}
-			/*if (*(UINT32*)(vga.dirty+pos+0x10)) */
-			{
-				bitmapline[c+4] = vga.memory[pos+0x10];
-				bitmapline[c+5] = vga.memory[pos+0x11];
-				bitmapline[c+6] = vga.memory[pos+0x12];
-				bitmapline[c+7] = vga.memory[pos+0x13];
-				/**(UINT32*)(vga.dirty+pos+0x10)=0; */
-			}
+			bitmapline[c+0] = vga.memory[pos+0];
+			bitmapline[c+1] = vga.memory[pos+1];
+			bitmapline[c+2] = vga.memory[pos+2];
+			bitmapline[c+3] = vga.memory[pos+3];
+			bitmapline[c+4] = vga.memory[pos+0x10];
+			bitmapline[c+5] = vga.memory[pos+0x11];
+			bitmapline[c+6] = vga.memory[pos+0x12];
+			bitmapline[c+7] = vga.memory[pos+0x13];
 		}
 	}
 }
@@ -1222,24 +1346,45 @@ static pc_video_update_proc pc_vga_choosevideomode(int *width, int *height, stru
 			}
 		}
 
-		if (!GRAPHIC_MODE)
+		if (vga.svga_intf.choosevideomode)
+			proc = vga.svga_intf.choosevideomode(vga.sequencer.data, vga.crtc.data, vga.gc.data, width, height);
+
+		if (!proc)
 		{
-			proc = vga_vh_text;
-			*height = TEXT_LINES;
-			*width = TEXT_COLUMNS * CHAR_WIDTH;
-		}
-		else if (vga.gc.data[5]&0x40)
-		{
-			proc = vga_vh_vga;
-			*height = LINES;
-			*width = VGA_COLUMNS * 8;
-		}
-		else
-		{
-			proc = vga_vh_ega;
-			*height = LINES;
-			*width = EGA_COLUMNS * 8;
+			if (!GRAPHIC_MODE)
+			{
+				proc = vga_vh_text;
+				*height = TEXT_LINES;
+				*width = TEXT_COLUMNS * CHAR_WIDTH;
+			}
+			else if (vga.gc.data[5]&0x40)
+			{
+				proc = vga_vh_vga;
+				*height = LINES;
+				*width = VGA_COLUMNS * 8;
+			}
+			else
+			{
+				proc = vga_vh_ega;
+				*height = LINES;
+				*width = EGA_COLUMNS * 8;
+			}
 		}
 	}
 	return proc;
 }
+
+
+
+void *pc_vga_memory(void)
+{
+	return vga.memory;
+}
+
+
+
+size_t pc_vga_memory_size(void)
+{
+	return vga.svga_intf.vram_size;
+}
+
