@@ -8,12 +8,15 @@
 #include "vidhrdw/generic.h"
 #include "cpu/z80/z80.h"
 
+#define PRIORITY_BIT		0x1000
+
 UINT8 reg[NUM_OF_REGISTER];
 UINT8 ggCRAM[GG_CRAM_SIZE];
 UINT8 smsCRAM[SMS_CRAM_SIZE];
 UINT8 VRAM[VRAM_SIZE];
 UINT8 *lineCollisionBuffer;
 UINT8 *spriteCache;
+UINT8 reg9copy;
 
 int addr;
 int code;
@@ -29,10 +32,17 @@ UINT8 isSMSCRAMDirty[SMS_CRAM_SIZE];
 int currentLine;
 int lineCountDownCounter;
 int irqState;			/* The status of the IRQ line, as seen by the VDP */
+int y_pixels;			/* 192, 224, 240 */
+int start_blanking;		/* when is the transition from bottom border area to blanking area */
+int start_top_border;		/* when is the transition from blanking area to top border area */
+int max_y_pixels;		/* full range of y counter */
+int vdp_mode;			/* current mode of the VDP: 0,1,2,3,4 */
 
-struct mame_bitmap *prevBitMap;
+mame_bitmap *prevBitMap;
 int prevBitMapSaved;
 
+UINT8 *vcnt_lookup;
+
 /* NTSC 192 lines precalculated return values from the V counter */
 static UINT8 vcnt_ntsc_192[NTSC_Y_PIXELS] = {
 	0x00, 0x01, 0x02, 0x03, 0x04, 0x05, 0x06, 0x07, 0x08, 0x09, 0x0A, 0x0B, 0x0C, 0x0D, 0x0E, 0x0F,
@@ -168,56 +178,94 @@ static UINT8 vcnt_pal_240[PAL_Y_PIXELS] = {
 	0xF0, 0xF1, 0xF2, 0xF3, 0xF4, 0xF5, 0xF6, 0xF7, 0xF8, 0xF9, 0xFA, 0xFB, 0xFC, 0xFD, 0xFE, 0xFF
 };
 
- READ8_HANDLER(sms_vdp_curline_r) {
-	/* Is it NTSC */
-	if (IS_NTSC) {
-		/* must be mode 4 */
-		if (reg[0x00] & 0x04) {
-			if (IS_GG_ANY) {
-				if (reg[0x00] & 0x02) {
-					/* Is it 224-line display */
-					if ((reg[0x01] & 0x10) && !(reg[0x01] & 0x08)) {
-						return vcnt_ntsc_224[currentLine];
-					} else if (!(reg[0x01] & 0x10) && (reg[0x01] & 0x08)) {
-						/* 240-line display */
-						return vcnt_ntsc_240[currentLine];
-					}
-				}
+static void set_display_settings( void ) {
+	int M1, M2, M3, M4;
+	M1 = reg[0x01] & 0x10;
+	M2 = reg[0x00] & 0x02;
+	M3 = reg[0x01] & 0x08;
+	M4 = reg[0x00] & 0x04;
+	y_pixels = 192;
+	if ( M4 ) {
+		/* mode 4 */
+		vdp_mode = 4;
+		if ( M2 ) {
+			/* Is it 224-line display */
+			if ( M1 && ! M3 ) {
+				y_pixels = 224;
+			} else if ( ! M1 && M3 ) {
+				/* 240-line display */
+				y_pixels = 240;
 			}
 		}
-		/* 192-line display */
-		return vcnt_ntsc_192[currentLine];
 	} else {
-		/* It must be PAL */
-		if (reg[0x00] & 0x04) {
-			if (IS_GG_ANY) {
-				if (reg[0x00] & 0x02) {
-					/* Is it 224-line display */
-					if ((reg[0x01] & 0x10) && !(reg[0x01] & 0x08)) {
-						return vcnt_pal_224[currentLine];
-					} else if (!(reg[0x01] & 0x10) && (reg[0x01] & 0x08)) {
-						/* 240-line display */
-						return vcnt_pal_240[currentLine];
-					}
-				}
-			}
+		/* original TMS9918 mode */
+/*		if ( ! M1 && ! M2 && ! M3 ) { */
+/*			vdp_mode = 0; */
+/*		} else */
+/*		if ( M1 && ! M2 && ! M3 ) { */
+/*			vdp_mode = 1; */
+/*		} else */
+		if ( ! M1 && M2 && ! M3 ) {
+			vdp_mode = 2;
+/*		} else */
+/*		if ( ! M1 && ! M2 && M3 ) { */
+/*			vdp_mode = 3; */
+		} else {
+			logerror( "Unknown video mode detected (M1=%c, M2=%c, M3=%c, M4=%c)\n", M1 ? '1' : '0', M2 ? '1' : '0', M3 ? '1' : '0', M4 ? '1' : '0');
 		}
-		/* 192-line display */
-		return vcnt_pal_192[currentLine];
 	}
+	if ( IS_NTSC ) {
+		switch( y_pixels ) {
+		case 192:
+			vcnt_lookup = vcnt_ntsc_192;
+			start_blanking = y_pixels + NTSC_192_BBORDER_Y_PIXELS;
+			break;
+		case 224:
+			vcnt_lookup = vcnt_ntsc_224;
+			start_blanking = y_pixels + NTSC_224_BBORDER_Y_PIXELS;
+			break;
+		case 240:
+			vcnt_lookup = vcnt_ntsc_240;
+			start_blanking = y_pixels + 1;
+			break;
+		}
+		max_y_pixels = NTSC_Y_PIXELS;
+	} else {
+		switch( y_pixels ) {
+		case 192:
+			vcnt_lookup = vcnt_pal_192;
+			start_blanking = y_pixels + PAL_192_BBORDER_Y_PIXELS;
+			break;
+		case 224:
+			vcnt_lookup = vcnt_pal_224;
+			start_blanking = y_pixels + PAL_224_BBORDER_Y_PIXELS;
+			break;
+		case 240:
+			vcnt_lookup = vcnt_pal_240;
+			start_blanking = y_pixels + PAL_240_BBORDER_Y_PIXELS;
+			break;
+		}
+		max_y_pixels = PAL_Y_PIXELS;
+	}
+	start_top_border = start_blanking + 19;
+	if ( ! IS_GAMEGEAR ) {
+		set_visible_area( LBORDER_X_PIXELS, LBORDER_X_PIXELS + 255, TBORDER_Y_PIXELS, TBORDER_Y_PIXELS + y_pixels - 1 );
+	}
+	isCRAMDirty = 1;
+}
+
+ READ8_HANDLER(sms_vdp_curline_r) {
+	return vcnt_lookup[currentLine];
 }
 
 VIDEO_START(sms) {
 	/* Clear RAM */
 	memset(reg, 0, NUM_OF_REGISTER);
 	isCRAMDirty = 1;
-	if (IS_GG_ANY) {
-		memset(ggCRAM, 0, GG_CRAM_SIZE);
-		memset(isGGCRAMDirty, 1, GG_CRAM_SIZE);
-	} else {
-		memset(smsCRAM, 0, SMS_CRAM_SIZE);
-		memset(isSMSCRAMDirty, 1, SMS_CRAM_SIZE);
-	}
+	memset(ggCRAM, 0, GG_CRAM_SIZE);
+	memset(isGGCRAMDirty, 1, GG_CRAM_SIZE);
+	memset(smsCRAM, 0, SMS_CRAM_SIZE);
+	memset(isSMSCRAMDirty, 1, SMS_CRAM_SIZE);
 	memset(VRAM, 0, VRAM_SIZE);
 	reg[0x02] = 0x0E;			/* power up default */
 
@@ -225,19 +273,8 @@ VIDEO_START(sms) {
 	addr = code = pending = latch = buffer = statusReg = \
 	currentLine = lineCountDownCounter = irqState = 0;
 
-	if (IS_NTSC) {
-		lineCollisionBuffer = auto_malloc(NTSC_X_PIXELS);
-		spriteCache = auto_malloc(NTSC_X_PIXELS * 16);
-	} else {
-		lineCollisionBuffer = auto_malloc(PAL_X_PIXELS);
-		spriteCache = auto_malloc(PAL_X_PIXELS * 16);
-	}
-	if (!lineCollisionBuffer) {
-		return (1);
-	}
-	if (!spriteCache) {
-		return (1);
-	}
+	lineCollisionBuffer = auto_malloc(MAX_X_PIXELS);
+	spriteCache = auto_malloc(MAX_X_PIXELS * 16);
 
 	/* Make temp bitmap for rendering */
 	tmpbitmap = auto_bitmap_alloc(Machine->drv->screen_width, Machine->drv->screen_height);
@@ -251,78 +288,33 @@ VIDEO_START(sms) {
 		return (1);
 	}
 
+	set_display_settings();
+
 	return (0);
 }
 
 INTERRUPT_GEN(sms) {
-	static UINT8 irqAtLines[3] = { 0xC1, 0xE1, 0xF1 };
-	int irqAt;
 	int maxLine;
 
 	/* Is it NTSC */
 	if (IS_NTSC) {
 		/* Bump scanline counter */
 		currentLine = (currentLine + 1) % NTSC_Y_PIXELS;
-
-		/* We start a new frame, so reset line count down counter */
-		if (currentLine == 0x00) {
-			lineCountDownCounter = reg[0x0A];
-		}
-
-		/* must be mode 4 */
-		if (reg[0x00] & 0x04) {
-			if (IS_GG_ANY) {
-				if (reg[0x00] & 0x02) {
-					/* Is it 224-line display */
-					if ((reg[0x01] & 0x10) && !(reg[0x01] & 0x08)) {
-						irqAt = 0x01;
-						logerror("mode 4\n");
-					} else if (!(reg[0x01] & 0x10) && (reg[0x01] & 0x08)) {
-						/* 240-line display */
-						irqAt = 0x02;
-					}
-				}
-			}
-		}
-
-		/* 192-line display */
-		irqAt = 0x00;
 	} else {
 		/* It must be PAL */
 		/* Bump scanline counter */
 		currentLine = (currentLine + 1) % PAL_Y_PIXELS;
+	}
+
+	if (currentLine <= y_pixels) {
+		if (currentLine == y_pixels) {
+			statusReg |= STATUS_VINT;
+		}
 
 		/* We start a new frame, so reset line count down counter */
 		if (currentLine == 0x00) {
 			lineCountDownCounter = reg[0x0A];
-		}
-
-		/* must be mode 4 */
-		if (reg[0x00] & 0x04) {
-			if (IS_GG_ANY) {
-				if (reg[0x00] & 0x02) {
-					/* Is it 224-line display */
-					if ((reg[0x01] & 0x10) && !(reg[0x01] & 0x08)) {
-						irqAt = 0x01;
-					} else if (!(reg[0x01] & 0x10) && (reg[0x01] & 0x08)) {
-						/* 240-line display */
-						irqAt = 0x02;
-					}
-				}
-			}
-		}
-
-		/* 192-line display */
-		irqAt = 0x00;
-	}
-
-	if (currentLine <= irqAtLines[irqAt]) {
-		if (currentLine == irqAtLines[irqAt]) {
-			statusReg |= STATUS_VINT;
-		}
-
-		if (currentLine == 0x00) {
-			lineCountDownCounter = reg[0x0A];
+			reg9copy = reg[0x09];
 		}
 
 		if (lineCountDownCounter == 0x00) {
@@ -336,6 +328,10 @@ INTERRUPT_GEN(sms) {
 			irqState = 1;
 			cpunum_set_input_line(0, 0, ASSERT_LINE);
 		}
+
+		if ( currentLine == 112 ) {
+			check_pause_button();
+		}
 	} else {
 		lineCountDownCounter = reg[0x0A];
 
@@ -345,11 +341,11 @@ INTERRUPT_GEN(sms) {
 		}
 	}
 
-	if (!osd_skip_this_frame()) {
+	if (!skip_this_frame()) {
 #ifdef LOG_CURLINE
 		logerror("l %04x, pc: %04x\n", currentLine, activecpu_get_pc());
 #endif
-		if (IS_GG_ANY) {
+		if ( IS_GAMEGEAR ) {
 			if ((currentLine >= Machine->visible_area.min_y) && (currentLine <= Machine->visible_area.max_y)) {
 				sms_update_palette();
 #ifdef MAME_DEBUG
@@ -371,9 +367,9 @@ INTERRUPT_GEN(sms) {
 				sms_update_palette();
 #ifdef MAME_DEBUG
 				if (code_pressed(KEYCODE_T)) {
-					sms_show_tile_line(tmpbitmap, currentLine, 0);
+					sms_show_tile_line(tmpbitmap, currentLine - TBORDER_Y_PIXELS, 0);
 				} else if (code_pressed(KEYCODE_Y)) {
-					sms_show_tile_line(tmpbitmap, currentLine, 1);
+					sms_show_tile_line(tmpbitmap, currentLine - TBORDER_Y_PIXELS, 1);
 				} else {
 #endif
 					sms_refresh_line(tmpbitmap, currentLine);
@@ -414,7 +410,7 @@ INTERRUPT_GEN(sms) {
 	logerror("CTRL read\n");
 #endif
 
-	statusReg &= ~(STATUS_VINT | STATUS_HINT | STATUS_SPRCOL);
+	statusReg &= ~( STATUS_VINT | STATUS_SPROVR | STATUS_SPRCOL | STATUS_HINT );
 
 	if (irqState == 1) {
 		irqState = 0;
@@ -443,14 +439,14 @@ WRITE8_HANDLER(sms_vdp_data_w) {
 		}
 		break;
 		case 0x03: {
-			int address = IS_GG_ANY ? (addr & 0x3F) : (addr & 0x1F);
-			int _index	= IS_GG_ANY ? ((addr & 0x3E) >> 1) : (addr & 0x1F);
+			int address = IS_GAMEGEAR ? (addr & 0x3F) : (addr & 0x1F);
+			int _index	= IS_GAMEGEAR ? ((addr & 0x3E) >> 1) : (addr & 0x1F);
 
 #ifdef LOG_REG
 			logerror("CRAM[%x] = %x\n", address, data);
 #endif
 
-			if (IS_GG_ANY) {
+			if ( IS_GAMEGEAR ) {
 				if (data != ggCRAM[address]) {
 					ggCRAM[address] = data;
 					isGGCRAMDirty[_index] = isCRAMDirty = 1;
@@ -474,13 +470,17 @@ WRITE8_HANDLER(sms_vdp_ctrl_w) {
 
 	if (pending == 0) {
 		latch = data;
+		/* SMS 2 & GG behaviour. Seems like the latched data is passed straight through */
+                /* to the address register. Cosmic Spacehead needs this, among others */
+		addr = ( addr & 0xff00 ) | latch;
 		pending = 1;
 	} else {
 		/* Clear pending write flag */
 		pending = 0;
 
 		code = (data >> 6) & 0x03;
-		addr = ((data & 0x3F) << 8) | latch;
+/*		addr = ((data & 0x3F) << 8) | latch; */
+		addr = ( addr & 0xff ) | ( data << 8 );
 #ifdef LOG_REG
 		logerror("code = %x, addr = %x\n", code, addr);
 #endif
@@ -492,10 +492,15 @@ WRITE8_HANDLER(sms_vdp_ctrl_w) {
 			if (regNum == 0 && latch & 0x02) {
 				logerror("overscan enabled.\n");
 			}
+
+			if ( regNum == 0 || regNum == 1 ) {
+				set_display_settings();
+			}
+
 #ifdef LOG_REG
 			logerror("r%x = %x\n", regNum, latch);
 #endif
-			addr = code = 0;
+			code = 0;
 		} else if (code == 0x00) {
 			buffer = VRAM[(addr & 0x3FFF)];
 			addr += 1;
@@ -504,7 +509,7 @@ WRITE8_HANDLER(sms_vdp_ctrl_w) {
 }
 
 #ifdef MAME_DEBUG
-void sms_show_tile_line(struct mame_bitmap *bitmap, int line, int palletteSelected) {
+void sms_show_tile_line(mame_bitmap *bitmap, int line, int palletteSelected) {
 	int tileColumn, tileRow;
 	int pixelX;
 	int bitPlane0, bitPlane1, bitPlane2, bitPlane3;
@@ -514,7 +519,7 @@ void sms_show_tile_line(struct mame_bitmap *bitmap, int line, int palletteSelect
 	for (tileColumn = 0; tileColumn < 32; tileColumn++) {
 		if ((tileColumn + (32 * tileRow)) > 448) {
 			for (pixelX = 0; pixelX < 8 ; pixelX++) {
-				plot_pixel(bitmap, (tileColumn << 3) + pixelX, line, Machine->pens[BACKDROP_COLOR]);
+				plot_pixel(bitmap, LBORDER_X_PIXELS + (tileColumn << 3) + pixelX, line, Machine->pens[BACKDROP_COLOR]);
 			}
 		} else {
 			bitPlane0 = VRAM[(((tileColumn + (32 * tileRow)) << 5) + ((line & 0x07) << 2)) + 0x00];
@@ -536,79 +541,31 @@ void sms_show_tile_line(struct mame_bitmap *bitmap, int line, int palletteSelect
 					penSelected |= 0x10;
 				}
 
-				plot_pixel(bitmap, (tileColumn << 3) + pixelX, line, Machine->pens[penSelected]);
+				plot_pixel(bitmap, LBORDER_X_PIXELS + (tileColumn << 3) + pixelX, line, Machine->pens[penSelected]);
 			}
 		}
 	}
 }
 #endif
 
-void sms_refresh_line(struct mame_bitmap *bitmap, int line) {
+void sms_refresh_line_mode4(mame_bitmap *bitmap, int line, int pixelPlotY, int pixelOffsetX) {
 	int tileColumn;
 	int xScroll, yScroll, xScrollStartColumn;
 	int spriteIndex;
-	int pixelX, pixelPlotX, pixelPlotY, pixelOffsetX, prioritySelected[33];
+	int pixelX, pixelPlotX, prioritySelected[256];
 	int spriteX, spriteY, spriteLine, spriteTileSelected, spriteHeight;
 	int spriteBuffer[8], spriteBufferCount, spriteBufferIndex;
 	int bitPlane0, bitPlane1, bitPlane2, bitPlane3;
-	UINT16 *nameTable = (UINT16 *) &(VRAM[(((reg[0x02] & 0x0E) << 10) & 0x3800) + ((((line + reg[0x09]) % 224) >> 3) << 6)]);
+	UINT16 *nameTable = (UINT16 *) &(VRAM[(((reg[0x02] & 0x0E) << 10) & 0x3800) + ((((line + reg9copy) % 224) >> 3) << 6)]);
 	UINT8 *spriteTable = (UINT8 *) &(VRAM[(reg[0x05] << 7) & 0x3F00]);
-	struct rectangle rec;
 
-	rec = Machine->visible_area;
-	pixelPlotY = line;
-	pixelOffsetX = 0;
-	if (!(IS_GG_ANY)) {
-		pixelPlotY += (rec.min_y + TOP_192_BORDER);
-		pixelOffsetX = rec.min_x + LBORDER_X_PIXELS;
-	}
-
-	/* Check if display is disabled */
-	if (!(reg[0x01] & 0x40)) {
-		/* set whole line to reg[0x07] color */
-		rec = Machine->visible_area;
-		rec.min_y = rec.max_y = pixelPlotY;
-		fillbitmap(bitmap, Machine->pens[BACKDROP_COLOR], &rec);
-
-		return;
-	}
-
-	/* Only SMS have border */
-	if (!(IS_GG_ANY)) {
-		if (line >= 192 && line < (192 + BOTTOM_192_BORDER)) {
-			/* Draw bottom border */
-			rec = Machine->visible_area;
-			rec.min_y = rec.max_y = pixelPlotY;
-			fillbitmap(bitmap, Machine->pens[BACKDROP_COLOR], &rec);
-
-			return;
-		}
-		if (line >= (192 + BOTTOM_192_BORDER) && line < (192 + BOTTOM_192_BORDER + 19)) {
-			return;
-		}
-		if (line >= (192 + BOTTOM_192_BORDER + 19) && line < (192 + BOTTOM_192_BORDER + 19 + TOP_192_BORDER)) {
-			/* Draw top border */
-			rec = Machine->visible_area;
-			rec.min_y = rec.max_y = line + rec.min_y - (192 + BOTTOM_192_BORDER + 19);
-			fillbitmap(bitmap, Machine->pens[BACKDROP_COLOR], &rec);
-
-			return;
-		}
-		/* Draw left border */
-		rec = Machine->visible_area;
-		rec.min_y = rec.max_y = pixelPlotY;
-		rec.max_x = rec.min_x + LBORDER_X_PIXELS;
-		fillbitmap(bitmap, Machine->pens[BACKDROP_COLOR], &rec);
-		/* Draw right border */
-		rec = Machine->visible_area;
-		rec.min_y = rec.max_y = pixelPlotY;
-		rec.min_x = rec.max_x - RBORDER_X_PIXELS;
-		fillbitmap(bitmap, Machine->pens[BACKDROP_COLOR], &rec);
+	if ( y_pixels != 192 ) {
+		nameTable = (UINT16 *) &(VRAM[(((reg[0x02] & 0x0C) << 10) | 0x0700) + ((((line + reg9copy) % 256) >> 3 ) << 6)]);
 	}
 
 	/* if top 2 rows of screen not affected by horizontal scrolling, then xScroll = 0 */
 	/* else xScroll = reg[0x08] (SMS Only)                                            */
-	if (IS_GG_ANY) {
+	if ( IS_GAMEGEAR ) {
 		xScroll = 0x0100 - reg[0x08];
 	} else {
 		xScroll = (((reg[0x00] & 0x40) && (line < 16)) ? 0 : 0x0100 - reg[0x08]);
@@ -619,15 +576,15 @@ void sms_refresh_line(struct mame_bitmap *bitmap, int line) {
 	/* Draw background layer */
 	for (tileColumn = 0; tileColumn < 33; tileColumn++) {
 		UINT16 tileData;
-		int tileSelected, palletteSelected, horizSelected, vertSelected;
+		int tileSelected, palletteSelected, horizSelected, vertSelected, prioritySelect;
 		int tileLine;
 
 		/* Rightmost 8 columns for SMS (or 2 columns for GG) not affected by */
 		/* vertical scrolling when bit 7 of reg[0x00] is set */
-		if (IS_GG_ANY) {
-			yScroll = (((reg[0x00] & 0x80) && (tileColumn > 29)) ? 0 : (reg[0x09]) % 224);
+		if ( IS_GAMEGEAR ) {
+			yScroll = (((reg[0x00] & 0x80) && (tileColumn > 29)) ? 0 : (reg9copy) % 224);
 		} else {
-			yScroll = (((reg[0x00] & 0x80) && (tileColumn > 23)) ? 0 : (reg[0x09]) % 224);
+			yScroll = (((reg[0x00] & 0x80) && (tileColumn > 23)) ? 0 : (reg9copy) % 224);
 		}
 
 		#ifndef LSB_FIRST
@@ -637,7 +594,7 @@ void sms_refresh_line(struct mame_bitmap *bitmap, int line) {
 		#endif
 
 		tileSelected = (tileData & 0x01FF);
-		prioritySelected[tileColumn] = (tileData >> 12) & 0x01;
+		prioritySelect = tileData & PRIORITY_BIT;
 		palletteSelected = (tileData >> 11) & 0x01;
 		vertSelected = (tileData >> 10) & 0x01;
 		horizSelected = (tileData >> 9) & 0x01;
@@ -674,6 +631,7 @@ void sms_refresh_line(struct mame_bitmap *bitmap, int line) {
 			if (pixelPlotX >= 0 && pixelPlotX < 256) {
 /*				logerror("%x %x\n", pixelPlotX + pixelOffsetX, pixelPlotY); */
 				plot_pixel(bitmap, pixelPlotX + pixelOffsetX, pixelPlotY, Machine->pens[penSelected]);
+				prioritySelected[pixelPlotX] = prioritySelect | ( penSelected & 0x0F );
 			}
 		}
 	}
@@ -685,7 +643,7 @@ void sms_refresh_line(struct mame_bitmap *bitmap, int line) {
 		spriteHeight <<= 1;
 	}
 	spriteBufferCount = 0;
-	for (spriteIndex = 0; (spriteIndex < 64) && (spriteTable[spriteIndex] != 0xD0) && (spriteBufferCount < 8); spriteIndex++) {
+	for (spriteIndex = 0; (spriteIndex < 64) && (spriteTable[spriteIndex] != 0xD0 || y_pixels != 192) && (spriteBufferCount < 9); spriteIndex++) {
 		spriteY = spriteTable[spriteIndex] + 1; /* sprite y position starts at line 1 */
 		if (spriteY > 240) {
 			spriteY -= 256; /* wrap from top if y position is > 240 */
@@ -693,15 +651,18 @@ void sms_refresh_line(struct mame_bitmap *bitmap, int line) {
 		if ((line >= spriteY) && (line < (spriteY + spriteHeight))) {
 			if (spriteBufferCount < 8) {
 				spriteBuffer[spriteBufferCount] = spriteIndex;
-				spriteBufferCount++;
 			} else {
-				/* too many sprites per line */
-				statusReg |= STATUS_HINT;
+				/* Too many sprites per line */
+				statusReg |= STATUS_SPROVR;
 			}
+			spriteBufferCount++;
 		}
 	}
+	if ( spriteBufferCount > 8 ) {
+		spriteBufferCount = 8;
+	}
 	/* Is it NTSC */
-	memset(lineCollisionBuffer, 0, (IS_NTSC) ? NTSC_X_PIXELS : PAL_X_PIXELS);
+	memset(lineCollisionBuffer, 0, MAX_X_PIXELS);
 	spriteBufferCount--;
 	for (spriteBufferIndex = spriteBufferCount; spriteBufferIndex >= 0; spriteBufferIndex--) {
 		spriteIndex = spriteBuffer[spriteBufferIndex];
@@ -745,24 +706,30 @@ void sms_refresh_line(struct mame_bitmap *bitmap, int line) {
 
 			if (reg[0x01] & 0x01) {
 				/* sprite doubling is enabled */
-				pixelPlotX = spriteX + (pixelX << 1) + pixelOffsetX;
-				if (spriteLine < (spriteHeight >> 1)) {
-					spriteCache[pixelPlotX + (((IS_NTSC) ? NTSC_X_PIXELS : PAL_X_PIXELS) * spriteLine)] = penSelected;
+				pixelPlotX = spriteX + (pixelX << 1);
+
+				/* check to prevent going outside of active display area */
+				if ( pixelPlotX > 256 ) {
+					continue;
 				}
 
-				penSelected = pixelPlotX + (((IS_NTSC) ? NTSC_X_PIXELS : PAL_X_PIXELS) * ((spriteLine & 0xFE) >> 1));
+				if (spriteLine < (spriteHeight >> 1)) {
+					spriteCache[pixelPlotX + ( MAX_X_PIXELS * spriteLine)] = penSelected;
+				}
+
+				penSelected = pixelPlotX + (MAX_X_PIXELS * ((spriteLine & 0xFE) >> 1));
 				if (spriteCache[penSelected] == 0x10) {		/* Transparent pallette so skip draw */
 					continue;
 				}
-				if (!prioritySelected[(((xScroll & 0x07) + pixelPlotX - pixelOffsetX) / 8) & 0x1F]) {
-					plot_pixel(bitmap, pixelPlotX, pixelPlotY, Machine->pens[spriteCache[penSelected]]);
-					plot_pixel(bitmap, pixelPlotX + 1, pixelPlotY, Machine->pens[spriteCache[penSelected]]);
+				if ( ! ( prioritySelected[pixelPlotX] & PRIORITY_BIT ) ) {
+					plot_pixel(bitmap, pixelOffsetX + pixelPlotX, pixelPlotY, Machine->pens[spriteCache[penSelected]]);
+					plot_pixel(bitmap, pixelOffsetX + pixelPlotX + 1, pixelPlotY, Machine->pens[spriteCache[penSelected]]);
 				} else {
-					if (read_pixel(bitmap, pixelPlotX, pixelPlotY) == Machine->pens[0x00]) {
-						plot_pixel(bitmap, pixelPlotX, pixelPlotY, Machine->pens[spriteCache[penSelected]]);
+					if ( prioritySelected[pixelPlotX] == PRIORITY_BIT ) {
+						plot_pixel(bitmap, pixelOffsetX + pixelPlotX, pixelPlotY, Machine->pens[spriteCache[penSelected]]);
 					}
-					if (read_pixel(bitmap, pixelPlotX + 1, pixelPlotY) == Machine->pens[0x00]) {
-						plot_pixel(bitmap, pixelPlotX + 1, pixelPlotY, Machine->pens[spriteCache[penSelected]]);
+					if ( prioritySelected[pixelPlotX + 1] == PRIORITY_BIT ) {
+						plot_pixel(bitmap, pixelOffsetX + pixelPlotX + 1, pixelPlotY, Machine->pens[spriteCache[penSelected]]);
 					}
 				}
 				if (lineCollisionBuffer[pixelPlotX] != 1) {
@@ -782,12 +749,18 @@ void sms_refresh_line(struct mame_bitmap *bitmap, int line) {
 					continue;
 				}
 
-				pixelPlotX = spriteX + pixelX + pixelOffsetX;
-				if (!prioritySelected[(((xScroll & 0x07) + pixelPlotX - pixelOffsetX) / 8) & 0x1F]) {
-					plot_pixel(bitmap, pixelPlotX, pixelPlotY, Machine->pens[penSelected]);
+				pixelPlotX = spriteX + pixelX;
+
+				/* check to prevent going outside of active display area */
+				if ( pixelPlotX > 256 ) {
+					continue;
+				}
+
+				if ( ! ( prioritySelected[pixelPlotX] & PRIORITY_BIT ) ) {
+					plot_pixel(bitmap, pixelOffsetX + pixelPlotX, pixelPlotY, Machine->pens[penSelected]);
 				} else {
-					if (read_pixel(bitmap, pixelPlotX, pixelPlotY) == Machine->pens[0x00]) {
-						plot_pixel(bitmap, pixelPlotX, pixelPlotY, Machine->pens[penSelected]);
+					if ( prioritySelected[pixelPlotX] == PRIORITY_BIT ) {
+						plot_pixel(bitmap, pixelOffsetX + pixelPlotX, pixelPlotY, Machine->pens[penSelected]);
 					}
 				}
 				if (lineCollisionBuffer[pixelPlotX] != 1) {
@@ -801,17 +774,225 @@ void sms_refresh_line(struct mame_bitmap *bitmap, int line) {
 	}
 
 	/* Fill column 0 with overscan color from reg[0x07]	 (SMS Only) */
-	if (!IS_GG_ANY) {
+	if ( ! IS_GAMEGEAR ) {
 		if (reg[0x00] & 0x20) {
-			rec = Machine->visible_area;
+			rectangle rec;
 			rec.min_y = rec.max_y = pixelPlotY;
-			rec.min_x += LBORDER_X_PIXELS;
-			rec.max_x = rec.min_x + 8;
+			rec.min_x = LBORDER_X_PIXELS;
+			rec.max_x = rec.min_x + 7;
 			fillbitmap(bitmap, Machine->pens[BACKDROP_COLOR], &rec);
 		}
 	}
 }
 
+void sms_refresh_line_mode2(mame_bitmap *bitmap, int line, int pixelPlotY, int pixelOffsetX) {
+	int tileColumn;
+	int pixelX, pixelPlotX;
+	int spriteHeight, spriteBufferCount, spriteIndex, spriteY, spriteBuffer[4], spriteBufferIndex;
+	UINT8 *nameTable, *colorTable, *patternTable, *spriteTable, *spritePatternTable;
+	int patternMask, colorMask, patternOffset;
+
+	/* Draw background layer */
+	nameTable = VRAM + ( ( reg[0x02] & 0x0F ) << 10 ) + ( ( line >> 3 ) * 32 );
+	colorTable = VRAM + ( ( reg[0x03] & 0x80 ) << 6 );
+	colorMask = ( ( reg[0x03] & 0x7F ) << 3 ) | 0x07;
+	patternTable = VRAM + ( ( reg[0x04] & 0x04 ) << 11 );
+	patternMask = ( ( reg[0x04] & 0x03 ) << 8 ) | 0xFF;
+	patternOffset = ( line & 0xC0 ) << 2;
+	for ( tileColumn = 0; tileColumn < 32; tileColumn++ ) {
+		UINT8 pattern;
+		UINT8 colors;
+		pattern = patternTable[ ( ( ( patternOffset + nameTable[tileColumn] ) & patternMask ) * 8 ) + ( line & 0x07 ) ];
+		colors = colorTable[ ( ( ( patternOffset + nameTable[tileColumn] ) & colorMask ) * 8 ) + ( line & 0x07 ) ];
+		for ( pixelX = 0; pixelX < 8; pixelX++ ) {
+			int penSelected;
+			if ( pattern & ( 1 << ( 7 - pixelX ) ) ) {
+				penSelected = colors >> 4;
+			} else {
+				penSelected = colors & 0x0F;
+			} 
+			if ( ! penSelected ) {
+				penSelected = BACKDROP_COLOR;
+			}
+			pixelPlotX = ( tileColumn << 3 ) + pixelX;
+			plot_pixel( bitmap, pixelPlotX + pixelOffsetX, pixelPlotY, Machine->pens[penSelected] );
+		}
+	}
+
+	/* Draw sprite layer */
+	spriteTable = VRAM + ( ( reg[0x05] & 0x7F ) << 7 );
+	spritePatternTable = VRAM + ( ( reg[0x06] & 0x07 ) << 11 );
+	spriteHeight = ( reg[0x01] & 0x03 ? 16 : 8 ); /* check if either MAG or SI is set */
+	spriteBufferCount = 0;
+	for ( spriteIndex = 0; (spriteIndex < 32*4 ) && ( spriteTable[spriteIndex * 4] != 0xD0 ) && ( spriteBufferCount < 5); spriteIndex+= 4 ) {
+		spriteY = spriteTable[spriteIndex] + 1;
+		if ( spriteY > 240 ) {
+			spriteY -= 256;
+		}
+		if ( ( line >= spriteY ) && ( line < ( spriteY + spriteHeight ) ) ) {
+			if ( spriteBufferCount < 5 ) {
+				spriteBuffer[spriteBufferCount] = spriteIndex;
+			} else {
+				/* Too many sprites per line */
+				statusReg |= STATUS_SPROVR;
+			}
+			spriteBufferCount++;
+		}
+	}
+	if ( spriteBufferCount > 4 ) {
+		spriteBufferCount = 4;
+	}
+	memset( lineCollisionBuffer, 0, MAX_X_PIXELS );
+	spriteBufferCount--;
+	for ( spriteBufferIndex = spriteBufferCount; spriteBufferIndex >= 0; spriteBufferIndex-- ) {
+		int penSelected;
+		int spriteLine, pixelX, spriteX, spriteTileSelected;
+		UINT8 pattern;
+		spriteIndex = spriteBuffer[ spriteBufferIndex ];
+		spriteY = spriteTable[ spriteIndex ] + 1;
+		if ( spriteY > 240 ) {
+			spriteY -= 256;
+		}
+		spriteX = spriteTable[ spriteIndex + 1 ];
+		penSelected = spriteTable[ spriteIndex + 3 ] & 0x0F;
+		if ( spriteTable[ spriteIndex + 3 ] & 0x80 ) {
+			spriteX -= 32;
+		}
+		spriteTileSelected = spriteTable[ spriteIndex + 2 ];
+		spriteLine = line - spriteY;
+		if ( reg[0x01] & 0x01 ) {
+			spriteLine >>= 1;
+		}
+		if ( reg[0x01] & 0x02 ) {
+			spriteTileSelected &= 0xFC;
+			if ( spriteLine > 0x07 ) {
+				spriteTileSelected += 1;
+				spriteLine -= 8;
+			}
+		}
+		pattern = spritePatternTable[ spriteTileSelected * 8 + spriteLine ];
+		for ( pixelX = 0; pixelX < 8; pixelX++ ) {
+			if ( reg[0x01] & 0x01 ) {
+				pixelPlotX = spriteX + pixelX * 2;
+				if ( pixelPlotX < 0 || pixelPlotX > 255 ) {
+					continue;
+				}
+				if ( penSelected && ( pattern & ( 1 << ( 7 - pixelX ) ) ) ) {
+					plot_pixel( bitmap, pixelOffsetX + pixelPlotX, pixelPlotY, Machine->pens[penSelected] );
+					if ( lineCollisionBuffer[pixelPlotX] != 1 ) {
+						lineCollisionBuffer[pixelPlotX] = 1;
+					} else {
+						statusReg |= STATUS_SPRCOL;
+					}
+					plot_pixel( bitmap, pixelOffsetX + pixelPlotX + 1, pixelPlotY, Machine->pens[penSelected] );
+					if ( lineCollisionBuffer[pixelPlotX + 1] != 1 ) {
+						lineCollisionBuffer[pixelPlotX + 1] = 1;
+					} else {
+						statusReg |= STATUS_SPRCOL;
+					}
+				}
+			} else {
+				pixelPlotX = spriteX + pixelX;
+				if ( pixelPlotX < 0 || pixelPlotX > 255 ) {
+					continue;
+				}
+				if ( penSelected && ( pattern & ( 1 << ( 7 - pixelX ) ) ) ) {
+					plot_pixel( bitmap, pixelOffsetX + pixelPlotX, pixelPlotY, Machine->pens[penSelected] );
+					if ( lineCollisionBuffer[pixelPlotX] != 1 ) {
+						lineCollisionBuffer[pixelPlotX] = 1;
+					} else {
+						statusReg |= STATUS_SPRCOL;
+					}
+				}
+			}
+		}
+		if ( reg[0x01] & 0x02 ) {
+			spriteTileSelected += 2;
+			pattern = spritePatternTable[ spriteTileSelected * 8 + spriteLine ];
+			spriteX += 8;
+			for ( pixelX = 0; pixelX < 8; pixelX++ ) {
+				pixelPlotX = spriteX + pixelX;
+				if ( pixelPlotX < 0 || pixelPlotX > 255 ) {
+					continue;
+				}
+				if ( penSelected && ( pattern & ( 1 << ( 7 - pixelX ) ) ) ) {
+					plot_pixel( bitmap, pixelOffsetX + pixelPlotX, pixelPlotY, Machine->pens[penSelected] );
+					if ( lineCollisionBuffer[pixelPlotX] != 1 ) {
+						lineCollisionBuffer[pixelPlotX] = 1;
+					} else {
+						statusReg |= STATUS_SPRCOL;
+					}
+				}
+			}
+		}
+	}
+}
+
+void sms_refresh_line( mame_bitmap *bitmap, int line ) {
+	int pixelPlotY = line;
+	int pixelOffsetX = 0;
+
+	if ( ! IS_GAMEGEAR ) {
+		pixelPlotY += TBORDER_Y_PIXELS;
+		pixelOffsetX = LBORDER_X_PIXELS;
+	}
+
+	/* Check if display is disabled */
+	if ( ! ( reg[0x01] & 0x40 ) ) {
+		rectangle rec;
+		/* set whole line to backdrop color */
+		rec.min_x = 0;
+		rec.max_x = LBORDER_X_PIXELS + 255 + RBORDER_X_PIXELS;
+		rec.min_y = rec.max_y = pixelPlotY;
+		fillbitmap( bitmap, Machine->pens[BACKDROP_COLOR], &rec );
+		return;
+	}
+
+	/* Only SMS has border */
+	if ( ! IS_GAMEGEAR ) {
+		rectangle rec;
+		if ( line >= y_pixels && line < start_blanking ) {
+			/* Bottom border; draw no more than 11 lines */
+			if ( line - y_pixels < 11 ) {
+				rec.min_x = 0;
+				rec.max_x = LBORDER_X_PIXELS + 255 + RBORDER_X_PIXELS;
+				rec.min_y = rec.max_y = pixelPlotY;
+				fillbitmap( bitmap, Machine->pens[BACKDROP_COLOR], &rec );
+			}
+			return;
+		}
+		if ( line >= start_blanking && line < start_top_border ) {
+			return;
+		}
+		if ( line >= start_top_border && line < max_y_pixels ) {
+			/* Top border; draw no more than 11 lines */
+			if ( line - start_top_border < 11 ) {
+				rec.min_x = 0;
+				rec.max_x = LBORDER_X_PIXELS + 255 + RBORDER_X_PIXELS;
+				rec.min_y = rec.max_y = 10 - ( line - start_top_border );
+				fillbitmap( bitmap, Machine->pens[BACKDROP_COLOR], &rec );
+				return;
+			}
+		}
+		/* Draw left border */
+		rec.min_y = rec.max_y = pixelPlotY;
+		rec.min_x = 0;
+		rec.max_x = LBORDER_X_PIXELS - 1;
+		fillbitmap( bitmap, Machine->pens[BACKDROP_COLOR], &rec );
+		/* Draw right border */
+		rec.min_y = rec.max_y = pixelPlotY;
+		rec.min_x = LBORDER_X_PIXELS + 256;
+		rec.max_x = rec.min_x + RBORDER_X_PIXELS - 1;
+		fillbitmap( bitmap, Machine->pens[BACKDROP_COLOR], &rec );
+	}
+
+	if ( vdp_mode == 2 ) {
+		sms_refresh_line_mode2( bitmap, line, pixelPlotY, pixelOffsetX );
+	} else {
+		sms_refresh_line_mode4( bitmap, line, pixelPlotY, pixelOffsetX );
+	}
+}
+
 void sms_update_palette(void) {
 	int i, r, g, b;
 
@@ -821,7 +1002,30 @@ void sms_update_palette(void) {
 	}
 	isCRAMDirty = 0;
 
-	if (IS_GG_ANY) {
+	if ( vdp_mode != 4 ) {
+#ifdef LOG_COLOR
+		logerror( "Switched palette to TMS9918 palette\n" );
+#endif
+		palette_set_color( 0,   0,   0,   0 );
+		palette_set_color( 1,   0,   0,   0 );
+		palette_set_color( 2,  33, 200,  66 );
+		palette_set_color( 3,  94, 220, 120 );
+		palette_set_color( 4,  84,  85, 237 );
+		palette_set_color( 5, 125, 118, 252 );
+		palette_set_color( 6, 212,  82,  77 );
+		palette_set_color( 7,  66, 235, 245 );
+		palette_set_color( 8, 252,  85,  84 );
+		palette_set_color( 9, 255, 121, 120 );
+		palette_set_color(10, 212, 193,  84 );
+		palette_set_color(11, 230, 206, 128 );
+		palette_set_color(12,  33, 176,  59 );
+		palette_set_color(13, 201,  91, 186 );
+		palette_set_color(14, 204, 204, 204 );
+		palette_set_color(15, 255, 255, 255 );
+		return;
+	}
+
+	if ( IS_GAMEGEAR ) {
 		for (i = 0; i < (GG_CRAM_SIZE >> 1); i += 1) {
 			if (isGGCRAMDirty[i] == 1) {
 				isGGCRAMDirty[i] = 0;
