@@ -38,14 +38,14 @@ extern void vic4567_init (int pal, int (*dma_read) (int),
 	memset(&vic2, 0, sizeof(vic2));
 
 	vic2.lines = VIC2_LINES;
-	vic2.vic3=true;
+	vic2.vic3 = TRUE;
 
 	vic2.dma_read = dma_read;
 	vic2.dma_read_color = dma_read_color;
 	vic2.interrupt = irq;
 	vic2.pal = pal;
 	vic2.port_changed = param_port_changed;
-	vic2.on = true;
+	vic2.on = TRUE;
 }
 
 WRITE8_HANDLER ( vic3_port_w )
@@ -176,7 +176,7 @@ static void vic3_drawlines (int first, int last)
 	if (first == last)
 		return;
 	vic2.lastline = last;
-	if (osd_skip_this_frame ())
+	if (skip_this_frame ())
 		return;
 
 	/* top part of display not rastered */
@@ -193,16 +193,8 @@ static void vic3_drawlines (int first, int last)
 
 	if (!SCREENON)
 	{
-/*		if (Machine->color_depth == 8)
-		{
-			for (line = first; (line < last) && (line < vic2.bitmap->height); line++)
-				memset (vic2.bitmap->line[line], Machine->pens[0], vic2.bitmap->width);
-		}
-		else
-*/		{
-			for (line = first; (line < last) && (line < vic2.bitmap->height); line++)
-				memset16 (vic2.bitmap->line[line], Machine->pens[0], vic2.bitmap->width);
-		}
+		for (line = first; (line < last) && (line < vic2.bitmap->height); line++)
+			memset16 (vic2.bitmap->line[line], Machine->pens[0], vic2.bitmap->width);
 		return;
 	}
 	if (COLUMNS40)
@@ -214,18 +206,13 @@ static void vic3_drawlines (int first, int last)
 		end = last;
 	else
 		end = vic2.y_begin + YPOS;
-/*	if (Machine->color_depth == 8)
+
+	for (line = first; line < end; line++)
 	{
-		for (line = first; line < end; line++)
-			memset (vic2.bitmap->line[line], Machine->pens[FRAMECOLOR],
-					vic2.bitmap->width);
-	}
-	else
-*/	{
-		for (line = first; line < end; line++)
-			memset16 (vic2.bitmap->line[line], Machine->pens[FRAMECOLOR],
-					  vic2.bitmap->width);
+		memset16 (vic2.bitmap->line[line], Machine->pens[FRAMECOLOR],
+			vic2.bitmap->width);
 	}
+
 	if (LINES25)
 	{
 		vline = line - vic2.y_begin - YPOS;
@@ -348,41 +335,24 @@ static void vic3_drawlines (int first, int last)
 				memset (vic2.sprites[i].paintedline, 0, sizeof (vic2.sprites[i].paintedline));
 			}
 		}
-/*		if (Machine->color_depth == 8)
+
+		for (i = ybegin; i <= yend; i++)
 		{
-			for (i = ybegin; i <= yend; i++)
-			{
-				memset (vic2.bitmap->line[yoff + i], Machine->pens[FRAMECOLOR], xbegin);
-				memset (vic2.bitmap->line[yoff + i] + xend, Machine->pens[FRAMECOLOR],
-						vic2.bitmap->width - xend);
-			}
-		}
-		else
-*/		{
-			for (i = ybegin; i <= yend; i++)
-			{
-				memset16 (vic2.bitmap->line[yoff + i], Machine->pens[FRAMECOLOR],
-						  xbegin);
-				memset16 ((short *) vic2.bitmap->line[yoff + i] + xend,
-						  Machine->pens[FRAMECOLOR], vic2.bitmap->width - xend);
-			}
+			memset16 (vic2.bitmap->line[yoff + i], Machine->pens[FRAMECOLOR],
+						xbegin);
+			memset16 ((short *) vic2.bitmap->line[yoff + i] + xend,
+						Machine->pens[FRAMECOLOR], vic2.bitmap->width - xend);
 		}
 	}
 	if (last < vic2.bitmap->height)
 		end = last;
 	else
 		end = vic2.bitmap->height;
-/*	if (Machine->color_depth == 8)
+
+	for (; line < end; line++)
 	{
-		for (; line < end; line++)
-			memset (vic2.bitmap->line[line], Machine->pens[FRAMECOLOR],
-					vic2.bitmap->width);
-	}
-	else
-*/	{
-		for (; line < end; line++)
-			memset16 (vic2.bitmap->line[line], Machine->pens[FRAMECOLOR],
-					  vic2.bitmap->width);
+		memset16 (vic2.bitmap->line[line], Machine->pens[FRAMECOLOR],
+			vic2.bitmap->width);
 	}
 }
 
@@ -692,7 +662,7 @@ static void vic3_draw_bitplanes(void)
 #ifndef OPTIMIZE
 	UINT8 colors[8];
 #endif
-	struct rectangle vis;
+	rectangle vis;
 
 	if (VIC3_LINES==400) { /* interlaced! */
 		for ( y1s=0, offset=0; y1s<400; y1s+=16) {
@@ -731,31 +701,32 @@ static void vic3_draw_bitplanes(void)
 		}
 	}
 	if (XPOS>0) {
-		vis.min_x=0;
-		vis.max_x=XPOS-1;
-		vis.min_y=0;
-		vis.max_y=Machine->uiheight-1;
+		vis.min_x = 0;
+		vis.max_x = XPOS-1;
+		vis.min_y = 0;
+		vis.max_y = Machine->visible_area.max_y;
 		fillbitmap(vic2.bitmap, Machine->pens[FRAMECOLOR],&vis);
 	}
 	if (XPOS+VIC3_BITPLANES_WIDTH<Machine->visible_area.max_x) {
-		vis.min_x=XPOS+VIC3_BITPLANES_WIDTH;
-		vis.max_x=Machine->uiwidth-1;
-		vis.min_y=0;
-		vis.max_y=Machine->uiheight-1;
+		vis.min_x = XPOS+VIC3_BITPLANES_WIDTH;
+		vis.max_x = Machine->visible_area.max_x;
+		vis.min_y = 0;
+		vis.max_y = Machine->visible_area.max_y;
 		fillbitmap(vic2.bitmap, Machine->pens[FRAMECOLOR],&vis);
 	}
-	if (YPOS>0) {
-		vis.min_y=0;
-		vis.max_y=YPOS-1;
-		vis.min_x=0;
-		vis.max_x=Machine->uiwidth-1;
+	if (YPOS>0)
+	{
+		vis.min_y = 0;
+		vis.max_y = YPOS-1;
+		vis.min_x = 0;
+		vis.max_x = Machine->visible_area.max_x;
 		fillbitmap(vic2.bitmap, Machine->pens[FRAMECOLOR],&vis);
 	}
 	if (YPOS+VIC3_LINES<Machine->visible_area.max_y) {
-		vis.min_y=YPOS+VIC3_LINES;
-		vis.max_y=Machine->uiheight-1;
-		vis.min_x=0;
-		vis.max_x=Machine->uiwidth-1;
+		vis.min_y = YPOS+VIC3_LINES;
+		vis.max_y = Machine->visible_area.max_y;
+		vis.min_x = 0;
+		vis.max_x = Machine->visible_area.max_x;
 		fillbitmap(vic2.bitmap, Machine->pens[FRAMECOLOR],&vis);
 	}
 }
@@ -803,7 +774,7 @@ INTERRUPT_GEN( vic3_raster_irq )
 			set_visible_area(0,columns+16-1,0, raws+16-1);
 		}
 		if (VIC3_BITPLANES) {
-			if (!osd_skip_this_frame ()) vic3_draw_bitplanes();
+			if (!skip_this_frame ()) vic3_draw_bitplanes();
 		} else {
 			if (vic2.on) vic2_drawlines (vic2.lastline, vic2.lines);
 		}
