@@ -4,10 +4,17 @@
 
     Second generation artwork implementation.
 
+    Copyright (c) 1996-2006, Nicola Salmoria and the MAME Team.
+    Visit http://mamedev.org for licensing and usage restrictions.
+
 *********************************************************************/
 
-#ifndef ARTWORK_H
-#define ARTWORK_H
+#pragma once
+
+#ifndef __ARTWORK_H__
+#define __ARTWORK_H__
+
+#include "mamecore.h"
 
 
 /***************************************************************************
@@ -37,7 +44,7 @@
 ***************************************************************************/
 
 #define OVERLAY_START(name)	\
-	static const struct overlay_piece name[] = {
+	static const artwork_overlay_piece name[] = {
 
 #define OVERLAY_END \
 	{ OVERLAY_TYPE_END } };
@@ -59,21 +66,24 @@
 
 ***************************************************************************/
 
-struct artwork_callbacks
+struct _artwork_callbacks
 {
 	/* provides an additional way to activate artwork system; can be NULL */
-	int (*activate_artwork)(struct osd_create_params *params);
+	int (*activate_artwork)(osd_create_params *params);
 
 	/* function to load an artwork file for a particular driver */
-	mame_file *(*load_artwork)(const struct GameDriver **driver);
+	mame_file *(*load_artwork)(const game_driver **driver);
 };
+typedef struct _artwork_callbacks artwork_callbacks;
 
-struct overlay_piece
+
+struct _artwork_overlay_piece
 {
 	UINT8 type;
 	rgb_t color;
 	float left, top, right, bottom;
 };
+typedef struct _artwork_overlay_piece artwork_overlay_piece;
 
 
 
@@ -83,25 +93,25 @@ struct overlay_piece
 
 ***************************************************************************/
 
-int artwork_create_display(struct osd_create_params *params, UINT32 *rgb_components, const struct artwork_callbacks *callbacks);
-void artwork_update_video_and_audio(struct mame_display *display);
-void artwork_override_screenshot_params(struct mame_bitmap **bitmap, struct rectangle *rect, UINT32 *rgb_components);
+int artwork_create_display(osd_create_params *params, UINT32 *rgb_components, const artwork_callbacks *callbacks);
+void artwork_update_video_and_audio(mame_display *display);
+void artwork_override_screenshot_params(mame_bitmap **bitmap, rectangle *rect, UINT32 *rgb_components);
 
-struct mame_bitmap *artwork_get_ui_bitmap(void);
+mame_bitmap *artwork_get_ui_bitmap(void);
 void artwork_mark_ui_dirty(int minx, int miny, int maxx, int maxy);
 void artwork_get_screensize(int *width, int *height);
 void artwork_enable(int enable);
 
-void artwork_set_overlay(const struct overlay_piece *overlist);
+void artwork_set_overlay(const artwork_overlay_piece *overlist);
 void artwork_show(const char *tag, int show);
 
-mame_file *artwork_load_artwork_file(const struct GameDriver **driver);
+mame_file *artwork_load_artwork_file(const game_driver **driver);
 
 /*
  * Export some variables needed by OSD vector code in xmame.
  */
-const struct rectangle *artwork_get_game_rect(void);
+const rectangle *artwork_get_game_rect(void);
 int artwork_overlay_active(void);
 
-#endif /* ARTWORK_H */
+#endif /* __ARTWORK_H__ */
 
