@@ -1,25 +1,36 @@
-#include "driver.h"
+/***************************************************************************
+
+    audit.c
+
+    ROM set auditing functions.
+
+    Copyright (c) 1996-2006, Nicola Salmoria and the MAME Team.
+    Visit http://mamedev.org for licensing and usage restrictions.
+
+***************************************************************************/
+
 #include <stdarg.h>
-#include <string.h>
+#include "driver.h"
+#include "hash.h"
 #include "audit.h"
 #include "harddisk.h"
 #include "sound/samples.h"
 
-static tAuditRecord *gAudits = NULL;
+static audit_record *audit_records = NULL;
 
-static const struct GameDriver *chd_gamedrv;
+static const game_driver *chd_gamedrv;
 
 /*-------------------------------------------------
     audit_chd_open - interface for opening
     a hard disk image
 -------------------------------------------------*/
 
-struct chd_interface_file *audit_chd_open(const char *filename, const char *mode)
+chd_interface_file *audit_chd_open(const char *filename, const char *mode)
 {
-	const struct GameDriver *drv;
+	const game_driver *drv;
 
 	/* attempt reading up the chain through the parents */
-	for (drv = chd_gamedrv; drv != NULL; drv = drv->clone_of)
+	for (drv = chd_gamedrv; drv != NULL; drv = driver_get_clone(drv))
 	{
 		void* file = mame_fopen(drv->name, filename, FILETYPE_IMAGE, 0);
 
@@ -37,7 +48,7 @@ struct chd_interface_file *audit_chd_open(const char *filename, const char *mode
     a hard disk image
 -------------------------------------------------*/
 
-void audit_chd_close(struct chd_interface_file *file)
+void audit_chd_close(chd_interface_file *file)
 {
 	mame_fclose((mame_file *)file);
 }
@@ -49,7 +60,7 @@ void audit_chd_close(struct chd_interface_file *file)
     from a hard disk image
 -------------------------------------------------*/
 
-UINT32 audit_chd_read(struct chd_interface_file *file, UINT64 offset, UINT32 count, void *buffer)
+UINT32 audit_chd_read(chd_interface_file *file, UINT64 offset, UINT32 count, void *buffer)
 {
 	mame_fseek((mame_file *)file, offset, SEEK_SET);
 	return mame_fread((mame_file *)file, buffer, count);
@@ -62,7 +73,7 @@ UINT32 audit_chd_read(struct chd_interface_file *file, UINT64 offset, UINT32 cou
     to a hard disk image
 -------------------------------------------------*/
 
-UINT32 audit_chd_write(struct chd_interface_file *file, UINT64 offset, UINT32 count, const void *buffer)
+UINT32 audit_chd_write(chd_interface_file *file, UINT64 offset, UINT32 count, const void *buffer)
 {
 	return 0;
 }
@@ -73,14 +84,14 @@ UINT32 audit_chd_write(struct chd_interface_file *file, UINT64 offset, UINT32 co
     the length a hard disk image
 -------------------------------------------------*/
 
-UINT64 audit_chd_length(struct chd_interface_file *file)
+UINT64 audit_chd_length(chd_interface_file *file)
 {
 	return mame_fsize((mame_file *)file);
 }
 
 
 
-static struct chd_interface audit_chd_interface =
+static chd_interface audit_chd_interface =
 {
 	audit_chd_open,
 	audit_chd_close,
@@ -91,9 +102,9 @@ static struct chd_interface audit_chd_interface =
 
 
 /* returns 1 if rom is defined in this set */
-int RomInSet (const struct GameDriver *gamedrv, const char* hash)
+int audit_is_rom_used (const game_driver *gamedrv, const char* hash)
 {
-	const struct RomModule *region, *rom;
+	const rom_entry *region, *rom;
 
 	for (region = rom_first_region(gamedrv); region; region = rom_next_region(region))
 		for (rom = rom_first_file(region); rom; rom = rom_next_file(rom))
@@ -106,13 +117,14 @@ int RomInSet (const struct GameDriver *gamedrv, const char* hash)
 
 
 /* returns nonzero if romset is missing */
-int RomsetMissing (int game)
+int audit_has_missing_roms (int game)
 {
-	const struct GameDriver *gamedrv = drivers[game];
+	const game_driver *gamedrv = drivers[game];
+	const game_driver *clone_of = driver_get_clone(gamedrv);
 
-	if (gamedrv->clone_of)
+	if (clone_of != NULL)
 	{
-		tAuditRecord	*aud;
+		audit_record	*aud;
 		int				count;
 		int 			i;
 
@@ -120,14 +132,14 @@ int RomsetMissing (int game)
         int cloneRomsFound = 0;
         int uniqueRomsFound = 0;
 
-		if ((count = AuditRomSet (game, &aud)) == 0)
+		if ((count = audit_roms (game, &aud)) == 0)
 			return 1;
 
 		if (count == -1) return 0;
 
         /* count number of roms found that are unique to clone */
         for (i = 0; i < count; i++)
-			if (!RomInSet (gamedrv->clone_of, aud[i].exphash))
+			if (!audit_is_rom_used (clone_of, aud[i].exphash))
 			{
 				uniqueRomsFound++;
 				if (aud[i].status != AUD_ROM_NOT_FOUND)
@@ -136,7 +148,7 @@ int RomsetMissing (int game)
 #else
 		int cloneRomsFound = 0;
 
-		if ((count = AuditRomSet (game, &aud)) == 0)
+		if ((count = audit_roms (game, &aud)) == 0)
 			return 1;
 
 		if (count == -1) return 0;
@@ -144,7 +156,7 @@ int RomsetMissing (int game)
 		/* count number of roms found that are unique to clone */
 		for (i = 0; i < count; i++)
 			if (aud[i].status != AUD_ROM_NOT_FOUND)
-				if (!RomInSet (gamedrv->clone_of, aud[i].exphash))
+				if (!audit_is_rom_used (clone_of, aud[i].exphash))
 					cloneRomsFound++;
 #endif
 
@@ -157,31 +169,33 @@ int RomsetMissing (int game)
 /* Fills in an audit record for each rom in the romset. Sets 'audit' to
    point to the list of audit records. Returns total number of roms
    in the romset (same as number of audit records), 0 if romset missing. */
-int AuditRomSet (int game, tAuditRecord **audit)
+int audit_roms (int game, audit_record **audit)
 {
-	const struct RomModule *region, *rom, *chunk;
+	const rom_entry *region, *rom, *chunk;
 	const char *name;
-	const struct GameDriver *gamedrv;
+	const game_driver *gamedrv;
+	const game_driver *clone_of;
 
 	int count = 0;
-	tAuditRecord *aud;
+	audit_record *aud;
 	int	err;
 
-	if (!gAudits)
+	if (!audit_records)
 	{
-		gAudits = (tAuditRecord *)malloc (AUD_MAX_ROMS * sizeof (tAuditRecord));
+		audit_records = (audit_record *)malloc (AUD_MAX_ROMS * sizeof (audit_record));
 
 		/* Make sure the memory is cleared - it's needed by the hashing */
 		/*  engine */
-		memset(gAudits, 0, AUD_MAX_ROMS * sizeof(tAuditRecord));
+		memset(audit_records, 0, AUD_MAX_ROMS * sizeof(audit_record));
 	}
 
-	if (gAudits)
-		*audit = aud = gAudits;
+	if (audit_records)
+		*audit = aud = audit_records;
 	else
 		return 0;
 
 	gamedrv = drivers[game];
+	clone_of = driver_get_clone(gamedrv);
 
 	if (!gamedrv->rom) return -1;
 
@@ -189,8 +203,8 @@ int AuditRomSet (int game, tAuditRecord **audit)
 	if (!mame_faccess (gamedrv->name, FILETYPE_ROM))
 	{
 		/* if the game is a clone, check for parent */
-		if (gamedrv->clone_of == 0 || (gamedrv->clone_of->flags & NOT_A_DRIVER) ||
-				!mame_faccess(gamedrv->clone_of->name,FILETYPE_ROM))
+		if (clone_of == NULL || (clone_of->flags & NOT_A_DRIVER) ||
+				!mame_faccess(clone_of->name,FILETYPE_ROM))
 			return 0;
 	}
 
@@ -199,7 +213,7 @@ int AuditRomSet (int game, tAuditRecord **audit)
 		{
 			if (ROMREGION_ISROMDATA(region))
 			{
-				const struct GameDriver *drv;
+				const game_driver *drv;
 
 				name = ROM_GETNAME(rom);
 				strcpy (aud->rom, name);
@@ -218,7 +232,7 @@ int AuditRomSet (int game, tAuditRecord **audit)
 				do
 				{
 					err = mame_fchecksum(drv->name, name, &aud->length, aud->hash);
-					drv = drv->clone_of;
+					drv = driver_get_clone(drv);
 				} while (err && drv);
 
 				/* spin through ROM_CONTINUEs, totaling length */
@@ -242,12 +256,12 @@ int AuditRomSet (int game, tAuditRecord **audit)
 						/* not found */
 						aud->status = AUD_ROM_NOT_FOUND;
 
-						drv = gamedrv->clone_of;
+						drv = clone_of;
 
 						/* If missing ROM is also present in a parent set, indicate that */
 						while (drv)
 						{
-							if (RomInSet (drv, aud->exphash))
+							if (audit_is_rom_used (drv, aud->exphash))
 							{
 								if (drv->flags & NOT_A_DRIVER)
 								{
@@ -261,7 +275,7 @@ int AuditRomSet (int game, tAuditRecord **audit)
 							/* Walk up the inheritance list. If this ROM is a clone of a set which */
 							/* contains a BIOS that is missing, we can correctly mark it as */
 							/* such. */
-							drv = drv->clone_of;
+							drv = driver_get_clone(drv);
 						}
 					}
 				}
@@ -290,7 +304,7 @@ int AuditRomSet (int game, tAuditRecord **audit)
 			{
 				const UINT8 nullhash[HASH_BUF_SIZE] = { 0 };
 				void *source;
-				struct chd_header header;
+				chd_header header;
 
 				name = ROM_GETNAME(rom);
 				strcpy (aud->rom, name);
@@ -358,7 +372,7 @@ int AuditRomSet (int game, tAuditRecord **audit)
 	return count;
 }
 
-static void VerifyDumpHashData(const char* hash, const char* head, verify_printf_proc verify_printf)
+static void verify_dump_hash_data(const char* hash, const char* head, verify_printf_proc verify_printf)
 {
 	char buf[512];
 
@@ -369,21 +383,22 @@ static void VerifyDumpHashData(const char* hash, const char* head, verify_printf
 
 
 /* Generic function for evaluating a romset. Some platforms may wish to
-   call AuditRomSet() instead and implement their own reporting (like MacMAME). */
-int VerifyRomSet (int game, verify_printf_proc verify_printf)
+   call audit_roms() instead and implement their own reporting (like MacMAME). */
+int audit_verify_roms (int game, verify_printf_proc verify_printf)
 {
-	tAuditRecord			*aud;
+	audit_record			*aud;
 	int						count;
 	int						archive_status = 0;
-	const struct GameDriver *gamedrv = drivers[game];
+	const game_driver *gamedrv = drivers[game];
+	const game_driver *clone_of = driver_get_clone(gamedrv);
 
-	if ((count = AuditRomSet (game, &aud)) == 0)
+	if ((count = audit_roms (game, &aud)) == 0)
 		return NOTFOUND;
 
 	if (count == -1) return CORRECT;
 
 #if 1
-    if (gamedrv->clone_of)
+    if (clone_of != NULL)
     {
         int i;
         int cloneRomsFound = 0;
@@ -391,7 +406,7 @@ int VerifyRomSet (int game, verify_printf_proc verify_printf)
 
         /* count number of roms found that are unique to clone */
         for (i = 0; i < count; i++)
-			if (!RomInSet (gamedrv->clone_of, aud[i].exphash))
+			if (!audit_is_rom_used (clone_of, aud[i].exphash))
 			{
 				uniqueRomsFound++;
 				if (aud[i].status != AUD_ROM_NOT_FOUND)
@@ -404,7 +419,7 @@ int VerifyRomSet (int game, verify_printf_proc verify_printf)
         #endif
     }
 #else
-	if (gamedrv->clone_of)
+	if (clone_of != NULL)
 	{
 		int i;
 		int cloneRomsFound = 0;
@@ -412,7 +427,7 @@ int VerifyRomSet (int game, verify_printf_proc verify_printf)
 		/* count number of roms found that are unique to clone */
 		for (i = 0; i < count; i++)
 			if (aud[i].status != AUD_ROM_NOT_FOUND)
-				if (!RomInSet (gamedrv->clone_of, aud[i].exphash))
+				if (!audit_is_rom_used (clone_of, aud[i].exphash))
 					cloneRomsFound++;
 
                 #ifndef MESS
@@ -432,22 +447,22 @@ int VerifyRomSet (int game, verify_printf_proc verify_printf)
 			case AUD_ROM_NOT_FOUND:
 				verify_printf ("%-8s: %-12s %7d bytes NOT FOUND\n",
 					drivers[game]->name, aud->rom, aud->explength);
-				VerifyDumpHashData(aud->exphash, NULL, verify_printf);
+				verify_dump_hash_data(aud->exphash, NULL, verify_printf);
 				break;
 			case AUD_ROM_NOT_FOUND_PARENT:
 				verify_printf ("%-8s: %-12s %7d bytes NOT FOUND (shared with parent)\n",
 					drivers[game]->name, aud->rom, aud->explength);
-				VerifyDumpHashData(aud->exphash, NULL, verify_printf);
+				verify_dump_hash_data(aud->exphash, NULL, verify_printf);
 				break;
 			case AUD_ROM_NOT_FOUND_BIOS:
 				verify_printf ("%-8s: %-12s %7d bytes NOT FOUND (BIOS)\n",
 					drivers[game]->name, aud->rom, aud->explength);
-				VerifyDumpHashData(aud->exphash, NULL, verify_printf);
+				verify_dump_hash_data(aud->exphash, NULL, verify_printf);
 				break;
 			case AUD_OPTIONAL_ROM_NOT_FOUND:
 				verify_printf ("%-8s: %-12s %7d bytes NOT FOUND BUT OPTIONAL\n",
 					drivers[game]->name, aud->rom, aud->explength);
-				VerifyDumpHashData(aud->exphash, NULL, verify_printf);
+				verify_dump_hash_data(aud->exphash, NULL, verify_printf);
 				break;
 			case AUD_NOT_AVAILABLE:
 				verify_printf ("%-8s: %-12s %7d bytes NOT FOUND - NO GOOD DUMP KNOWN\n",
@@ -460,8 +475,8 @@ int VerifyRomSet (int game, verify_printf_proc verify_printf)
 			case AUD_BAD_CHECKSUM:
 				verify_printf ("%-8s: %-12s %7d bytes INCORRECT CHECKSUM:\n",
 					drivers[game]->name, aud->rom, aud->explength);
-				VerifyDumpHashData(aud->exphash, "EXPECTED: ", verify_printf);
-				VerifyDumpHashData(aud->hash,    "   FOUND: ", verify_printf);
+				verify_dump_hash_data(aud->exphash, "EXPECTED: ", verify_printf);
+				verify_dump_hash_data(aud->hash,    "   FOUND: ", verify_printf);
 				break;
 			case AUD_ROM_NEED_REDUMP:
 				verify_printf ("%-8s: %-12s %7d bytes ROM NEEDS REDUMP\n",
@@ -473,32 +488,32 @@ int VerifyRomSet (int game, verify_printf_proc verify_printf)
 			case AUD_LENGTH_MISMATCH:
 				verify_printf ("%-8s: %-12s %7d bytes INCORRECT LENGTH: %8d\n",
 					drivers[game]->name, aud->rom, aud->explength, aud->length);
-				VerifyDumpHashData(aud->exphash, NULL, verify_printf);
+				verify_dump_hash_data(aud->exphash, NULL, verify_printf);
 				break;
 			case AUD_ROM_GOOD:
 #if 0    /* if you want a full accounting of roms */
 				verify_printf ("%-8s: %-12s %7d bytes ROM GOOD\n",
 					drivers[game]->name, aud->rom, aud->explength);
-				VerifyDumpHashData(aud->hash, NULL, verify_printf);
+				verify_dump_hash_data(aud->hash, NULL, verify_printf);
 #endif
 				break;
 			case AUD_DISK_GOOD:
 #if 0    /* if you want a full accounting of roms */
 				verify_printf ("%-8s: %-12s GOOD\n",
 					drivers[game]->name, aud->rom);
-				VerifyDumpHashData(aud->hash, NULL, verify_printf);
+				verify_dump_hash_data(aud->hash, NULL, verify_printf);
 #endif
 				break;
 			case AUD_DISK_NOT_FOUND:
 				verify_printf ("%-8s: %-12s NOT FOUND\n",
 					drivers[game]->name, aud->rom);
-				VerifyDumpHashData(aud->exphash, NULL, verify_printf);
+				verify_dump_hash_data(aud->exphash, NULL, verify_printf);
 				break;
 			case AUD_DISK_BAD_MD5:
 				verify_printf ("%-8s: %-12s INCORRECT CHECKSUM:\n",
 					drivers[game]->name, aud->rom);
-				VerifyDumpHashData(aud->exphash, "EXPECTED: ", verify_printf);
-				VerifyDumpHashData(aud->hash,    "   FOUND: ", verify_printf);
+				verify_dump_hash_data(aud->exphash, "EXPECTED: ", verify_printf);
+				verify_dump_hash_data(aud->hash,    "   FOUND: ", verify_printf);
 				break;
 			case AUD_DISK_NOT_AVAILABLE:
 				verify_printf ("%-8s: %-12s NO GOOD DUMP KNOWN\n",
@@ -507,7 +522,7 @@ int VerifyRomSet (int game, verify_printf_proc verify_printf)
 			case AUD_DISK_NEED_DUMP:
 				verify_printf ("%-8s: %-12s FOUND BUT NO GOOD DUMP KNOWN\n",
 					drivers[game]->name, aud->rom);
-				VerifyDumpHashData(aud->hash, NULL, verify_printf);
+				verify_dump_hash_data(aud->hash, NULL, verify_printf);
 				break;
 		}
 		aud++;
@@ -525,22 +540,22 @@ int VerifyRomSet (int game, verify_printf_proc verify_printf)
 }
 
 
-static tMissingSample *gMissingSamples = NULL;
+static missing_sample *missing_samples = NULL;
 
 /* Builds a list of every missing sample. Returns total number of missing
    samples, or -1 if no samples were found. Sets audit to point to the
    list of missing samples. */
-int AuditSampleSet (int game, tMissingSample **audit)
+int audit_samples (int game, missing_sample **audit)
 {
-	struct InternalMachineDriver drv;
+	machine_config drv;
 	int skipfirst;
 	mame_file *f;
 	const char **samplenames, *sharedname;
 	int exist;
-	static const struct GameDriver *gamedrv;
+	static const game_driver *gamedrv;
 	int j;
 	int count = 0;
-	tMissingSample *aud;
+	missing_sample *aud;
 
 	gamedrv = drivers[game];
 	expand_machine_driver(gamedrv->drv, &drv);
@@ -583,11 +598,11 @@ int AuditSampleSet (int game, tMissingSample **audit)
 		return -1;
 
 	/* allocate missing samples list (if necessary) */
-	if (!gMissingSamples)
-		gMissingSamples = (tMissingSample *)malloc (AUD_MAX_SAMPLES * sizeof (tMissingSample));
+	if (!missing_samples)
+		missing_samples = (missing_sample *)malloc (AUD_MAX_SAMPLES * sizeof (missing_sample));
 
-	if (gMissingSamples)
-		*audit = aud = gMissingSamples;
+	if (missing_samples)
+		*audit = aud = missing_samples;
 	else
 		return 0;
 
@@ -614,13 +629,13 @@ int AuditSampleSet (int game, tMissingSample **audit)
 
 
 /* Generic function for evaluating a sampleset. Some platforms may wish to
-   call AuditSampleSet() instead and implement their own reporting (like MacMAME). */
-int VerifySampleSet (int game, verify_printf_proc verify_printf)
+   call audit_samples() instead and implement their own reporting (like MacMAME). */
+int audit_verify_samples (int game, verify_printf_proc verify_printf)
 {
-	tMissingSample	*aud;
+	missing_sample	*aud;
 	int				count;
 
-	count = AuditSampleSet (game, &aud);
+	count = audit_samples (game, &aud);
 	if (count==-1)
 		return NOTFOUND;
 	else if (count==0)
