@@ -4,6 +4,9 @@
 
     ROM set auditing functions.
 
+    Copyright (c) 1996-2006, Nicola Salmoria and the MAME Team.
+    Visit http://mamedev.org for licensing and usage restrictions.
+
 ***************************************************************************/
 
 #pragma once
@@ -11,6 +14,8 @@
 #ifndef __AUDIT_H__
 #define __AUDIT_H__
 
+#include "mamecore.h"
+
 /* return values from audit_verify_roms and audit_verify_samples */
 #define CORRECT   		0
 #define NOTFOUND  		1
