@@ -1,20 +1,16 @@
-/*###################################################################################################
-**
-**
-**      dsp32ops.c
-**      Core implementation for the portable DSP32 emulator.
-**      Written by Aaron Giles
-**
-**
-**#################################################################################################*/
+/***************************************************************************
+
+    dsp32ops.c
+    Core implementation for the portable DSP32 emulator.
+    Written by Aaron Giles
+
+***************************************************************************/
 
 
-extern int debug_key_pressed;
 
-
-/*###################################################################################################
-**  COMPILE-TIME OPTIONS
-**#################################################################################################*/
+/***************************************************************************
+    COMPILE-TIME OPTIONS
+***************************************************************************/
 
 /* these defined latencies are a pain to implement, but are necessary */
 #define EMULATE_MEMORY_LATENCY		(1)
@@ -29,9 +25,9 @@ extern int debug_key_pressed;
 
 
 
-/*###################################################################################################
-**  MACROS
-**#################################################################################################*/
+/***************************************************************************
+    MACROS
+***************************************************************************/
 
 #define SET_V_16(a,b,r)		dsp32.vflags = (((a) ^ (b) ^ (r) ^ ((r) >> 1)) << 8)
 #define SET_NZC_16(r)		dsp32.nzcflags = ((r) << 8)
@@ -96,17 +92,17 @@ extern int debug_key_pressed;
 
 
 
-/*###################################################################################################
-**  FORWARD DECLARATIONS
-**#################################################################################################*/
+/***************************************************************************
+    FORWARD DECLARATIONS
+***************************************************************************/
 
-void (*dsp32ops[])(void);
+extern void (*dsp32ops[])(void);
 
 
 
-/*###################################################################################################
-**  TYPEDEFS
-**#################################################################################################*/
+/***************************************************************************
+    TYPEDEFS
+***************************************************************************/
 
 typedef union int_double
 {
@@ -116,9 +112,9 @@ typedef union int_double
 
 
 
-/*###################################################################################################
-**  IMPLEMENTATION
-**#################################################################################################*/
+/***************************************************************************
+    IMPLEMENTATION
+***************************************************************************/
 
 #if 0
 #pragma mark INLINE HELPERS
@@ -131,8 +127,7 @@ static void illegal(void)
 
 static void unimplemented(void)
 {
-	fprintf(stderr, "Unimplemented op @ %06X: %08X (dis=%02X, tbl=%03X)\n", dsp32.PC - 4, OP, OP >> 25, OP >> 21);
-	exit(1);
+    fatalerror("Unimplemented op @ %06X: %08X (dis=%02X, tbl=%03X)", dsp32.PC - 4, OP, OP >> 25, OP >> 21);
 }
 
 
@@ -149,9 +144,9 @@ INLINE void execute_one(void)
 
 
 
-/*###################################################################################################
-**  CAU HELPERS
-**#################################################################################################*/
+/***************************************************************************
+    CAU HELPERS
+***************************************************************************/
 
 #if 0
 #pragma mark -
@@ -291,9 +286,9 @@ INLINE void cau_write_pi_4byte(int pi, UINT32 val)
 
 
 
-/*###################################################################################################
-**  DAU HELPERS
-**#################################################################################################*/
+/***************************************************************************
+    DAU HELPERS
+***************************************************************************/
 
 #if 0
 #pragma mark -
@@ -382,7 +377,7 @@ INLINE void dau_set_val_flags(int aidx, double res)
 	else if (absres > 3.40282e38)
 	{
 		dsp32.VUflags = VFLAGBIT;
-/*      debug_key_pressed = 1; */
+/*      DEBUGGER_BREAK; */
 /*      fprintf(stderr, "Result = %g\n", absres); */
 		res = (res < 0) ? -3.40282e38 : 3.40282e38;
 	}
@@ -427,7 +422,7 @@ INLINE UINT32 double_to_dsp(double val)
 		return 0x00000000;
 	else if (exponent > 255)
 	{
-/*      debug_key_pressed = 1; */
+/*      DEBUGGER_BREAK; */
 /*      fprintf(stderr, "Exponent = %d\n", exponent); */
 		return ((INT32)id.i[BYTE_XOR_BE(0)] >= 0) ? 0x7fffffff : 0x800000ff;
 	}
@@ -444,16 +439,14 @@ INLINE UINT32 double_to_dsp(double val)
 
 static double dau_read_pi_special(int i)
 {
-	fprintf(stderr, "Unimplemented dau_read_pi_special(%d)\n", i);
-	exit(1);
+    fatalerror("Unimplemented dau_read_pi_special(%d)", i);
 	return 0;
 }
 
 
 static void dau_write_pi_special(int i, double val)
 {
-	fprintf(stderr, "Unimplemented dau_write_pi_special(%d)\n", i);
-	exit(1);
+    fatalerror("Unimplemented dau_write_pi_special(%d)", i);
 }
 
 
@@ -615,9 +608,9 @@ INLINE void dau_write_pi_2bytes(int pi, UINT16 val)
 
 
 
-/*###################################################################################################
-**  COMMON CONDITION ROUTINE
-**#################################################################################################*/
+/***************************************************************************
+    COMMON CONDITION ROUTINE
+***************************************************************************/
 
 #if (!ASSUME_UNCONDITIONAL_CAU)
 static int condition(int cond)
@@ -695,17 +688,16 @@ static int condition(int cond)
 		case 46:	/* !ireq2 */
 		case 47:	/* ireq2 */
 		default:
-			fprintf(stderr, "Unimplemented condition: %X\n", cond);
-			exit(1);
+		    fatalerror("Unimplemented condition: %X", cond);
 	}
 }
 #endif
 
 
 
-/*###################################################################################################
-**  CAU BRANCH INSTRUCTION IMPLEMENTATION
-**#################################################################################################*/
+/***************************************************************************
+    CAU BRANCH INSTRUCTION IMPLEMENTATION
+***************************************************************************/
 
 #if 0
 #pragma mark -
@@ -1178,9 +1170,9 @@ static void do_r(void)
 
 
 
-/*###################################################################################################
-**  CAU 16-BIT ARITHMETIC IMPLEMENTATION
-**#################################################################################################*/
+/***************************************************************************
+    CAU 16-BIT ARITHMETIC IMPLEMENTATION
+***************************************************************************/
 
 #if 0
 #pragma mark -
@@ -1521,9 +1513,9 @@ static void test_di(void)
 
 
 
-/*###################################################################################################
-**  CAU 24-BIT ARITHMETIC IMPLEMENTATION
-**#################################################################################################*/
+/***************************************************************************
+    CAU 24-BIT ARITHMETIC IMPLEMENTATION
+***************************************************************************/
 
 #if 0
 #pragma mark -
@@ -1864,9 +1856,9 @@ static void teste_di(void)
 
 
 
-/*###################################################################################################
-**  CAU LOAD/STORE IMPLEMENTATION
-**#################################################################################################*/
+/***************************************************************************
+    CAU LOAD/STORE IMPLEMENTATION
+***************************************************************************/
 
 #if 0
 #pragma mark -
@@ -2051,9 +2043,9 @@ static void load24(void)
 
 
 
-/*###################################################################################################
-**  DAU FORM 1 IMPLEMENTATION
-**#################################################################################################*/
+/***************************************************************************
+    DAU FORM 1 IMPLEMENTATION
+***************************************************************************/
 
 #if 0
 #pragma mark -
@@ -2207,9 +2199,9 @@ static void d1_aMmmr(void)
 
 
 
-/*###################################################################################################
-**  DAU FORM 2 IMPLEMENTATION
-**#################################################################################################*/
+/***************************************************************************
+    DAU FORM 2 IMPLEMENTATION
+***************************************************************************/
 
 #if 0
 #pragma mark -
@@ -2289,9 +2281,9 @@ static void d2_aMmmr(void)
 
 
 
-/*###################################################################################################
-**  DAU FORM 3 IMPLEMENTATION
-**#################################################################################################*/
+/***************************************************************************
+    DAU FORM 3 IMPLEMENTATION
+***************************************************************************/
 
 #if 0
 #pragma mark -
@@ -2371,9 +2363,9 @@ static void d3_aMmmr(void)
 
 
 
-/*###################################################################################################
-**  DAU FORM 4 IMPLEMENTATION
-**#################################################################################################*/
+/***************************************************************************
+    DAU FORM 4 IMPLEMENTATION
+***************************************************************************/
 
 #if 0
 #pragma mark -
@@ -2453,9 +2445,9 @@ static void d4_mmr(void)
 
 
 
-/*###################################################################################################
-**  DAU FORM 5 IMPLEMENTATION
-**#################################################################################################*/
+/***************************************************************************
+    DAU FORM 5 IMPLEMENTATION
+***************************************************************************/
 
 #if 0
 #pragma mark -
@@ -2597,9 +2589,9 @@ static void d5_seed(void)
 
 
 
-/*###################################################################################################
-**  FUNCTION TABLE
-**#################################################################################################*/
+/***************************************************************************
+    FUNCTION TABLE
+***************************************************************************/
 
 #if 0
 #pragma mark -
