@@ -6,13 +6,10 @@
 */
 
 #include <math.h>
-#include <stdio.h>
-#include <string.h>
-#include "cpuintrf.h"
-#include "mamedbg.h"
+#include "debugger.h"
 #include "e132xs.h"
 
-const char *L_REG[] =
+static const char *L_REG[] =
 {
   "L0",  "L1",  "L2",  "L3",  "L4",  "L5",  "L6",  "L7",  "L8",  "L9",
   "L10", "L11", "L12", "L13", "L14", "L15", "L16", "L17", "L18", "L19",
@@ -23,7 +20,7 @@ const char *L_REG[] =
   "L60", "L61", "L62", "L63"
 };
 
-const char *G_REG[] =
+static const char *G_REG[] =
 {
   "PC",  "SR",  "FER", "G03", "G04", "G05", "G06", "G07", "G08", "G09",
   "G10", "G11", "G12", "G13", "G14", "G15", "G16", "G17", "SP",  "UB",
@@ -31,7 +28,7 @@ const char *G_REG[] =
   "G30", "G31"
 };
 
-const char *SETxx[] =
+static const char *SETxx[] =
 {
   "SETADR",   "Reserved", "SET1",   "SET0",     "SETLE",  "SETGT",  "SETLT",  "SETGE",
   "SETSE",    "SETHT",    "SETST",  "SETHE",    "SETE",   "SETNE",  "SETV",   "SETNV",
@@ -49,13 +46,13 @@ const char *SETxx[] =
 
 static int size, global_fp;
 
-void LL_format(char *source, char *dest, UINT16 op)
+static void LL_format(char *source, char *dest, UINT16 op)
 {
 	strcpy(source, L_REG[(SOURCECODE(op)+global_fp)%64]);
 	strcpy(dest, L_REG[(DESTCODE(op)+global_fp)%64]);
 }
 
-void LR_format(char *source, char *dest, UINT16 op)
+static void LR_format(char *source, char *dest, UINT16 op)
 {
 	if( SOURCEBIT(op) )
 	{
@@ -69,7 +66,7 @@ void LR_format(char *source, char *dest, UINT16 op)
 	strcpy(dest, L_REG[(DESTCODE(op)+global_fp)%64]);
 }
 
-void RR_format(char *source, char *dest, UINT16 op, unsigned h_flag)
+static void RR_format(char *source, char *dest, UINT16 op, unsigned h_flag)
 {
 	if( SOURCEBIT(op) )
 	{
@@ -90,7 +87,7 @@ void RR_format(char *source, char *dest, UINT16 op, unsigned h_flag)
 	}
 }
 
-UINT32 LRconst_format(char *source, char *dest, UINT16 op, unsigned *pc)
+static UINT32 LRconst_format(char *source, char *dest, UINT16 op, unsigned *pc)
 {
 	UINT16 next_op;
 	UINT32 const_val;
@@ -140,7 +137,7 @@ UINT32 LRconst_format(char *source, char *dest, UINT16 op, unsigned *pc)
 	return const_val;
 }
 
-UINT32 RRconst_format(char *source, char *dest, UINT16 op, unsigned *pc)
+static UINT32 RRconst_format(char *source, char *dest, UINT16 op, unsigned *pc)
 {
 	UINT16 next_op;
 	UINT32 const_val;
@@ -197,7 +194,7 @@ UINT32 RRconst_format(char *source, char *dest, UINT16 op, unsigned *pc)
 	return const_val;
 }
 
-INT32 Rimm_format(char *dest, UINT16 op, unsigned *pc, unsigned h_flag)
+static INT32 Rimm_format(char *dest, UINT16 op, unsigned *pc, unsigned h_flag)
 {
 	UINT16 imm1, imm2;
 	INT32 ret;
@@ -285,14 +282,14 @@ INT32 Rimm_format(char *dest, UINT16 op, unsigned *pc, unsigned h_flag)
 	}
 }
 
-UINT8 Ln_format(char *dest, UINT16 op)
+static UINT8 Ln_format(char *dest, UINT16 op)
 {
 	strcpy(dest, L_REG[(DESTCODE(op)+global_fp)%64]);
 
 	return N_VALUE(op);
 }
 
-UINT8 Rn_format(char *dest, UINT16 op)
+static UINT8 Rn_format(char *dest, UINT16 op)
 {
 	if( DESTBIT(op) )
 	{
@@ -306,7 +303,7 @@ UINT8 Rn_format(char *dest, UINT16 op)
 	return N_VALUE(op);
 }
 
-INT32 PCrel_format(UINT16 op, unsigned pc)
+static INT32 PCrel_format(UINT16 op, unsigned pc)
 {
 	INT32 ret;
 
@@ -338,7 +335,7 @@ INT32 PCrel_format(UINT16 op, unsigned pc)
 	return (pc + ret);
 }
 
-UINT32 RRdis_format(char *source, char *dest, UINT16 op, UINT16 next_op, unsigned pc)
+static UINT32 RRdis_format(char *source, char *dest, UINT16 op, UINT16 next_op, unsigned pc)
 {
 	UINT32 ret;
 
