@@ -7,6 +7,8 @@
 #ifndef _H83002_H_
 #define _H83002_H_
 
+#include "cpuintrf.h"
+
 #define IFLAG  0x80
 #define UIFLAG 0x40
 #define HFLAG  0x20
@@ -55,14 +57,14 @@ enum
 	H8_PORTB,	/* 6 */
 
 	/* analog inputs */
-	H8_ADC_0_L = 0x10,
-	H8_ADC_0_H,
-	H8_ADC_1_L,
+	H8_ADC_0_H = 0x10,
+	H8_ADC_0_L,
 	H8_ADC_1_H,
-	H8_ADC_2_L,
+	H8_ADC_1_L,
 	H8_ADC_2_H,
-	H8_ADC_3_L,
+	H8_ADC_2_L,
 	H8_ADC_3_H,
+	H8_ADC_3_L,
 
 	/* serial ports */
 	H8_SERIAL_A = 0x20,
