@@ -34,11 +34,8 @@
  * Jeffery L. Post
  *****************************************************************************/
 
-#include <stdio.h>
-
-#ifdef MAME_DEBUG
-#include "driver.h"
-#include "mamedbg.h"
+#include "debugger.h"
+#include "debug/eainfo.h"
 #include "i8051.h"
 
 #define SHOW_MEMORY_NAMES	1
@@ -167,7 +164,7 @@ static const char regbank[][6] = {
     "rb3r4",  "rb3r5",  "rb3r6",  "rb3r7"
 };
 
-const char *get_data_address( UINT8 arg )
+static const char *get_data_address( UINT8 arg )
 {
 	const char *sym;
 	static char buffer[8][63+1];
@@ -189,7 +186,7 @@ const char *get_data_address( UINT8 arg )
 	return buffer[which];
 }
 
-const char *get_bit_address( UINT8 arg )
+static const char *get_bit_address( UINT8 arg )
 {
 	const char *sym;
 	static char buffer[8][63+1];
@@ -215,7 +212,7 @@ const char *get_bit_address( UINT8 arg )
 
 /*Just display the actual memory address for data & bit address access*/
 
-const char *get_data_address( UINT8 arg )
+static const char *get_data_address( UINT8 arg )
 {
 	const char *sym;
 	static char buffer[8][63+1];
@@ -226,7 +223,7 @@ const char *get_data_address( UINT8 arg )
 	return buffer[which];
 }
 
-const char *get_bit_address( UINT8 arg )
+static const char *get_bit_address( UINT8 arg )
 {
 	const char *sym;
 	static char buffer[8][63+1];
@@ -1151,5 +1148,3 @@ unsigned Dasm8051(char *dst, unsigned pc)
     }
 	return PC - pc;
 }
-
-#endif
