@@ -1,49 +1,47 @@
 /*****************************************************************************
  *
- *	 8085dasm.c
- *	 Portable I8085A disassembler
+ *   8085dasm.c
+ *   Portable I8085A disassembler
  *
  *   Copyright (C) 1998,1999,2000 Juergen Buchmueller, all rights reserved.
- *	 You can contact me at juergen@mame.net or pullmoll@stop1984.com
+ *   You can contact me at juergen@mame.net or pullmoll@stop1984.com
  *
  *   - This source code is released as freeware for non-commercial purposes
  *     as part of the M.A.M.E. (Multiple Arcade Machine Emulator) project.
- *	   The licensing terms of MAME apply to this piece of code for the MAME
- *	   project and derviative works, as defined by the MAME license. You
- *	   may opt to make modifications, improvements or derivative works under
- *	   that same conditions, and the MAME project may opt to keep
- *	   modifications, improvements or derivatives under their terms exclusively.
+ *     The licensing terms of MAME apply to this piece of code for the MAME
+ *     project and derviative works, as defined by the MAME license. You
+ *     may opt to make modifications, improvements or derivative works under
+ *     that same conditions, and the MAME project may opt to keep
+ *     modifications, improvements or derivatives under their terms exclusively.
  *
- *	 - Alternatively you can choose to apply the terms of the "GPL" (see
+ *   - Alternatively you can choose to apply the terms of the "GPL" (see
  *     below) to this - and only this - piece of code or your derivative works.
- *	   Note that in no case your choice can have any impact on any other
- *	   source code of the MAME project, or binary, or executable, be it closely
- *	   or losely related to this piece of code.
+ *     Note that in no case your choice can have any impact on any other
+ *     source code of the MAME project, or binary, or executable, be it closely
+ *     or losely related to this piece of code.
  *
- *	-  At your choice you are also free to remove either licensing terms from
- *	   this file and continue to use it under only one of the two licenses. Do this
- *	   if you think that licenses are not compatible (enough) for you, or if you
- *	   consider either license 'too restrictive' or 'too free'.
+ *  -  At your choice you are also free to remove either licensing terms from
+ *     this file and continue to use it under only one of the two licenses. Do this
+ *     if you think that licenses are not compatible (enough) for you, or if you
+ *     consider either license 'too restrictive' or 'too free'.
  *
- *	-  GPL (GNU General Public License)
- *	   This program is free software; you can redistribute it and/or
- *	   modify it under the terms of the GNU General Public License
- *	   as published by the Free Software Foundation; either version 2
- *	   of the License, or (at your option) any later version.
+ *  -  GPL (GNU General Public License)
+ *     This program is free software; you can redistribute it and/or
+ *     modify it under the terms of the GNU General Public License
+ *     as published by the Free Software Foundation; either version 2
+ *     of the License, or (at your option) any later version.
  *
- *	   This program is distributed in the hope that it will be useful,
- *	   but WITHOUT ANY WARRANTY; without even the implied warranty of
- *	   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *	   GNU General Public License for more details.
+ *     This program is distributed in the hope that it will be useful,
+ *     but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *     GNU General Public License for more details.
  *
- *	   You should have received a copy of the GNU General Public License
- *	   along with this program; if not, write to the Free Software
- *	   Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+ *     You should have received a copy of the GNU General Public License
+ *     along with this program; if not, write to the Free Software
+ *     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
  *
  *****************************************************************************/
 
-#include <stdio.h>
-#include "osd_cpu.h"
 #include "memory.h"
 
 /* 8080/8085A mnemonics were more irritation than information
@@ -543,19 +541,19 @@ unsigned Dasm8085(char *buff, unsigned pc)
 		case 0xdd: sprintf (buff,"jnx  $%04x (*)", ARGW(pc)); pc+=2; break;
 		case 0xde: sprintf (buff,"sbi  $%02x", ARG(pc)); pc++;       break;
 		case 0xdf: sprintf (buff,"rst  3");                          break;
-		case 0xe0: sprintf (buff,"rpe");                             break;
+		case 0xe0: sprintf (buff,"rpo");                             break;
 		case 0xe1: sprintf (buff,"pop  h");                          break;
 		case 0xe2: sprintf (buff,"jpo  $%04x", ARGW(pc)); pc+=2;     break;
 		case 0xe3: sprintf (buff,"xthl");                            break;
-		case 0xe4: sprintf (buff,"cpe  $%04x", ARGW(pc)); pc+=2;     break;
+		case 0xe4: sprintf (buff,"cpo  $%04x", ARGW(pc)); pc+=2;     break;
 		case 0xe5: sprintf (buff,"push h");                          break;
 		case 0xe6: sprintf (buff,"ani  $%02x", ARG(pc)); pc++;       break;
 		case 0xe7: sprintf (buff,"rst  4");                          break;
-		case 0xe8: sprintf (buff,"rpo");                             break;
+		case 0xe8: sprintf (buff,"rpe");                             break;
 		case 0xe9: sprintf (buff,"pchl");                            break;
 		case 0xea: sprintf (buff,"jpe  $%04x", ARGW(pc)); pc+=2;     break;
 		case 0xeb: sprintf (buff,"xchg");                            break;
-		case 0xec: sprintf (buff,"cpo  $%04x", ARGW(pc)); pc+=2;     break;
+		case 0xec: sprintf (buff,"cpe  $%04x", ARGW(pc)); pc+=2;     break;
 		case 0xed: sprintf (buff,"lhlx d (*)");                      break;
 		case 0xee: sprintf (buff,"xri  $%02x", ARG(pc)); pc++;       break;
 		case 0xef: sprintf (buff,"rst  5");                          break;
