@@ -1,12 +1,9 @@
 /*
-	Intel i960 disassembler
+    Intel i960 disassembler
 
-	By Farfetch'd and R. Belmont
+    By Farfetch'd and R. Belmont
 */
 
-#include <stdio.h>
-#include <string.h>
-#include "driver.h"
 #include "i960.h"
 #include "i960dis.h"
 
@@ -17,7 +14,7 @@ typedef struct
 } mnemonic_t;
 
 
-mnemonic_t mnemonic[256] = {
+static const mnemonic_t mnemonic[256] = {
 	{ "?", 0 }, { "?", 0 }, { "?", 0 }, { "?", 0 }, { "?", 0 }, { "?", 0 }, { "?", 0 }, { "?", 0 }, /* 00 */
 	{ "b", 8 }, { "call", 8 }, { "ret", 9 }, { "bal", 8 }, { "?", 0 }, { "?", 0 }, { "?", 0 }, { "?", 0 },
 
@@ -67,7 +64,7 @@ mnemonic_t mnemonic[256] = {
 	{ "?", 0 }, { "?", 0 }, { "?", 0 }, { "?", 0 }, { "?", 0 }, { "?", 0 }, { "?", 0 }, { "?", 0 }
 };
 
-mnemonic_t mnem_reg[100] =
+static const mnemonic_t mnem_reg[100] =
 {
 	{ "notbit", 0x580 }, { "and", 0x581 }, { "andnot", 0x582 }, { "setbit", 0x583 }, { "notand",0x584 },
 	{ "xor", 0x586 }, { "or", 0x587 }, { "nor", 0x588 }, { "xnor",0x589 }, { "not",0x58a },
@@ -82,9 +79,9 @@ mnemonic_t mnem_reg[100] =
 	{ "modify",0x650 }, { "extract",0x651 }, { "modtc",0x654 }, { "modpc",0x655 },
 	{ "emul",0x670 }, { "ediv",0x671 },
 	{ "atanr",0x680 }, { "logepr", 0x681 }, { "logr", 0x682 }, { "remr", 0x683 }, { "cmpor", 0x684 }, { "cmpr", 0x685 }, { "sqrtr", 0x688 },
-	{ "expr", 0x689 }, { "logbnr", 0x68a }, { "roundr", 0x68b }, { "sinr", 0x68c }, { "cosr", 0x68d }, { "tanr", 0x68e }, { "classr", 0x68f }, 
+	{ "expr", 0x689 }, { "logbnr", 0x68a }, { "roundr", 0x68b }, { "sinr", 0x68c }, { "cosr", 0x68d }, { "tanr", 0x68e }, { "classr", 0x68f },
 	{ "atanrl",0x690 }, { "logeprl", 0x691 }, { "logrl", 0x692 }, { "remrl", 0x693 }, { "cmporl", 0x694 }, { "cmprl", 0x695 }, { "sqrtrl", 0x698 },
-	{ "exprl", 0x699 }, { "logbnrl", 0x69a }, { "roundrl", 0x69b }, { "sinrl", 0x69c }, { "cosrl", 0x69d }, { "tanrl", 0x69e }, { "classrl", 0x69f }, 
+	{ "exprl", 0x699 }, { "logbnrl", 0x69a }, { "roundrl", 0x69b }, { "sinrl", 0x69c }, { "cosrl", 0x69d }, { "tanrl", 0x69e }, { "classrl", 0x69f },
 	{ "cvtri", 0x6c0 }, { "cvtril", 0x6c1 }, { "cvtzri", 0x6c2 }, { "cvtzril", 0x6c3 }, { "movr", 0x6c9 },
 	{ "movrl", 0x6d9 },
 	{ "movre", 0x6e1 }, { "cpysre", 0x6e2 }, { "cpyrsre", 0x6e3 },
@@ -93,7 +90,7 @@ mnemonic_t mnem_reg[100] =
 	{ "ending_code",0 }
 };
 
-const char *regnames[32] =
+static const char *regnames[32] =
 {
 	"pfp","sp","rip","r3", "r4","r5","r6","r7", "r8","r9","r10","r11", "r12","r13","r14","r15",
 	"g0","g1","g2","g3", "g4","g5","g6","g7", "g8","g9","g10","g11", "g12","g13","g14","fp",
@@ -124,7 +121,7 @@ const char *regnames[32] =
 #define COBRSRC1 ((iCode >> 19) & 0x1f)
 #define COBRSRC2 ((iCode >> 14) & 0x1f)
 
-char *dis_decode_reg(unsigned long iCode, char* tmpStr,unsigned char cnt)
+static char *dis_decode_reg(unsigned long iCode, char* tmpStr,unsigned char cnt)
 {
 	char src1[10];
 	char src2[10];
