@@ -1,5 +1,5 @@
 /*
-    Mitsubishi M37710 CPU Emulator
+    Mitsubishi M37702/37710 CPU Emulator
 
     The 7700 series is based on the WDC 65C816 core, with the following
     notable changes:
@@ -22,6 +22,10 @@
       0x42 when used before an instruction involving the A accumulator makes
       it use the B accumulator instead.  0x89 adds multiply and divide
       opcodes, which the real 65816 doesn't have.
+    - The 65C816 preserves the upper 8 bits of A when in 8-bit M mode, but
+      not the upper 8 bits of X or Y when in 8-bit X.  The 7700 preserves
+      the top bits of all registers in all modes (code in the C74 BIOS
+      starting at d881 requires this!).
 
     The various 7700 series models differ primarily by their on board
     peripherals.  The 7750 and later models do include some additional
@@ -42,13 +46,12 @@
     - v1.0  RB  First version, basic operation OK, timers not complete
     - v1.1  RB  Data bus is 16-bit, dozens of bugfixes to IRQs, opcodes,
                     and opcode mapping.  New opcodes added, internal timers added.
+    - v1.2  RB  Fixed execution outside of bank 0, fixed LDM outside of bank 0,
+                fixed so top 8 bits of X & Y are preserved while in 8-bit mode,
+        added save state support.
 */
 
-#include "cpuintrf.h"
-#include "memory.h"
-#include "driver.h"
-#include "state.h"
-#include "mamedbg.h"
+#include "debugger.h"
 #include "m37710cm.h"
 
 #define M37710_DEBUG	(0)	/* enables verbose logging for peripherals, etc. */
@@ -96,23 +99,23 @@ int m37710_irq_levels[M37710_LINE_MAX] =
 
 static int m37710_irq_vectors[M37710_LINE_MAX] =
 {
-	/* maskable */
-	0xffd6, /* A-D converter */
-	0xffd8, /* UART1 transmit */
-	0xffda, /* UART1 receive */
-	0xffdc, /* UART0 transmit */
-	0xffde,	/* UART0 receive */
-	0xffe0, /* Timer B2 */
-	0xffe2, /* Timer B1 */
-	0xffe4, /* Timer B0 */
-	0xffe6, /* Timer A4 */
-	0xffe8, /* Timer A3 */
-	0xffea, /* Timer A2 */
-	0xffec, /* Timer A1 */
-	0xffee, /* Timer A0 */
-	0xfff0, /* external INT2 pin */
-	0xfff2, /* external INT1 pin */
-	0xfff4, /* external INT0 pin */
+	/* maskable          C74 */
+	0xffd6, /* A-D converter     c68b */
+	0xffd8, /* UART1 transmit    c68e */
+	0xffda, /* UART1 receive     c691 */
+	0xffdc, /* UART0 transmit    c694 */
+	0xffde,	/* UART0 receive     c697 */
+	0xffe0, /* Timer B2      c69a */
+	0xffe2, /* Timer B1      c69d */
+	0xffe4, /* Timer B0      c6a0 */
+	0xffe6, /* Timer A4      c6a3 */
+	0xffe8, /* Timer A3      c6a6 */
+	0xffea, /* Timer A2      c6a9 */
+	0xffec, /* Timer A1      c6ac */
+	0xffee, /* Timer A0      c6af */
+	0xfff0, /* external INT2 pin c6b2 */
+	0xfff2, /* external INT1 pin c6b5 */
+	0xfff4, /* external INT0 pin c6b8 */
 
 	/* non-maskable */
 	0xfff6, /* watchdog timer */
@@ -132,16 +135,16 @@ static unsigned char m37710i_register_layout[] =
 /* Layout of the MAME debugger windows x,y,w,h */
 static unsigned char m37710i_window_layout[] = {
 	 0, 0,80, 4,	/* register window (top rows) */
-	 0, 5,34,16,	/* disassembler window (left colums) */
-	35, 5,50, 7,	/* memory #1 window (right, upper middle) */
-	35,14,50, 8,	/* memory #2 window (right, lower middle) */
+	 0, 5,29,16,	/* disassembler window (left colums) */
+	30, 5,50, 7,	/* memory #1 window (right, upper middle) */
+	30,14,50, 8,	/* memory #2 window (right, lower middle) */
 	 0,23,80, 1,	/* command line window (bottom rows) */
 };
 
 /* M37710 internal peripherals */
 
 #if M37710_DEBUG
-static char *m37710_rnames[128] =
+static const char *m37710_rnames[128] =
 {
 	"",
 	"",
@@ -159,7 +162,7 @@ static char *m37710_rnames[128] =
 	"Port P5 dir reg",
 	"Port P6 reg",
 	"Port P7 reg",
-	"Port P6 dir reg",
+	"Port P6 dir reg",	/* 16 */
 	"Port P7 dir reg",
 	"Port P8 reg",
 	"",
@@ -175,7 +178,7 @@ static char *m37710_rnames[128] =
 	"",
 	"A/D control reg",
 	"A/D sweep pin select",
-	"A/D 0",
+	"A/D 0",		/* 32 (0x20) */
 	"",
 	"A/D 1",
 	"",
@@ -191,15 +194,15 @@ static char *m37710_rnames[128] =
 	"",
 	"A/D 7",
 	"",
-	"UART0 transmit/recv mode",
-	"UART0 baud rate",
-	"UART0 transmit buf L",
-	"UART0 transmit buf H",
-	"UART0 transmit/recv ctrl 0",
-	"UART0 transmit/recv ctrl 1",
-	"UART0 recv buf L",
-	"UART0 recv buf H",
-	"UART1 transmit/recv mode",
+	"UART0 transmit/recv mode", 	/* 48 (0x30) */
+	"UART0 baud rate",	     	/* 0x31 */
+	"UART0 transmit buf L",		/* 0x32 */
+	"UART0 transmit buf H",		/* 0x33 */
+	"UART0 transmit/recv ctrl 0",	/* 0x34 */
+	"UART0 transmit/recv ctrl 1",	/* 0x35 */
+	"UART0 recv buf L",		/* 0x36 */
+	"UART0 recv buf H",		/* 0x37 */
+	"UART1 transmit/recv mode",	/* 0x38 */
 	"UART1 baud rate",
 	"UART1 transmit buf L",
 	"UART1 transmit buf H",
@@ -273,74 +276,98 @@ static char *m37710_rnames[128] =
 	"INT2 IRQ ctrl",
 };
 
-static char *m37710_tnames[8] =
+static const char *m37710_tnames[8] =
 {
 	"A0", "A1", "A2", "A3", "A4", "B0", "B1", "B2"
 };
 #endif
 
-static void m37710_timer_a0_cb(int num)
+static void m37710_timer_a0_cb(int cpunum)
 {
-	timer_adjust(m37710i_cpu.timers[0], TIME_IN_HZ(m37710i_cpu.reload[0]), 0, 0);
+	cpuintrf_push_context(cpunum);
+	timer_adjust(m37710i_cpu.timers[0], TIME_IN_HZ(m37710i_cpu.reload[0]), cpunum, 0);
 
 	m37710i_cpu.m37710_regs[m37710_irq_levels[12]] |= 0x04;
 	m37710_set_irq_line(M37710_LINE_TIMERA0, PULSE_LINE);
+	cpu_triggerint(cpunum);
+	cpuintrf_pop_context();
 }
 
-static void m37710_timer_a1_cb(int num)
+static void m37710_timer_a1_cb(int cpunum)
 {
-	timer_adjust(m37710i_cpu.timers[1], TIME_IN_HZ(m37710i_cpu.reload[1]), 0, 0);
+	cpuintrf_push_context(cpunum);
+	timer_adjust(m37710i_cpu.timers[1], TIME_IN_HZ(m37710i_cpu.reload[1]), cpunum, 0);
 
 	m37710i_cpu.m37710_regs[m37710_irq_levels[11]] |= 0x04;
 	m37710_set_irq_line(M37710_LINE_TIMERA1, PULSE_LINE);
+	cpu_triggerint(cpunum);
+	cpuintrf_pop_context();
 }
 
-static void m37710_timer_a2_cb(int num)
+static void m37710_timer_a2_cb(int cpunum)
 {
-	timer_adjust(m37710i_cpu.timers[2], TIME_IN_HZ(m37710i_cpu.reload[2]), 0, 0);
+	cpuintrf_push_context(cpunum);
+	timer_adjust(m37710i_cpu.timers[2], TIME_IN_HZ(m37710i_cpu.reload[2]), cpunum, 0);
 
 	m37710i_cpu.m37710_regs[m37710_irq_levels[10]] |= 0x04;
 	m37710_set_irq_line(M37710_LINE_TIMERA2, PULSE_LINE);
+	cpu_triggerint(cpunum);
+	cpuintrf_pop_context();
 }
 
-static void m37710_timer_a3_cb(int num)
+static void m37710_timer_a3_cb(int cpunum)
 {
-	timer_adjust(m37710i_cpu.timers[3], TIME_IN_HZ(m37710i_cpu.reload[3]), 0, 0);
+	cpuintrf_push_context(cpunum);
+	timer_adjust(m37710i_cpu.timers[3], TIME_IN_HZ(m37710i_cpu.reload[3]), cpunum, 0);
 
 	m37710i_cpu.m37710_regs[m37710_irq_levels[9]] |= 0x04;
 	m37710_set_irq_line(M37710_LINE_TIMERA3, PULSE_LINE);
+	cpu_triggerint(cpunum);
+	cpuintrf_pop_context();
 }
 
-static void m37710_timer_a4_cb(int num)
+static void m37710_timer_a4_cb(int cpunum)
 {
-	timer_adjust(m37710i_cpu.timers[4], TIME_IN_HZ(m37710i_cpu.reload[4]), 0, 0);
+	cpuintrf_push_context(cpunum);
+	timer_adjust(m37710i_cpu.timers[4], TIME_IN_HZ(m37710i_cpu.reload[4]), cpunum, 0);
 
 	m37710i_cpu.m37710_regs[m37710_irq_levels[8]] |= 0x04;
 	m37710_set_irq_line(M37710_LINE_TIMERA4, PULSE_LINE);
+	cpu_triggerint(cpunum);
+	cpuintrf_pop_context();
 }
 
-static void m37710_timer_b0_cb(int num)
+static void m37710_timer_b0_cb(int cpunum)
 {
-	timer_adjust(m37710i_cpu.timers[5], TIME_IN_HZ(m37710i_cpu.reload[5]), 0, 0);
+	cpuintrf_push_context(cpunum);
+	timer_adjust(m37710i_cpu.timers[5], TIME_IN_HZ(m37710i_cpu.reload[5]), cpunum, 0);
 
 	m37710i_cpu.m37710_regs[m37710_irq_levels[7]] |= 0x04;
 	m37710_set_irq_line(M37710_LINE_TIMERB0, PULSE_LINE);
+	cpu_triggerint(cpunum);
+	cpuintrf_pop_context();
 }
 
-static void m37710_timer_b1_cb(int num)
+static void m37710_timer_b1_cb(int cpunum)
 {
-	timer_adjust(m37710i_cpu.timers[6], TIME_IN_HZ(m37710i_cpu.reload[6]), 0, 0);
+	cpuintrf_push_context(cpunum);
+	timer_adjust(m37710i_cpu.timers[6], TIME_IN_HZ(m37710i_cpu.reload[6]), cpunum, 0);
 
 	m37710i_cpu.m37710_regs[m37710_irq_levels[6]] |= 0x04;
 	m37710_set_irq_line(M37710_LINE_TIMERB1, PULSE_LINE);
+	cpu_triggerint(cpunum);
+	cpuintrf_pop_context();
 }
 
-static void m37710_timer_b2_cb(int num)
+static void m37710_timer_b2_cb(int cpunum)
 {
-	timer_adjust(m37710i_cpu.timers[7], TIME_IN_HZ(m37710i_cpu.reload[7]), 0, 0);
+	cpuintrf_push_context(cpunum);
+	timer_adjust(m37710i_cpu.timers[7], TIME_IN_HZ(m37710i_cpu.reload[7]), cpunum, 0);
 
 	m37710i_cpu.m37710_regs[m37710_irq_levels[5]] |= 0x04;
 	m37710_set_irq_line(M37710_LINE_TIMERB2, PULSE_LINE);
+	cpu_triggerint(cpunum);
+	cpuintrf_pop_context();
 }
 
 static void m37710_external_tick(int timer, int state)
@@ -375,16 +402,17 @@ static void m37710_external_tick(int timer, int state)
 
 static void m37710_recalc_timer(int timer)
 {
+	int cpunum = cpu_getactivecpu();
 	int tval;
-	int tcr[8] = { 0x56, 0x57, 0x58, 0x59, 0x5a, 0x5b, 0x5c, 0x5d };
+	static const int tcr[8] = { 0x56, 0x57, 0x58, 0x59, 0x5a, 0x5b, 0x5c, 0x5d };
 	double time;
-	static double tscales[4] = { 2.0, 16.0, 64.0, 512.0 };
+	static const double tscales[4] = { 2.0, 16.0, 64.0, 512.0 };
 
 	/* check if enabled */
 	if (m37710i_cpu.m37710_regs[0x40] & (1<<timer))
 	{
 		#if M37710_DEBUG
-		logerror("Timer %d (%s) is enabled\n", timer, m37710_tnames[timer]);
+		printf("Timer %d (%s) is enabled\n", timer, m37710_tnames[timer]);
 		#endif
 
 		/* set the timer's value */
@@ -397,32 +425,32 @@ static void m37710_recalc_timer(int timer)
 			switch (m37710i_cpu.m37710_regs[0x56+timer] & 0x3)
 			{
 				case 0:	      	/* timer mode */
-					#if M37710_DEBUG
-					logerror("Timer %d in timer mode\n", timer);
-					#endif
-
 					time = (double)16000000 / tscales[m37710i_cpu.m37710_regs[tcr[timer]]>>6];
 					time /= ((double)tval+1.0);
 
-					timer_adjust(m37710i_cpu.timers[timer], TIME_IN_HZ(time), 0, 0);
+					#if M37710_DEBUG
+					printf("Timer %d in timer mode, %f Hz\n", timer, time);
+					#endif
+
+					timer_adjust(m37710i_cpu.timers[timer], TIME_IN_HZ(time), cpunum, 0);
 					m37710i_cpu.reload[timer] = time;
 					break;
 
 				case 1:	      	/* event counter mode */
 					#if M37710_DEBUG
-					logerror("Timer %d in event counter mode\n", timer);
+					printf("Timer %d in event counter mode\n", timer);
 					#endif
 					break;
 
 				case 2:		/* one-shot pulse mode */
 					#if M37710_DEBUG
-					logerror("Timer %d in one-shot mode\n", timer);
+					printf("Timer %d in one-shot mode\n", timer);
 					#endif
 					break;
 
 				case 3:	      	/* PWM mode */
 					#if M37710_DEBUG
-					logerror("Timer %d in PWM mode\n", timer);
+					printf("Timer %d in PWM mode\n", timer);
 					#endif
 					break;
 			}
@@ -432,32 +460,32 @@ static void m37710_recalc_timer(int timer)
 			switch (m37710i_cpu.m37710_regs[0x56+timer] & 0x3)
 			{
 				case 0:	      	/* timer mode */
-					#if M37710_DEBUG
-					logerror("Timer %d in timer mode\n", timer);
-					#endif
-
 					time = (double)16000000 / tscales[m37710i_cpu.m37710_regs[tcr[timer]]>>6];
 					time /= ((double)tval+1.0);
 
-					timer_adjust(m37710i_cpu.timers[timer], TIME_IN_HZ(time), 0, 0);
+					#if M37710_DEBUG
+					printf("Timer %d in timer mode, %f Hz\n", timer, time);
+					#endif
+
+					timer_adjust(m37710i_cpu.timers[timer], TIME_IN_HZ(time), cpunum, 0);
 					m37710i_cpu.reload[timer] = time;
 					break;
 
 				case 1:	      	/* event counter mode */
 					#if M37710_DEBUG
-					logerror("Timer %d in event counter mode\n", timer);
+					printf("Timer %d in event counter mode\n", timer);
 					#endif
 					break;
 
 				case 2:		/* pulse period/pulse width measurement mode */
 					#if M37710_DEBUG
-					logerror("Timer %d in pulse period/width measurement mode\n", timer);
+					printf("Timer %d in pulse period/width measurement mode\n", timer);
 					#endif
 					break;
 
 				case 3:
 					#if M37710_DEBUG
-					logerror("Timer %d in unknown mode!\n", timer);
+					printf("Timer %d in unknown mode!\n", timer);
 					#endif
 					break;
 			}
@@ -465,7 +493,7 @@ static void m37710_recalc_timer(int timer)
 	}
 }
 
-static data8_t m37710_internal_r(int offset)
+static UINT8 m37710_internal_r(int offset)
 {
 	#if M37710_DEBUG
 	if (offset > 1)
@@ -550,6 +578,9 @@ static data8_t m37710_internal_r(int offset)
 		case 0x2f:
 			return io_read_byte_8(M37710_ADC7_H);
 			break;
+		case 0x35:
+			return 0xff;	/* UART control */
+			break;
 
 		case 0x70:	/* A/D IRQ control */
 			return m37710i_cpu.m37710_regs[offset] | 8;
@@ -559,7 +590,7 @@ static data8_t m37710_internal_r(int offset)
 	return m37710i_cpu.m37710_regs[offset];
 }
 
-static void m37710_internal_w(int offset, data8_t data)
+static void m37710_internal_w(int offset, UINT8 data)
 {
 	int i;
 
@@ -625,7 +656,7 @@ static void m37710_internal_w(int offset, data8_t data)
 	m37710i_cpu.m37710_regs[offset] = data;
 
 	#if M37710_DEBUG
-	if (offset >= 0x1e && offset <= 0x30)
+	if (offset >= 0x1e && offset <= 0x40)
 	logerror("m37710_internal_w %x to %02x: %s = %x\n", data, (int)offset, m37710_rnames[(int)offset], m37710i_cpu.m37710_regs[offset]);
 	#endif
 }
@@ -786,6 +817,7 @@ void m37710i_update_irqs(void)
 			/* this IRQ is set */
 			if (m37710_irq_levels[curirq])
 			{
+/*              logerror("line %d set, level %x curpri %x IPL %x\n", curirq, m37710i_cpu.m37710_regs[m37710_irq_levels[curirq]] & 7, curpri, m37710i_cpu.ipl); */
 				/* it's maskable, check if the level works */
 				if ((m37710i_cpu.m37710_regs[m37710_irq_levels[curirq]] & 7) > curpri)
 				{
@@ -827,11 +859,11 @@ void m37710i_update_irqs(void)
 		/* let's do it... */
 		/* push PB, then PC, then status */
 		CLK(8);
-/*      logerror("taking IRQ %d: PC = %06x, SP = %04x\n", wantedIRQ, REG_PB | REG_PC, REG_S); */
+/*      printf("taking IRQ %d: PC = %06x, SP = %04x, IPL %d\n", wantedIRQ, REG_PB | REG_PC, REG_S, m37710i_cpu.ipl); */
 		m37710i_push_8(REG_PB>>16);
 		m37710i_push_16(REG_PC);
-		m37710i_push_8(m37710i_get_reg_p());
 		m37710i_push_8(m37710i_cpu.ipl);
+		m37710i_push_8(m37710i_get_reg_p());
 
 		/* set I to 1, set IPL to the interrupt we're taking */
 		FLAG_I = IFLAG_SET;
@@ -847,7 +879,7 @@ void m37710i_update_irqs(void)
 
 /* external functions */
 
-void m37710_reset(void* param)
+void m37710_reset(void)
 {
 	/* Start the CPU */
 	CPU_STOPPED = 0;
@@ -996,16 +1028,26 @@ void m37710_set_irq_callback(int (*callback)(int))
 unsigned m37710_dasm(char *buffer, unsigned pc)
 {
 #ifdef MAME_DEBUG
-	return m7700_disassemble(buffer, (pc&0xffff), REG_PB>>16, FLAG_M, FLAG_X);
+	return m7700_disassemble(buffer, (pc&0xffff), pc>>16, FLAG_M, FLAG_X);
 #else
-	sprintf(buffer, "$%02X", m37710_read_8_immediate(REG_PB | (pc&0xffff)));
+	sprintf(buffer, "$%02X", m37710_read_8_immediate(pc));
 	return 1;
 #endif
 }
 
-
-void m37710_init(void)
+static void m37710_restore_state(void)
 {
+	/* restore proper function pointers */
+	m37710i_set_execution_mode((FLAG_M>>4) | (FLAG_X>>4));
+
+	/* make sure the memory system can keep up */
+	m37710i_jumping(REG_PB | REG_PC);
+}
+
+void m37710_init(int index, int clock, const void *config, int (*irqcallback)(int))
+{
+	INT_ACK = irqcallback;
+
 	m37710i_cpu.timers[0] = timer_alloc(m37710_timer_a0_cb);
 	m37710i_cpu.timers[1] = timer_alloc(m37710_timer_a1_cb);
 	m37710i_cpu.timers[2] = timer_alloc(m37710_timer_a2_cb);
@@ -1014,6 +1056,42 @@ void m37710_init(void)
 	m37710i_cpu.timers[5] = timer_alloc(m37710_timer_b0_cb);
 	m37710i_cpu.timers[6] = timer_alloc(m37710_timer_b1_cb);
 	m37710i_cpu.timers[7] = timer_alloc(m37710_timer_b2_cb);
+
+	state_save_register_item("M377xx", index, m37710i_cpu.a);
+	state_save_register_item("M377xx", index, m37710i_cpu.b);
+	state_save_register_item("M377xx", index, m37710i_cpu.ba);
+	state_save_register_item("M377xx", index, m37710i_cpu.bb);
+	state_save_register_item("M377xx", index, m37710i_cpu.x);
+	state_save_register_item("M377xx", index, m37710i_cpu.y);
+	state_save_register_item("M377xx", index, m37710i_cpu.s);
+	state_save_register_item("M377xx", index, m37710i_cpu.pc);
+	state_save_register_item("M377xx", index, m37710i_cpu.ppc);
+	state_save_register_item("M377xx", index, m37710i_cpu.pb);
+	state_save_register_item("M377xx", index, m37710i_cpu.db);
+	state_save_register_item("M377xx", index, m37710i_cpu.d);
+	state_save_register_item("M377xx", index, m37710i_cpu.flag_e);
+	state_save_register_item("M377xx", index, m37710i_cpu.flag_m);
+	state_save_register_item("M377xx", index, m37710i_cpu.flag_x);
+	state_save_register_item("M377xx", index, m37710i_cpu.flag_n);
+	state_save_register_item("M377xx", index, m37710i_cpu.flag_v);
+	state_save_register_item("M377xx", index, m37710i_cpu.flag_d);
+	state_save_register_item("M377xx", index, m37710i_cpu.flag_i);
+	state_save_register_item("M377xx", index, m37710i_cpu.flag_z);
+	state_save_register_item("M377xx", index, m37710i_cpu.flag_c);
+	state_save_register_item("M377xx", index, m37710i_cpu.line_irq);
+	state_save_register_item("M377xx", index, m37710i_cpu.ipl);
+	state_save_register_item("M377xx", index, m37710i_cpu.ir);
+	state_save_register_item("M377xx", index, m37710i_cpu.im);
+	state_save_register_item("M377xx", index, m37710i_cpu.im2);
+	state_save_register_item("M377xx", index, m37710i_cpu.im3);
+	state_save_register_item("M377xx", index, m37710i_cpu.im4);
+	state_save_register_item("M377xx", index, m37710i_cpu.irq_delay);
+	state_save_register_item("M377xx", index, m37710i_cpu.irq_level);
+	state_save_register_item("M377xx", index, m37710i_cpu.stopped);
+	state_save_register_item_array("M377xx", index, m37710i_cpu.m37710_regs);
+	state_save_register_item_array("M377xx", index, m37710i_cpu.reload);
+
+	state_save_register_func_postload(m37710_restore_state);
 }
 
 /**************************************************************************
@@ -1054,9 +1132,6 @@ static void m37710_set_info(UINT32 state, union cpuinfo *info)
 		case CPUINFO_INT_REGISTER + M37710_E:			m37710_set_reg(M37710_E, info->i);		break;
 		case CPUINFO_INT_REGISTER + M37710_NMI_STATE:		m37710_set_reg(M37710_NMI_STATE, info->i); break;
 		case CPUINFO_INT_REGISTER + M37710_IRQ_STATE:		m37710_set_reg(M37710_IRQ_STATE, info->i); break;
-
-		/* --- the following bits of info are set as pointers to data or functions --- */
-		case CPUINFO_PTR_IRQ_CALLBACK:					INT_ACK = info->irqcallback; break;
 	}
 }
 
@@ -1128,7 +1203,6 @@ void m37710_get_info(UINT32 state, union cpuinfo *info)
 		case CPUINFO_PTR_EXECUTE:						info->execute = m37710_execute;			break;
 		case CPUINFO_PTR_BURN:							info->burn = NULL;						break;
 		case CPUINFO_PTR_DISASSEMBLE:					info->disassemble = m37710_dasm;		break;
-		case CPUINFO_PTR_IRQ_CALLBACK:					info->irqcallback = INT_ACK;			break;
 		case CPUINFO_PTR_INSTRUCTION_COUNTER:			info->icount = &m37710_ICount;			break;
 		case CPUINFO_PTR_REGISTER_LAYOUT:				info->p = m37710i_register_layout;		break;
 		case CPUINFO_PTR_WINDOW_LAYOUT:					info->p = m37710i_window_layout;		break;
@@ -1140,9 +1214,9 @@ void m37710_get_info(UINT32 state, union cpuinfo *info)
 		/* --- the following bits of info are returned as NULL-terminated strings --- */
 		case CPUINFO_STR_NAME:						strcpy(info->s = cpuintrf_temp_str(), "M37710"); break;
 		case CPUINFO_STR_CORE_FAMILY:					strcpy(info->s = cpuintrf_temp_str(), "M7700"); break;
-		case CPUINFO_STR_CORE_VERSION:					strcpy(info->s = cpuintrf_temp_str(), "1.1"); break;
+		case CPUINFO_STR_CORE_VERSION:					strcpy(info->s = cpuintrf_temp_str(), "1.2"); break;
 		case CPUINFO_STR_CORE_FILE:					strcpy(info->s = cpuintrf_temp_str(), __FILE__); break;
-		case CPUINFO_STR_CORE_CREDITS:					strcpy(info->s = cpuintrf_temp_str(), "Copyright (c) 2004 R. Belmont, based on G65816 by Karl Stenerud"); break;
+		case CPUINFO_STR_CORE_CREDITS:					strcpy(info->s = cpuintrf_temp_str(), "Copyright (c) 2004-2006 R. Belmont, based on G65816 by Karl Stenerud"); break;
 
 		case CPUINFO_STR_FLAGS:
 			sprintf(info->s = cpuintrf_temp_str(), "%c%c%c%c%c%c%c%c",
@@ -1179,6 +1253,18 @@ void m37710_get_info(UINT32 state, union cpuinfo *info)
 	}
 }
 
+/* 37702 is identical except with an internal ROM, so just change the name */
+void m37702_get_info(UINT32 state, union cpuinfo *info)
+{
+	if (state == CPUINFO_STR_NAME)
+	{
+		strcpy(info->s = cpuintrf_temp_str(), "M37702");
+		return;
+	}
+
+	m37710_get_info(state, info);
+}
+
 /* ======================================================================== */
 /* ============================== END OF FILE ============================= */
 /* ======================================================================== */
