@@ -203,6 +203,9 @@ INLINE void m37710i_branch_16(uint offset)
 /* ============================ STATUS REGISTER =========================== */
 /* ======================================================================== */
 
+/* note: difference from 65816.  when switching to 8-bit X/Y, X and Y are *not* truncated
+   to 8 bits! */
+
 INLINE void m37710i_set_flag_mx(uint value)
 {
 #if FLAG_SET_M
@@ -232,8 +235,6 @@ INLINE void m37710i_set_flag_mx(uint value)
 #else
 	if(value & FLAGPOS_X)
 	{
-		REG_X = MAKE_UINT_8(REG_X);
-		REG_Y = MAKE_UINT_8(REG_Y);
 		FLAG_X = XFLAG_SET;
 	}
 #endif
@@ -686,12 +687,12 @@ INLINE uint EA_SIY(void)   {return MAKE_UINT_16(read_16_SIY(REG_S + OPER_8_IMM()
 #define OP_MPY(MODE)														\
 	CLK(CLK_OP + CLK_R8 + CLK_##MODE);	\
 	SRC = OPER_8_##MODE();			\
-	{ int temp = SRC * REG_A;  REG_A = temp & 0xff; REG_BA = (temp>>8)&0xff; FLAG_Z = temp; FLAG_N = (temp & 0x8000) ? 1 : 0; }
+	{ int temp = SRC * REG_A;  REG_A = temp & 0xff; REG_BA = (temp>>8)&0xff; FLAG_Z = temp; FLAG_N = (temp & 0x8000) ? 1 : 0; FLAG_C = 0; }
 #else
 #define OP_MPY(MODE)														\
 	CLK(CLK_OP + CLK_R16 + CLK_##MODE);	\
 	SRC = OPER_16_##MODE();			\
-	{ int temp = SRC * REG_A;  REG_A = temp & 0xffff;  REG_BA = (temp>>16)&0xffff; FLAG_Z = temp; FLAG_N = (temp & 0x80000000) ? 1 : 0; }
+	{ int temp = SRC * REG_A;  REG_A = temp & 0xffff;  REG_BA = (temp>>16)&0xffff; FLAG_Z = temp; FLAG_N = (temp & 0x80000000) ? 1 : 0; FLAG_C = 0; }
 #endif
 
 /* M37710   Divide */
@@ -933,7 +934,7 @@ INLINE uint EA_SIY(void)   {return MAKE_UINT_16(read_16_SIY(REG_S + OPER_8_IMM()
 #undef OP_BRK
 #define OP_BRK()															\
 			REG_PC++;													\
-			osd_die("BRK at PC=%06x\n", REG_PB|REG_PC);									\
+			fatalerror("BRK at PC=%06x", REG_PB|REG_PC);									\
 			m37710i_interrupt_software(0xfffa)
 
 /* M37710  Branch Always */
@@ -1251,14 +1252,14 @@ INLINE uint EA_SIY(void)   {return MAKE_UINT_16(read_16_SIY(REG_S + OPER_8_IMM()
 #define OP_LDM(MODE)														\
 			CLK(CLK_OP + CLK_R8 + CLK_##MODE);	\
 			REG_IM2 = EA_##MODE();		\
-			REG_IM = read_8_NORM(REG_PC);		\
+			REG_IM = read_8_NORM(REG_PB|REG_PC);		\
 			REG_PC++;				\
 			write_8_##MODE(REG_IM2, REG_IM)
 #else
 #define OP_LDM(MODE)														\
 			CLK(CLK_OP + CLK_R16 + CLK_##MODE);	\
 			REG_IM2 = EA_##MODE();		\
-			REG_IM = read_16_NORM(REG_PC);		\
+			REG_IM = read_16_NORM(REG_PB|REG_PC);		\
 			REG_PC+=2;				\
 			write_16_##MODE(REG_IM2, REG_IM)
 #endif
@@ -1808,7 +1809,6 @@ INLINE uint EA_SIY(void)   {return MAKE_UINT_16(read_16_SIY(REG_S + OPER_8_IMM()
 			m37710i_jumping(REG_PB | REG_PC)
 
 /* M37710  Return from Subroutine Long */
-/* Unusual behavior: Gets PC and increments */
 #undef OP_RTL
 #define OP_RTL()															\
 			CLK(6);															\
@@ -1880,6 +1880,65 @@ INLINE uint EA_SIY(void)   {return MAKE_UINT_16(read_16_SIY(REG_S + OPER_8_IMM()
 			FLAG_C = ~FLAG_C
 #endif
 
+/* M37710   Subtract with Carry - B accumulator */
+/* Unusual behavior: C flag is inverted */
+#undef OP_SBCB
+#if FLAG_SET_M
+#define OP_SBCB(MODE)														\
+			CLK(CLK_OP + CLK_R8 + CLK_##MODE);								\
+			SRC = OPER_8_##MODE();											\
+			FLAG_C = ~FLAG_C;												\
+			if(!FLAG_D)														\
+			{																\
+				FLAG_C = REG_BA - SRC - CFLAG_AS_1();						\
+				FLAG_V = VFLAG_SUB_8(SRC, REG_BA, FLAG_C);					\
+				FLAG_N = FLAG_Z = REG_BA = MAKE_UINT_8(FLAG_C);				\
+				FLAG_C = ~FLAG_C;											\
+				BREAKOUT;													\
+			}																\
+			DST = CFLAG_AS_1();												\
+			FLAG_C = REG_BA - SRC - DST;										\
+			FLAG_V = VFLAG_SUB_8(SRC, REG_BA, FLAG_C);						\
+			if((FLAG_C & 0xf) > 9)											\
+				FLAG_C-=6;													\
+			if((FLAG_C & 0xf0) > 0x90)										\
+				FLAG_C-=0x60;												\
+			FLAG_N = FLAG_Z = REG_BA = MAKE_UINT_8(FLAG_C);					\
+			FLAG_C = ~FLAG_C
+#else
+#define OP_SBCB(MODE)														\
+			CLK(CLK_OP + CLK_R16 + CLK_##MODE);								\
+			SRC = OPER_16_##MODE();											\
+			FLAG_C = ~FLAG_C;												\
+			if(!FLAG_D)														\
+			{																\
+				FLAG_C = REG_BA - SRC - CFLAG_AS_1();						\
+				FLAG_V = VFLAG_SUB_16(SRC, REG_BA, FLAG_C);					\
+				FLAG_Z = REG_BA = MAKE_UINT_16(FLAG_C);						\
+				FLAG_N = NFLAG_16(REG_BA);									\
+				FLAG_C = ~CFLAG_16(FLAG_C);									\
+				BREAKOUT;													\
+			}																\
+			DST    = CFLAG_AS_1();											\
+			FLAG_C = MAKE_UINT_8(REG_BA) - MAKE_UINT_8(SRC) - DST;			\
+			if((FLAG_C & 0xf) > 9)											\
+				FLAG_C-=6;													\
+			if((FLAG_C & 0xf0) > 0x90)										\
+				FLAG_C-=0x60;												\
+			FLAG_Z = MAKE_UINT_8(FLAG_C);									\
+			DST    = CFLAG_AS_1();											\
+			FLAG_C = MAKE_UINT_8(REG_A>>8) - MAKE_UINT_8(SRC>>8) - DST;		\
+			if((FLAG_C & 0xf) > 9)											\
+				FLAG_C-=6;													\
+			if((FLAG_C & 0xf0) > 0x90)										\
+				FLAG_C-=0x60;												\
+			FLAG_Z |= MAKE_UINT_8(FLAG_C) << 8;								\
+			FLAG_N = NFLAG_16(FLAG_Z);										\
+			FLAG_V = VFLAG_SUB_16(SRC, REG_BA, FLAG_Z);						\
+			REG_BA = FLAG_Z;												\
+			FLAG_C = ~FLAG_C
+#endif
+
 /* M37710   Set Carry flag */
 #undef OP_SEC
 #define OP_SEC()															\
@@ -2216,7 +2275,7 @@ INLINE uint EA_SIY(void)   {return MAKE_UINT_16(read_16_SIY(REG_S + OPER_8_IMM()
 /* M37710 unimplemented opcode */
 #undef OP_UNIMP
 #define OP_UNIMP()															\
-	osd_die("M37710: UNIMPLEMENTED OPCODE!  K=%x PC=%x\n", REG_PB, REG_PPC);
+	fatalerror("M37710: UNIMPLEMENTED OPCODE!  K=%x PC=%x", REG_PB, REG_PPC);
 
 /* M37710 load data bank register */
 #undef OP_LDTAAA
@@ -2581,6 +2640,7 @@ OP(192, OP_STB   ( DI          ) ) /* STB di  (C) */
 OP(193, OP_STB   ( SIY         ) ) /* STB siy (G) */
 OP(195, OP_STB   ( DX          ) ) /* STB dx      */
 OP(197, OP_STB   ( DLIY        ) ) /* STB dliy(G) */
+OP(198, OP_TXB   ( REG_Y       ) ) /* TYB         */
 OP(199, OP_STB   ( AY          ) ) /* STB ay      */
 OP(19d, OP_STB   ( AX          ) ) /* STB ax      */
 OP(19f, OP_STB   ( ALX         ) ) /* STB alx (G) */
@@ -2609,11 +2669,14 @@ OP(1d7, OP_CMPB  ( DLIY        ) ) /* CMPB dliy(G) */
 OP(1d9, OP_CMPB  ( AY          ) ) /* CMPB ay      */
 OP(1dd, OP_CMPB  ( AX          ) ) /* CMPB ax      */
 OP(1df, OP_CMPB  ( ALX         ) ) /* CMPB alx (G) */
+OP(1e9, OP_SBCB  ( IMM         ) ) /* SBCB imm     */
+OP(1f5, OP_SBCB  ( DX          ) ) /* SBCB dx      */
 OP(200, OP_UNIMP (             ) ) /* unimplemented */
 OP(203, OP_MPY   ( S           ) ) /* MPY s       */
 OP(205, OP_MPY   ( D           ) ) /* MPY d       */
 OP(209, OP_MPY   ( IMM         ) ) /* MPY imm     */
 OP(215, OP_MPY   ( DX          ) ) /* MPY dx      */
+OP(219, OP_MPY   ( AY	       ) ) /* MPY ay      */
 OP(225, OP_DIV   ( D           ) ) /* DIV d       */
 OP(228, OP_XAB   (             ) ) /* XAB         */
 OP(235, OP_DIV   ( DX          ) ) /* DIV dx      */
@@ -2677,7 +2740,7 @@ TABLE_OPCODES2 =
 	O(200),O(181),O(200),O(183),O(200),O(185),O(200),O(187),	/* 80 */
 	O(200),O(200),O(18a),O(200),O(200),O(18d),O(200),O(18f),
 	O(200),O(191),O(192),O(193),O(200),O(195),O(200),O(197),	/* 90 */
-	O(200),O(199),O(200),O(200),O(200),O(19d),O(200),O(19f),
+	O(198),O(199),O(200),O(200),O(200),O(19d),O(200),O(19f),
 	O(200),O(1a1),O(200),O(200),O(200),O(1a5),O(200),O(200),	/* a0 */
 	O(1a8),O(1a9),O(1aa),O(200),O(200),O(1ad),O(200),O(200),
 	O(200),O(200),O(1b2),O(200),O(200),O(1b5),O(200),O(200),	/* b0 */
@@ -2687,8 +2750,8 @@ TABLE_OPCODES2 =
 	O(200),O(1d1),O(1d2),O(1d3),O(200),O(1d5),O(200),O(1d7),	/* d0 */
 	O(200),O(1d9),O(200),O(200),O(200),O(1dd),O(200),O(1df),
 	O(200),O(200),O(200),O(200),O(200),O(200),O(200),O(200),	/* e0 */
-	O(200),O(200),O(200),O(200),O(200),O(200),O(200),O(200),
-	O(200),O(200),O(200),O(200),O(200),O(200),O(200),O(200),	/* f0 */
+	O(200),O(1e9),O(200),O(200),O(200),O(200),O(200),O(200),
+	O(200),O(200),O(200),O(200),O(200),O(1f5),O(200),O(200),	/* f0 */
 	O(200),O(200),O(200),O(200),O(200),O(200),O(200),O(200)
 };
 
@@ -2697,7 +2760,7 @@ TABLE_OPCODES3 =
 	O(200),O(200),O(200),O(203),O(200),O(205),O(200),O(200),
 	O(200),O(209),O(200),O(200),O(200),O(200),O(200),O(200),
 	O(200),O(200),O(200),O(200),O(200),O(215),O(200),O(200),	/* 10 */
-	O(200),O(200),O(200),O(200),O(200),O(200),O(200),O(200),
+	O(200),O(219),O(200),O(200),O(200),O(200),O(200),O(200),
 	O(200),O(200),O(200),O(200),O(200),O(225),O(200),O(200),	/* 20 */
 	O(228),O(200),O(200),O(200),O(200),O(200),O(200),O(200),
 	O(200),O(200),O(200),O(200),O(200),O(235),O(200),O(200),	/* 30 */
@@ -2839,7 +2902,6 @@ TABLE_FUNCTION(int, execute, (int clocks))
 		CLOCKS = clocks;
 		do
 		{
-/*          if ((REG_PC < 0xc000) || (REG_PB|REG_PC > 0xffff)) osd_die("Dying: PC = %04x, PPC = %04x\n", REG_PC, REG_PPC); */
 			REG_PPC = REG_PC;
 			M37710_CALL_DEBUGGER;
 			REG_PC++;
