@@ -7,8 +7,6 @@ Based on G65C816 CPU Emulator by Karl Stenerud
 
 */
 
-#include <stdio.h>
-#include <string.h>
 #include "cpuintrf.h"
 #include "m7700ds.h"
 
@@ -22,7 +20,7 @@ Based on G65C816 CPU Emulator by Karl Stenerud
 #define INLINE static
 #endif
 
-#define m7700_read_8_disassembler(A) program_read_byte_8(A)
+#define m7700_read_8_disassembler(A) program_read_byte_16le(A)
 
 typedef struct
 {
@@ -165,7 +163,7 @@ static opcode_struct g_opcodes_prefix42[256] =
 {
 	{BRK, I, SIG }, {ORB, M, DXI }, {COP, I, SIG }, {ORB, M, S   },
 	{TSB, M, D   }, {ORB, M, D   }, {ASL, M, D   }, {ORB, M, DLI },
-	{PHP, I, IMP }, {ORB, M, IMM }, {ASL, M, ACC }, {PHD, I, IMP },
+	{PHP, I, IMP }, {ORB, M, IMM }, {ASL, M, ACCB }, {PHD, I, IMP },
 	{TSB, M, A   }, {ORB, M, A   }, {ASL, M, A   }, {ORB, M, AL  },
 /* 0x10 */
 	{BPL, I, RELB}, {ORB, M, DIY }, {ORB, M, DI  }, {ORB, M, SIY },
@@ -253,7 +251,7 @@ static opcode_struct g_opcodes_prefix89[256] =
 /* 0x10 */
 	{BPL, I, RELB}, {ORA, M, DIY }, {ORA, M, DI  }, {ORA, M, SIY },
 	{TRB, M, D   }, {MPY, M, DX  }, {ASL, M, DX  }, {ORA, M, DLIY},
-	{CLC, I, IMP }, {ORA, M, AY  }, {INA, I, IMP }, {TCS, I, IMP },
+	{CLC, I, IMP }, {MPY, M, AY  }, {INA, I, IMP }, {TCS, I, IMP },
 	{TRB, M, A   }, {ORA, M, AX  }, {ASL, M, AX  }, {ORA, M, ALX },
 /* 0x20 */
 	{JSR, I, A   }, {AND, M, DXI }, {JSL, I, AL  }, {AND, M, S   },
