@@ -6,9 +6,7 @@
 /* ======================================================================== */
 
 #include "driver.h"
-#include "cpuintrf.h"
-#include "memory.h"
-#include "mamedbg.h"
+#include "debugger.h"
 #include "m68000.h"
 
 /* Configuration switches (see m68kconf.h for explanation) */
@@ -48,7 +46,7 @@
 #define M68K_LOG_1010_1111          OPT_OFF
 #define M68K_LOG_FILEHANDLE         errorlog
 
-#define M68K_EMULATE_ADDRESS_ERROR  OPT_OFF
+#define M68K_EMULATE_ADDRESS_ERROR  OPT_ON
 
 #define M68K_USE_64_BIT             OPT_OFF
 
@@ -179,6 +177,12 @@ void m68k_set_encrypted_opcode_range(int cpunum, offs_t start, offs_t end);
 
 #endif /* A68K2 */
 
+#if HAS_M68040
+#define M68K_EMULATE_040			OPT_ON
+#else
+#define M68K_EMULATE_040			OPT_OFF
+#endif
+
 /* ======================================================================== */
 /* ============================== END OF FILE ============================= */
 /* ======================================================================== */
