@@ -1,22 +1,22 @@
 /*** m6805: Portable 6805 emulator ******************************************
 
-	m6805.c (Also supports hd68705 and hd63705 variants)
+    m6805.c (Also supports hd68705 and hd63705 variants)
 
-	References:
+    References:
 
-		6809 Simulator V09, By L.C. Benschop, Eidnhoven The Netherlands.
+        6809 Simulator V09, By L.C. Benschop, Eidnhoven The Netherlands.
 
-		m6809: Portable 6809 emulator, DS (6809 code in MAME, derived from
-			the 6809 Simulator V09)
+        m6809: Portable 6809 emulator, DS (6809 code in MAME, derived from
+            the 6809 Simulator V09)
 
-		6809 Microcomputer Programming & Interfacing with Experiments"
-			by Andrew C. Staugaard, Jr.; Howard W. Sams & Co., Inc.
+        6809 Microcomputer Programming & Interfacing with Experiments"
+            by Andrew C. Staugaard, Jr.; Howard W. Sams & Co., Inc.
 
-	System dependencies:	UINT16 must be 16 bit unsigned int
-							UINT8 must be 8 bit unsigned int
-							UINT32 must be more than 16 bits
-							arrays up to 65536 bytes must be supported
-							machine must be twos complement
+    System dependencies:    UINT16 must be 16 bit unsigned int
+                            UINT8 must be 8 bit unsigned int
+                            UINT32 must be more than 16 bits
+                            arrays up to 65536 bytes must be supported
+                            machine must be twos complement
 
   Additional Notes:
 
@@ -31,12 +31,7 @@
 *****************************************************************************/
 
 
-#include <stdio.h>
-#include <stdlib.h>
-#include "driver.h"
-#include "cpuintrf.h"
-#include "state.h"
-#include "mamedbg.h"
+#include "debugger.h"
 #include "m6805.h"
 
 #define IRQ_LEVEL_DETECT 0
@@ -119,7 +114,7 @@ int m6805_ICount=50000;
 #define PULLWORD(w) rd_s_handler_w(&w)
 
 /* CC masks      H INZC
-              7654 3210	*/
+              7654 3210 */
 #define CFLAG 0x01
 #define ZFLAG 0x02
 #define NFLAG 0x04
@@ -214,7 +209,7 @@ static UINT8 flags8d[256]= /* decrement */
 #define IDX1BYTE(b) {INDEXED1;b=RM(EAD);}
 #define IDX2BYTE(b) {INDEXED2;b=RM(EAD);}
 /* Macros for branch instructions */
-#define BRANCH(f) { UINT8 t; IMMBYTE(t); if(f) { PC+=SIGNED(t); if (t==0xfe) { /* speed up busy loops */ if(m6805_ICount > 0) m6805_ICount = 0; } } }
+#define BRANCH(f) { UINT8 t; IMMBYTE(t); if(f) { PC+=SIGNED(t); change_pc(PC); if (t==0xfe) { /* speed up busy loops */ if(m6805_ICount > 0) m6805_ICount = 0; } } }
 
 /* what they say it is ... */
 static unsigned char cycles1[] =
@@ -276,7 +271,7 @@ INLINE void RM16( UINT32 Addr, PAIR *p )
 	CLEAR_PAIR(p);
     p->b.h = RM(Addr);
     ++Addr;
-/*	if( ++Addr > AMASK ) Addr = 0; */
+/*  if( ++Addr > AMASK ) Addr = 0; */
 	p->b.l = RM(Addr);
 }
 
@@ -284,7 +279,7 @@ INLINE void WM16( UINT32 Addr, PAIR *p )
 {
 	WM( Addr, p->b.h );
     ++Addr;
-/*	if( ++Addr > AMASK ) Addr = 0; */
+/*  if( ++Addr > AMASK ) Addr = 0; */
 	WM( Addr, p->b.l );
 }
 
@@ -293,9 +288,9 @@ INLINE void WM16( UINT32 Addr, PAIR *p )
 /* Generate interrupt - m68705 version */
 static void m68705_Interrupt(void)
 {
-	if( (m6805.pending_interrupts & ((1<<M6805_IRQ_LINE)|M68705_INT_MASK)) != 0 ) 
+	if( (m6805.pending_interrupts & ((1<<M6805_IRQ_LINE)|M68705_INT_MASK)) != 0 )
 	{
-		if ( (CC & IFLAG) == 0 ) 
+		if ( (CC & IFLAG) == 0 )
 		{
 			PUSHWORD(m6805.pc);
 			PUSHBYTE(m6805.x);
@@ -309,17 +304,19 @@ static void m68705_Interrupt(void)
 			{
 				m6805.pending_interrupts &= ~(1<<M68705_IRQ_LINE);
 				RM16( 0xfffa, &pPC);
+				change_pc(PC);
 			}
 			else if((m6805.pending_interrupts&(1<<M68705_INT_TIMER))!=0)
 			{
 				m6805.pending_interrupts &= ~(1<<M68705_INT_TIMER);
 				RM16( 0xfff8, &pPC);
+				change_pc(PC);
 			}
 		}
 		m6805_ICount -= 11;
 	}
 }
-#endif 
+#endif
 
 /* Generate interrupts */
 static void Interrupt(void)
@@ -341,6 +338,7 @@ static void Interrupt(void)
 			(*m6805.irq_callback)(0);
 
 		RM16( 0x1ffc, &pPC);
+		change_pc(PC);
 		m6805.pending_interrupts &= ~(1<<HD63705_INT_NMI);
 
 		m6805_ICount -= 11;
@@ -355,9 +353,9 @@ static void Interrupt(void)
 	{
         /* standard IRQ */
 /*#if (HAS_HD63705) */
-/*		if(SUBTYPE!=SUBTYPE_HD63705) */
+/*      if(SUBTYPE!=SUBTYPE_HD63705) */
 /*#endif */
-/*			PC |= ~AMASK; */
+/*          PC |= ~AMASK; */
 		PUSHWORD(m6805.pc);
 		PUSHBYTE(m6805.x);
 		PUSHBYTE(m6805.a);
@@ -378,47 +376,56 @@ static void Interrupt(void)
 			{
 				m6805.pending_interrupts &= ~(1<<HD63705_INT_IRQ1);
 				RM16( 0x1ff8, &pPC);
+				change_pc(PC);
 			}
 			else if((m6805.pending_interrupts&(1<<HD63705_INT_IRQ2))!=0)
 			{
 				m6805.pending_interrupts &= ~(1<<HD63705_INT_IRQ2);
 				RM16( 0x1fec, &pPC);
+				change_pc(PC);
 			}
 			else if((m6805.pending_interrupts&(1<<HD63705_INT_ADCONV))!=0)
 			{
 				m6805.pending_interrupts &= ~(1<<HD63705_INT_ADCONV);
 				RM16( 0x1fea, &pPC);
+				change_pc(PC);
 			}
 			else if((m6805.pending_interrupts&(1<<HD63705_INT_TIMER1))!=0)
 			{
 				m6805.pending_interrupts &= ~(1<<HD63705_INT_TIMER1);
 				RM16( 0x1ff6, &pPC);
+				change_pc(PC);
 			}
 			else if((m6805.pending_interrupts&(1<<HD63705_INT_TIMER2))!=0)
 			{
 				m6805.pending_interrupts &= ~(1<<HD63705_INT_TIMER2);
 				RM16( 0x1ff4, &pPC);
+				change_pc(PC);
 			}
 			else if((m6805.pending_interrupts&(1<<HD63705_INT_TIMER3))!=0)
 			{
 				m6805.pending_interrupts &= ~(1<<HD63705_INT_TIMER3);
 				RM16( 0x1ff2, &pPC);
+				change_pc(PC);
 			}
 			else if((m6805.pending_interrupts&(1<<HD63705_INT_PCI))!=0)
 			{
 				m6805.pending_interrupts &= ~(1<<HD63705_INT_PCI);
 				RM16( 0x1ff0, &pPC);
+				change_pc(PC);
 			}
 			else if((m6805.pending_interrupts&(1<<HD63705_INT_SCI))!=0)
 			{
 				m6805.pending_interrupts &= ~(1<<HD63705_INT_SCI);
 				RM16( 0x1fee, &pPC);
+				change_pc(PC);
 			}
 		}
 		else
 #endif
 		{
 			RM16( 0xffff - 5, &pPC );
+			change_pc(PC);
 		}
 
 		}	/* CC & IFLAG */
@@ -428,26 +435,28 @@ static void Interrupt(void)
 	}
 }
 
-static void state_register(const char *type)
+static void state_register(const char *type, int index)
 {
-	int cpu = cpu_getactivecpu();
-	state_save_register_UINT8(type, cpu, "A", &A, 1);
-	state_save_register_UINT16(type, cpu, "PC", &PC, 1);
-	state_save_register_UINT16(type, cpu, "S", &S, 1);
-	state_save_register_UINT8(type, cpu, "X", &X, 1);
-	state_save_register_UINT8(type, cpu, "CC", &CC, 1);
-	state_save_register_UINT16(type, cpu, "PENDING", &m6805.pending_interrupts, 1);
-	state_save_register_INT32(type, cpu, "IRQ_STATE", &m6805.irq_state[0], 1);
+	state_save_register_item(type, index, A);
+	state_save_register_item(type, index, PC);
+	state_save_register_item(type, index, S);
+	state_save_register_item(type, index, X);
+	state_save_register_item(type, index, CC);
+	state_save_register_item(type, index, m6805.pending_interrupts);
+	state_save_register_item_array(type, index, m6805.irq_state);
 }
 
-static void m6805_init(void)
+static void m6805_init(int index, int clock, const void *config, int (*irqcallback)(int))
 {
-	state_register("m6805");
+	state_register("m6805", index);
+	m6805.irq_callback = irqcallback;
 }
 
-static void m6805_reset(void *param)
+static void m6805_reset(void)
 {
+	int (*save_irqcallback)(int) = m6805.irq_callback;
 	memset(&m6805, 0, sizeof(m6805));
+	m6805.irq_callback = save_irqcallback;
 	/* Force CPU sub-type and relevant masks */
 	m6805.subtype	= SUBTYPE_M6805;
 	SP_MASK = 0x07f;
@@ -457,6 +466,7 @@ static void m6805_reset(void *param)
 	/* IRQ disabled */
     SEI;
 	RM16( 0xfffe , &pPC );
+	change_pc(PC);
 }
 
 static void m6805_exit(void)
@@ -502,7 +512,7 @@ static void set_irq_line(int irqline, int state)
 
 
 /* execute instructions on this CPU until icount expires */
-int m6805_execute(int cycles)
+static int m6805_execute(int cycles)
 {
 	UINT8 ireg;
 	m6805_ICount = cycles;
@@ -810,20 +820,21 @@ static offs_t m6805_dasm(char *buffer, offs_t pc)
  * M68705 section
  ****************************************************************************/
 #if (HAS_M68705)
-void m68705_init(void)
+static void m68705_init(int index, int clock, const void *config, int (*irqcallback)(int))
 {
-	state_register("m68705");
+	state_register("m68705", index);
+	m6805.irq_callback = irqcallback;
 }
 
-void m68705_reset(void *param)
+static void m68705_reset(void)
 {
-	m6805_reset(param);
+	m6805_reset();
 	/* Overide default 6805 type */
 	m6805.subtype = SUBTYPE_M68705;
 	RM16( 0xfffe, &m6805.pc );
 }
 
-void m68705_set_irq_line(int irqline, int state)
+static void m68705_set_irq_line(int irqline, int state)
 {
 	if (m6805.irq_state[irqline] == state ) return;
 	m6805.irq_state[irqline] = state;
@@ -836,23 +847,15 @@ void m68705_set_irq_line(int irqline, int state)
  * HD63705 section
  ****************************************************************************/
 #if (HAS_HD63705)
-void hd63705_init(void)
+static void hd63705_init(int index, int clock, const void *config, int (*irqcallback)(int))
 {
-	int cpu = cpu_getactivecpu();
-	state_register("hd63705");
-	state_save_register_INT32("hd63705",cpu,"IRQ1_STATE", &m6805.irq_state[0], 1);
-	state_save_register_INT32("hd63705",cpu,"IRQ2_STATE", &m6805.irq_state[1], 1);
-	state_save_register_INT32("hd63705",cpu,"TIMER1_STATE", &m6805.irq_state[2], 1);
-	state_save_register_INT32("hd63705",cpu,"TIMER2_STATE", &m6805.irq_state[3], 1);
-	state_save_register_INT32("hd63705",cpu,"TIMER3_STATE", &m6805.irq_state[4], 1);
-	state_save_register_INT32("hd63705",cpu,"PCI_STATE", &m6805.irq_state[5], 1);
-	state_save_register_INT32("hd63705",cpu,"SCI_STATE", &m6805.irq_state[6], 1);
-	state_save_register_INT32("hd63705",cpu,"ADCONV_STATE", &m6805.irq_state[7], 1);
+	state_register("hd63705", index);
+	m6805.irq_callback = irqcallback;
 }
 
-void hd63705_reset(void *param)
+static void hd63705_reset(void)
 {
-	m6805_reset(param);
+	m6805_reset();
 
 	/* Overide default 6805 types */
 	m6805.subtype	= SUBTYPE_HD63705;
@@ -862,7 +865,7 @@ void hd63705_reset(void *param)
 	S = 0x17f;
 }
 
-void hd63705_set_irq_line(int irqline, int state)
+static void hd63705_set_irq_line(int irqline, int state)
 {
 	if (irqline == INPUT_LINE_NMI)
 	{
@@ -896,14 +899,11 @@ static void m6805_set_info(UINT32 state, union cpuinfo *info)
 
 		case CPUINFO_INT_REGISTER + M6805_A:			A = info->i;							break;
 		case CPUINFO_INT_PC:
-		case CPUINFO_INT_REGISTER + M6805_PC:			PC = info->i;							break;
+		case CPUINFO_INT_REGISTER + M6805_PC:			PC = info->i; change_pc(PC); 			break;
 		case CPUINFO_INT_SP:
 		case CPUINFO_INT_REGISTER + M6805_S:			S = SP_ADJUST(info->i);					break;
 		case CPUINFO_INT_REGISTER + M6805_X:			X = info->i;							break;
 		case CPUINFO_INT_REGISTER + M6805_CC:			CC = info->i;							break;
-		
-		/* --- the following bits of info are set as pointers to data or functions --- */
-		case CPUINFO_PTR_IRQ_CALLBACK:					m6805.irq_callback = info->irqcallback;	break;
 	}
 }
 
@@ -927,7 +927,7 @@ void m6805_get_info(UINT32 state, union cpuinfo *info)
 		case CPUINFO_INT_MAX_INSTRUCTION_BYTES:			info->i = 3;							break;
 		case CPUINFO_INT_MIN_CYCLES:					info->i = 2;							break;
 		case CPUINFO_INT_MAX_CYCLES:					info->i = 10;							break;
-		
+
 		case CPUINFO_INT_DATABUS_WIDTH + ADDRESS_SPACE_PROGRAM:	info->i = 8;					break;
 		case CPUINFO_INT_ADDRBUS_WIDTH + ADDRESS_SPACE_PROGRAM: info->i = 12;					break;
 		case CPUINFO_INT_ADDRBUS_SHIFT + ADDRESS_SPACE_PROGRAM: info->i = 0;					break;
@@ -960,7 +960,6 @@ void m6805_get_info(UINT32 state, union cpuinfo *info)
 		case CPUINFO_PTR_EXECUTE:						info->execute = m6805_execute;			break;
 		case CPUINFO_PTR_BURN:							info->burn = NULL;						break;
 		case CPUINFO_PTR_DISASSEMBLE:					info->disassemble = m6805_dasm;			break;
-		case CPUINFO_PTR_IRQ_CALLBACK:					info->irqcallback = m6805.irq_callback;	break;
 		case CPUINFO_PTR_INSTRUCTION_COUNTER:			info->icount = &m6805_ICount;			break;
 		case CPUINFO_PTR_REGISTER_LAYOUT:				info->p = m6805_reg_layout;				break;
 		case CPUINFO_PTR_WINDOW_LAYOUT:					info->p = m6805_win_layout;				break;
@@ -1016,7 +1015,7 @@ void m68705_get_info(UINT32 state, union cpuinfo *info)
 	{
 		/* --- the following bits of info are returned as 64-bit signed integers --- */
 		case CPUINFO_INT_INPUT_STATE + M68705_INT_TIMER:	info->i = m6805.irq_state[M68705_INT_TIMER]; break;
-	
+
 		/* --- the following bits of info are returned as pointers to data or functions --- */
 		case CPUINFO_PTR_SET_INFO:						info->setinfo = m68705_set_info;		break;
 		case CPUINFO_PTR_INIT:							info->init = m68705_init;				break;
