@@ -70,11 +70,7 @@
 
 *****************************************************************************/
 
-#include <stdio.h>
-#include <stdlib.h>
-#include "cpuintrf.h"
-#include "state.h"
-#include "mamedbg.h"
+#include "debugger.h"
 #include "m6809.h"
 
 /* Enable big switch statement for the main opcodes */
@@ -90,6 +86,10 @@
 #define LOG(x)
 #endif
 
+#ifdef MAME_DEBUG
+extern offs_t m6809_dasm(char *buffer, offs_t pc, UINT8 *oprom, UINT8 *opram, int bytes);
+#endif
+
 
 static UINT8 m6809_reg_layout[] = {
 	M6809_PC, M6809_S, M6809_CC, M6809_A, M6809_B, M6809_X, -1,
@@ -137,7 +137,6 @@ typedef struct
 
 /* 6809 registers */
 static m6809_Regs m6809;
-int m6809_slapstic = 0;
 
 #define pPPC    m6809.ppc
 #define pPC 	m6809.pc
@@ -170,14 +169,6 @@ static PAIR ea;         /* effective address */
 #define EAD ea.d
 
 #define CHANGE_PC change_pc(PCD)
-#if 0
-#define CHANGE_PC	{			\
-	if( m6809_slapstic )		\
-		cpu_setOPbase16(PCD);	\
-	else						\
-		change_pc(PCD);		\
-	}
-#endif
 
 #define M6809_CWAI		8	/* set when CWAI is waiting for an interrupt */
 #define M6809_SYNC		16	/* set when SYNC is waiting for an interrupt */
@@ -442,23 +433,25 @@ static void m6809_set_context(void *src)
 /****************************************************************************/
 /* Reset registers to their initial values                                  */
 /****************************************************************************/
-static void m6809_init(void)
+static void m6809_init(int index, int clock, const void *config, int (*irqcallback)(int))
 {
-	int cpu = cpu_getactivecpu();
-	state_save_register_UINT16("m6809", cpu, "PC", &PC, 1);
-	state_save_register_UINT16("m6809", cpu, "U", &U, 1);
-	state_save_register_UINT16("m6809", cpu, "S", &S, 1);
-	state_save_register_UINT16("m6809", cpu, "X", &X, 1);
-	state_save_register_UINT16("m6809", cpu, "Y", &Y, 1);
-	state_save_register_UINT8("m6809", cpu, "DP", &DP, 1);
-	state_save_register_UINT8("m6809", cpu, "CC", &CC, 1);
-	state_save_register_UINT8("m6809", cpu, "INT", &m6809.int_state, 1);
-	state_save_register_UINT8("m6809", cpu, "NMI", &m6809.nmi_state, 1);
-	state_save_register_UINT8("m6809", cpu, "IRQ", &m6809.irq_state[0], 1);
-	state_save_register_UINT8("m6809", cpu, "FIRQ", &m6809.irq_state[1], 1);
+	state_save_register_item("m6809", index, PC);
+	state_save_register_item("m6809", index, PPC);
+	state_save_register_item("m6809", index, D);
+	state_save_register_item("m6809", index, DP);
+	state_save_register_item("m6809", index, U);
+	state_save_register_item("m6809", index, S);
+	state_save_register_item("m6809", index, X);
+	state_save_register_item("m6809", index, Y);
+	state_save_register_item("m6809", index, CC);
+	state_save_register_item_array("m6809", index, m6809.irq_state);
+	state_save_register_item("m6809", index, m6809.int_state);
+	state_save_register_item("m6809", index, m6809.nmi_state);
+
+	m6809.irq_callback = irqcallback;
 }
 
-static void m6809_reset(void *param)
+static void m6809_reset(void)
 {
 	m6809.int_state = 0;
 	m6809.nmi_state = CLEAR_LINE;
@@ -528,16 +521,6 @@ static void set_irq_line(int irqline, int state)
 	}
 }
 
-static offs_t m6809_dasm(char *buffer, offs_t pc)
-{
-#ifdef MAME_DEBUG
-    return Dasm6809(buffer,pc);
-#else
-	sprintf( buffer, "$%02X", cpu_readop(pc) );
-	return 1;
-#endif
-}
-
 /* includes the static function prototypes and the master opcode table */
 #include "6809tbl.c"
 
@@ -1145,9 +1128,6 @@ static void m6809_set_info(UINT32 state, union cpuinfo *info)
 		case CPUINFO_INT_REGISTER + M6809_X:			X = info->i;							break;
 		case CPUINFO_INT_REGISTER + M6809_Y:			Y = info->i;							break;
 		case CPUINFO_INT_REGISTER + M6809_DP:			DP = info->i;							break;
-
-		/* --- the following bits of info are set as pointers to data or functions --- */
-		case CPUINFO_PTR_IRQ_CALLBACK:					m6809.irq_callback = info->irqcallback;			break;
 	}
 }
 
@@ -1209,8 +1189,9 @@ void m6809_get_info(UINT32 state, union cpuinfo *info)
 		case CPUINFO_PTR_EXIT:							info->exit = m6809_exit;					break;
 		case CPUINFO_PTR_EXECUTE:						info->execute = m6809_execute;				break;
 		case CPUINFO_PTR_BURN:							info->burn = NULL;						break;
-		case CPUINFO_PTR_DISASSEMBLE:					info->disassemble = m6809_dasm;					break;
-		case CPUINFO_PTR_IRQ_CALLBACK:					info->irqcallback = m6809.irq_callback;			break;
+#ifdef MAME_DEBUG
+		case CPUINFO_PTR_DISASSEMBLE_NEW:				info->disassemble_new = m6809_dasm;					break;
+#endif /* MAME_DEBUG */
 		case CPUINFO_PTR_INSTRUCTION_COUNTER:			info->icount = &m6809_ICount;				break;
 		case CPUINFO_PTR_REGISTER_LAYOUT:				info->p = m6809_reg_layout;				break;
 		case CPUINFO_PTR_WINDOW_LAYOUT:					info->p = m6809_win_layout;				break;
