@@ -1,63 +1,56 @@
 /****************************************************************************
 
-	NEC V20/V30/V33 emulator
+    NEC V20/V30/V33 emulator
 
-	(Re)Written June-September 2000 by Bryan McPhail (mish@tendril.co.uk) based
-	on code by Oliver Bergmann (Raul_Bloodworth@hotmail.com) who based code
-	on the i286 emulator by Fabrice Frances which had initial work based on
-	David Hedley's pcemu(!).
+    (Re)Written June-September 2000 by Bryan McPhail (mish@tendril.co.uk) based
+    on code by Oliver Bergmann (Raul_Bloodworth@hotmail.com) who based code
+    on the i286 emulator by Fabrice Frances which had initial work based on
+    David Hedley's pcemu(!).
 
-	This new core features 99% accurate cycle counts for each processor,
-	there are still some complex situations where cycle counts are wrong,
-	typically where a few instructions have differing counts for odd/even
-	source and odd/even destination memory operands.
+    This new core features 99% accurate cycle counts for each processor,
+    there are still some complex situations where cycle counts are wrong,
+    typically where a few instructions have differing counts for odd/even
+    source and odd/even destination memory operands.
 
-	Flag settings are also correct for the NEC processors rather than the
-	I86 versions.
+    Flag settings are also correct for the NEC processors rather than the
+    I86 versions.
 
-	Changelist:
+    Changelist:
 
-	22/02/2003:
-		Removed cycle counts from memory accesses - they are certainly wrong,
-		and there is already a memory access cycle penalty in the opcodes
-		using them.
+    22/02/2003:
+        Removed cycle counts from memory accesses - they are certainly wrong,
+        and there is already a memory access cycle penalty in the opcodes
+        using them.
 
-		Fixed save states.
+        Fixed save states.
 
-		Fixed ADJBA/ADJBS/ADJ4A/ADJ4S flags/return values for all situations.
-		(Fixes bugs in Geostorm and Thunderblaster)
+        Fixed ADJBA/ADJBS/ADJ4A/ADJ4S flags/return values for all situations.
+        (Fixes bugs in Geostorm and Thunderblaster)
 
-		Fixed carry flag on NEG (I thought this had been fixed circa Mame 0.58,
-		but it seems I never actually submitted the fix).
+        Fixed carry flag on NEG (I thought this had been fixed circa Mame 0.58,
+        but it seems I never actually submitted the fix).
 
-		Fixed many cycle counts in instructions and bug in cycle count
-		macros (odd word cases were testing for odd instruction word address
-		not data address).
+        Fixed many cycle counts in instructions and bug in cycle count
+        macros (odd word cases were testing for odd instruction word address
+        not data address).
 
-	Todo!
-		Double check cycle timing is 100%.
-		Fix memory interface (should be 16 bit).
+    Todo!
+        Double check cycle timing is 100%.
+        Fix memory interface (should be 16 bit).
 
 ****************************************************************************/
 
-#include <stdio.h>
-#include <string.h>
-#include "osd_cpu.h"
+#include "debugger.h"
 
 typedef UINT8 BOOLEAN;
 typedef UINT8 BYTE;
 typedef UINT16 WORD;
 typedef UINT32 DWORD;
 
-#include "cpuintrf.h"
-#include "memory.h"
-#include "mamedbg.h"
 #include "nec.h"
 #include "necintrf.h"
-#include "driver.h"
-#include "state.h"
 
-extern int i386_dasm_one(char *buffer, UINT32 eip, int addr_size, int op_size);
+extern int necv_dasm_one(char *buffer, UINT32 eip, UINT8 *oprom, int addr_size, int op_size);
 
 static UINT8 nec_reg_layout[] = {
 	NEC_IP,NEC_SP,NEC_FLAGS,NEC_AW,NEC_CW,NEC_DW,NEC_BW,NEC_BP,NEC_IX,NEC_IY, -1,
@@ -109,10 +102,10 @@ static nec_Regs I;
 
 static UINT32 cpu_type;
 static UINT32 prefix_base;	/* base address of the latest prefix segment */
-char seg_prefix;		/* prefix segment indicator */
+static char seg_prefix;		/* prefix segment indicator */
 
 
-/* The interrupt number of a pending external interrupt pending NMI is 2.	*/
+/* The interrupt number of a pending external interrupt pending NMI is 2.   */
 /* For INTR interrupts, the level is caught on the bus during an INTA cycle */
 
 #define INT_IRQ 0x01
@@ -126,12 +119,15 @@ static UINT8 parity_table[256];
 
 /***************************************************************************/
 
-static void nec_reset (void *param)
+static void nec_reset (void)
 {
     unsigned int i,j,c;
-    BREGS reg_name[8]={ AL, CL, DL, BL, AH, CH, DH, BH };
+    static const BREGS reg_name[8]={ AL, CL, DL, BL, AH, CH, DH, BH };
+    int (*save_irqcallback)(int);
 
+	save_irqcallback = I.irq_callback;
 	memset( &I, 0, sizeof(I) );
+	I.irq_callback = save_irqcallback;
 
 	I.sregs[CS] = 0xffff;
 
@@ -572,7 +568,13 @@ OP( 0x98, i_cbw       ) { I.regs.b[AH] = (I.regs.b[AL] & 0x80) ? 0xff : 0;		CLK(
 OP( 0x99, i_cwd       ) { I.regs.w[DW] = (I.regs.b[AH] & 0x80) ? 0xffff : 0;	CLK(4);	}
 OP( 0x9a, i_call_far  ) { UINT32 tmp, tmp2;	FETCHWORD(tmp); FETCHWORD(tmp2); PUSH(I.sregs[CS]); PUSH(I.ip); I.ip = (WORD)tmp; I.sregs[CS] = (WORD)tmp2; CHANGE_PC; CLKW(29,29,13,29,21,9,I.regs.w[SP]); }
 OP( 0x9b, i_wait      ) { logerror("%06x: Hardware POLL\n",activecpu_get_pc()); }
+#ifdef _MSC_VER
+#pragma optimize("",off)
+#endif
 OP( 0x9c, i_pushf     ) { PUSH( CompressFlags() ); CLKS(12,8,3); }
+#ifdef _MSC_VER
+#pragma optimize("",on)
+#endif
 OP( 0x9d, i_popf      ) { UINT32 tmp; POP(tmp); ExpandFlags(tmp); CLKS(12,8,5); if (I.TF) nec_trap(); }
 OP( 0x9e, i_sahf      ) { UINT32 tmp = (CompressFlags() & 0xff00) | (I.regs.b[AH] & 0xd5); ExpandFlags(tmp); CLKS(3,3,2); }
 OP( 0x9f, i_lahf      ) { I.regs.b[AH] = CompressFlags() & 0xff; CLKS(3,3,2); }
@@ -921,66 +923,56 @@ static void set_irq_line(int irqline, int state)
 		I.irq_state = state;
 		if (state == CLEAR_LINE)
 		{
-	/*		if (!I.IF)	NS010718 fix interrupt request loss */
+	/*      if (!I.IF)  NS010718 fix interrupt request loss */
 				I.pending_irq &= ~INT_IRQ;
 		}
 		else
 		{
-	/*		if (I.IF)	NS010718 fix interrupt request loss */
+	/*      if (I.IF)   NS010718 fix interrupt request loss */
 				I.pending_irq |= INT_IRQ;
 		}
 	}
 }
 
-/*
- WARNING: this doesn't support NEC extended instructions or special
- encrypted fetching.  But the previous disassembler was GPL'd so it had to go.
- */
-static offs_t nec_dasm(char *buffer, offs_t pc)
+static offs_t nec_dasm(char *buffer, offs_t pc, UINT8 *oprom, UINT8 *opram, int bytes)
 {
 #ifdef MAME_DEBUG
-	return i386_dasm_one(buffer, pc, 0, 0);
+	return necv_dasm_one(buffer, pc, oprom, 0, 0);
 #else
-	sprintf( buffer, "$%02X", cpu_readop(pc) );
+	sprintf( buffer, "$%02X", *oprom );
 	return 1;
 #endif
 }
 
-static void nec_init(int type)
+static void nec_init(int index, int clock, const void *config, int (*irqcallback)(int), int type)
 {
-	const char *names[]={"V20","V30","V33"};
-	int cpu = cpu_getactivecpu(),i;
-	char buf[16];
+	static const char *names[]={"V20","V30","V33"};
 
-	for (i=0; i<8; i++) {
-		sprintf(buf,"R%d",i);
-		state_save_register_UINT16(names[type], cpu, buf, &I.regs.w[i], 1);
-	}
-	for (i=0; i<4; i++) {
-		sprintf(buf,"SR%d",i);
-		state_save_register_UINT16(names[type], cpu, buf, &I.sregs[i], 1);
-	}
+	state_save_register_item_array(names[type], index, I.regs.w);
+	state_save_register_item_array(names[type], index, I.sregs);
 
-	state_save_register_UINT16(names[type], cpu, "IP", &I.ip, 1);
-	state_save_register_UINT8(names[type], cpu, "TF", &I.TF, 1);
-	state_save_register_UINT8(names[type], cpu, "IF", &I.IF, 1);
-	state_save_register_UINT8(names[type], cpu, "DF", &I.DF, 1);
-	state_save_register_UINT8(names[type], cpu, "MF", &I.MF, 1);
-	state_save_register_INT32(names[type], cpu, "SV", &I.SignVal, 1);
-	state_save_register_UINT32(names[type], cpu, "IV", &I.int_vector, 1);
-	state_save_register_UINT32(names[type], cpu, "PI", &I.pending_irq, 1);
-	state_save_register_UINT32(names[type], cpu, "NS", &I.nmi_state, 1);
-	state_save_register_UINT32(names[type], cpu, "IS", &I.irq_state, 1);
-	state_save_register_UINT32(names[type], cpu, "AV", &I.AuxVal, 1);
-	state_save_register_UINT32(names[type], cpu, "OV", &I.OverVal, 1);
-	state_save_register_UINT32(names[type], cpu, "ZV", &I.ZeroVal, 1);
-	state_save_register_UINT32(names[type], cpu, "CV", &I.CarryVal, 1);
-	state_save_register_UINT32(names[type], cpu, "PV", &I.ParityVal, 1);
+	state_save_register_item(names[type], index, I.ip);
+	state_save_register_item(names[type], index, I.TF);
+	state_save_register_item(names[type], index, I.IF);
+	state_save_register_item(names[type], index, I.DF);
+	state_save_register_item(names[type], index, I.MF);
+	state_save_register_item(names[type], index, I.SignVal);
+	state_save_register_item(names[type], index, I.int_vector);
+	state_save_register_item(names[type], index, I.pending_irq);
+	state_save_register_item(names[type], index, I.nmi_state);
+	state_save_register_item(names[type], index, I.irq_state);
+	state_save_register_item(names[type], index, I.AuxVal);
+	state_save_register_item(names[type], index, I.OverVal);
+	state_save_register_item(names[type], index, I.ZeroVal);
+	state_save_register_item(names[type], index, I.CarryVal);
+	state_save_register_item(names[type], index, I.ParityVal);
+
+	I.irq_callback = irqcallback;
 }
 
 /* Wrappers for the different CPU types */
 #if (HAS_V20)
-void v20_init(void) { nec_init(0); }
+void v20_init(int index, int clock, const void *config, int (*irqcallback)(int)) { nec_init(index, clock, config, irqcallback, 0); }
 int v20_execute(int cycles)
 {
 	nec_ICount=cycles;
@@ -1008,7 +1000,7 @@ int v20_execute(int cycles)
 #endif
 
 #if (HAS_V30)
-void v30_init(void) { nec_init(1); }
+void v30_init(int index, int clock, const void *config, int (*irqcallback)(int)) { nec_init(index, clock, config, irqcallback, 1); }
 int v30_execute(int cycles) {
 	nec_ICount=cycles;
 	cpu_type=V30;
@@ -1035,7 +1027,7 @@ int v30_execute(int cycles) {
 #endif
 
 #if (HAS_V33)
-void v33_init(void) { nec_init(2); }
+void v33_init(int index, int clock, const void *config, int (*irqcallback)(int)) { nec_init(index, clock, config, irqcallback, 2); }
 int v33_execute(int cycles)
 {
 	nec_ICount=cycles;
@@ -1115,9 +1107,6 @@ static void nec_set_info(UINT32 state, union cpuinfo *info)
 		case CPUINFO_INT_REGISTER + NEC_SS:				I.sregs[SS] = info->i;					break;
 		case CPUINFO_INT_REGISTER + NEC_DS:				I.sregs[DS] = info->i;					break;
 		case CPUINFO_INT_REGISTER + NEC_VECTOR:			I.int_vector = info->i;					break;
-
-		/* --- the following bits of info are set as pointers to data or functions --- */
-		case CPUINFO_PTR_IRQ_CALLBACK:					I.irq_callback = info->irqcallback;		break;
 	}
 }
 
@@ -1188,8 +1177,7 @@ void nec_get_info(UINT32 state, union cpuinfo *info)
 		case CPUINFO_PTR_EXIT:							info->exit = nec_exit;					break;
 		case CPUINFO_PTR_EXECUTE:						/* set per-CPU */						break;
 		case CPUINFO_PTR_BURN:							info->burn = NULL;						break;
-		case CPUINFO_PTR_DISASSEMBLE:					info->disassemble = nec_dasm;			break;
-		case CPUINFO_PTR_IRQ_CALLBACK:					info->irqcallback = I.irq_callback;		break;
+		case CPUINFO_PTR_DISASSEMBLE_NEW:				info->disassemble_new = nec_dasm;			break;
 		case CPUINFO_PTR_INSTRUCTION_COUNTER:			info->icount = &nec_ICount;				break;
 		case CPUINFO_PTR_REGISTER_LAYOUT:				info->p = nec_reg_layout;				break;
 		case CPUINFO_PTR_WINDOW_LAYOUT:					info->p = nec_win_layout;				break;
