@@ -1,8 +1,8 @@
 /* IBM/Motorola PowerPC 4xx/6xx Emulator */
 
-#include "driver.h"
+#include <setjmp.h>
 #include "ppc.h"
-#include "mamedbg.h"
+#include "debugger.h"
 
 #if (HAS_PPC603)
 void ppc603_exception(int exception);
@@ -12,6 +12,8 @@ void ppc602_exception(int exception);
 #endif
 #if (HAS_PPC403)
 void ppc403_exception(int exception);
+UINT8 ppc403_spu_r(UINT32 a);
+void ppc403_spu_w(UINT32 a, UINT8 d);
 #endif
 
 #define RD				((op >> 21) & 0x1F)
@@ -47,6 +49,8 @@ void ppc403_exception(int exception);
 #define MSR				(ppc.msr)
 #define SRR0			(ppc.srr0)
 #define SRR1			(ppc.srr1)
+#define SRR2			(ppc.srr2)
+#define SRR3			(ppc.srr3)
 #define EVPR			(ppc.evpr)
 #define EXIER			(ppc.exier)
 #define EXISR			(ppc.exisr)
@@ -94,27 +98,30 @@ static UINT32		ppc_field_xlat[256];
 #define XER_OV			0x40000000
 #define XER_CA			0x20000000
 
-#define MSR_POW			0x00040000
+#define MSR_POW			0x00040000	/* Power Management Enable */
 #define MSR_WE			0x00040000
 #define MSR_CE			0x00020000
-#define MSR_ILE			0x00010000
-#define MSR_EE			0x00008000
-#define MSR_PR			0x00004000
-#define MSR_FP			0x00002000
-#define MSR_ME			0x00001000
+#define MSR_ILE			0x00010000	/* Interrupt Little Endian Mode */
+#define MSR_EE			0x00008000	/* External Interrupt Enable */
+#define MSR_PR			0x00004000	/* Problem State */
+#define MSR_FP			0x00002000	/* Floating Point Available */
+#define MSR_ME			0x00001000	/* Machine Check Enable */
 #define MSR_FE0			0x00000800
-#define MSR_SE			0x00000400
-#define MSR_BE			0x00000200
+#define MSR_SE			0x00000400	/* Single Step Trace Enable */
+#define MSR_BE			0x00000200	/* Branch Trace Enable */
 #define MSR_DE			0x00000200
 #define MSR_FE1			0x00000100
-#define MSR_IP			0x00000040
-#define MSR_IR			0x00000020
-#define MSR_DR			0x00000010
+#define MSR_IP			0x00000040	/* Interrupt Prefix */
+#define MSR_IR			0x00000020	/* Instruction Relocate */
+#define MSR_DR			0x00000010	/* Data Relocate */
 #define MSR_PE			0x00000008
 #define MSR_PX			0x00000004
-#define MSR_RI			0x00000002
+#define MSR_RI			0x00000002	/* Recoverable Interrupt Enable */
 #define MSR_LE			0x00000001
 
+#define TSR_ENW			0x80000000
+#define TSR_WIS			0x40000000
+
 #define BYTE_REVERSE16(x)	((((x) >> 8) & 0xff) | (((x) << 8) & 0xff00))
 #define BYTE_REVERSE32(x)	((((x) >> 24) & 0xff) | (((x) >> 8) & 0xff00) | (((x) << 8) & 0xff0000) | (((x) << 24) & 0xff000000))
 
@@ -135,6 +142,8 @@ typedef struct {
 	UINT8 sptc;
 	UINT8 sprb;
 	UINT8 sptb;
+	mame_timer *rx_timer;
+	mame_timer *tx_timer;
 } SPU_REGS;
 
 typedef union {
@@ -147,6 +156,11 @@ typedef union {
 	float f;
 } FPR32;
 
+typedef struct {
+	UINT32 u;
+	UINT32 l;
+} BATENT;
+
 
 typedef struct {
 	UINT32 r[32];
@@ -161,31 +175,28 @@ typedef struct {
 	UINT32 pvr;
 	UINT32 srr0;
 	UINT32 srr1;
+	UINT32 srr2;
+	UINT32 srr3;
 	UINT32 hid0;
 	UINT32 hid1;
+	UINT32 hid2;
 	UINT32 sdr1;
 	UINT32 sprg[4];
 
 	UINT32 dsisr;
 	UINT32 dar;
 	UINT32 ear;
+	UINT32 dmiss;
+	UINT32 dcmp;
+	UINT32 hash1;
+	UINT32 hash2;
+	UINT32 imiss;
+	UINT32 icmp;
+	UINT32 rpa;
 
-	UINT32 ibat0l;
-	UINT32 ibat0u;
-	UINT32 ibat1l;
-	UINT32 ibat1u;
-	UINT32 ibat2l;
-	UINT32 ibat2u;
-	UINT32 ibat3l;
-	UINT32 ibat3u;
-	UINT32 dbat0l;
-	UINT32 dbat0u;
-	UINT32 dbat1l;
-	UINT32 dbat1u;
-	UINT32 dbat2l;
-	UINT32 dbat2u;
-	UINT32 dbat3l;
-	UINT32 dbat3u;
+
+	BATENT ibat[4];
+	BATENT dbat[4];
 
 	UINT32 evpr;
 	UINT32 exier;
@@ -199,8 +210,17 @@ typedef struct {
 	UINT32 iccr;
 	UINT32 dccr;
 	UINT32 pit;
+	UINT32 pit_counter;
+ 	UINT32 pit_int_enable;
 	UINT32 tsr;
 	UINT32 dbsr;
+	UINT32 sgr;
+	UINT32 pid;
+	UINT32 pbl1, pbl2, pbu1, pbu2;
+	UINT32 fit_bit;
+	UINT32 fit_int_enable;
+	UINT32 wdt_bit;
+	UINT32 wdt_int_enable;
 
 	SPU_REGS spu;
 	DMA_REGS dma[4];
@@ -209,7 +229,8 @@ typedef struct {
 	int reserved;
 	UINT32 reserved_address;
 
-	int exception_pending;
+	int interrupt_pending;
+	int external_int;
 
 	UINT64 tb;			/* 56-bit timebase register */
 
@@ -217,20 +238,41 @@ typedef struct {
 
 
 	/* STUFF added for the 6xx series */
-	UINT32 dec;
+	UINT32 dec, dec_frac;
 	UINT32 fpscr;
 
 	FPR	fpr[32];
 	UINT32 sr[16];
 
+#if HAS_PPC603
 	int is603;
+#endif
+#if HAS_PPC602
 	int is602;
+#endif
 
 	/* PowerPC 602 specific registers */
 	UINT32 lt;
 	UINT32 sp;
 	UINT32 tcr;
 	UINT32 ibr;
+
+	/* PowerPC function pointers for memory accesses/exceptions */
+	jmp_buf exception_jmpbuf;
+	UINT8 (*read8)(offs_t address);
+	UINT16 (*read16)(offs_t address);
+	UINT32 (*read32)(offs_t address);
+	UINT64 (*read64)(offs_t address);
+	void (*write8)(offs_t address, UINT8 data);
+	void (*write16)(offs_t address, UINT16 data);
+	void (*write32)(offs_t address, UINT32 data);
+	void (*write64)(offs_t address, UINT64 data);
+	UINT16 (*read16_unaligned)(offs_t address);
+	UINT32 (*read32_unaligned)(offs_t address);
+	UINT64 (*read64_unaligned)(offs_t address);
+	void (*write16_unaligned)(offs_t address, UINT16 data);
+	void (*write32_unaligned)(offs_t address, UINT32 data);
+	void (*write64_unaligned)(offs_t address, UINT64 data);
 } PPC_REGS;
 
 
@@ -244,12 +286,48 @@ typedef struct {
 
 
 static int ppc_icount;
+static int ppc_tb_base_icount;
+static int ppc_dec_base_icount;
+static int ppc_dec_trigger_cycle;
+static int bus_freq_multiplier = 1;
 static PPC_REGS ppc;
 static UINT32 ppc_rotate_mask[32][32];
 
 #define ROPCODE(pc)			cpu_readop32(pc)
 #define ROPCODE64(pc)		cpu_readop64(DWORD_XOR_BE(pc))
 
+/*********************************************************************/
+
+INLINE int IS_PPC602(void)
+{
+#if HAS_PPC602
+	return ppc.is602;
+#else
+	return 0;
+#endif
+}
+
+INLINE int IS_PPC603(void)
+{
+#if HAS_PPC603
+	return ppc.is603;
+#else
+	return 0;
+#endif
+}
+
+INLINE int IS_PPC403(void)
+{
+#if HAS_PPC403
+	return !IS_PPC602() && !IS_PPC603();
+#else
+	return 0;
+#endif
+}
+
+/*********************************************************************/
+
+
 INLINE void SET_CR0(INT32 rd)
 {
 	if( rd < 0 ) {
@@ -319,6 +397,63 @@ INLINE UINT32 check_condition_code(UINT32 bo, UINT32 bi)
 	return ctr_ok && condition_ok;
 }
 
+INLINE UINT64 ppc_read_timebase(void)
+{
+	int cycles = ppc_tb_base_icount - ppc_icount;
+
+	if (IS_PPC603() || IS_PPC602())
+	{
+		/* timebase is incremented once every four core clock cycles, so adjust the cycles accordingly */
+		return ppc.tb + (cycles / 4);
+	}
+	else
+	{
+		/* timebase is incremented once every core cycle on PPC403 */
+		return ppc.tb + cycles;
+	}
+}
+
+INLINE void ppc_write_timebase_l(UINT32 tbl)
+{
+	ppc_tb_base_icount = ppc_icount;
+
+	ppc.tb &= ~0xffffffff;
+	ppc.tb |= tbl;
+}
+
+INLINE void ppc_write_timebase_h(UINT32 tbh)
+{
+	ppc_tb_base_icount = ppc_icount;
+
+	ppc.tb &= 0xffffffff;
+	ppc.tb |= (UINT64)(tbh) << 32;
+}
+
+INLINE UINT32 read_decrementer(void)
+{
+	int cycles = ppc_dec_base_icount - ppc_icount;
+
+	/* decrementer is decremented once every four bus clock cycles, so adjust the cycles accordingly */
+	return DEC - (cycles / (bus_freq_multiplier * 2));
+}
+
+INLINE void write_decrementer(UINT32 value)
+{
+	ppc_dec_base_icount = ppc_icount + (ppc_dec_base_icount - ppc_icount) % (bus_freq_multiplier * 2);
+
+	DEC = value;
+
+	/* check if decrementer exception occurs during execution */
+	if ((UINT32)(DEC - ppc_icount) > (UINT32)(DEC))
+	{
+		ppc_dec_trigger_cycle = ppc_icount - DEC;
+	}
+	else
+	{
+		ppc_dec_trigger_cycle = 0x7fffffff;
+	}
+}
+
 /*********************************************************************/
 
 INLINE void ppc_set_spr(int spr, UINT32 value)
@@ -338,54 +473,66 @@ INLINE void ppc_set_spr(int spr, UINT32 value)
 	}
 
 #if (HAS_PPC603 || HAS_PPC602)
-	if(ppc.is603 || ppc.is602) {
+	if(IS_PPC602() || IS_PPC603()) {
 		switch(spr)
 		{
 			case SPR603E_DEC:
 				if((value & 0x80000000) && !(DEC & 0x80000000))
 				{
 					/* trigger interrupt */
-					printf("ERROR: set_spr to DEC triggers IRQ\n");
-					exit(1);
+#if HAS_PPC602
+					if (IS_PPC602())
+						ppc602_exception(EXCEPTION_DECREMENTER);
+#endif
+#if HAS_PPC603
+					if (IS_PPC603())
+						ppc603_exception(EXCEPTION_DECREMENTER);
+#endif
 				}
-				DEC = value;
+				write_decrementer(value);
 				return;
 
 			case SPR603E_TBL_W:
 			case SPR603E_TBL_R: /* special 603e case */
-				ppc.tb &= U64(0xffffffff00000000);
-				ppc.tb |= (UINT64)(value);
+				ppc_write_timebase_l(value);
 				return;
 
 			case SPR603E_TBU_R:
 			case SPR603E_TBU_W: /* special 603e case */
-				osd_die("ERROR: set_spr - TBU_W = %08X\n", value);
+				ppc_write_timebase_h(value);
 				return;
 
-			case SPR603E_HID0:
-				ppc.hid0 = value;
-				return;
+			case SPR603E_HID0:			ppc.hid0 = value; return;
+			case SPR603E_HID1:			ppc.hid1 = value; return;
+			case SPR603E_HID2:			ppc.hid2 = value; return;
 
-			case SPR603E_HID1:
-				ppc.hid1 = value;
-				return;
+			case SPR603E_DSISR:			ppc.dsisr = value; return;
+			case SPR603E_DAR:			ppc.dar = value; return;
+			case SPR603E_EAR:			ppc.ear = value; return;
+			case SPR603E_DMISS:			ppc.dmiss = value; return;
+			case SPR603E_DCMP:			ppc.dcmp = value; return;
+			case SPR603E_HASH1:			ppc.hash1 = value; return;
+			case SPR603E_HASH2:			ppc.hash2 = value; return;
+			case SPR603E_IMISS:			ppc.imiss = value; return;
+			case SPR603E_ICMP:			ppc.icmp = value; return;
+			case SPR603E_RPA:			ppc.rpa = value; return;
 
-			case SPR603E_IBAT0L:		ppc.ibat0l = value; return;
-			case SPR603E_IBAT0U:		ppc.ibat0u = value; return;
-			case SPR603E_IBAT1L:		ppc.ibat1l = value; return;
-			case SPR603E_IBAT1U:		ppc.ibat1u = value; return;
-			case SPR603E_IBAT2L:		ppc.ibat2l = value; return;
-			case SPR603E_IBAT2U:		ppc.ibat2u = value; return;
-			case SPR603E_IBAT3L:		ppc.ibat3l = value; return;
-			case SPR603E_IBAT3U:		ppc.ibat3u = value; return;
-			case SPR603E_DBAT0L:		ppc.dbat0l = value; return;
-			case SPR603E_DBAT0U:		ppc.dbat0u = value; return;
-			case SPR603E_DBAT1L:		ppc.dbat1l = value; return;
-			case SPR603E_DBAT1U:		ppc.dbat1u = value; return;
-			case SPR603E_DBAT2L:		ppc.dbat2l = value; return;
-			case SPR603E_DBAT2U:		ppc.dbat2u = value; return;
-			case SPR603E_DBAT3L:		ppc.dbat3l = value; return;
-			case SPR603E_DBAT3U:		ppc.dbat3u = value; return;
+			case SPR603E_IBAT0L:		ppc.ibat[0].l = value; return;
+			case SPR603E_IBAT0U:		ppc.ibat[0].u = value; return;
+			case SPR603E_IBAT1L:		ppc.ibat[1].l = value; return;
+			case SPR603E_IBAT1U:		ppc.ibat[1].u = value; return;
+			case SPR603E_IBAT2L:		ppc.ibat[2].l = value; return;
+			case SPR603E_IBAT2U:		ppc.ibat[2].u = value; return;
+			case SPR603E_IBAT3L:		ppc.ibat[3].l = value; return;
+			case SPR603E_IBAT3U:		ppc.ibat[3].u = value; return;
+			case SPR603E_DBAT0L:		ppc.dbat[0].l = value; return;
+			case SPR603E_DBAT0U:		ppc.dbat[0].u = value; return;
+			case SPR603E_DBAT1L:		ppc.dbat[1].l = value; return;
+			case SPR603E_DBAT1U:		ppc.dbat[1].u = value; return;
+			case SPR603E_DBAT2L:		ppc.dbat[2].l = value; return;
+			case SPR603E_DBAT2U:		ppc.dbat[2].u = value; return;
+			case SPR603E_DBAT3L:		ppc.dbat[3].l = value; return;
+			case SPR603E_DBAT3U:		ppc.dbat[3].u = value; return;
 
 			case SPR603E_SDR1:
 				ppc.sdr1 = value;
@@ -409,25 +556,54 @@ INLINE void ppc_set_spr(int spr, UINT32 value)
 #endif
 
 #if (HAS_PPC403)
-	if (!ppc.is603 && !ppc.is602) {
+	if (IS_PPC403()) {
 		switch(spr)
 		{
-			case SPR403_TBHI:		ppc.tb &= 0xffffffff; ppc.tb |= (UINT64)value << 32; return;
-			case SPR403_TBLO:		ppc.tb &= U64(0xffffffff00000000); ppc.tb |= value; return;
+			case SPR403_TBHI:		ppc_write_timebase_h(value); return;
+			case SPR403_TBLO:		ppc_write_timebase_l(value); return;
+
 			case SPR403_TSR:
 				ppc.tsr &= ~value; /* 1 clears, 0 does nothing */
 				return;
+
+			case SPR403_TCR:
+				switch((value >> 24) & 0x3)
+				{
+					case 0: ppc.fit_bit = 1 << 8; break;
+					case 1: ppc.fit_bit = 1 << 12; break;
+					case 2: ppc.fit_bit = 1 << 16; break;
+					case 3: ppc.fit_bit = 1 << 20; break;
+				}
+				switch((value >> 30) & 0x3)
+				{
+					case 0: ppc.wdt_bit = 1 << 16; break;
+					case 1: ppc.wdt_bit = 1 << 20; break;
+					case 2: ppc.wdt_bit = 1 << 24; break;
+					case 3: ppc.wdt_bit = 1 << 28; break;
+				}
+				ppc.fit_int_enable = (value >> 23) & 0x1;
+				ppc.wdt_int_enable = (value >> 27) & 0x1;
+				ppc.tcr = value;
+				return;
+
 			case SPR403_ESR:		ppc.esr = value; return;
-			case SPR403_TCR:		ppc.tcr = value; return;
 			case SPR403_ICCR:		ppc.iccr = value; return;
 			case SPR403_DCCR:		ppc.dccr = value; return;
 			case SPR403_EVPR:		EVPR = value & 0xffff0000; return;
 			case SPR403_PIT:		ppc.pit = value; return;
+			case SPR403_SGR:		ppc.sgr = value; return;
+			case SPR403_DBSR:		ppc.dbsr = value; return;
+			case SPR403_DCWR:		return;
+			case SPR403_PID:		ppc.pid = value; return;
+			case SPR403_PBL1:		ppc.pbl1 = value; printf("PPC: PBL1 = %08X\n", ppc.pbl1); return;
+			case SPR403_PBU1:		ppc.pbu1 = value; printf("PPC: PBU1 = %08X\n", ppc.pbu1); return;
+			case SPR403_PBL2:		ppc.pbl2 = value; printf("PPC: PBL2 = %08X\n", ppc.pbl2); return;
+			case SPR403_PBU2:		ppc.pbu2 = value; printf("PPC: PBU2 = %08X\n", ppc.pbu2); return;
 		}
 	}
 #endif
 
-	osd_die("ppc: set_spr: unknown spr %d (%03X) !\n", spr, spr);
+	fatalerror("ppc: set_spr: unknown spr %d (%03X) !", spr, spr);
 }
 
 INLINE UINT32 ppc_get_spr(int spr)
@@ -447,12 +623,15 @@ INLINE UINT32 ppc_get_spr(int spr)
 	}
 
 #if (HAS_PPC403)
-	if (!ppc.is603 && !ppc.is602)
+	if (IS_PPC403())
 	{
 		switch (spr)
 		{
-			case SPR403_TBLO:		return (ppc.tb & 0xffffffff);
-			case SPR403_TBHI:		return ((ppc.tb >> 32) & 0xffffff);
+			case SPR403_TBLU:
+			case SPR403_TBLO:		return (UINT32)(ppc_read_timebase());
+			case SPR403_TBHU:
+			case SPR403_TBHI:		return (UINT32)(ppc_read_timebase() >> 32);
+
 			case SPR403_EVPR:		return EVPR;
 			case SPR403_ESR:		return ppc.esr;
 			case SPR403_TCR:		return ppc.tcr;
@@ -460,6 +639,12 @@ INLINE UINT32 ppc_get_spr(int spr)
 			case SPR403_DCCR:		return ppc.dccr;
 			case SPR403_PIT:		return ppc.pit;
 			case SPR403_DBSR:		return ppc.dbsr;
+			case SPR403_SGR:		return ppc.sgr;
+			case SPR403_TSR:		return ppc.tsr;
+			case SPR403_PBL1:		return ppc.pbl1;
+			case SPR403_PBU1:		return ppc.pbu1;
+			case SPR403_PBL2:		return ppc.pbl2;
+			case SPR403_PBU2:		return ppc.pbu2;
 		}
 	}
 #endif
@@ -477,80 +662,98 @@ INLINE UINT32 ppc_get_spr(int spr)
 #endif
 
 #if (HAS_PPC603 || HAS_PPC602)
-	if (ppc.is603 || ppc.is602)
+	if (IS_PPC603() || IS_PPC602())
 	{
 		switch (spr)
 		{
 			case SPR603E_TBL_R:
-				osd_die("ppc: get_spr: TBL_R \n");
+				fatalerror("ppc: get_spr: TBL_R ");
 				break;
 
 			case SPR603E_TBU_R:
-				osd_die("ppc: get_spr: TBU_R \n");
+				fatalerror("ppc: get_spr: TBU_R ");
 				break;
 
-			case SPR603E_TBL_W:		return (ppc.tb & 0xffffffff);
-			case SPR603E_TBU_W:		return ((ppc.tb >> 32) & 0xffffffff);
+			case SPR603E_TBL_W:		return (UINT32)(ppc_read_timebase());
+			case SPR603E_TBU_W:		return (UINT32)(ppc_read_timebase() >> 32);
 			case SPR603E_HID0:		return ppc.hid0;
 			case SPR603E_HID1:		return ppc.hid1;
-			case SPR603E_DEC:		return DEC;
+			case SPR603E_HID2:		return ppc.hid2;
+			case SPR603E_DEC:		return read_decrementer();
 			case SPR603E_SDR1:		return ppc.sdr1;
 			case SPR603E_DSISR:		return ppc.dsisr;
 			case SPR603E_DAR:		return ppc.dar;
 			case SPR603E_EAR:		return ppc.ear;
-			case SPR603E_IBAT0L:	return ppc.ibat0l;
-			case SPR603E_IBAT0U:	return ppc.ibat0u;
-			case SPR603E_IBAT1L:	return ppc.ibat1l;
-			case SPR603E_IBAT1U:	return ppc.ibat1u;
-			case SPR603E_IBAT2L:	return ppc.ibat2l;
-			case SPR603E_IBAT2U:	return ppc.ibat2u;
-			case SPR603E_IBAT3L:	return ppc.ibat3l;
-			case SPR603E_IBAT3U:	return ppc.ibat3u;
-			case SPR603E_DBAT0L:	return ppc.dbat0l;
-			case SPR603E_DBAT0U:	return ppc.dbat0u;
-			case SPR603E_DBAT1L:	return ppc.dbat1l;
-			case SPR603E_DBAT1U:	return ppc.dbat1u;
-			case SPR603E_DBAT2L:	return ppc.dbat2l;
-			case SPR603E_DBAT2U:	return ppc.dbat2u;
-			case SPR603E_DBAT3L:	return ppc.dbat3l;
-			case SPR603E_DBAT3U:	return ppc.dbat3u;
+			case SPR603E_DMISS:		return ppc.dmiss;
+			case SPR603E_DCMP:		return ppc.dcmp;
+			case SPR603E_HASH1:		return ppc.hash1;
+			case SPR603E_HASH2:		return ppc.hash2;
+			case SPR603E_IMISS:		return ppc.imiss;
+			case SPR603E_ICMP:		return ppc.icmp;
+			case SPR603E_RPA:		return ppc.rpa;
+			case SPR603E_IBAT0L:	return ppc.ibat[0].l;
+			case SPR603E_IBAT0U:	return ppc.ibat[0].u;
+			case SPR603E_IBAT1L:	return ppc.ibat[1].l;
+			case SPR603E_IBAT1U:	return ppc.ibat[1].u;
+			case SPR603E_IBAT2L:	return ppc.ibat[2].l;
+			case SPR603E_IBAT2U:	return ppc.ibat[2].u;
+			case SPR603E_IBAT3L:	return ppc.ibat[3].l;
+			case SPR603E_IBAT3U:	return ppc.ibat[3].u;
+			case SPR603E_DBAT0L:	return ppc.dbat[0].l;
+			case SPR603E_DBAT0U:	return ppc.dbat[0].u;
+			case SPR603E_DBAT1L:	return ppc.dbat[1].l;
+			case SPR603E_DBAT1U:	return ppc.dbat[1].u;
+			case SPR603E_DBAT2L:	return ppc.dbat[2].l;
+			case SPR603E_DBAT2U:	return ppc.dbat[2].u;
+			case SPR603E_DBAT3L:	return ppc.dbat[3].l;
+			case SPR603E_DBAT3U:	return ppc.dbat[3].u;
 		}
 	}
 #endif
 
-	osd_die("ppc: get_spr: unknown spr %d (%03X) !\n", spr, spr);
+	fatalerror("ppc: get_spr: unknown spr %d (%03X) !", spr, spr);
 	return 0;
 }
 
+static UINT8 ppc_read8_translated(offs_t address);
+static UINT16 ppc_read16_translated(offs_t address);
+static UINT32 ppc_read32_translated(offs_t address);
+static UINT64 ppc_read64_translated(offs_t address);
+static void ppc_write8_translated(offs_t address, UINT8 data);
+static void ppc_write16_translated(offs_t address, UINT16 data);
+static void ppc_write32_translated(offs_t address, UINT32 data);
+static void ppc_write64_translated(offs_t address, UINT64 data);
+
 INLINE void ppc_set_msr(UINT32 value)
 {
-	int i;
 	if( value & (MSR_ILE | MSR_LE) )
-		osd_die("ppc: set_msr: little_endian mode not supported !\n");
+		fatalerror("ppc: set_msr: little_endian mode not supported !");
+
 	MSR = value;
 
-	if( value & MSR_EE ) {
-		/* check for pending interrupts */
-		for(i=0; i < 32; i++) {
-			if(ppc.exception_pending & (1 << i)) {
-				ppc.exception_pending &= ~(1 << i);
-#if (HAS_PPC603)
-				if(ppc.is603) {
-					ppc603_exception(i);
-				}
-#endif
-#if (HAS_PPC602)
-				if(ppc.is602) {
-					ppc602_exception(i);
-				}
-#endif
-#if (HAS_PPC403)
-				if(!ppc.is602 && !ppc.is603) {
-					ppc403_exception(i);
-				}
-#endif
-				break;
-			}
+	if (IS_PPC603() || IS_PPC602())
+	{
+		if (!(MSR & MSR_DR))
+		{
+			ppc.read8 = program_read_byte_64be;
+			ppc.read16 = program_read_word_64be;
+			ppc.read32 = program_read_dword_64be;
+			ppc.read64 = program_read_qword_64be;
+			ppc.write8 = program_write_byte_64be;
+			ppc.write16 = program_write_word_64be;
+			ppc.write32 = program_write_dword_64be;
+			ppc.write64 = program_write_qword_64be;
+		}
+		else
+		{
+			ppc.read8 = ppc_read8_translated;
+			ppc.read16 = ppc_read16_translated;
+			ppc.read32 = ppc_read32_translated;
+			ppc.read64 = ppc_read64_translated;
+			ppc.write8 = ppc_write8_translated;
+			ppc.write16 = ppc_write16_translated;
+			ppc.write32 = ppc_write32_translated;
+			ppc.write64 = ppc_write64_translated;
 		}
 	}
 }
@@ -577,6 +780,11 @@ INLINE UINT32 ppc_get_cr(void)
 	return CR(0) << 28 | CR(1) << 24 | CR(2) << 20 | CR(3) << 16 | CR(4) << 12 | CR(5) << 8 | CR(6) << 4 | CR(7);
 }
 
+INLINE void ppc_exception(int exception_type)
+{
+	longjmp(ppc.exception_jmpbuf, exception_type);
+}
+
 /***********************************************************************/
 
 static void (* optable19[1024])(UINT32);
@@ -585,6 +793,8 @@ static void (* optable59[1024])(UINT32);
 static void (* optable63[1024])(UINT32);
 static void (* optable[64])(UINT32);
 
+#include "ppc_mem.c"
+
 #if (HAS_PPC403)
 #include "ppc403.c"
 #endif
@@ -597,147 +807,6 @@ static void (* optable[64])(UINT32);
 #include "ppc603.c"
 #endif
 
-INLINE UINT8 READ8(UINT32 a)
-{
-	if (ppc.is603)
-	{
-		return program_read_byte_64be(a);
-	}
-
-	if(a >= 0x40000000 && a <= 0x4000000f ) {		/* Serial Port */
-		return ppc403_spu_r(a);
-	} else {
-		return program_read_byte_32be(a);
-	}
-}
-
-INLINE UINT16 READ16(UINT32 a)
-{
-	if (ppc.is603) {
-		if( a & 0x1 ) {
-			return ((UINT16)program_read_byte_64be(a+0) << 8) | ((UINT16)program_read_byte_64be(a+1) << 0);
-		}
-		return program_read_word_64be(a);
-	}
-
-	if( a & 0x1 ) {
-		osd_die("ppc: Unaligned read16 %08X\n", a);
-	}
-
-	return program_read_word_32be(a);
-}
-
-INLINE UINT32 READ32(UINT32 a)
-{
-	if (ppc.is603) {
-		if( a & 0x3 ) {
-			return ((UINT32)program_read_byte_64be(a+0) << 24) | ((UINT32)program_read_byte_64be(a+1) << 16) |
-				   ((UINT32)program_read_byte_64be(a+2) << 8) | ((UINT32)program_read_byte_64be(a+3) << 0);
-		}
-		return program_read_dword_64be(a);
-	}
-
-	if( a & 0x3 ) {
-		osd_die("ppc: Unaligned read32 %08X\n", a);
-	}
-
-	return program_read_dword_32be(a);
-}
-
-INLINE UINT64 READ64(UINT32 a)
-{
-#if (HAS_PPC603)
-	if( a & 0x7 ) {
-		return ((UINT64)READ32(a+0) << 32) | (UINT64)(READ32(a+4));
-	}
-	return program_read_qword_64be(a);
-#else
-	return 0
-#endif
-}
-
-
-INLINE void WRITE8(UINT32 a, UINT8 d)
-{
-	if (ppc.is603)
-	{
-		program_write_byte_64be(a, d&0xff);
-		return;
-	}
-
-	if( a >= 0x40000000 && a <= 0x4000000f ) {		/* Serial Port */
-		ppc403_spu_w(a, d);
-	} else {
-		program_write_byte_32be(a, d);
-	}
-}
-
-INLINE void WRITE16(UINT32 a, UINT16 d)
-{
-	if (ppc.is603)
-	{
-		if( a & 0x1 ) {
-			program_write_byte_64be(a+0, (UINT8)(d >> 8));
-			program_write_byte_64be(a+1, (UINT8)(d));
-			return;
-		}
-		program_write_word_64be(a, d);
-		return;
-	}
-
-	if( a & 0x1 ) {
-		osd_die("ppc: Unaligned write16 %08X, %04X\n", a, d);
-	} else {
-		program_write_word_32be(a, d);
-	}
-}
-
-INLINE void WRITE32(UINT32 a, UINT32 d)
-{
-	if (ppc.is603)
-	{
-		if( ppc.reserved ) {
-			if( a == ppc.reserved_address ) {
-				ppc.reserved = 0;
-			}
-		}
-		if( a & 0x3 ) {
-			program_write_byte_64be(a+0, (UINT8)(d >> 24));
-			program_write_byte_64be(a+1, (UINT8)(d >> 16));
-			program_write_byte_64be(a+2, (UINT8)(d >> 8));
-			program_write_byte_64be(a+3, (UINT8)(d >> 0));
-			return;
-		}
-		program_write_dword_64be(a, d);
-		return;
-	}
-
-	if( a & 0x3 ) {
-		osd_die("ppc: Unaligned write32 %08X, %08X\n", a, d);
-	} else {
-		if( ppc.reserved ) {
-			if( a == ppc.reserved_address ) {
-				ppc.reserved = 0;
-			}
-		}
-		program_write_dword_32be(a, d);
-	}
-}
-
-INLINE void WRITE64(UINT32 a, UINT64 d)
-{
-#if (HAS_PPC603)
-	if( a & 0x7 ) {
-		WRITE32(a+0, (UINT32)(d >> 32));
-		WRITE32(a+4, (UINT32)(d));
-		return;
-	}
-	program_write_qword_64be(a, d);
-#else
-	return 0;
-#endif
-}
-
 /********************************************************************/
 
 #include "ppc_ops.c"
@@ -749,6 +818,8 @@ void ppc_init(void)
 {
 	int i,j;
 
+	memset(&ppc, 0, sizeof(ppc));
+
 	for( i=0; i < 64; i++ ) {
 		optable[i] = ppc_invalid;
 	}
@@ -799,8 +870,11 @@ void ppc_init(void)
 
 
 /* !!! probably should move this stuff elsewhere !!! */
-static void ppc403_init(void)
+#if HAS_PPC403
+static void ppc403_init(int index, int clock, const void *_config, int (*irqcallback)(int))
 {
+	const ppc_config *config = _config;
+
 	ppc_init();
 
 	/* PPC403 specific opcodes */
@@ -817,17 +891,38 @@ static void ppc403_init(void)
 	/* !!! why is rfci here !!! */
 	optable19[51] = ppc_rfci;
 
-	ppc.is603 = 0;
+	ppc.spu.rx_timer = timer_alloc(ppc403_spu_rx_callback);
+	ppc.spu.tx_timer = timer_alloc(ppc403_spu_tx_callback);
+
+	ppc.read8 = ppc403_read8;
+	ppc.read16 = ppc403_read16;
+	ppc.read32 = ppc403_read32;
+	ppc.write8 = ppc403_write8;
+	ppc.write16 = ppc403_write16;
+	ppc.write32 = ppc403_write32;
+	ppc.read16_unaligned = ppc403_read16_unaligned;
+	ppc.read32_unaligned = ppc403_read32_unaligned;
+	ppc.write16_unaligned = ppc403_write16_unaligned;
+	ppc.write32_unaligned = ppc403_write32_unaligned;
+
+	ppc.irq_callback = irqcallback;
+
+	ppc.pvr = config->pvr;
 }
 
 static void ppc403_exit(void)
 {
 
 }
+#endif /* HAS_PPC403 */
 
 
-static void ppc603_init(void)
+#if (HAS_PPC603)
+static void ppc603_init(int index, int clock, const void *_config, int (*irqcallback)(int))
 {
+	const ppc_config *config = _config;
+	int pll_config = 0;
+	float multiplier;
 	int i ;
 
 	ppc_init() ;
@@ -918,16 +1013,58 @@ static void ppc603_init(void)
 	}
 
 	ppc.is603 = 1;
+
+	ppc.read8 = program_read_byte_64be;
+	ppc.read16 = program_read_word_64be;
+	ppc.read32 = program_read_dword_64be;
+	ppc.read64 = program_read_qword_64be;
+	ppc.write8 = program_write_byte_64be;
+	ppc.write16 = program_write_word_64be;
+	ppc.write32 = program_write_dword_64be;
+	ppc.write64 = program_write_qword_64be;
+	ppc.read16_unaligned = ppc_read16_unaligned;
+	ppc.read32_unaligned = ppc_read32_unaligned;
+	ppc.read64_unaligned = ppc_read64_unaligned;
+	ppc.write16_unaligned = ppc_write16_unaligned;
+	ppc.write32_unaligned = ppc_write32_unaligned;
+	ppc.write64_unaligned = ppc_write64_unaligned;
+
+	ppc.irq_callback = irqcallback;
+
+	ppc.pvr = config->pvr;
+
+	multiplier = (float)((config->bus_frequency_multiplier >> 4) & 0xf) +
+				 (float)(config->bus_frequency_multiplier & 0xf) / 10.0f;
+	bus_freq_multiplier = (int)(multiplier * 2);
+
+	switch(config->pvr)
+	{
+		case PPC_MODEL_603E:	pll_config = mpc603e_pll_config[bus_freq_multiplier-1][config->bus_frequency]; break;
+		case PPC_MODEL_603EV:	pll_config = mpc603ev_pll_config[bus_freq_multiplier-1][config->bus_frequency]; break;
+		case PPC_MODEL_603R:	pll_config = mpc603r_pll_config[bus_freq_multiplier-1][config->bus_frequency]; break;
+		default: break;
+	}
+
+	if (pll_config == -1)
+	{
+		fatalerror("PPC: Invalid bus/multiplier combination (bus frequency = %d, multiplier = %1.1f)", config->bus_frequency, multiplier);
+	}
+
+	ppc.hid1 = pll_config << 28;
 }
 
 static void ppc603_exit(void)
 {
 
 }
+#endif
 
 #if (HAS_PPC602)
-static void ppc602_init(void)
+static void ppc602_init(int index, int clock, const void *_config, int (*irqcallback)(int))
 {
+	float multiplier;
+	const ppc_config *config = _config;
+
 	int i ;
 
 	ppc_init() ;
@@ -1017,8 +1154,30 @@ static void ppc602_init(void)
 			((i & 0x01) ? 0x0000000F : 0);
 	}
 
-	ppc.is603 = 0;
 	ppc.is602 = 1;
+
+	ppc.read8 = program_read_byte_64be;
+	ppc.read16 = program_read_word_64be;
+	ppc.read32 = program_read_dword_64be;
+	ppc.read64 = program_read_qword_64be;
+	ppc.write8 = program_write_byte_64be;
+	ppc.write16 = program_write_word_64be;
+	ppc.write32 = program_write_dword_64be;
+	ppc.write64 = program_write_qword_64be;
+	ppc.read16_unaligned = ppc_read16_unaligned;
+	ppc.read32_unaligned = ppc_read32_unaligned;
+	ppc.read64_unaligned = ppc_read64_unaligned;
+	ppc.write16_unaligned = ppc_write16_unaligned;
+	ppc.write32_unaligned = ppc_write32_unaligned;
+	ppc.write64_unaligned = ppc_write64_unaligned;
+
+	ppc.irq_callback = irqcallback;
+
+	ppc.pvr = config->pvr;
+
+	multiplier = (float)((config->bus_frequency_multiplier >> 4) & 0xf) +
+				 (float)(config->bus_frequency_multiplier & 0xf) / 10.0f;
+	bus_freq_multiplier = (int)(multiplier * 2);
 }
 
 static void ppc602_exit(void)
@@ -1053,6 +1212,7 @@ static UINT8 ppc_reg_layout[] =
 	PPC_PC,			PPC_MSR,		-1,
 	PPC_CR,			PPC_LR,			-1,
 	PPC_CTR,		PPC_XER,		-1,
+	PPC_SRR0,		PPC_SRR1,		-1,
 	PPC_R0,		 	PPC_R16,		-1,
 	PPC_R1, 		PPC_R17,		-1,
 	PPC_R2, 		PPC_R18,		-1,
@@ -1080,25 +1240,30 @@ static UINT8 ppc_win_layout[] =
 	 0,23,80, 1,	/* command line window (bottom rows) */
 };
 
-static offs_t ppc_dasm(char *buffer, offs_t pc)
+static UINT8 ppc603_reg_layout[] =
 {
-#ifdef MAME_DEBUG
-	return ppc_dasm_one(buffer, pc, ROPCODE(pc));
-#else
-	sprintf(buffer, "$%08X", ROPCODE(pc));
-	return 4;
-#endif
-}
-
-static offs_t ppc_dasm64(char *buffer, offs_t pc)
-{
-#ifdef MAME_DEBUG
-	return ppc_dasm_one(buffer, pc, ROPCODE64(pc));
-#else
-	sprintf(buffer, "$%08X", (UINT32)ROPCODE64(pc));
-	return 4;
-#endif
-}
+	PPC_PC,			PPC_MSR,		-1,
+	PPC_CR,			PPC_LR,			-1,
+	PPC_CTR,		PPC_XER,		-1,
+	PPC_SRR0,		PPC_SRR1,		-1,
+	PPC_DEC,						-1,
+	PPC_R0,		 	PPC_R16,		-1,
+	PPC_R1, 		PPC_R17,		-1,
+	PPC_R2, 		PPC_R18,		-1,
+	PPC_R3, 		PPC_R19,		-1,
+	PPC_R4, 		PPC_R20,		-1,
+	PPC_R5, 		PPC_R21,		-1,
+	PPC_R6, 		PPC_R22,		-1,
+	PPC_R7, 		PPC_R23,		-1,
+	PPC_R8,			PPC_R24,		-1,
+	PPC_R9,			PPC_R25,		-1,
+	PPC_R10,		PPC_R26,		-1,
+	PPC_R11,		PPC_R27,		-1,
+	PPC_R12,		PPC_R28,		-1,
+	PPC_R13,		PPC_R29,		-1,
+	PPC_R14,		PPC_R30,		-1,
+	PPC_R15,		PPC_R31,		0
+};
 
 /**************************************************************************
  * Generic set_info
@@ -1115,6 +1280,8 @@ static void ppc_set_info(UINT32 state, union cpuinfo *info)
 		case CPUINFO_INT_REGISTER + PPC_LR:				LR = info->i;							break;
 		case CPUINFO_INT_REGISTER + PPC_CTR:			CTR = info->i;							break;
 		case CPUINFO_INT_REGISTER + PPC_XER:			XER = info->i;						 	break;
+		case CPUINFO_INT_REGISTER + PPC_SRR0:			SRR0 = info->i;							break;
+		case CPUINFO_INT_REGISTER + PPC_SRR1:			SRR1 = info->i;							break;
 
 		case CPUINFO_INT_REGISTER + PPC_R0:				ppc.r[0] = info->i;						break;
 		case CPUINFO_INT_REGISTER + PPC_R1:				ppc.r[1] = info->i;						break;
@@ -1148,16 +1315,13 @@ static void ppc_set_info(UINT32 state, union cpuinfo *info)
 		case CPUINFO_INT_REGISTER + PPC_R29:			ppc.r[29] = info->i;					break;
 		case CPUINFO_INT_REGISTER + PPC_R30:			ppc.r[30] = info->i;					break;
 		case CPUINFO_INT_REGISTER + PPC_R31:			ppc.r[31] = info->i;					break;
-
-		/* --- the following bits of info are set as pointers to data or functions --- */
-		case CPUINFO_PTR_IRQ_CALLBACK:					ppc.irq_callback = info->irqcallback;	break;
 	}
 }
 
 #if (HAS_PPC403)
-void ppc403_set_info(UINT32 state, union cpuinfo *info)
+static void ppc403_set_info(UINT32 state, union cpuinfo *info)
 {
-	if (state >= CPUINFO_INT_INPUT_STATE && state <= CPUINFO_INT_INPUT_STATE + 5)
+	if (state >= CPUINFO_INT_INPUT_STATE && state <= CPUINFO_INT_INPUT_STATE + 8)
 	{
 		ppc403_set_irq_line(state-CPUINFO_INT_INPUT_STATE, info->i);
 		return;
@@ -1170,7 +1334,7 @@ void ppc403_set_info(UINT32 state, union cpuinfo *info)
 #endif
 
 #if (HAS_PPC603)
-void ppc603_set_info(UINT32 state, union cpuinfo *info)
+static void ppc603_set_info(UINT32 state, union cpuinfo *info)
 {
 	if (state >= CPUINFO_INT_INPUT_STATE && state <= CPUINFO_INT_INPUT_STATE + 5)
 	{
@@ -1179,6 +1343,8 @@ void ppc603_set_info(UINT32 state, union cpuinfo *info)
 	}
 	switch(state)
 	{
+		case CPUINFO_INT_REGISTER + PPC_DEC:				write_decrementer(info->i);		break;
+		case CPUINFO_INT_INPUT_STATE + PPC_INPUT_LINE_SMI:	ppc603_set_smi_line(info->i);	break;
 		default:	ppc_set_info(state, info);		break;
 	}
 }
@@ -1220,6 +1386,8 @@ void ppc_get_info(UINT32 state, union cpuinfo *info)
 		case CPUINFO_INT_REGISTER + PPC_LR:				info->i = LR;							break;
 		case CPUINFO_INT_REGISTER + PPC_CTR:			info->i = CTR;							break;
 		case CPUINFO_INT_REGISTER + PPC_XER:			info->i = XER;							break;
+		case CPUINFO_INT_REGISTER + PPC_SRR0:			info->i = SRR0;							break;
+		case CPUINFO_INT_REGISTER + PPC_SRR1:			info->i = SRR1;							break;
 
 		case CPUINFO_INT_REGISTER + PPC_R0:				info->i = ppc.r[0];						break;
 		case CPUINFO_INT_REGISTER + PPC_R1:				info->i = ppc.r[1];						break;
@@ -1259,13 +1427,8 @@ void ppc_get_info(UINT32 state, union cpuinfo *info)
 		/* --- the following bits of info are returned as pointers to data or functions --- */
 		case CPUINFO_PTR_GET_CONTEXT:					info->getcontext = ppc_get_context;		break;
 		case CPUINFO_PTR_SET_CONTEXT:					info->setcontext = ppc_set_context;		break;
-		case CPUINFO_PTR_INIT:							info->init = ppc403_init;				break;
-		case CPUINFO_PTR_RESET:							info->reset = ppc403_reset;				break;
-		case CPUINFO_PTR_EXIT:							info->exit = ppc403_exit;				break;
-		case CPUINFO_PTR_EXECUTE:						info->execute = ppc403_execute;			break;
 		case CPUINFO_PTR_BURN:							info->burn = NULL;						break;
-		case CPUINFO_PTR_DISASSEMBLE:					info->disassemble = ppc_dasm;			break;
-		case CPUINFO_PTR_IRQ_CALLBACK:					info->irqcallback = ppc.irq_callback;	break;
+		case CPUINFO_PTR_DISASSEMBLE_NEW:				info->disassemble_new = ppc_dasm;		break;
 		case CPUINFO_PTR_INSTRUCTION_COUNTER:			info->icount = &ppc_icount;				break;
 		case CPUINFO_PTR_REGISTER_LAYOUT:				info->p = ppc_reg_layout;				break;
 		case CPUINFO_PTR_WINDOW_LAYOUT:					info->p = ppc_win_layout;				break;
@@ -1285,6 +1448,8 @@ void ppc_get_info(UINT32 state, union cpuinfo *info)
 		case CPUINFO_STR_REGISTER + PPC_LR:				sprintf(info->s = cpuintrf_temp_str(), "LR: %08X", LR); break;
 		case CPUINFO_STR_REGISTER + PPC_CTR:			sprintf(info->s = cpuintrf_temp_str(), "CTR: %08X", CTR); break;
 		case CPUINFO_STR_REGISTER + PPC_XER:			sprintf(info->s = cpuintrf_temp_str(), "XER: %08X", XER); break;
+		case CPUINFO_STR_REGISTER + PPC_SRR0:			sprintf(info->s = cpuintrf_temp_str(), "SRR0: %08X", SRR0); break;
+		case CPUINFO_STR_REGISTER + PPC_SRR1:			sprintf(info->s = cpuintrf_temp_str(), "SRR1: %08X", SRR1); break;
 
 		case CPUINFO_STR_REGISTER + PPC_R0:				sprintf(info->s = cpuintrf_temp_str(), "R0: %08X", ppc.r[0]); break;
 		case CPUINFO_STR_REGISTER + PPC_R1:				sprintf(info->s = cpuintrf_temp_str(), "R1: %08X", ppc.r[1]); break;
@@ -1327,7 +1492,7 @@ void ppc403_get_info(UINT32 state, union cpuinfo *info)
 	switch(state)
 	{
 		/* --- the following bits of info are returned as 64-bit signed integers --- */
-		case CPUINFO_INT_INPUT_LINES:					info->i = 5;							break;
+		case CPUINFO_INT_INPUT_LINES:					info->i = 8;							break;
 		case CPUINFO_INT_ENDIANNESS:					info->i = CPU_IS_BE;					break;
 
 		/* --- the following bits of info are returned as pointers to data or functions --- */
@@ -1356,6 +1521,9 @@ void ppc603_get_info(UINT32 state, union cpuinfo *info)
 
 		case CPUINFO_INT_DATABUS_WIDTH + ADDRESS_SPACE_PROGRAM:	info->i = 64;					break;
 		case CPUINFO_INT_ADDRBUS_WIDTH + ADDRESS_SPACE_PROGRAM: info->i = 32;					break;
+		case CPUINFO_INT_LOGADDR_WIDTH + ADDRESS_SPACE_PROGRAM: info->i = 32;					break;
+		case CPUINFO_INT_PAGE_SHIFT + ADDRESS_SPACE_PROGRAM: 	info->i = 17;					break;
+		case CPUINFO_INT_REGISTER + PPC_DEC:			info->i = read_decrementer(); break;
 
 		/* --- the following bits of info are returned as pointers to data or functions --- */
 		case CPUINFO_PTR_SET_INFO:					info->setinfo = ppc603_set_info;		break;
@@ -1363,10 +1531,15 @@ void ppc603_get_info(UINT32 state, union cpuinfo *info)
 		case CPUINFO_PTR_RESET:						info->reset = ppc603_reset;				break;
 		case CPUINFO_PTR_EXIT:						info->exit = ppc603_exit;				break;
 		case CPUINFO_PTR_EXECUTE:					info->execute = ppc603_execute;			break;
-		case CPUINFO_PTR_DISASSEMBLE:					info->disassemble = ppc_dasm64;			break;
+		case CPUINFO_PTR_READ:							info->read = ppc_read;					break;
+		case CPUINFO_PTR_WRITE:							info->write = ppc_write;				break;
+		case CPUINFO_PTR_READOP:						info->readop = ppc_readop;				break;
+		case CPUINFO_PTR_REGISTER_LAYOUT:				info->p = ppc603_reg_layout;				break;
+		case CPUINFO_PTR_TRANSLATE:						info->translate = ppc_translate_address_cb;	break;
 
 		/* --- the following bits of info are returned as NULL-terminated strings --- */
 		case CPUINFO_STR_NAME:							strcpy(info->s = cpuintrf_temp_str(), "PPC603"); break;
+		case CPUINFO_STR_REGISTER + PPC_DEC:			sprintf(info->s = cpuintrf_temp_str(), "DEC: %08X", read_decrementer()); break;
 
 		default:	ppc_get_info(state, info);		break;
 	}
@@ -1376,7 +1549,7 @@ void ppc603_get_info(UINT32 state, union cpuinfo *info)
 /* PowerPC 602 */
 
 #if (HAS_PPC602)
-void ppc602_set_info(UINT32 state, union cpuinfo *info)
+static void ppc602_set_info(UINT32 state, union cpuinfo *info)
 {
 	if (state >= CPUINFO_INT_INPUT_STATE && state <= CPUINFO_INT_INPUT_STATE + 5)
 	{
@@ -1406,7 +1579,9 @@ void ppc602_get_info(UINT32 state, union cpuinfo *info)
 		case CPUINFO_PTR_RESET:						info->reset = ppc602_reset;				break;
 		case CPUINFO_PTR_EXIT:						info->exit = ppc602_exit;				break;
 		case CPUINFO_PTR_EXECUTE:					info->execute = ppc602_execute;			break;
-		case CPUINFO_PTR_DISASSEMBLE:					info->disassemble = ppc_dasm64;			break;
+		case CPUINFO_PTR_READ:							info->read = ppc_read;					break;
+		case CPUINFO_PTR_WRITE:							info->write = ppc_write;				break;
+		case CPUINFO_PTR_READOP:						info->readop = ppc_readop;				break;
 
 		/* --- the following bits of info are returned as NULL-terminated strings --- */
 		case CPUINFO_STR_NAME:							strcpy(info->s = cpuintrf_temp_str(), "PPC602"); break;
