@@ -94,7 +94,7 @@ void ppc602_exception(int exception)
 
 
 		default:
-			osd_die("ppc: Unhandled exception %d\n", exception);
+			fatalerror("ppc: Unhandled exception %d", exception);
 			break;
 	}
 }
@@ -128,16 +128,9 @@ INLINE void ppc602_check_interrupts(void)
 	}
 }
 
-static void ppc602_reset(void *param)
+static void ppc602_reset(void)
 {
-	float multiplier;
-	ppc_config *config = param;
 	ppc.pc = ppc.npc = 0xfff00100;
-	ppc.pvr = config->pvr;
-
-	multiplier = (float)((config->bus_frequency_multiplier >> 4) & 0xf) +
-				 (float)(config->bus_frequency_multiplier & 0xf) / 10.0f;
-	bus_freq_multiplier = (int)(multiplier * 2);
 
 	ppc_set_msr(0x40);
 	change_pc(ppc.pc);
