@@ -13,8 +13,8 @@
  * PowerPC 403 opcodes and MAME conversion by Ville Linde
  */
 
-#include "driver.h"
-#include "mamedbg.h"
+#include "cpuintrf.h"
+#include "debugger.h"
 
 /*
  * Masks
