@@ -5,7 +5,7 @@
 
 static void ppc_unimplemented(UINT32 op)
 {
-	osd_die("ppc: Unimplemented opcode %08X at %08X", op, ppc.pc);
+	fatalerror("ppc: Unimplemented opcode %08X at %08X", op, ppc.pc);
 }
 
 static void ppc_addx(UINT32 op)
@@ -703,12 +703,38 @@ static void ppc_lmw(UINT32 op)
 
 static void ppc_lswi(UINT32 op)
 {
-	osd_die("ppc: lswi unimplemented\n");
+	int n, r, i;
+	UINT32 ea = 0;
+	if( RA != 0 )
+		ea = REG(RA);
+
+	if( RB == 0 )
+		n = 32;
+	else
+		n = RB;
+
+	r = RT - 1;
+	i = 0;
+
+	while(n > 0)
+	{
+		if (i == 0) {
+			r = (r + 1) % 32;
+			REG(r) = 0;
+		}
+		REG(r) |= ((READ8(ea) & 0xff) << (24 - i));
+		i += 8;
+		if (i == 32) {
+			i = 0;
+		}
+		ea++;
+		n--;
+	}
 }
 
 static void ppc_lswx(UINT32 op)
 {
-	osd_die("ppc: lswx unimplemented\n");
+	fatalerror("ppc: lswx unimplemented at %08X", ppc.pc);
 }
 
 static void ppc_lwarx(UINT32 op)
@@ -787,7 +813,8 @@ static void ppc_mcrf(UINT32 op)
 
 static void ppc_mcrxr(UINT32 op)
 {
-	osd_die("ppc: mcrxr unimplemented\n");
+	CR(RT >> 2) = (XER >> 28) & 0x0F;
+	XER &= ~0xf0000000;
 }
 
 static void ppc_mfcr(UINT32 op)
@@ -1000,10 +1027,26 @@ static void ppc_rlwnmx(UINT32 op)
 	}
 }
 
+#ifndef PPC_DRC
 static void ppc_sc(UINT32 op)
 {
-	ppc603_exception(EXCEPTION_SYSTEM_CALL);
+#if (HAS_PPC603)
+	if (ppc.is603) {
+		ppc603_exception(EXCEPTION_SYSTEM_CALL);
+	}
+#endif
+#if (HAS_PPC602)
+	if (ppc.is602) {
+		ppc602_exception(EXCEPTION_SYSTEM_CALL);
+	}
+#endif
+#if (HAS_PPC403)
+	if (IS_PPC403()) {
+		ppc403_exception(EXCEPTION_SYSTEM_CALL);
+	}
+#endif
 }
+#endif
 
 static void ppc_slwx(UINT32 op)
 {
@@ -1028,7 +1071,10 @@ static void ppc_srawx(UINT32 op)
 	XER &= ~XER_CA;
 
 	if( sh > 31 ) {
-		REG(RA) = (INT32)(REG(RS)) >> 31;
+		if (REG(RS) & 0x80000000)
+			REG(RA) = 0xffffffff;
+		else
+			REG(RA) = 0;
 		if( REG(RA) )
 			XER |= XER_CA;
 	}
@@ -1188,12 +1234,37 @@ static void ppc_stmw(UINT32 op)
 
 static void ppc_stswi(UINT32 op)
 {
-	osd_die("ppc: stswi unimplemented\n");
+	int n, r, i;
+	UINT32 ea = 0;
+	if( RA != 0 )
+		ea = REG(RA);
+
+	if( RB == 0 )
+		n = 32;
+	else
+		n = RB;
+
+	r = RT - 1;
+	i = 0;
+
+	while(n > 0)
+	{
+		if (i == 0) {
+			r = (r + 1) % 32;
+		}
+		WRITE8(ea, (REG(r) >> (24-i)) & 0xff);
+		i += 8;
+		if (i == 32) {
+			i = 0;
+		}
+		ea++;
+		n--;
+	}
 }
 
 static void ppc_stswx(UINT32 op)
 {
-	osd_die("ppc: stswx unimplemented\n");
+	fatalerror("ppc: stswx unimplemented");
 }
 
 static void ppc_stw(UINT32 op)
@@ -1380,51 +1451,93 @@ static void ppc_sync(UINT32 op)
 
 }
 
+#ifndef PPC_DRC
 static void ppc_tw(UINT32 op)
 {
+	int exception = 0;
 	INT32 a = REG(RA);
 	INT32 b = REG(RB);
 	int to = RT;
 
 	if( (a < b) && (to & 0x10) ) {
-		ppc603_exception(EXCEPTION_TRAP);
+		exception = 1;
 	}
 	if( (a > b) && (to & 0x08) ) {
-		ppc603_exception(EXCEPTION_TRAP);
+		exception = 1;
 	}
 	if( (a == b) && (to & 0x04) ) {
-		ppc603_exception(EXCEPTION_TRAP);
+		exception = 1;
 	}
 	if( ((UINT32)a < (UINT32)b) && (to & 0x02) ) {
-		ppc603_exception(EXCEPTION_TRAP);
+		exception = 1;
 	}
 	if( ((UINT32)a > (UINT32)b) && (to & 0x01) ) {
-		ppc603_exception(EXCEPTION_TRAP);
+		exception = 1;
+	}
+
+	if (exception) {
+#if (HAS_PPC603)
+		if (ppc.is603) {
+			ppc603_exception(EXCEPTION_TRAP);
+		}
+#endif
+#if (HAS_PPC602)
+		if (ppc.is602) {
+			ppc602_exception(EXCEPTION_TRAP);
+		}
+#endif
+#if (HAS_PPC403)
+		if (IS_PPC403()) {
+			ppc403_exception(EXCEPTION_TRAP);
+		}
+#endif
 	}
 }
+#endif
 
+#ifndef PPC_DRC
 static void ppc_twi(UINT32 op)
 {
+	int exception = 0;
 	INT32 a = REG(RA);
 	INT32 i = SIMM16;
 	int to = RT;
 
 	if( (a < i) && (to & 0x10) ) {
-		ppc603_exception(EXCEPTION_TRAP);
+		exception = 1;
 	}
 	if( (a > i) && (to & 0x08) ) {
-		ppc603_exception(EXCEPTION_TRAP);
+		exception = 1;
 	}
 	if( (a == i) && (to & 0x04) ) {
-		ppc603_exception(EXCEPTION_TRAP);
+		exception = 1;
 	}
 	if( ((UINT32)a < (UINT32)i) && (to & 0x02) ) {
-		ppc603_exception(EXCEPTION_TRAP);
+		exception = 1;
 	}
 	if( ((UINT32)a > (UINT32)i) && (to & 0x01) ) {
-		ppc603_exception(EXCEPTION_TRAP);
+		exception = 1;
+	}
+
+	if (exception) {
+#if (HAS_PPC603)
+		if (ppc.is603) {
+			ppc603_exception(EXCEPTION_TRAP);
+		}
+#endif
+#if (HAS_PPC602)
+		if (ppc.is602) {
+			ppc602_exception(EXCEPTION_TRAP);
+		}
+#endif
+#if (HAS_PPC403)
+		if (IS_PPC403()) {
+			ppc403_exception(EXCEPTION_TRAP);
+		}
+#endif
 	}
 }
+#endif
 
 static void ppc_xorx(UINT32 op)
 {
@@ -1449,7 +1562,7 @@ static void ppc_xoris(UINT32 op)
 
 static void ppc_invalid(UINT32 op)
 {
-	osd_die("ppc: Invalid opcode %08X PC : %X\n", op, ppc.pc);
+	fatalerror("ppc: Invalid opcode %08X PC : %X", op, ppc.pc);
 }
 
 
@@ -1516,7 +1629,14 @@ INLINE int sign_double(FPR x)
 
 INLINE INT64 round_to_nearest(FPR f)
 {
-	return (INT64)(f.fd + 0.5);
+	if (f.fd >= 0)
+	{
+		return (INT64)(f.fd + 0.5);
+	}
+	else
+	{
+		return -(INT64)(-f.fd + 0.5);
+	}
 }
 
 INLINE INT64 round_toward_zero(FPR f)
@@ -1776,9 +1896,9 @@ static void ppc_mftb(UINT32 op)
 
 	switch(x)
 	{
-		case 268:	REG(RT) = (UINT32)(ppc.tb); break;
-		case 269:	REG(RT) = (UINT32)(ppc.tb >> 32); break;
-		default:	osd_die("ppc: Invalid timebase register %d at %08X", x, ppc.pc); break;
+		case 268:	REG(RT) = (UINT32)(ppc_read_timebase()); break;
+		case 269:	REG(RT) = (UINT32)(ppc_read_timebase() >> 32); break;
+		default:	fatalerror("ppc: Invalid timebase register %d at %08X", x, ppc.pc); break;
 	}
 }
 
@@ -1933,9 +2053,39 @@ static void ppc_faddx(UINT32 op)
 
 static void ppc_fcmpo(UINT32 op)
 {
+	UINT32 b = RB;
+	UINT32 a = RA;
+	UINT32 t = (RT >> 2);
+	UINT32 c;
+
 	CHECK_FPU_AVAILABLE();
 
-    ppc_unimplemented(op);
+	SET_VXSNAN(FPR(a), FPR(b));
+
+	if(is_nan_double(FPR(a)) || is_nan_double(FPR(b)))
+	{
+		c = 1; /* OX */
+		if(is_snan_double(FPR(a)) || is_snan_double(FPR(b))) {
+			ppc.fpscr |= 0x01000000; /* VXSNAN */
+
+			if(!(ppc.fpscr & 0x40000000) || is_qnan_double(FPR(a)) || is_qnan_double(FPR(b)))
+				ppc.fpscr |= 0x00080000; /* VXVC */
+		}
+	}
+	else if(FPR(a).fd < FPR(b).fd){
+		c = 8; /* FX */
+	}
+	else if(FPR(a).fd > FPR(b).fd){
+		c = 4; /* FEX */
+	}
+	else {
+		c = 2; /* VX */
+	}
+
+	CR(t) = c;
+
+	ppc.fpscr &= ~0x0001F000;
+	ppc.fpscr |= (c << 12);
 }
 
 static void ppc_fcmpu(UINT32 op)
