@@ -1,5 +1,4 @@
 #include "cpuintrf.h"
-#include "osd_cpu.h"
 
 enum {
 	SE3208_PC=1, SE3208_SR, SE3208_ER, SE3208_SP,SE3208_PPC,
@@ -11,5 +10,5 @@ enum {
 extern void SE3208_get_info(UINT32 state, union cpuinfo *info);
 
 #ifdef MAME_DEBUG
-int SE3208Dasm(data32_t PC,char *Buffer);
+int SE3208Dasm(UINT32 PC,char *Buffer);
 #endif
