@@ -1,10 +1,5 @@
-#include "stdio.h"
-#include "string.h"
-#include "driver.h"
-#include "state.h"
-#include "mamedbg.h"
+#include "debugger.h"
 #include "se3208.h"
-#include "memory.h"
 
 
 /*Decode the ER value thorugh the last opcodes, set to 0 to disable */
@@ -1075,7 +1070,7 @@ INST(MVFC)
 	sprintf(dst,"MVFC  %%CR0%d,%%R0",Imm);
 }
 
-_OP DecodeOp(UINT16 Opcode)
+static _OP DecodeOp(UINT16 Opcode)
 {
 	switch(EXTRACT(Opcode,14,15))
 	{
@@ -1352,7 +1347,7 @@ int SE3208Dasm(UINT32 PC,char *Buffer)
 			continue;
 		}
 		Context.PC=PC;
-		Opcode=cpu_readop16(PC);
+		Opcode=cpu_readop16(WORD_XOR_LE(PC));
 		DecodeOp(Opcode)(Opcode,Buffer);
 		PC+=2;
 	}
