@@ -6,9 +6,8 @@
    Portions based on ElSemi's SHARC emulator
 */
 
-#include "driver.h"
 #include "sharc.h"
-#include "mamedbg.h"
+#include "debugger.h"
 
 static void sharc_dma_exec(int channel);
 
@@ -21,6 +20,7 @@ enum {
 	SHARC_R8,		SHARC_R9,		SHARC_R10,		SHARC_R11,
 	SHARC_R12,		SHARC_R13,		SHARC_R14,		SHARC_R15,
 	SHARC_SYSCON,	SHARC_SYSSTAT,	SHARC_MRF,		SHARC_MRB,
+	SHARC_STATUS_STKP,
 	SHARC_I0,		SHARC_I1,		SHARC_I2,		SHARC_I3,
 	SHARC_I4,		SHARC_I5,		SHARC_I6,		SHARC_I7,
 	SHARC_I8,		SHARC_I9,		SHARC_I10,		SHARC_I11,
@@ -51,6 +51,19 @@ typedef union {
 	float f;
 } SHARC_REG;
 
+typedef struct
+{
+	UINT32 control;
+	UINT32 int_index;
+	UINT32 int_modifier;
+	UINT32 int_count;
+	UINT32 chain_ptr;
+	UINT32 gen_purpose;
+	UINT32 ext_index;
+	UINT32 ext_modifier;
+	UINT32 ext_count;
+} DMA_REGS;
+
 typedef struct {
 	UINT32 pc;
 	UINT32 npc;
@@ -78,6 +91,8 @@ typedef struct {
 	SHARC_DAG dag1_alt;
 	SHARC_DAG dag2_alt;
 
+	DMA_REGS dma[12];
+
 	/* System registers */
 	UINT32 mode1;
 	UINT32 mode2;
@@ -107,6 +122,8 @@ typedef struct {
 	int idle;
 	int irq_active;
 	int irq_active_num;
+
+	SHARC_BOOT_MODE boot_mode;
 } SHARC_REGS;
 
 static SHARC_REGS sharc;
@@ -123,44 +140,114 @@ static int sharc_icount;
 void decode_and_exec_opcode(void);
 
 /*****************************************************************************/
-/* SHARC DMA Controller */
 
-static UINT32 dma_control6;
-static UINT32 dma_ii6;
-static UINT32 dma_im6;
-static UINT32 dma_c6;
-static UINT32 dma_cp6;
-static UINT32 dma_gp6;
-static UINT32 dma_ei6;
-static UINT32 dma_em6;
-static UINT32 dma_ec6;
+static UINT32 dmaop_src;
+static UINT32 dmaop_dst;
+static UINT32 dmaop_chain_ptr;
+static int dmaop_src_modifier;
+static int dmaop_dst_modifier;
+static int dmaop_src_count;
+static int dmaop_dst_count;
+static int dmaop_pmode;
+static int dmaop_cycles = 0;
+static int dmaop_channel;
+static int dmaop_chained_direction;
+
+
+
+static int iop_latency_cycles = 0;
+static int iop_latency_reg = 0;
+static UINT32 iop_latency_data = 0;
+
+static void add_iop_latency_op(int iop_reg, UINT32 data, int latency)
+{
+	iop_latency_cycles = latency;
+	iop_latency_reg = iop_reg;
+	iop_latency_data = data;
+}
+
+static void iop_latency_op(void)
+{
+	UINT32 data = iop_latency_data;
+
+	switch (iop_latency_reg)
+	{
+		case 0x1c:
+		{
+			sharc.dma[6].control = data;
+			if (data & 0x1) {
+				sharc_dma_exec(6);
+			}
+			break;
+		}
+
+		case 0x1d:
+		{
+			sharc.dma[7].control = data;
+			if (data & 0x1) {
+				sharc_dma_exec(7);
+			}
+			break;
+		}
+
+		default:	fatalerror("SHARC: add_iop_latency_op: unknown IOP register %02X", iop_latency_reg);
+	}
+}
 
-/*****************************************************************************/
 
 /* IOP registers */
 static UINT32 sharc_iop_r(UINT32 address)
 {
+	switch (address)
+	{
+		case 0x00: return 0;	/* System configuration */
+
+		case 0x37:		/* DMA status */
+		{
+			UINT32 r = 0;
+			if (dmaop_cycles > 0)
+			{
+				r |= 1 << dmaop_channel;
+			}
+			return r;
+		}
+		default:		fatalerror("sharc_iop_r: Unimplemented IOP reg %02X", address);
+	}
 	return 0;
 }
 
 static void sharc_iop_w(UINT32 address, UINT32 data)
 {
-	switch(address)
+	switch (address)
 	{
-		case 0x1c:
-			dma_control6 = data;
-			if (data & 0x1) {
-				sharc_dma_exec(6);
-			}
-			return;
-		case 0x40:		dma_ii6 = data; return;
-		case 0x41:		dma_im6 = data; return;
-		case 0x42:		dma_c6 = data; return;
-		case 0x43:		dma_cp6 = data; return;
-		case 0x44:		dma_gp6 = data; return;
-		case 0x45:		dma_ei6 = data; return;
-		case 0x46:		dma_em6 = data; return;
-		case 0x47:		dma_ec6 = data; return;
+		case 0x00: break;		/* System configuration */
+		case 0x02: break;		/* External Memory Wait State Configuration */
+
+		/* DMA 6 */
+		case 0x1c: add_iop_latency_op(0x1c, data, 1); break;
+
+		case 0x40: sharc.dma[6].int_index = data; return;
+		case 0x41: sharc.dma[6].int_modifier = data; return;
+		case 0x42: sharc.dma[6].int_count = data; return;
+		case 0x43: sharc.dma[6].chain_ptr = data; return;
+		case 0x44: sharc.dma[6].gen_purpose = data; return;
+		case 0x45: sharc.dma[6].ext_index = data; return;
+		case 0x46: sharc.dma[6].ext_modifier = data; return;
+		case 0x47: sharc.dma[6].ext_count = data; return;
+
+		/* DMA 7 */
+		case 0x1d: add_iop_latency_op(0x1d, data, 20); break;
+
+		case 0x48: sharc.dma[7].int_index = data; return;
+		case 0x49: sharc.dma[7].int_modifier = data; return;
+		case 0x4a: sharc.dma[7].int_count = data; return;
+		case 0x4b: sharc.dma[7].chain_ptr = data; return;
+		case 0x4c: sharc.dma[7].gen_purpose = data; return;
+		case 0x4d: sharc.dma[7].ext_index = data; return;
+		case 0x4e: sharc.dma[7].ext_modifier = data; return;
+		case 0x4f: sharc.dma[7].ext_count = data; return;
+
+		default:		fatalerror("sharc_iop_w: Unimplemented IOP reg %02X, %08X", address, data);
 	}
 }
 
@@ -190,7 +277,7 @@ static UINT32 pm_read32(UINT32 address)
 					   (sharc.internal_ram_block1[((address-0x38000) * 3) + 1]);
 	}
 	else {
-		osd_die("SHARC: PM Bus Read %08X at %08X\n", address, sharc.pc);
+		fatalerror("SHARC: PM Bus Read %08X at %08X", address, sharc.pc);
 	}
 }
 
@@ -221,7 +308,7 @@ static void pm_write32(UINT32 address, UINT32 data)
 		return;
 	}
 	else {
-		osd_die("SHARC: PM Bus Write %08X, %08X at %08X\n", address, data, sharc.pc);
+		fatalerror("SHARC: PM Bus Write %08X, %08X at %08X", address, data, sharc.pc);
 	}
 }
 
@@ -252,7 +339,7 @@ static UINT64 pm_read48(UINT32 address)
 			   ((UINT64)(sharc.internal_ram_block1[((address-0x38000) * 3) + 2]) << 0);
 	}
 	else {
-		osd_die("SHARC: PM Bus Read %08X at %08X\n", address, sharc.pc);
+		fatalerror("SHARC: PM Bus Read %08X at %08X", address, sharc.pc);
 	}
 
 	return 0;
@@ -289,7 +376,7 @@ static void pm_write48(UINT32 address, UINT64 data)
 		return;
 	}
 	else {
-		osd_die("SHARC: PM Bus Write %08X, %04X%08X at %08X\n", address, (UINT16)(data >> 32),(UINT32)data, sharc.pc);
+		fatalerror("SHARC: PM Bus Write %08X, %04X%08X at %08X", address, (UINT16)(data >> 32),(UINT32)data, sharc.pc);
 	}
 }
 
@@ -323,19 +410,55 @@ static UINT32 dm_read32(UINT32 address)
 	/* short word addressing */
 	else if (address >= 0x40000 && address < 0x50000)
 	{
-		return sharc.internal_ram_block0[(address-0x40000) ^ 1];
+		UINT16 r = sharc.internal_ram_block0[(address-0x40000) ^ 1];
+		if (sharc.mode1 & 0x4000)
+		{
+			/* sign-extend */
+			return (INT32)(INT16)(r);
+		}
+		else
+		{
+			return (UINT32)(r);
+		}
 	}
 	else if (address >= 0x50000 && address < 0x60000)
 	{
-		return sharc.internal_ram_block1[(address-0x50000) ^ 1];
+		UINT16 r = sharc.internal_ram_block1[(address-0x50000) ^ 1];
+		if (sharc.mode1 & 0x4000)
+		{
+			/* sign-extend */
+			return (INT32)(INT16)(r);
+		}
+		else
+		{
+			return (UINT32)(r);
+		}
 	}
 	else if (address >= 0x60000 && address < 0x70000)
 	{
-		return sharc.internal_ram_block1[(address-0x60000) ^ 1];
+		UINT16 r = sharc.internal_ram_block1[(address-0x60000) ^ 1];
+		if (sharc.mode1 & 0x4000)
+		{
+			/* sign-extend */
+			return (INT32)(INT16)(r);
+		}
+		else
+		{
+			return (UINT32)(r);
+		}
 	}
 	else if (address >= 0x70000 && address < 0x80000)
 	{
-		return sharc.internal_ram_block1[(address-0x70000) ^ 1];
+		UINT16 r = sharc.internal_ram_block1[(address-0x70000) ^ 1];
+		if (sharc.mode1 & 0x4000)
+		{
+			/* sign-extend */
+			return (INT32)(INT16)(r);
+		}
+		else
+		{
+			return (UINT32)(r);
+		}
 	}
 
 	return data_read_dword_32le(address << 2);
@@ -400,54 +523,175 @@ static void dm_write32(UINT32 address, UINT32 data)
 
 /*****************************************************************************/
 
-static void sharc_dma_exec(int channel)
+static void schedule_chained_dma_op(int channel, UINT32 dma_chain_ptr, int chained_direction)
+{
+	UINT32 op_ptr = 0x20000 + dma_chain_ptr;
+
+	UINT32 int_index 		= dm_read32(op_ptr - 0);
+	UINT32 int_modifier		= dm_read32(op_ptr - 1);
+	UINT32 int_count		= dm_read32(op_ptr - 2);
+	UINT32 chain_ptr 		= dm_read32(op_ptr - 3);
+	/*UINT32 gen_purpose        = dm_read32(op_ptr - 4); */
+	UINT32 ext_index 		= dm_read32(op_ptr - 5);
+	UINT32 ext_modifier 	= dm_read32(op_ptr - 6);
+	UINT32 ext_count 		= dm_read32(op_ptr - 7);
+
+	if (dmaop_cycles > 0)
+	{
+		fatalerror("schedule_chained_dma_op: DMA operation already scheduled at %08X!", sharc.pc);
+	}
+
+	if (chained_direction)		/* Transmit to external */
+	{
+		dmaop_dst 			= ext_index;
+		dmaop_dst_modifier	= ext_modifier;
+		dmaop_dst_count		= ext_count;
+		dmaop_src			= int_index;
+		dmaop_src_modifier	= int_modifier;
+		dmaop_src_count		= int_count;
+	}
+	else			/* Receive from external */
+	{
+		dmaop_src 			= ext_index;
+		dmaop_src_modifier	= ext_modifier;
+		dmaop_src_count		= ext_count;
+		dmaop_dst			= int_index;
+		dmaop_dst_modifier	= int_modifier;
+		dmaop_dst_count		= int_count;
+	}
+
+	dmaop_pmode = 0;
+	dmaop_channel = channel;
+	dmaop_cycles = dmaop_src_count / 4;
+	dmaop_chain_ptr = chain_ptr;
+	dmaop_chained_direction = chained_direction;
+}
+
+static void schedule_dma_op(int channel, UINT32 src, UINT32 dst, int src_modifier, int dst_modifier, int src_count, int dst_count, int pmode)
+{
+	if (dmaop_cycles > 0)
+	{
+		fatalerror("schedule_dma_op: DMA operation already scheduled at %08X!", sharc.pc);
+	}
+
+	dmaop_channel = channel;
+	dmaop_src = src;
+	dmaop_dst = dst;
+	dmaop_src_modifier = src_modifier;
+	dmaop_dst_modifier = dst_modifier;
+	dmaop_src_count = src_count;
+	dmaop_dst_count = dst_count;
+	dmaop_pmode = pmode;
+	dmaop_chain_ptr = 0;
+	dmaop_cycles = src_count / 4;
+}
+
+static void dma_op(UINT32 src, UINT32 dst, int src_modifier, int dst_modifier, int src_count, int dst_count, int pmode)
 {
 	int i;
-	UINT32 src, dst;
-	int chen, tran, dtype, pmode, mswf, master, ishake, intio, ext, flsh;
-	if (channel != 6) {
-		osd_die("SHARC: DMA channels other than 6 not supported yet (%d)\n", channel);
-	}
-
-	chen = (dma_control6 >> 1) & 0x1;
-	tran = (dma_control6 >> 2) & 0x1;
-	dtype = (dma_control6 >> 5) & 0x1;
-	pmode = (dma_control6 >> 6) & 0x3;
-	mswf = (dma_control6 >> 8) & 0x1;
-	master = (dma_control6 >> 9) & 0x1;
-	ishake = (dma_control6 >> 10) & 0x1;
-	intio = (dma_control6 >> 11) & 0x1;
-	ext = (dma_control6 >> 12) & 0x1;
-	flsh = (dma_control6 >> 13) & 0x1;
-
-	printf("IMask = %08X\n", sharc.imask);
-	printf("DMA Channel 6 op\n");
-	printf("   Chaining %s\n", chen ? "enabled" : "disabled");
-	printf("   %s ext. memory\n", tran ? "Write to" : "Read from");
-	printf("   Data type %s\n", dtype ? "data" : "instructions");
-	printf("   Packing mode %d\n", pmode);
-	printf("   MSWF %d\n", mswf);
-	printf("   Extern %d\n", ext);
-	printf("\n");
-	printf("   Internal Index: %08X\n", dma_ii6);
-	printf("   Internal Modifier: %08X\n", dma_im6);
-	printf("   Internal Count: %08X\n", dma_c6);
-	printf("   Chain Pointer: %08X\n", dma_cp6);
-	printf("   General Purpose: %08X\n", dma_gp6);
-	printf("   External Index: %08X\n", dma_ei6);
-	printf("   External Modifier: %08X\n", dma_em6);
-	printf("   External Count: %08X\n", dma_ec6);
-
-	src = dma_ei6;
-	dst = dma_ii6;
-	for (i=0; i < dma_ec6; i+=6)
+	switch (pmode)
 	{
-		UINT64 data = (UINT64)dm_read32(src+0) << 0 | (UINT64)dm_read32(src+1) << 8 | (UINT64)dm_read32(src+2) << 16 |
-					  (UINT64)dm_read32(src+3) << 24 | (UINT64)dm_read32(src+4) << 32 | (UINT64)dm_read32(src+5) << 40;
-		pm_write48(0x20000 + (dst & 0x1ffff), data);
-		src += dma_em6*6;
-		dst += dma_im6;
+		case 0:
+		{
+			if (src_count == dst_count)
+			{
+				for (i=0; i < src_count; i++)
+				{
+					UINT32 data = dm_read32(src);
+					dm_write32(dst, data);
+					src += src_modifier;
+					dst += dst_modifier;
+				}
+			}
+			else
+			{
+				for (i=0; i < src_count; i+=6)
+				{
+					UINT64 data = (UINT64)dm_read32(src+0) << 0 | (UINT64)dm_read32(src+1) << 8 | (UINT64)dm_read32(src+2) << 16 |
+								  (UINT64)dm_read32(src+3) << 24 | (UINT64)dm_read32(src+4) << 32 | (UINT64)dm_read32(src+5) << 40;
+					pm_write48(dst, data);
+					src += src_modifier*6;
+					dst += dst_modifier;
+				}
+			}
+			break;
+		}
+		case 1:
+		{
+			for (i=0; i < src_count/2; i++)
+			{
+				UINT32 data1 = dm_read32(src+0) & 0xffff;
+				UINT32 data2 = dm_read32(src+1) & 0xffff;
+				dm_write32(dst, (data1 << 16) | data2);
+				src += src_modifier*2;
+				dst += dst_modifier;
+			}
+			break;
+		}
 	}
+}
+
+static void sharc_dma_exec(int channel)
+{
+	UINT32 src, dst;
+	UINT32 src_count, dst_count;
+	UINT32 src_modifier, dst_modifier;
+	int chen, tran, dtype, pmode, mswf, master, ishake, intio, ext, flsh;
+
+	chen = (sharc.dma[channel].control >> 1) & 0x1;
+	tran = (sharc.dma[channel].control >> 2) & 0x1;
+	dtype = (sharc.dma[channel].control >> 5) & 0x1;
+	pmode = (sharc.dma[channel].control >> 6) & 0x3;
+	mswf = (sharc.dma[channel].control >> 8) & 0x1;
+	master = (sharc.dma[channel].control >> 9) & 0x1;
+	ishake = (sharc.dma[channel].control >> 10) & 0x1;
+	intio = (sharc.dma[channel].control >> 11) & 0x1;
+	ext = (sharc.dma[channel].control >> 12) & 0x1;
+	flsh = (sharc.dma[channel].control >> 13) & 0x1;
+
+	if (ishake)
+		fatalerror("SHARC: dma_exec: handshake not supported");
+	if (intio)
+		fatalerror("SHARC: dma_exec: single-word interrupt enable not supported");
+
+
+
+	if (chen)		/* Chained DMA */
+	{
+		UINT32 dma_chain_ptr = sharc.dma[channel].chain_ptr & 0x1ffff;
+
+		schedule_chained_dma_op(channel, dma_chain_ptr, tran);
+	}
+	else
+	{
+		if (tran)		/* Transmit to external */
+		{
+			dst 			= sharc.dma[channel].ext_index;
+			dst_modifier	= sharc.dma[channel].ext_modifier;
+			dst_count		= sharc.dma[channel].ext_count;
+			src				= sharc.dma[channel].int_index;
+			src_modifier	= sharc.dma[channel].int_modifier;
+			src_count		= sharc.dma[channel].int_count;
+		}
+		else			/* Receive from external */
+		{
+			src 			= sharc.dma[channel].ext_index;
+			src_modifier	= sharc.dma[channel].ext_modifier;
+			src_count		= sharc.dma[channel].ext_count;
+			dst				= sharc.dma[channel].int_index;
+			dst_modifier	= sharc.dma[channel].int_modifier;
+			dst_count		= sharc.dma[channel].int_count;
+		}
+
+		if (dst < 0x20000)
+		{
+			dst |= 0x20000;
+		}
+
+		schedule_dma_op(channel, src, dst, src_modifier, dst_modifier, src_count, dst_count, pmode);
+	}
+
+	sharc.irptl |= (1 << (channel+10));
 
 	/* DMA interrupt */
 	if (sharc.imask & (1 << (channel+10)))
@@ -464,6 +708,16 @@ void sharc_write_program_ram(UINT32 address, UINT64 data)
 
 /*****************************************************************************/
 
+#define IOP_LATENCY_OP()					\
+		if (iop_latency_cycles > 0)			\
+		{									\
+			iop_latency_cycles--;			\
+			if (iop_latency_cycles == 0)	\
+			{								\
+				iop_latency_op();			\
+			}								\
+		}
+
 static void sharc_set_flag_input(int flag_num, int state)
 {
 	if (flag_num >= 0 && flag_num < 4)
@@ -476,7 +730,7 @@ static void sharc_set_flag_input(int flag_num, int state)
 		}
 		else
 		{
-			osd_die("sharc_set_flag_input: flag %d is set output!", flag_num);
+			fatalerror("sharc_set_flag_input: flag %d is set output!", flag_num);
 		}
 	}
 }
@@ -494,44 +748,11 @@ static offs_t sharc_dasm(char *buffer, offs_t pc)
 	return 1;
 }
 
+static void check_interrupts(void);
+
 #include "sharcops.c"
 #include "sharcops.h"
 
-static void sharc_init(void)
-{
-	sharc.opcode_table = sharc_op;
-
-	sharc.internal_ram = auto_malloc(2 * 0x20000);
-	sharc.internal_ram_block0 = &sharc.internal_ram[0];
-	sharc.internal_ram_block1 = &sharc.internal_ram[0x20000/2];
-}
-
-static void sharc_reset(void *param)
-{
-	sharc_config *config = param;
-	sharc.pc = 0x20004;
-	sharc.npc = sharc.pc + 1;
-	sharc.idle = 0;
-
-	switch(config->boot_mode)
-	{
-		case BOOT_MODE_EPROM:
-			dma_ii6 = 0x20000;
-			dma_im6 = 1;
-			dma_c6 = 0x100;
-			dma_ei6 = 0x400000;
-			dma_em6 = 1;
-			dma_ec6 = 0x600;
-			sharc_dma_exec(6);
-			break;
-
-		case BOOT_MODE_HOST:
-			break;
-
-		default:
-			osd_die("SHARC: Unimplemented boot mode %d\n", config->boot_mode);
-	}
-}
 
 static void sharc_exit(void)
 {
@@ -569,7 +790,7 @@ static void sharc_set_irq_line(int irqline, int state)
 
 static void check_interrupts(void)
 {
-	if (sharc.imask & (1 << sharc.irq_active_num) && sharc.mode1 & 0x1000)
+	if ((sharc.imask & (1 << sharc.irq_active_num)) && (sharc.mode1 & 0x1000))
 	{
 		PUSH_PC(sharc.npc);
 
@@ -588,6 +809,53 @@ static void check_interrupts(void)
 	}
 }
 
+static void sharc_init(int index, int clock, const void *_config, int (*irqcallback)(int))
+{
+	const sharc_config *config = _config;
+	sharc.boot_mode = config->boot_mode;
+
+	sharc.irq_callback = irqcallback;
+
+	sharc.opcode_table = sharc_op;
+
+	sharc.internal_ram = auto_malloc(2 * 0x20000);
+	sharc.internal_ram_block0 = &sharc.internal_ram[0];
+	sharc.internal_ram_block1 = &sharc.internal_ram[0x20000/2];
+}
+
+static void sharc_reset(void)
+{
+	sharc.pc = 0x20004;
+	sharc.npc = sharc.pc + 1;
+	sharc.idle = 0;
+	sharc.stky = 0x5400000;
+
+	switch(sharc.boot_mode)
+	{
+		case BOOT_MODE_EPROM:
+		{
+			sharc.dma[6].int_index		= 0x20000;
+			sharc.dma[6].int_modifier	= 1;
+			sharc.dma[6].int_count		= 0x100;
+			sharc.dma[6].ext_index		= 0x400000;
+			sharc.dma[6].ext_modifier	= 1;
+			sharc.dma[6].ext_count		= 0x600;
+
+			sharc_dma_exec(6);
+			dma_op(dmaop_src, dmaop_dst, dmaop_src_modifier, dmaop_dst_modifier, dmaop_src_count, dmaop_dst_count, dmaop_pmode);
+			dmaop_cycles = 0;
+
+			break;
+		}
+
+		case BOOT_MODE_HOST:
+			break;
+
+		default:
+			fatalerror("SHARC: Unimplemented boot mode %d", sharc.boot_mode);
+	}
+}
+
 static int sharc_execute(int num_cycles)
 {
 	sharc_icount = num_cycles;
@@ -606,23 +874,27 @@ static int sharc_execute(int num_cycles)
 	{
 		sharc.pc = sharc.npc;
 		sharc.npc++;
-		CALL_MAME_DEBUG;
-		DECODE_AND_EXEC_OPCODE();
 
-		systemreg_latency_op();
+		CALL_MAME_DEBUG;
 
 		/* handle looping */
-		if(sharc.pc == (sharc.laddr & 0xffffff)) {
+		if(sharc.pc == (sharc.laddr & 0xffffff))
+		{
 			int cond = (sharc.laddr >> 24) & 0x1f;
 
 			/* loop type */
 			switch((sharc.laddr >> 30) & 0x3)
 			{
 				case 0:		/* arithmetic condition-based */
-					if(DO_CONDITION_CODE(cond)) {
+					if(DO_CONDITION_CODE(cond))
+					{
+						DECODE_AND_EXEC_OPCODE();
 						POP_LOOP();
 						POP_PC();
-					} else {
+					}
+					else
+					{
+						DECODE_AND_EXEC_OPCODE();
 						sharc.npc = TOP_PC();
 					}
 					break;
@@ -631,18 +903,50 @@ static int sharc_execute(int num_cycles)
 				case 3:		/* counter-based, length >2 */
 					sharc.lcstack[sharc.lstkp]--;
 					sharc.curlcntr--;
-					if(sharc.curlcntr == 0) {
+					if(sharc.curlcntr == 0)
+					{
+						DECODE_AND_EXEC_OPCODE();
 						POP_LOOP();
 						POP_PC();
-					} else {
+					}
+					else
+					{
+						DECODE_AND_EXEC_OPCODE();
 						sharc.npc = TOP_PC();
 					}
 					break;
 			}
 		}
+		else
+		{
+			DECODE_AND_EXEC_OPCODE();
+		}
+
+		systemreg_latency_op();
+		IOP_LATENCY_OP();
+		if (dmaop_cycles > 0)
+		{
+			dmaop_cycles--;
+			if (dmaop_cycles <= 0)
+			{
+				dma_op(dmaop_src, dmaop_dst, dmaop_src_modifier, dmaop_dst_modifier, dmaop_src_count, dmaop_dst_count, dmaop_pmode);
+				if (dmaop_chain_ptr != 0)
+				{
+					schedule_chained_dma_op(dmaop_channel, dmaop_chain_ptr, dmaop_chained_direction);
+				}
+			}
+		}
 
 		sharc_icount--;
 	}
+
+	/* handle pending DMA operation */
+	if (dmaop_cycles > 0)
+	{
+		dma_op(dmaop_src, dmaop_dst, dmaop_src_modifier, dmaop_dst_modifier, dmaop_src_count, dmaop_dst_count, dmaop_pmode);
+		dmaop_cycles = 0;
+	}
+
 	return num_cycles - sharc_icount;
 }
 
@@ -735,9 +1039,6 @@ static void sharc_set_info(UINT32 state, union cpuinfo *info)
 		case CPUINFO_INT_REGISTER + SHARC_M13:			sharc.dag2.m[5] = info->i;					break;
 		case CPUINFO_INT_REGISTER + SHARC_M14:			sharc.dag2.m[6] = info->i;					break;
 		case CPUINFO_INT_REGISTER + SHARC_M15:			sharc.dag2.m[7] = info->i;					break;
-
-		/* --- the following bits of info are set as pointers to data or functions --- */
-		case CPUINFO_PTR_IRQ_CALLBACK:					sharc.irq_callback = info->irqcallback;	break;
 	}
 }
 
@@ -761,10 +1062,49 @@ void adsp21062_set_info(UINT32 state, union cpuinfo *info)
 }
 #endif
 
+static int sharc_debug_read(int space, UINT32 offset, int size, UINT64 *value)
+{
+	if (space == ADDRESS_SPACE_PROGRAM)
+	{
+		if (offset >= 0x20000 && offset < 0x30000)
+		{
+			*value = pm_read48(offset);
+		}
+		else
+		{
+			*value = 0;
+		}
+	}
+	else if (space == ADDRESS_SPACE_DATA)
+	{
+		if (offset >= 0x20000)
+		{
+			*value = dm_read32(offset/4);
+		}
+		else
+		{
+			offset = 0;
+		}
+	}
+	return 1;
+}
+
 static int sharc_debug_readop(UINT32 offset, int size, UINT64 *value)
 {
-	if (offset >= 0x20000 && offset < 0x30000)
-		*value = ROPCODE(offset);
+	if (offset >= 0x20000 && offset < 0x28000)
+	{
+		UINT64 op = ((UINT64)(sharc.internal_ram_block0[((offset-0x20000) * 3) + 0]) << 32) |
+					((UINT64)(sharc.internal_ram_block0[((offset-0x20000) * 3) + 1]) << 16) |
+					((UINT64)(sharc.internal_ram_block0[((offset-0x20000) * 3) + 2]) << 0);
+		*value = op;
+	}
+	else if (offset >= 0x28000 && offset < 0x30000)
+	{
+		UINT64 op = ((UINT64)(sharc.internal_ram_block1[((offset-0x28000) * 3) + 0]) << 32) |
+					((UINT64)(sharc.internal_ram_block1[((offset-0x28000) * 3) + 1]) << 16) |
+					((UINT64)(sharc.internal_ram_block1[((offset-0x28000) * 3) + 2]) << 0);
+		*value = op;
+	}
 
 	return 1;
 }
@@ -810,6 +1150,7 @@ void sharc_get_info(UINT32 state, union cpuinfo *info)
 		case CPUINFO_INT_REGISTER + SHARC_IMASK:		info->i = sharc.imask;					break;
 		case CPUINFO_INT_REGISTER + SHARC_USTAT1:		info->i = sharc.ustat1;					break;
 		case CPUINFO_INT_REGISTER + SHARC_USTAT2:		info->i = sharc.ustat2;					break;
+		case CPUINFO_INT_REGISTER + SHARC_STATUS_STKP:	info->i = sharc.status_stkp;			break;
 
 		case CPUINFO_INT_REGISTER + SHARC_R0:			info->i = sharc.r[0].r;					break;
 		case CPUINFO_INT_REGISTER + SHARC_R1:			info->i = sharc.r[1].r;					break;
@@ -871,10 +1212,10 @@ void sharc_get_info(UINT32 state, union cpuinfo *info)
 		case CPUINFO_PTR_EXECUTE:						info->execute = sharc_execute;			break;
 		case CPUINFO_PTR_BURN:							info->burn = NULL;						break;
 		case CPUINFO_PTR_DISASSEMBLE:					info->disassemble = sharc_dasm;			break;
-		case CPUINFO_PTR_IRQ_CALLBACK:					info->irqcallback = sharc.irq_callback;	break;
 		case CPUINFO_PTR_INSTRUCTION_COUNTER:			info->icount = &sharc_icount;			break;
 		case CPUINFO_PTR_REGISTER_LAYOUT:				info->p = sharc_reg_layout;				break;
 		case CPUINFO_PTR_WINDOW_LAYOUT:					info->p = sharc_win_layout;				break;
+		case CPUINFO_PTR_READ:							info->read = sharc_debug_read;			break;
 		case CPUINFO_PTR_READOP:						info->readop = sharc_debug_readop;		break;
 
 		/* --- the following bits of info are returned as NULL-terminated strings --- */
@@ -894,6 +1235,7 @@ void sharc_get_info(UINT32 state, union cpuinfo *info)
 		case CPUINFO_STR_REGISTER + SHARC_IMASK:		sprintf(info->s = cpuintrf_temp_str(), "IMASK: %08X", sharc.imask); break;
 		case CPUINFO_STR_REGISTER + SHARC_USTAT1:		sprintf(info->s = cpuintrf_temp_str(), "USTAT1: %08X", sharc.ustat1); break;
 		case CPUINFO_STR_REGISTER + SHARC_USTAT2:		sprintf(info->s = cpuintrf_temp_str(), "USTAT2: %08X", sharc.ustat2); break;
+		case CPUINFO_STR_REGISTER + SHARC_STATUS_STKP:	sprintf(info->s = cpuintrf_temp_str(), "STATUSSTKP: %08X", sharc.status_stkp); break;
 
 		case CPUINFO_STR_REGISTER + SHARC_R0:			sprintf(info->s = cpuintrf_temp_str(), "R0: %08X", (UINT32)sharc.r[0].r); break;
 		case CPUINFO_STR_REGISTER + SHARC_R1:			sprintf(info->s = cpuintrf_temp_str(), "R1: %08X", (UINT32)sharc.r[1].r); break;
