@@ -12,12 +12,19 @@
   It was designed by Sony's Ken Kutaragi, later the "father of the PlayStation".
 
   Original emulation by Anthony Kruize and Lee Hammerton.
-  Substantially revised September 2005 by R. Belmont.
+  Substantially revised by R. Belmont.
 
   Thanks to Anonymous, TRAC, Brad Martin, anomie, Blargg, and everyone
   else on ZSNES Technical for probing the darker corners of the SNES
   with test programs so we have a chance at getting things accurate.
 
+  MESS Bugzilla bugs:
+  - 804 ADC sets carry too late (FIXED)
+  - 805 ADDW/SUBW set V wrongly (FIXED)
+  - 806 BRK should modify PSW (FIXED)
+  - 807 DAA/DAS problem (FIXED)
+
+
 */
 /* ======================================================================== */
 /* ================================= NOTES ================================ */
@@ -54,9 +61,8 @@ Address  Function Register  R/W  When Reset          Remarks
 /* ======================================================================== */
 
 #include <limits.h>
-#include <stdio.h>
 #include "spc700.h"
-
+#include "debugger.h"
 
 /* ======================================================================== */
 /* ==================== ARCHITECTURE-DEPENDANT DEFINES ==================== */
@@ -289,7 +295,7 @@ INLINE uint read_8_immediate(uint address)
 INLINE uint read_8_instruction(uint address)
 {
 	address = MAKE_UINT_16(address);
-	return spc700_read_8_instruction(address);
+	return spc700_read_instruction(address);
 }
 
 INLINE uint read_8_direct(uint address)
@@ -576,9 +582,9 @@ INLINE void SET_FLAG_I(uint value)
 
 #define SUBOP_ADC(A, B)						\
 	spc_int16 = (A) + (B) + CFLAG_AS_1();			\
+	TMP1 = ((A) & 0x0f) + (CFLAG_AS_1());			\
 	FLAG_C  = (spc_int16 > 0xff) ? CFLAG_SET : 0;		\
 	FLAG_V =  (~((A) ^ (B))) & (((A) ^ spc_int16) & 0x80); \
-	TMP1 = ((A) & 0x0f) + (CFLAG_AS_1());			\
 	FLAG_H = (((spc_int16 & 0x0f) - TMP1) & 0x10) >> 1; 	\
 	FLAG_NZ = (UINT8)spc_int16
 
@@ -611,7 +617,7 @@ INLINE void SET_FLAG_I(uint value)
 			FLAG_C = (TMP3 > 0xff) ? CFLAG_SET : 0;	\
 			FLAG_H = ((unsigned) ((((DST) >> 8) & 0x0F) + \
 				(((SRC) >> 8) & 0x0F) + TMP2)) > 0x0F ? HFLAG_SET : 0; \
-			FLAG_V = (~((DST) ^ (SRC)) & ((SRC) ^ (UINT16) spc_int32) & 0x8000) ? VFLAG_SET : 0; \
+			FLAG_V = (~((DST) ^ (SRC)) & ((SRC) ^ (UINT16) spc_int16) & 0x8000) ? VFLAG_SET : 0; \
 			FLAG_Z = (spc_int16 != 0);		\
 			FLAG_N = (spc_int16>>8);		\
 			SET_REG_YA(spc_int16);
@@ -714,6 +720,8 @@ INLINE void SET_FLAG_I(uint value)
 			CLK(BCLK);														\
 			PUSH_16(REG_PC);												\
 			PUSH_8(GET_REG_P_BRK());										\
+			FLAG_B |= FLAGPOS_B;												\
+			FLAG_I = IFLAG_CLEAR;												\
 			JUMP(read_16_VEC(VECTOR_BRK))
 
 /* Call subroutine */
@@ -798,7 +806,7 @@ INLINE void SET_FLAG_I(uint value)
 				REG_A += 0x60;		\
 				FLAG_C = CFLAG_SET;	\
 			}				\
-			FLAG_NZ = REG_A;
+			FLAG_NZ = REG_A = MAKE_UINT_8(REG_A);
 
 /* Decimal adjust for subtraction */
 #define OP_DAS(BCLK)														\
@@ -813,7 +821,7 @@ INLINE void SET_FLAG_I(uint value)
 				REG_A -= 0x60;		\
 				FLAG_C = 0;		\
 			}				\
-			FLAG_NZ = REG_A
+			FLAG_NZ = REG_A = MAKE_UINT_8(REG_A)
 
 /* Decrement register and branch if not zero */
 /* speed up busy loops */
@@ -1215,8 +1223,8 @@ INLINE void SET_FLAG_I(uint value)
 			spc_int16 = ((TMP1 & 0xff) + (TMP3 << 8)) & 0xffff;	\
 			FLAG_C = (TMP3 <= 0xff) ? CFLAG_SET : 0;	\
 			FLAG_H = ((unsigned) ((((DST) >> 8) & 0x0F) - \
-				(((SRC) >> 8) & 0x0F) - TMP2)) > 0x0F ? HFLAG_SET : 0; \
-			FLAG_V = (((DST) ^ (SRC)) & ((DST) ^ (UINT16) spc_int32) & 0x8000) ? VFLAG_SET : 0; \
+				(((SRC) >> 8) & 0x0F) - TMP2)) > 0x0F ?  0: HFLAG_SET; \
+			FLAG_V = (((DST) ^ (SRC)) & ((DST) ^ (UINT16) spc_int16) & 0x8000) ? VFLAG_SET : 0; \
 			FLAG_Z = (spc_int16 != 0);		\
 			FLAG_N = (spc_int16>>8);		\
 			SET_REG_YA(spc_int16);
@@ -1256,10 +1264,13 @@ INLINE void SET_FLAG_I(uint value)
 /* ================================= API ================================== */
 /* ======================================================================== */
 
-void spc700_init(void) {}
+void spc700_init(int index, int clock, const void *config, int (*irqcallback)(int))
+{
+	INT_ACK = irqcallback;
+}
 
 
-void spc700_reset(void* param)
+void spc700_reset(void)
 {
 	CPU_STOPPED = 0;
 #if !SPC700_OPTIMIZE_SNES
@@ -1750,9 +1761,6 @@ static void spc700_set_info(UINT32 state, union cpuinfo *info)
 		case CPUINFO_INT_REGISTER + SPC700_A:			REG_A = MAKE_UINT_8(info->i);			break;
 		case CPUINFO_INT_REGISTER + SPC700_X:			REG_X = MAKE_UINT_8(info->i);			break;
 		case CPUINFO_INT_REGISTER + SPC700_Y:			REG_Y = MAKE_UINT_8(info->i);			break;
-
-		/* --- the following bits of info are set as pointers to data or functions --- */
-		case CPUINFO_PTR_IRQ_CALLBACK:					INT_ACK = info->irqcallback;			break;
 	}
 }
 
@@ -1819,7 +1827,6 @@ void spc700_get_info(UINT32 state, union cpuinfo *info)
 		case CPUINFO_PTR_EXECUTE:						info->execute = spc700_execute;			break;
 		case CPUINFO_PTR_BURN:							info->burn = NULL;						break;
 		case CPUINFO_PTR_DISASSEMBLE:					info->disassemble = mame_spc700_dasm;	break;
-		case CPUINFO_PTR_IRQ_CALLBACK:					info->irqcallback = INT_ACK;			break;
 		case CPUINFO_PTR_INSTRUCTION_COUNTER:			info->icount = &spc700_ICount;			break;
 		case CPUINFO_PTR_REGISTER_LAYOUT:				info->p = spc700_register_layout;		break;
 		case CPUINFO_PTR_WINDOW_LAYOUT:					info->p = spc700_window_layout;			break;
