@@ -118,14 +118,8 @@ Table 3-2.  TMS32025/26 Memory Blocks
 
 
 
-#include <stdio.h>
-#include <string.h>
-#include <stdlib.h>
-#include "driver.h"
-#include "cpuintrf.h"
-#include "mamedbg.h"
-#include "state.h"
 #include "tms32025.h"
+#include "debugger.h"
 
 
 #define CLK 4	/* 1 cycle equals 4 clock ticks */		/* PE/DI */
@@ -139,6 +133,8 @@ Table 3-2.  TMS32025/26 Memory Blocks
 UINT16 *tms32025_pgmmap[0x200];
 UINT16 *tms32025_datamap[0x200];
 
+#define SET_PC(x)	do { R.PC = (x); change_pc(R.PC<<1); } while (0)
+
 INLINE UINT16 M_RDROM(offs_t addr)
 {
 	UINT16 *ram;
@@ -640,52 +636,52 @@ static void apac(void)
 }
 static void br(void)
 {
-		R.PC = M_RDOP_ARG(R.PC);
+		SET_PC(M_RDOP_ARG(R.PC));
 		MODIFY_AR_ARP();
 }
 static void bacc(void)
 {
-		R.PC = R.ACC.w.l;
+		SET_PC(R.ACC.w.l);
 }
 static void banz(void)
 {
-		if (R.AR[ARP]) R.PC = M_RDOP_ARG(R.PC);
+		if (R.AR[ARP]) SET_PC(M_RDOP_ARG(R.PC));
 		else R.PC++ ;
 		MODIFY_AR_ARP();
 }
 static void bbnz(void)
 {
-		if (TC) R.PC = M_RDOP_ARG(R.PC);
+		if (TC) SET_PC(M_RDOP_ARG(R.PC));
 		else R.PC++ ;
 		MODIFY_AR_ARP();
 }
 static void bbz(void)
 {
-		if (TC == 0) R.PC = M_RDOP_ARG(R.PC);
+		if (TC == 0) SET_PC(M_RDOP_ARG(R.PC));
 		else R.PC++ ;
 		MODIFY_AR_ARP();
 }
 static void bc(void)
 {
-		if (CARRY) R.PC = M_RDOP_ARG(R.PC);
+		if (CARRY) SET_PC(M_RDOP_ARG(R.PC));
 		else R.PC++ ;
 		MODIFY_AR_ARP();
 }
 static void bgez(void)
 {
-		if ( (INT32)(R.ACC.d) >= 0 ) R.PC = M_RDOP_ARG(R.PC);
+		if ( (INT32)(R.ACC.d) >= 0 ) SET_PC(M_RDOP_ARG(R.PC));
 		else R.PC++ ;
 		MODIFY_AR_ARP();
 }
 static void bgz(void)
 {
-		if ( (INT32)(R.ACC.d) > 0 ) R.PC = M_RDOP_ARG(R.PC);
+		if ( (INT32)(R.ACC.d) > 0 ) SET_PC(M_RDOP_ARG(R.PC));
 		else R.PC++ ;
 		MODIFY_AR_ARP();
 }
 static void bioz(void)
 {
-		if (S_IN(TMS32025_BIO) != CLEAR_LINE) R.PC = M_RDOP_ARG(R.PC);
+		if (S_IN(TMS32025_BIO) != CLEAR_LINE) SET_PC(M_RDOP_ARG(R.PC));
 		else R.PC++ ;
 		MODIFY_AR_ARP();
 }
@@ -703,7 +699,7 @@ static void bitt(void)
 }
 static void blez(void)
 {
-		if ( (INT32)(R.ACC.d) <= 0 ) R.PC = M_RDOP_ARG(R.PC);
+		if ( (INT32)(R.ACC.d) <= 0 ) SET_PC(M_RDOP_ARG(R.PC));
 		else R.PC++ ;
 		MODIFY_AR_ARP();
 }
@@ -731,19 +727,19 @@ static void blkp(void)
 }
 static void blz(void)
 {
-		if ( (INT32)(R.ACC.d) <  0 ) R.PC = M_RDOP_ARG(R.PC);
+		if ( (INT32)(R.ACC.d) <  0 ) SET_PC(M_RDOP_ARG(R.PC));
 		else R.PC++ ;
 		MODIFY_AR_ARP();
 }
 static void bnc(void)
 {
-		if (CARRY == 0) R.PC = M_RDOP_ARG(R.PC);
+		if (CARRY == 0) SET_PC(M_RDOP_ARG(R.PC));
 		else R.PC++ ;
 		MODIFY_AR_ARP();
 }
 static void bnv(void)
 {
-		if (OV == 0) R.PC = M_RDOP_ARG(R.PC);
+		if (OV == 0) SET_PC(M_RDOP_ARG(R.PC));
 		else {
 			R.PC++ ;
 			CLR0(OV_FLAG);
@@ -752,14 +748,14 @@ static void bnv(void)
 }
 static void bnz(void)
 {
-		if (R.ACC.d != 0) R.PC = M_RDOP_ARG(R.PC);
+		if (R.ACC.d != 0) SET_PC(M_RDOP_ARG(R.PC));
 		else R.PC++ ;
 		MODIFY_AR_ARP();
 }
 static void bv(void)
 {
 		if (OV) {
-			R.PC = M_RDOP_ARG(R.PC);
+			SET_PC(M_RDOP_ARG(R.PC));
 			CLR0(OV_FLAG);
 		}
 		else R.PC++ ;
@@ -767,20 +763,20 @@ static void bv(void)
 }
 static void bz(void)
 {
-		if (R.ACC.d == 0) R.PC = M_RDOP_ARG(R.PC);
+		if (R.ACC.d == 0) SET_PC(M_RDOP_ARG(R.PC));
 		else R.PC++ ;
 		MODIFY_AR_ARP();
 }
 static void cala(void)
 {
 		PUSH_STACK(R.PC);
-		R.PC = R.ACC.w.l;
+		SET_PC(R.ACC.w.l);
 }
 static void call(void)
 {
 		R.PC++ ;
 		PUSH_STACK(R.PC);
-		R.PC = M_RDOP_ARG((R.PC - 1));
+		SET_PC(M_RDOP_ARG((R.PC - 1)));
 		MODIFY_AR_ARP();
 }
 static void cmpl(void)
@@ -1231,7 +1227,7 @@ static void rc(void)
 }
 static void ret(void)
 {
-		R.PC = POP_STACK();
+		SET_PC(POP_STACK());
 }
 static void rfsm(void)				/** serial port mode */
 {
@@ -1542,7 +1538,7 @@ static void tblw(void)
 static void trap(void)
 {
 		PUSH_STACK(R.PC);
-		R.PC = 0x001E;		/* Trap vector */
+		SET_PC(0x001E);		/* Trap vector */
 }
 static void xor(void)
 {
@@ -1746,52 +1742,51 @@ static opcode_fn opcode_CE_subset[256]=
 /****************************************************************************
  *  Inits CPU emulation
  ****************************************************************************/
-static void tms32025_init (void)
+static void tms32025_init (int index, int clock, const void *config, int (*irqcallback)(int))
 {
-	int cpu = cpu_getactivecpu();
+	R.intRAM = auto_malloc(0x800*2);
+	R.irq_callback = irqcallback;
 
-	R.intRAM = malloc(0x800*2);
+	state_save_register_item("tms32025", index, R.PC);
+	state_save_register_item("tms32025", index, R.STR0);
+	state_save_register_item("tms32025", index, R.STR1);
+	state_save_register_item("tms32025", index, R.PFC);
+	state_save_register_item("tms32025", index, R.IFR);
+	state_save_register_item("tms32025", index, R.RPTC);
+	state_save_register_item("tms32025", index, R.ACC.d);
+	state_save_register_item("tms32025", index, R.ALU.d);
+	state_save_register_item("tms32025", index, R.Preg.d);
+	state_save_register_item("tms32025", index, R.Treg);
+	state_save_register_item("tms32025", index, R.AR[0]);
+	state_save_register_item("tms32025", index, R.AR[1]);
+	state_save_register_item("tms32025", index, R.AR[2]);
+	state_save_register_item("tms32025", index, R.AR[3]);
+	state_save_register_item("tms32025", index, R.AR[4]);
+	state_save_register_item("tms32025", index, R.AR[5]);
+	state_save_register_item("tms32025", index, R.AR[6]);
+	state_save_register_item("tms32025", index, R.AR[7]);
+	state_save_register_item("tms32025", index, R.STACK[0]);
+	state_save_register_item("tms32025", index, R.STACK[1]);
+	state_save_register_item("tms32025", index, R.STACK[2]);
+	state_save_register_item("tms32025", index, R.STACK[3]);
+	state_save_register_item("tms32025", index, R.STACK[4]);
+	state_save_register_item("tms32025", index, R.STACK[5]);
+	state_save_register_item("tms32025", index, R.STACK[6]);
+	state_save_register_item("tms32025", index, R.STACK[7]);
 
-	state_save_register_UINT16("tms32025", cpu, "PC", &R.PC, 1);
-	state_save_register_UINT16("tms32025", cpu, "STR0", &R.STR0, 1);
-	state_save_register_UINT16("tms32025", cpu, "STR1", &R.STR1, 1);
-	state_save_register_UINT16("tms32025", cpu, "PFC", &R.PFC, 1);
-	state_save_register_UINT8("tms32025", cpu, "IFR", &R.IFR, 1);
-	state_save_register_UINT8("tms32025", cpu, "RPTC", &R.RPTC, 1);
-	state_save_register_UINT32("tms32025", cpu, "ACC", &R.ACC.d, 1);
-	state_save_register_UINT32("tms32025", cpu, "ALU", &R.ALU.d, 1);
-	state_save_register_UINT32("tms32025", cpu, "Preg", &R.Preg.d, 1);
-	state_save_register_UINT16("tms32025", cpu, "Treg", &R.Treg, 1);
-	state_save_register_UINT16("tms32025", cpu, "AR0", &R.AR[0], 1);
-	state_save_register_UINT16("tms32025", cpu, "AR1", &R.AR[1], 1);
-	state_save_register_UINT16("tms32025", cpu, "AR2", &R.AR[2], 1);
-	state_save_register_UINT16("tms32025", cpu, "AR3", &R.AR[3], 1);
-	state_save_register_UINT16("tms32025", cpu, "AR4", &R.AR[4], 1);
-	state_save_register_UINT16("tms32025", cpu, "AR5", &R.AR[5], 1);
-	state_save_register_UINT16("tms32025", cpu, "AR6", &R.AR[6], 1);
-	state_save_register_UINT16("tms32025", cpu, "AR7", &R.AR[7], 1);
-	state_save_register_UINT16("tms32025", cpu, "Stack0", &R.STACK[0], 1);
-	state_save_register_UINT16("tms32025", cpu, "Stack1", &R.STACK[1], 1);
-	state_save_register_UINT16("tms32025", cpu, "Stack2", &R.STACK[2], 1);
-	state_save_register_UINT16("tms32025", cpu, "Stack3", &R.STACK[3], 1);
-	state_save_register_UINT16("tms32025", cpu, "Stack4", &R.STACK[4], 1);
-	state_save_register_UINT16("tms32025", cpu, "Stack5", &R.STACK[5], 1);
-	state_save_register_UINT16("tms32025", cpu, "Stack6", &R.STACK[6], 1);
-	state_save_register_UINT16("tms32025", cpu, "Stack7", &R.STACK[7], 1);
-
-	state_save_register_INT32("tms32025", cpu, "idle", &R.idle, 1);
-	state_save_register_INT32("tms32025", cpu, "hold", &R.hold, 1);
-	state_save_register_INT32("tms32025", cpu, "external_mem_access", &R.external_mem_access, 1);
-	state_save_register_INT32("tms32025", cpu, "init_load_addr", &R.init_load_addr, 1);
-	state_save_register_UINT16("tms32025", cpu, "prevpc", &R.PREVPC, 1);
+	state_save_register_item("tms32025", index, R.idle);
+	state_save_register_item("tms32025", index, R.hold);
+	state_save_register_item("tms32025", index, R.external_mem_access);
+	state_save_register_item("tms32025", index, R.init_load_addr);
+	state_save_register_item("tms32025", index, R.PREVPC);
 }
 
 /****************************************************************************
  *  Reset registers to their initial values
  ****************************************************************************/
-static void tms32025_reset (void *param)
+static void tms32025_reset (void)
 {
-	R.PC = 0;			/* Starting address on a reset */
+	SET_PC(0);			/* Starting address on a reset */
 	R.STR0 |= 0x0600;	/* INTM and unused bit set to 1 */
 	R.STR0 &= 0xefff;	/* OV cleared to 0. Remaining bits undefined */
 	R.STR1 |= 0x07f0;	/* SXM, C, HM, FSM, XF and unused bits set to 1 */
@@ -1822,9 +1817,9 @@ static void tms32025_reset (void *param)
 	tms32025_datamap[7] = &R.intRAM[0x380];			/* B1 */
 }
 
-static void tms32026_reset (void *param)
+static void tms32026_reset (void)
 {
-	tms32025_reset(param);
+	tms32025_reset();
 
 	/* Reset the Data/Program address banks */
 	memset(tms32025_pgmmap, 0, sizeof(tms32025_pgmmap));
@@ -1851,9 +1846,6 @@ static void tms32026_reset (void *param)
  ****************************************************************************/
 static void tms32025_exit (void)
 {
-	if (R.intRAM)
-		free(R.intRAM);
-	R.intRAM = NULL;
 }
 
 
@@ -1877,7 +1869,7 @@ static int process_IRQs(void)
 
 		if ((R.IFR & 0x01) && (IMR & 0x01)) {		/* IRQ line 0 */
 			/*logerror("TMS32025:  Active INT0\n"); */
-			R.PC = 0x0002;
+			SET_PC(0x0002);
 			(*R.irq_callback)(0);
 			R.idle = 0;
 			R.IFR &= (~0x01);
@@ -1886,7 +1878,7 @@ static int process_IRQs(void)
 		}
 		if ((R.IFR & 0x02) && (IMR & 0x02)) {		/* IRQ line 1 */
 			/*logerror("TMS32025:  Active INT1\n"); */
-			R.PC = 0x0004;
+			SET_PC(0x0004);
 			(*R.irq_callback)(1);
 			R.idle = 0;
 			R.IFR &= (~0x02);
@@ -1895,7 +1887,7 @@ static int process_IRQs(void)
 		}
 		if ((R.IFR & 0x04) && (IMR & 0x04)) {		/* IRQ line 2 */
 			/*logerror("TMS32025:  Active INT2\n"); */
-			R.PC = 0x0006;
+			SET_PC(0x0006);
 			(*R.irq_callback)(2);
 			R.idle = 0;
 			R.IFR &= (~0x04);
@@ -1904,7 +1896,7 @@ static int process_IRQs(void)
 		}
 		if ((R.IFR & 0x08) && (IMR & 0x08)) {		/* Timer IRQ (internal) */
 /*          logerror("TMS32025:  Active TINT (Timer)\n"); */
-			R.PC = 0x0018;
+			SET_PC(0x0018);
 			R.idle = 0;
 			R.IFR &= (~0x08);
 			SET0(INTM_FLAG);
@@ -1913,7 +1905,7 @@ static int process_IRQs(void)
 		if ((R.IFR & 0x10) && (IMR & 0x10)) {		/* Serial port receive IRQ (internal) */
 /*          logerror("TMS32025:  Active RINT (Serial recieve)\n"); */
 			DRR = S_IN(TMS32025_DR);
-			R.PC = 0x001A;
+			SET_PC(0x001A);
 			R.idle = 0;
 			R.IFR &= (~0x10);
 			SET0(INTM_FLAG);
@@ -1922,7 +1914,7 @@ static int process_IRQs(void)
 		if ((R.IFR & 0x20) && (IMR & 0x20)) {		/* Serial port transmit IRQ (internal) */
 /*          logerror("TMS32025:  Active XINT (Serial transmit)\n"); */
 			S_OUT(TMS32025_DX,DXR);
-			R.PC = 0x001C;
+			SET_PC(0x001C);
 			R.idle = 0;
 			R.IFR &= (~0x20);
 			SET0(INTM_FLAG);
@@ -2340,9 +2332,6 @@ static void tms32025_set_info(UINT32 state, union cpuinfo *info)
 		case CPUINFO_INT_REGISTER + TMS32025_PRD:		M_WRTRAM(3,info->i);					break;
 		case CPUINFO_INT_REGISTER + TMS32025_IMR:		M_WRTRAM(4,info->i);					break;
 		case CPUINFO_INT_REGISTER + TMS32025_GREG:		M_WRTRAM(5,info->i);					break;
-
-		/* --- the following bits of info are set as pointers to data or functions --- */
-		case CPUINFO_PTR_IRQ_CALLBACK:					R.irq_callback = info->irqcallback;		break;
 	}
 }
 
@@ -2433,7 +2422,6 @@ void tms32025_get_info(UINT32 state, union cpuinfo *info)
 		case CPUINFO_PTR_READ:							info->read = tms32025_read;				break;
 		case CPUINFO_PTR_WRITE:							info->write = tms32025_write;			break;
 		case CPUINFO_PTR_READOP:						info->readop = tms32025_readop;			break;
-		case CPUINFO_PTR_IRQ_CALLBACK:					info->irqcallback = R.irq_callback;		break;
 		case CPUINFO_PTR_INSTRUCTION_COUNTER:			info->icount = &tms32025_icount;		break;
 		case CPUINFO_PTR_REGISTER_LAYOUT:				info->p = tms32025_reg_layout;			break;
 		case CPUINFO_PTR_WINDOW_LAYOUT:					info->p = tms32025_win_layout;			break;
