@@ -1,23 +1,20 @@
-/*###################################################################################################
-**
-**
-**      tms32031.h
-**      Interface file for the portable TMS32C031 emulator.
-**      Written by Aaron Giles
-**
-**
-**#################################################################################################*/
+/***************************************************************************
+
+    tms32031.h
+    Interface file for the portable TMS32C031 emulator.
+    Written by Aaron Giles
+
+***************************************************************************/
 
 #ifndef _TMS32031_H
 #define _TMS32031_H
 
-#include "memory.h"
-#include "osd_cpu.h"
+#include "cpuintrf.h"
 
 
-/*###################################################################################################
-**  TYPE DEFINITIONS
-**#################################################################################################*/
+/***************************************************************************
+    TYPE DEFINITIONS
+***************************************************************************/
 
 struct tms32031_config
 {
@@ -28,9 +25,9 @@ struct tms32031_config
 };
 
 
-/*###################################################################################################
-**  REGISTER ENUMERATION
-**#################################################################################################*/
+/***************************************************************************
+    REGISTER ENUMERATION
+***************************************************************************/
 
 enum
 {
@@ -47,9 +44,9 @@ enum
 };
 
 
-/*###################################################################################################
-**  INTERRUPT CONSTANTS
-**#################################################################################################*/
+/***************************************************************************
+    INTERRUPT CONSTANTS
+***************************************************************************/
 
 #define TMS32031_IRQ0		0		/* IRQ0 */
 #define TMS32031_IRQ1		1		/* IRQ1 */
@@ -64,9 +61,9 @@ enum
 #define TMS32031_DINT		10		/* DMA interrupt */
 
 
-/*###################################################################################################
-**  PUBLIC FUNCTIONS
-**#################################################################################################*/
+/***************************************************************************
+    PUBLIC FUNCTIONS
+***************************************************************************/
 
 extern void tms32031_get_info(UINT32 state, union cpuinfo *info);
 
