@@ -2,7 +2,7 @@
 /* AM1 Functions (for ReadAM) */
 /* ************************** */
 
-UINT32 am1Register(void)
+static UINT32 am1Register(void)
 {
 	switch (modDim)
 	{
@@ -20,7 +20,7 @@ UINT32 am1Register(void)
 	return 1;
 }
 
-UINT32 am1RegisterIndirect(void)
+static UINT32 am1RegisterIndirect(void)
 {
 	switch (modDim)
 	{
@@ -38,14 +38,14 @@ UINT32 am1RegisterIndirect(void)
 	return 1;
 }
 
-UINT32 bam1RegisterIndirect(void)
+static UINT32 bam1RegisterIndirect(void)
 {
 	bamOffset=0;
 	amOut=MemRead32(v60.reg[modVal&0x1F]);
 	return 1;
 }
 
-UINT32 am1RegisterIndirectIndexed(void)
+static UINT32 am1RegisterIndirectIndexed(void)
 {
 	switch (modDim)
 	{
@@ -63,7 +63,7 @@ UINT32 am1RegisterIndirectIndexed(void)
 	return 2;
 }
 
-UINT32 bam1RegisterIndirectIndexed(void)
+static UINT32 bam1RegisterIndirectIndexed(void)
 {
 	bamOffset=v60.reg[modVal&0x1F];
 	amOut=MemRead32(v60.reg[modVal2&0x1F]+bamOffset/8);
@@ -71,7 +71,7 @@ UINT32 bam1RegisterIndirectIndexed(void)
 	return 2;
 }
 
-UINT32 am1Autoincrement(void)
+static UINT32 am1Autoincrement(void)
 {
 	switch (modDim)
 	{
@@ -92,7 +92,7 @@ UINT32 am1Autoincrement(void)
 	return 1;
 }
 
-UINT32 bam1Autoincrement(void)
+static UINT32 bam1Autoincrement(void)
 {
 	bamOffset=0;
 	amOut=MemRead32(v60.reg[modVal&0x1F]);
@@ -105,13 +105,13 @@ UINT32 bam1Autoincrement(void)
 		v60.reg[modVal&0x1F]+=4;
 		break;
 	default:
-		logerror("CPU - BAM1 - 7\n");
-		abort();
+		fatalerror("CPU - BAM1 - 7");
+		break;
 	}
 	return 1;
 }
 
-UINT32 am1Autodecrement(void)
+static UINT32 am1Autodecrement(void)
 {
 	switch (modDim)
 	{
@@ -132,7 +132,7 @@ UINT32 am1Autodecrement(void)
 	return 1;
 }
 
-UINT32 bam1Autodecrement(void)
+static UINT32 bam1Autodecrement(void)
 {
 	bamOffset=0;
 	switch (modDim)
@@ -144,14 +144,14 @@ UINT32 bam1Autodecrement(void)
 		v60.reg[modVal&0x1F]-=4;
 		break;
 	default:
-		logerror("CPU - BAM1 - 7\n");
-		abort();
+		fatalerror("CPU - BAM1 - 7");
+		break;
 	}
 	amOut=MemRead32(v60.reg[modVal&0x1F]);
 	return 1;
 }
 
-UINT32 am1Displacement8(void)
+static UINT32 am1Displacement8(void)
 {
 	switch (modDim)
 	{
@@ -169,7 +169,7 @@ UINT32 am1Displacement8(void)
 	return 2;
 }
 
-UINT32 bam1Displacement8(void)
+static UINT32 bam1Displacement8(void)
 {
 	bamOffset=MemRead8(modAdd+1);
 	amOut=MemRead32(v60.reg[modVal&0x1F]+bamOffset/8);
@@ -178,7 +178,7 @@ UINT32 bam1Displacement8(void)
 }
 
 
-UINT32 am1Displacement16(void)
+static UINT32 am1Displacement16(void)
 {
 	switch (modDim)
 	{
@@ -196,7 +196,7 @@ UINT32 am1Displacement16(void)
 	return 3;
 }
 
-UINT32 bam1Displacement16(void)
+static UINT32 bam1Displacement16(void)
 {
 	bamOffset=OpRead16(modAdd+1);
 	amOut=MemRead32(v60.reg[modVal&0x1F]+bamOffset/8);
@@ -204,7 +204,7 @@ UINT32 bam1Displacement16(void)
 	return 3;
 }
 
-UINT32 am1Displacement32(void)
+static UINT32 am1Displacement32(void)
 {
 	switch (modDim)
 	{
@@ -222,7 +222,7 @@ UINT32 am1Displacement32(void)
 	return 5;
 }
 
-UINT32 bam1Displacement32(void)
+static UINT32 bam1Displacement32(void)
 {
 	bamOffset=OpRead32(modAdd+1);
 	amOut=MemRead32(v60.reg[modVal&0x1F]+bamOffset/8);
@@ -230,7 +230,7 @@ UINT32 bam1Displacement32(void)
 	return 5;
 }
 
-UINT32 am1DisplacementIndexed8(void)
+static UINT32 am1DisplacementIndexed8(void)
 {
 	switch (modDim)
 	{
@@ -248,7 +248,7 @@ UINT32 am1DisplacementIndexed8(void)
 	return 3;
 }
 
-UINT32 bam1DisplacementIndexed8(void)
+static UINT32 bam1DisplacementIndexed8(void)
 {
 	bamOffset=v60.reg[modVal&0x1F];
 	amOut=MemRead32(v60.reg[modVal2&0x1F] + (INT8)OpRead8(modAdd+2)+bamOffset/8);
@@ -256,7 +256,7 @@ UINT32 bam1DisplacementIndexed8(void)
 	return 3;
 }
 
-UINT32 am1DisplacementIndexed16(void)
+static UINT32 am1DisplacementIndexed16(void)
 {
 	switch (modDim)
 	{
@@ -274,7 +274,7 @@ UINT32 am1DisplacementIndexed16(void)
 	return 4;
 }
 
-UINT32 bam1DisplacementIndexed16(void)
+static UINT32 bam1DisplacementIndexed16(void)
 {
 	bamOffset=v60.reg[modVal&0x1F];
 	amOut=MemRead32(v60.reg[modVal2&0x1F] + (INT16)OpRead16(modAdd+2)+bamOffset/8);
@@ -282,7 +282,7 @@ UINT32 bam1DisplacementIndexed16(void)
 	return 4;
 }
 
-UINT32 am1DisplacementIndexed32(void)
+static UINT32 am1DisplacementIndexed32(void)
 {
 	switch (modDim)
 	{
@@ -300,7 +300,7 @@ UINT32 am1DisplacementIndexed32(void)
 	return 6;
 }
 
-UINT32 bam1DisplacementIndexed32(void)
+static UINT32 bam1DisplacementIndexed32(void)
 {
 	bamOffset=v60.reg[modVal&0x1F];
 	amOut=MemRead32(v60.reg[modVal2&0x1F] + OpRead32(modAdd+2)+bamOffset/8);
@@ -309,7 +309,7 @@ UINT32 bam1DisplacementIndexed32(void)
 }
 
 
-UINT32 am1PCDisplacement8(void)
+static UINT32 am1PCDisplacement8(void)
 {
 	switch (modDim)
 	{
@@ -327,7 +327,7 @@ UINT32 am1PCDisplacement8(void)
 	return 2;
 }
 
-UINT32 bam1PCDisplacement8(void)
+static UINT32 bam1PCDisplacement8(void)
 {
 	bamOffset=OpRead8(modAdd+1);
 	amOut=MemRead32(PC+bamOffset/8);
@@ -335,7 +335,7 @@ UINT32 bam1PCDisplacement8(void)
 	return 2;
 }
 
-UINT32 am1PCDisplacement16(void)
+static UINT32 am1PCDisplacement16(void)
 {
 	switch (modDim)
 	{
@@ -353,7 +353,7 @@ UINT32 am1PCDisplacement16(void)
 	return 3;
 }
 
-UINT32 bam1PCDisplacement16(void)
+static UINT32 bam1PCDisplacement16(void)
 {
 	bamOffset=OpRead16(modAdd+1);
 	amOut=MemRead32(PC+bamOffset/8);
@@ -361,7 +361,7 @@ UINT32 bam1PCDisplacement16(void)
 	return 3;
 }
 
-UINT32 am1PCDisplacement32(void)
+static UINT32 am1PCDisplacement32(void)
 {
 	switch (modDim)
 	{
@@ -379,7 +379,7 @@ UINT32 am1PCDisplacement32(void)
 	return 5;
 }
 
-UINT32 bam1PCDisplacement32(void)
+static UINT32 bam1PCDisplacement32(void)
 {
 	bamOffset=OpRead32(modAdd+1);
 	amOut=MemRead32(PC+bamOffset/8);
@@ -387,7 +387,7 @@ UINT32 bam1PCDisplacement32(void)
 	return 5;
 }
 
-UINT32 am1PCDisplacementIndexed8(void)
+static UINT32 am1PCDisplacementIndexed8(void)
 {
 	switch (modDim)
 	{
@@ -405,7 +405,7 @@ UINT32 am1PCDisplacementIndexed8(void)
 	return 3;
 }
 
-UINT32 bam1PCDisplacementIndexed8(void)
+static UINT32 bam1PCDisplacementIndexed8(void)
 {
 	bamOffset=v60.reg[modVal&0x1F];
 	amOut=MemRead32(PC + (INT8)OpRead8(modAdd+2)+bamOffset/8);
@@ -414,7 +414,7 @@ UINT32 bam1PCDisplacementIndexed8(void)
 }
 
 
-UINT32 am1PCDisplacementIndexed16(void)
+static UINT32 am1PCDisplacementIndexed16(void)
 {
 	switch (modDim)
 	{
@@ -432,7 +432,7 @@ UINT32 am1PCDisplacementIndexed16(void)
 	return 4;
 }
 
-UINT32 bam1PCDisplacementIndexed16(void)
+static UINT32 bam1PCDisplacementIndexed16(void)
 {
 	bamOffset=v60.reg[modVal&0x1F];
 	amOut=MemRead32(PC + (INT16)OpRead16(modAdd+2)+bamOffset/8);
@@ -440,7 +440,7 @@ UINT32 bam1PCDisplacementIndexed16(void)
 	return 4;
 }
 
-UINT32 am1PCDisplacementIndexed32(void)
+static UINT32 am1PCDisplacementIndexed32(void)
 {
 	switch (modDim)
 	{
@@ -458,7 +458,7 @@ UINT32 am1PCDisplacementIndexed32(void)
 	return 6;
 }
 
-UINT32 bam1PCDisplacementIndexed32(void)
+static UINT32 bam1PCDisplacementIndexed32(void)
 {
 	bamOffset=v60.reg[modVal&0x1F];
 	amOut=MemRead32(PC + OpRead32(modAdd+2)+bamOffset/8);
@@ -466,7 +466,7 @@ UINT32 bam1PCDisplacementIndexed32(void)
 	return 6;
 }
 
-UINT32 am1DisplacementIndirect8(void)
+static UINT32 am1DisplacementIndirect8(void)
 {
 	switch (modDim)
 	{
@@ -484,14 +484,14 @@ UINT32 am1DisplacementIndirect8(void)
 	return 2;
 }
 
-UINT32 bam1DisplacementIndirect8(void)
+static UINT32 bam1DisplacementIndirect8(void)
 {
 	bamOffset=0;
 	amOut=MemRead32(MemRead32(v60.reg[modVal&0x1F] + (INT8)OpRead8(modAdd+1)));
 	return 2;
 }
 
-UINT32 am1DisplacementIndirect16(void)
+static UINT32 am1DisplacementIndirect16(void)
 {
 	switch (modDim)
 	{
@@ -509,14 +509,14 @@ UINT32 am1DisplacementIndirect16(void)
 	return 3;
 }
 
-UINT32 bam1DisplacementIndirect16(void)
+static UINT32 bam1DisplacementIndirect16(void)
 {
 	bamOffset=0;
 	amOut=MemRead32(MemRead32(v60.reg[modVal&0x1F] + (INT16)OpRead16(modAdd+1)));
 	return 3;
 }
 
-UINT32 am1DisplacementIndirect32(void)
+static UINT32 am1DisplacementIndirect32(void)
 {
 	switch (modDim)
 	{
@@ -534,14 +534,14 @@ UINT32 am1DisplacementIndirect32(void)
 	return 5;
 }
 
-UINT32 bam1DisplacementIndirect32(void)
+static UINT32 bam1DisplacementIndirect32(void)
 {
 	bamOffset=0;
 	amOut=MemRead32(MemRead32(v60.reg[modVal&0x1F] + OpRead32(modAdd+1)));
 	return 5;
 }
 
-UINT32 am1DisplacementIndirectIndexed8(void)
+static UINT32 am1DisplacementIndirectIndexed8(void)
 {
 	switch (modDim)
 	{
@@ -559,7 +559,7 @@ UINT32 am1DisplacementIndirectIndexed8(void)
 	return 3;
 }
 
-UINT32 bam1DisplacementIndirectIndexed8(void)
+static UINT32 bam1DisplacementIndirectIndexed8(void)
 {
 	bamOffset=v60.reg[modVal&0x1F];
 	amOut=MemRead32(MemRead32(v60.reg[modVal2&0x1F] + (INT8)OpRead8(modAdd+2))+bamOffset/8);
@@ -567,7 +567,7 @@ UINT32 bam1DisplacementIndirectIndexed8(void)
 	return 3;
 }
 
-UINT32 am1DisplacementIndirectIndexed16(void)
+static UINT32 am1DisplacementIndirectIndexed16(void)
 {
 	switch (modDim)
 	{
@@ -585,7 +585,7 @@ UINT32 am1DisplacementIndirectIndexed16(void)
 	return 4;
 }
 
-UINT32 bam1DisplacementIndirectIndexed16(void)
+static UINT32 bam1DisplacementIndirectIndexed16(void)
 {
 	bamOffset=v60.reg[modVal&0x1F];
 	amOut=MemRead32(MemRead32(v60.reg[modVal2&0x1F] + (INT16)OpRead16(modAdd+2))+bamOffset/8);
@@ -593,7 +593,7 @@ UINT32 bam1DisplacementIndirectIndexed16(void)
 	return 4;
 }
 
-UINT32 am1DisplacementIndirectIndexed32(void)
+static UINT32 am1DisplacementIndirectIndexed32(void)
 {
 	switch (modDim)
 	{
@@ -611,7 +611,7 @@ UINT32 am1DisplacementIndirectIndexed32(void)
 	return 6;
 }
 
-UINT32 bam1DisplacementIndirectIndexed32(void)
+static UINT32 bam1DisplacementIndirectIndexed32(void)
 {
 	bamOffset=v60.reg[modVal&0x1F];
 	amOut=MemRead32(MemRead32(v60.reg[modVal2&0x1F] + OpRead32(modAdd+2))+bamOffset/8);
@@ -619,7 +619,7 @@ UINT32 bam1DisplacementIndirectIndexed32(void)
 	return 6;
 }
 
-UINT32 am1PCDisplacementIndirect8(void)
+static UINT32 am1PCDisplacementIndirect8(void)
 {
 	switch (modDim)
 	{
@@ -637,14 +637,14 @@ UINT32 am1PCDisplacementIndirect8(void)
 	return 2;
 }
 
-UINT32 bam1PCDisplacementIndirect8(void)
+static UINT32 bam1PCDisplacementIndirect8(void)
 {
 	bamOffset=0;
 	amOut=MemRead32(MemRead32(PC + (INT8)OpRead8(modAdd+1)));
 	return 2;
 }
 
-UINT32 am1PCDisplacementIndirect16(void)
+static UINT32 am1PCDisplacementIndirect16(void)
 {
 	switch (modDim)
 	{
@@ -662,14 +662,14 @@ UINT32 am1PCDisplacementIndirect16(void)
 	return 3;
 }
 
-UINT32 bam1PCDisplacementIndirect16(void)
+static UINT32 bam1PCDisplacementIndirect16(void)
 {
 	bamOffset=0;
 	amOut=MemRead32(MemRead32(PC + (INT16)OpRead16(modAdd+1)));
 	return 3;
 }
 
-UINT32 am1PCDisplacementIndirect32(void)
+static UINT32 am1PCDisplacementIndirect32(void)
 {
 	switch (modDim)
 	{
@@ -687,14 +687,14 @@ UINT32 am1PCDisplacementIndirect32(void)
 	return 5;
 }
 
-UINT32 bam1PCDisplacementIndirect32(void)
+static UINT32 bam1PCDisplacementIndirect32(void)
 {
 	bamOffset=0;
 	amOut=MemRead32(MemRead32(PC + OpRead32(modAdd+1)));
 	return 5;
 }
 
-UINT32 am1PCDisplacementIndirectIndexed8(void)
+static UINT32 am1PCDisplacementIndirectIndexed8(void)
 {
 	switch (modDim)
 	{
@@ -712,7 +712,7 @@ UINT32 am1PCDisplacementIndirectIndexed8(void)
 	return 3;
 }
 
-UINT32 bam1PCDisplacementIndirectIndexed8(void)
+static UINT32 bam1PCDisplacementIndirectIndexed8(void)
 {
 	bamOffset=v60.reg[modVal&0x1F];
 	amOut=MemRead32(MemRead32(PC + (INT8)OpRead8(modAdd+2))+bamOffset/8);
@@ -720,7 +720,7 @@ UINT32 bam1PCDisplacementIndirectIndexed8(void)
 	return 3;
 }
 
-UINT32 am1PCDisplacementIndirectIndexed16(void)
+static UINT32 am1PCDisplacementIndirectIndexed16(void)
 {
 	switch (modDim)
 	{
@@ -738,7 +738,7 @@ UINT32 am1PCDisplacementIndirectIndexed16(void)
 	return 4;
 }
 
-UINT32 bam1PCDisplacementIndirectIndexed16(void)
+static UINT32 bam1PCDisplacementIndirectIndexed16(void)
 {
 	bamOffset=v60.reg[modVal&0x1F];
 	amOut=MemRead32(MemRead32(PC + (INT16)OpRead16(modAdd+2))+bamOffset/8);
@@ -746,7 +746,7 @@ UINT32 bam1PCDisplacementIndirectIndexed16(void)
 	return 4;
 }
 
-UINT32 am1PCDisplacementIndirectIndexed32(void)
+static UINT32 am1PCDisplacementIndirectIndexed32(void)
 {
 	switch (modDim)
 	{
@@ -764,7 +764,7 @@ UINT32 am1PCDisplacementIndirectIndexed32(void)
 	return 6;
 }
 
-UINT32 bam1PCDisplacementIndirectIndexed32(void)
+static UINT32 bam1PCDisplacementIndirectIndexed32(void)
 {
 	bamOffset=v60.reg[modVal&0x1F];
 	amOut=MemRead32(MemRead32(PC + OpRead32(modAdd+2))+bamOffset/8);
@@ -772,7 +772,7 @@ UINT32 bam1PCDisplacementIndirectIndexed32(void)
 	return 6;
 }
 
-UINT32 am1DoubleDisplacement8(void)
+static UINT32 am1DoubleDisplacement8(void)
 {
 	switch (modDim)
 	{
@@ -792,7 +792,7 @@ UINT32 am1DoubleDisplacement8(void)
 	return 3;
 }
 
-UINT32 bam1DoubleDisplacement8(void)
+static UINT32 bam1DoubleDisplacement8(void)
 {
 	bamOffset=OpRead8(modAdd+2);
 	amOut=MemRead32(MemRead32(v60.reg[modVal&0x1F] + (INT8)OpRead8(modAdd+1))+bamOffset/8);
@@ -800,7 +800,7 @@ UINT32 bam1DoubleDisplacement8(void)
 	return 3;
 }
 
-UINT32 am1DoubleDisplacement16(void)
+static UINT32 am1DoubleDisplacement16(void)
 {
 	switch (modDim)
 	{
@@ -820,7 +820,7 @@ UINT32 am1DoubleDisplacement16(void)
 	return 5;
 }
 
-UINT32 bam1DoubleDisplacement16(void)
+static UINT32 bam1DoubleDisplacement16(void)
 {
 	bamOffset=OpRead16(modAdd+3);
 	amOut=MemRead32(MemRead32(v60.reg[modVal&0x1F] + (INT16)OpRead16(modAdd+1))+bamOffset/8);
@@ -828,7 +828,7 @@ UINT32 bam1DoubleDisplacement16(void)
 	return 5;
 }
 
-UINT32 am1DoubleDisplacement32(void)
+static UINT32 am1DoubleDisplacement32(void)
 {
 	switch (modDim)
 	{
@@ -848,7 +848,7 @@ UINT32 am1DoubleDisplacement32(void)
 	return 9;
 }
 
-UINT32 bam1DoubleDisplacement32(void)
+static UINT32 bam1DoubleDisplacement32(void)
 {
 	bamOffset=OpRead32(modAdd+5);
 	amOut=MemRead32(MemRead32(v60.reg[modVal&0x1F] + OpRead32(modAdd+1))+bamOffset/8);
@@ -856,7 +856,7 @@ UINT32 bam1DoubleDisplacement32(void)
 	return 9;
 }
 
-UINT32 am1PCDoubleDisplacement8(void)
+static UINT32 am1PCDoubleDisplacement8(void)
 {
 	switch (modDim)
 	{
@@ -876,7 +876,7 @@ UINT32 am1PCDoubleDisplacement8(void)
 	return 3;
 }
 
-UINT32 bam1PCDoubleDisplacement8(void)
+static UINT32 bam1PCDoubleDisplacement8(void)
 {
 	bamOffset=OpRead8(modAdd+2);
 	amOut=MemRead32(MemRead32(PC + (INT8)OpRead8(modAdd+1))+bamOffset/8);
@@ -884,7 +884,7 @@ UINT32 bam1PCDoubleDisplacement8(void)
 	return 3;
 }
 
-UINT32 am1PCDoubleDisplacement16(void)
+static UINT32 am1PCDoubleDisplacement16(void)
 {
 	switch (modDim)
 	{
@@ -904,7 +904,7 @@ UINT32 am1PCDoubleDisplacement16(void)
 	return 5;
 }
 
-UINT32 bam1PCDoubleDisplacement16(void)
+static UINT32 bam1PCDoubleDisplacement16(void)
 {
 	bamOffset=OpRead16(modAdd+3);
 	amOut=MemRead32(MemRead32(PC + (INT16)OpRead16(modAdd+1))+bamOffset/8);
@@ -913,7 +913,7 @@ UINT32 bam1PCDoubleDisplacement16(void)
 }
 
 
-UINT32 am1PCDoubleDisplacement32(void)
+static UINT32 am1PCDoubleDisplacement32(void)
 {
 	switch (modDim)
 	{
@@ -933,7 +933,7 @@ UINT32 am1PCDoubleDisplacement32(void)
 	return 9;
 }
 
-UINT32 bam1PCDoubleDisplacement32(void)
+static UINT32 bam1PCDoubleDisplacement32(void)
 {
 	bamOffset=OpRead32(modAdd+5);
 	amOut=MemRead32(MemRead32(PC + OpRead32(modAdd+1))+bamOffset/8);
@@ -941,7 +941,7 @@ UINT32 bam1PCDoubleDisplacement32(void)
 	return 9;
 }
 
-UINT32 am1DirectAddress(void)
+static UINT32 am1DirectAddress(void)
 {
 	switch (modDim)
 	{
@@ -961,14 +961,14 @@ UINT32 am1DirectAddress(void)
 	return 5;
 }
 
-UINT32 bam1DirectAddress(void)
+static UINT32 bam1DirectAddress(void)
 {
 	bamOffset=0;
 	amOut=MemRead32(OpRead32(modAdd+1));
 	return 5;
 }
 
-UINT32 am1DirectAddressIndexed(void)
+static UINT32 am1DirectAddressIndexed(void)
 {
 	switch (modDim)
 	{
@@ -988,7 +988,7 @@ UINT32 am1DirectAddressIndexed(void)
 	return 6;
 }
 
-UINT32 bam1DirectAddressIndexed(void)
+static UINT32 bam1DirectAddressIndexed(void)
 {
 	bamOffset=v60.reg[modVal&0x1F];
 	amOut=MemRead32(OpRead32(modAdd+2)+bamOffset/8);
@@ -996,7 +996,7 @@ UINT32 bam1DirectAddressIndexed(void)
 	return 6;
 }
 
-UINT32 am1DirectAddressDeferred(void)
+static UINT32 am1DirectAddressDeferred(void)
 {
 	switch (modDim)
 	{
@@ -1016,14 +1016,14 @@ UINT32 am1DirectAddressDeferred(void)
 	return 5;
 }
 
-UINT32 bam1DirectAddressDeferred(void)
+static UINT32 bam1DirectAddressDeferred(void)
 {
 	bamOffset=0;
 	amOut=MemRead32(MemRead32(OpRead32(modAdd+1)));
 	return 5;
 }
 
-UINT32 am1DirectAddressDeferredIndexed(void)
+static UINT32 am1DirectAddressDeferredIndexed(void)
 {
 	switch (modDim)
 	{
@@ -1043,7 +1043,7 @@ UINT32 am1DirectAddressDeferredIndexed(void)
 	return 6;
 }
 
-UINT32 bam1DirectAddressDeferredIndexed(void)
+static UINT32 bam1DirectAddressDeferredIndexed(void)
 {
 	bamOffset=v60.reg[modVal&0x1F];
 	amOut=MemRead32(MemRead32(OpRead32(modAdd+2))+bamOffset/8);
@@ -1051,7 +1051,7 @@ UINT32 bam1DirectAddressDeferredIndexed(void)
 	return 6;
 }
 
-UINT32 am1Immediate(void)
+static UINT32 am1Immediate(void)
 {
 	switch (modDim)
 	{
@@ -1076,7 +1076,7 @@ UINT32 am1Immediate(void)
 	return 1;
 }
 
-UINT32 am1ImmediateQuick(void)
+static UINT32 am1ImmediateQuick(void)
 {
 	amOut=modVal&0xF;
 	return 1;
@@ -1088,73 +1088,73 @@ UINT32 am1ImmediateQuick(void)
 /* AM1 Tables (for ReadAM) */
 /* *********************** */
 
-UINT32 am1Error1(void)
+static UINT32 am1Error1(void)
 {
-	logerror("CPU - AM1 - 1 (PC=%06x)\n", PC);
-	abort();
+	fatalerror("CPU - AM1 - 1 (PC=%06x)", PC);
+	return 0; /* never reached, fatalerror won't return */
 }
 
-UINT32 bam1Error1(void)
+static UINT32 bam1Error1(void)
 {
-	logerror("CPU - BAM1 - 1 (PC=%06x)\n", PC);
-	abort();
+	fatalerror("CPU - BAM1 - 1 (PC=%06x)", PC);
+	return 0; /* never reached, fatalerror won't return */
 }
 
-UINT32 am1Error2(void)
+static UINT32 am1Error2(void)
 {
-	logerror("CPU - AM1 - 2 (PC=%06x)\n", PC);
-	abort();
+	fatalerror("CPU - AM1 - 2 (PC=%06x)", PC);
+	return 0; /* never reached, fatalerror won't return */
 }
 
-UINT32 bam1Error2(void)
+static UINT32 bam1Error2(void)
 {
-	logerror("CPU - BAM1 - 2 (PC=%06x)\n", PC);
-	abort();
+	fatalerror("CPU - BAM1 - 2 (PC=%06x)", PC);
+	return 0; /* never reached, fatalerror won't return */
 }
 
-UINT32 am1Error3(void)
+static UINT32 am1Error3(void)
 {
-	logerror("CPU - AM1 - 3 (PC=%06x)\n", PC);
-	abort();
+	fatalerror("CPU - AM1 - 3 (PC=%06x)", PC);
+	return 0; /* never reached, fatalerror won't return */
 }
 
-UINT32 bam1Error3(void)
+static UINT32 bam1Error3(void)
 {
-	logerror("CPU - BAM1 - 3 (PC=%06x)\n", PC);
-	abort();
+	fatalerror("CPU - BAM1 - 3 (PC=%06x)", PC);
+	return 0; /* never reached, fatalerror won't return */
 }
 
-UINT32 am1Error4(void)
+static UINT32 am1Error4(void)
 {
-	logerror("CPU - AM1 - 4 (PC=%06x)\n", PC);
-	abort();
+	fatalerror("CPU - AM1 - 4 (PC=%06x)", PC);
+	return 0; /* never reached, fatalerror won't return */
 }
 
-UINT32 bam1Error4(void)
+static UINT32 bam1Error4(void)
 {
-	logerror("CPU - BAM1 - 4 (PC=%06x)\n", PC);
-	abort();
+	fatalerror("CPU - BAM1 - 4 (PC=%06x)", PC);
+	return 0; /* never reached, fatalerror won't return */
 }
 
-UINT32 am1Error5(void)
+static UINT32 am1Error5(void)
 {
-	logerror("CPU - AM1 - 5 (PC=%06x)\n", PC);
-	abort();
+	fatalerror("CPU - AM1 - 5 (PC=%06x)", PC);
+	return 0; /* never reached, fatalerror won't return */
 }
 
-UINT32 bam1Error5(void)
+static UINT32 bam1Error5(void)
 {
-	logerror("CPU - BAM1 - 5 (PC=%06x)\n", PC);
-	abort();
+	fatalerror("CPU - BAM1 - 5 (PC=%06x)", PC);
+	return 0; /* never reached, fatalerror won't return */
 }
 
-UINT32 bam1Error6(void)
+static UINT32 bam1Error6(void)
 {
-	logerror("CPU - BAM1 - 6 (PC=%06x)\n", PC);
-	abort();
+	fatalerror("CPU - BAM1 - 6 (PC=%06x)", PC);
+	return 0; /* never reached, fatalerror won't return */
 }
 
-UINT32 (*AMTable1_G7a[16])(void) =
+static UINT32 (*const AMTable1_G7a[16])(void) =
 {
 	am1PCDisplacementIndexed8,
 	am1PCDisplacementIndexed16,
@@ -1174,7 +1174,7 @@ UINT32 (*AMTable1_G7a[16])(void) =
 	am1Error5
 };
 
-UINT32 (*BAMTable1_G7a[16])(void) =
+static UINT32 (*const BAMTable1_G7a[16])(void) =
 {
 	bam1PCDisplacementIndexed8,
 	bam1PCDisplacementIndexed16,
@@ -1195,7 +1195,7 @@ UINT32 (*BAMTable1_G7a[16])(void) =
 };
 
 
-UINT32 am1Group7a(void)
+static UINT32 am1Group7a(void)
 {
 	if (!(modVal2&0x10))
 		return am1Error4();
@@ -1203,7 +1203,7 @@ UINT32 am1Group7a(void)
 	return AMTable1_G7a[modVal2&0xF]();
 }
 
-UINT32 bam1Group7a(void)
+static UINT32 bam1Group7a(void)
 {
 	if (!(modVal2&0x10))
 		return bam1Error4();
@@ -1211,7 +1211,7 @@ UINT32 bam1Group7a(void)
 	return BAMTable1_G7a[modVal2&0xF]();
 }
 
-UINT32 (*AMTable1_G7[32])(void) =
+static UINT32 (*const AMTable1_G7[32])(void) =
 {
 	am1ImmediateQuick,
 	am1ImmediateQuick,
@@ -1247,7 +1247,7 @@ UINT32 (*AMTable1_G7[32])(void) =
   am1Error2
 };
 
-UINT32 (*BAMTable1_G7[32])(void) =
+static UINT32 (*const BAMTable1_G7[32])(void) =
 {
 	bam1Error6,
 	bam1Error6,
@@ -1285,7 +1285,7 @@ UINT32 (*BAMTable1_G7[32])(void) =
 
 
 
-UINT32 (*AMTable1_G6[8])(void) =
+static UINT32 (*const AMTable1_G6[8])(void) =
 {
 	am1DisplacementIndexed8,
 	am1DisplacementIndexed16,
@@ -1297,7 +1297,7 @@ UINT32 (*AMTable1_G6[8])(void) =
 	am1Group7a
 };
 
-UINT32 (*BAMTable1_G6[8])(void) =
+static UINT32 (*const BAMTable1_G6[8])(void) =
 {
 	bam1DisplacementIndexed8,
 	bam1DisplacementIndexed16,
@@ -1310,30 +1310,30 @@ UINT32 (*BAMTable1_G6[8])(void) =
 };
 
 
-UINT32 am1Group6(void)
+static UINT32 am1Group6(void)
 {
 	modVal2=OpRead8(modAdd+1);
 	return AMTable1_G6[modVal2>>5]();
 }
 
-UINT32 bam1Group6(void)
+static UINT32 bam1Group6(void)
 {
 	modVal2=OpRead8(modAdd+1);
 	return BAMTable1_G6[modVal2>>5]();
 }
 
 
-UINT32 am1Group7(void)
+static UINT32 am1Group7(void)
 {
 	return AMTable1_G7[modVal&0x1F]();
 }
 
-UINT32 bam1Group7(void)
+static UINT32 bam1Group7(void)
 {
 	return BAMTable1_G7[modVal&0x1F]();
 }
 
-UINT32 (*AMTable1[2][8])(void) =
+static UINT32 (*const AMTable1[2][8])(void) =
 {
 	{
 		am1Displacement8,
@@ -1359,7 +1359,7 @@ UINT32 (*AMTable1[2][8])(void) =
 };
 
 
-UINT32 (*BAMTable1[2][8])(void) =
+static UINT32 (*const BAMTable1[2][8])(void) =
 {
 	{
 		bam1Displacement8,
