@@ -3,15 +3,7 @@
 /* Main hacking and coding by Farfetch'd */
 /* Portability fixes by Richter Belmont */
 
-#include "driver.h"	/* needed for hack below. */
-#include "cpuintrf.h"
-#include "osd_cpu.h"
-#include "mamedbg.h"
-#include "state.h"
-
-#include <assert.h>
-#include <stdio.h>
-#include <stdarg.h>
+#include "debugger.h"
 #include "v60.h"
 
 /* memory accessors */
@@ -66,9 +58,6 @@
 #define SETREG8(a, b)  (a) = ((a) & ~0xff) | ((b) & 0xff)
 #define SETREG16(a, b) (a) = ((a) & ~0xffff) | ((b) & 0xffff)
 
-/* Ultra Function Tables */
-static UINT32 (*OpCodeTable[256])(void);
-
 typedef struct
 {
 	UINT8 CY;
@@ -78,12 +67,12 @@ typedef struct
 } Flags;
 
 /* v60 Register Inside (Hm... It's not a pentium inside :-))) ) */
-struct v60info {
+static struct v60info {
 	struct cpu_info info;
 	UINT32 reg[68];
 	Flags flags;
-	int irq_line;
-	int nmi_line;
+	UINT8 irq_line;
+	UINT8 nmi_line;
 	int (*irq_cb)(int irqline);
 	UINT32 PPC;
 } v60;
@@ -295,10 +284,10 @@ INLINE UINT32 v60_update_psw_for_exception(int is_interrupt, int target_level)
 #include "op6.c"
 #include "op7a.c"
 
-UINT32 opUNHANDLED(void)
+static UINT32 opUNHANDLED(void)
 {
-	osd_die("Unhandled OpCode found : %02x at %08x\n", OpRead16(PC), PC);
-	return 0; /* never reached, osd_die won't return */
+	fatalerror("Unhandled OpCode found : %02x at %08x", OpRead16(PC), PC);
+	return 0; /* never reached, fatalerror won't return */
 }
 
 /* Opcode jump table */
@@ -309,51 +298,41 @@ static int v60_default_irq_cb(int irqline)
 	return 0;
 }
 
-static void base_init(const char *type)
+static void base_init(const char *type, int index, int (*irqcallback)(int))
 {
-	int cpu = cpu_getactivecpu();
-	static int opt_init = 0;
-	if(!opt_init) {
-		InitTables();	/* set up opcode tables */
-#ifdef MAME_DEBUG
-		v60_dasm_init();
-#endif
-		opt_init = 1;
-	}
-
-	v60.irq_cb = v60_default_irq_cb;
+	v60.irq_cb = irqcallback;
 	v60.irq_line = CLEAR_LINE;
 	v60.nmi_line = CLEAR_LINE;
 
-	state_save_register_UINT32(type, cpu, "reg",       v60.reg, 68);
-	state_save_register_int   (type, cpu, "irq_line", &v60.irq_line);
-	state_save_register_int   (type, cpu, "nmi_line", &v60.nmi_line);
-	state_save_register_UINT32(type, cpu, "ppc",      &PPC, 1);
-	state_save_register_UINT8 (type, cpu, "f.cy",     &_CY, 1);
-	state_save_register_UINT8 (type, cpu, "f.ov",     &_OV, 1);
-	state_save_register_UINT8 (type, cpu, "f.f",      &_S, 1);
-	state_save_register_UINT8 (type, cpu, "f.z",      &_Z, 1);
+	state_save_register_item_array(type, index, v60.reg);
+	state_save_register_item(type, index, v60.irq_line);
+	state_save_register_item(type, index, v60.nmi_line);
+	state_save_register_item(type, index, PPC);
+	state_save_register_item(type, index, _CY);
+	state_save_register_item(type, index, _OV);
+	state_save_register_item(type, index, _S);
+	state_save_register_item(type, index, _Z);
 }
 
-void v60_init(void)
+static void v60_init(int index, int clock, const void *config, int (*irqcallback)(int))
 {
-	base_init("v60");
+	base_init("v60", index, irqcallback);
 	/* Set PIR (Processor ID) for NEC v60. LSB is reserved to NEC, */
 	/* so I don't know what it contains. */
 	PIR = 0x00006000;
 	v60.info = v60_i;
 }
 
-void v70_init(void)
+static void v70_init(int index, int clock, const void *config, int (*irqcallback)(int))
 {
-	base_init("v70");
+	base_init("v70", index, irqcallback);
 	/* Set PIR (Processor ID) for NEC v70. LSB is reserved to NEC, */
 	/* so I don't know what it contains. */
 	PIR = 0x00007000;
 	v60.info = v70_i;
 }
 
-void v60_reset(void *param)
+static void v60_reset(void)
 {
 	PSW		= 0x10000000;
 	PC		= v60.info.start_pc;
@@ -369,7 +348,7 @@ void v60_reset(void *param)
 	_Z	= 0;
 }
 
-void v60_exit(void)
+static void v60_exit(void)
 {
 }
 
@@ -590,9 +569,6 @@ static void v60_set_info(UINT32 state, union cpuinfo *info)
 		case CPUINFO_INT_REGISTER + V60_ADTR1:			ADTR1 = info->i;						break;
 		case CPUINFO_INT_REGISTER + V60_ADTMR0:			ADTMR0 = info->i;						break;
 		case CPUINFO_INT_REGISTER + V60_ADTMR1:			ADTMR1 = info->i;						break;
-
-		/* --- the following bits of info are set as pointers to data or functions --- */
-		case CPUINFO_PTR_IRQ_CALLBACK:					v60.irq_cb = info->irqcallback;			break;
 	}
 }
 
@@ -703,7 +679,6 @@ void v60_get_info(UINT32 state, union cpuinfo *info)
 		case CPUINFO_PTR_EXECUTE:						info->execute = v60_execute;			break;
 		case CPUINFO_PTR_BURN:							info->burn = NULL;						break;
 		case CPUINFO_PTR_DISASSEMBLE:					info->disassemble = v60_dasm;			break;
-		case CPUINFO_PTR_IRQ_CALLBACK:					info->irqcallback = v60.irq_cb;			break;
 		case CPUINFO_PTR_INSTRUCTION_COUNTER:			info->icount = &v60_ICount;				break;
 		case CPUINFO_PTR_REGISTER_LAYOUT:				info->p = v60_reg_layout;				break;
 		case CPUINFO_PTR_WINDOW_LAYOUT:					info->p = v60_win_layout;				break;
