@@ -69,7 +69,7 @@ INLINE void z180_mmu( void )
  * Read a byte from given memory location
  ***************************************************************/
 #define RM(addr)	program_read_byte_8(MMU_REMAP_ADDR(addr))
-data8_t cpu_readmemz180(offs_t offset)
+UINT8 z180_readmem(offs_t offset)
 {
 	return RM(offset);
 }
@@ -78,11 +78,12 @@ data8_t cpu_readmemz180(offs_t offset)
  * Write a byte to given memory location
  ***************************************************************/
 #define WM(addr,value) program_write_byte_8(MMU_REMAP_ADDR(addr),value)
-void cpu_writememz180(offs_t offset, data8_t data)
+void z180_writemem(offs_t offset, UINT8 data)
 {
 	WM(offset, data);
 }
 
+
 /***************************************************************
  * Read a word from given memory location
  ***************************************************************/
@@ -137,7 +138,7 @@ INLINE UINT32 ARG16(void)
  * Change program counter - MMU lookup
  ****************************************************************************/
 #define z180_change_pc(addr) change_pc(MMU_REMAP_ADDR(addr))
-void cpu_setOPbasez180(int pc)
+void z180_setOPbase(int pc)
 {
 	z180_change_pc(pc);
 }
@@ -317,8 +318,7 @@ void cpu_setOPbasez180(int pc)
 	if( _IFF1 == 0 && _IFF2 == 1 )								\
 	{															\
 		_IFF1 = 1;												\
-		if( Z180.irq_state[0] != CLEAR_LINE ||					\
-			Z180.request_irq >= 0 ) 							\
+		if( Z180.irq_state[0] != CLEAR_LINE )					\
 		{														\
 			LOG(("Z180 #%d RETN takes INT0\n",                  \
 				cpu_getactivecpu()));							\
@@ -344,17 +344,12 @@ void cpu_setOPbasez180(int pc)
  * RETI
  ***************************************************************/
 #define RETI	{												\
-	int device = Z180.service_irq;								\
 	POP(PC);													\
 	z180_change_pc(_PCD);										\
 /* according to http://www.msxnet.org/tech/Z80/z80undoc.txt */	\
 /*  _IFF1 = _IFF2;  */											\
-	if( device >= 0 )											\
-	{															\
-		LOG(("Z180 #%d RETI device %d: $%02x\n",                \
-			cpu_getactivecpu(), device, Z180.irq[device].irq_param)); \
-		Z180.irq[device].interrupt_reti(Z180.irq[device].irq_param); \
-	}															\
+	if (Z180.daisy)												\
+		z80daisy_call_reti_device(Z180.daisy);					\
 }
 
 /***************************************************************
@@ -1173,8 +1168,7 @@ INLINE UINT8 SET(UINT8 bit, UINT8 value)
 			_PC++;												\
 			_R++;												\
 		}														\
-		if( Z180.irq_state[0] != CLEAR_LINE ||					\
-			Z180.request_irq >= 0 ) 							\
+		if( Z180.irq_state[0] != CLEAR_LINE )					\
 		{														\
 			after_EI = 1;	/* avoid cycle skip hacks */		\
 			EXEC(op,ROP()); 									\
