@@ -4,18 +4,21 @@
 
     Core CPU interface functions and definitions.
 
+    Copyright (c) 1996-2006, Nicola Salmoria and the MAME Team.
+    Visit http://mamedev.org for licensing and usage restrictions.
+
 ***************************************************************************/
 
-#ifndef CPUINTRF_H
-#define CPUINTRF_H
+#pragma once
+
+#ifndef __CPUINTRF_H__
+#define __CPUINTRF_H__
 
-#include "osd_cpu.h"
 #include "memory.h"
-#include "timer.h"
+#include "cpuint.h"
+#include "cpuexec.h"
+#include "state.h"
 
-#ifdef __cplusplus
-extern "C" {
-#endif
 
 
 /*************************************
@@ -82,6 +85,7 @@ enum
 	CPU_M68010,
 	CPU_M68EC020,
 	CPU_M68020,
+	CPU_M68040,
 	CPU_T11,
 	CPU_S2650,
 	CPU_TMS34010,
@@ -101,6 +105,7 @@ enum
 	CPU_TMS32025,
 	CPU_TMS32026,
 	CPU_TMS32031,
+	CPU_TMS32051,
 	CPU_CCPU,
 	CPU_ADSP2100,
  	CPU_ADSP2101,
@@ -118,6 +123,8 @@ enum
 	CPU_R3000LE,
 	CPU_R4600BE,
 	CPU_R4600LE,
+	CPU_R4650BE,
+	CPU_R4650LE,
 	CPU_R4700BE,
 	CPU_R4700LE,
 	CPU_R5000BE,
@@ -152,16 +159,24 @@ enum
 	CPU_GMS30C2216,
 	CPU_GMS30C2232,
 	CPU_I386,
+	CPU_I486,
+	CPU_PENTIUM,
+	CPU_MEDIAGX,
 	CPU_I960,
 	CPU_H83002,
 	CPU_V810,
+	CPU_M37702,
 	CPU_M37710,
 	CPU_PPC403,
 	CPU_PPC602,
 	CPU_PPC603,
 	CPU_SE3208,
 	CPU_MC68HC11,
-
+	CPU_ADSP21062,
+	CPU_DSP56156,
+	CPU_RSP,
+	CPU_ALPHA8201,
+	CPU_ALPHA8301,
 #ifdef MESS
 	CPU_APEXC,
 	CPU_CDP1802,
@@ -176,7 +191,10 @@ enum
 	CPU_Z80GB,
 	CPU_TMS7000,
 	CPU_TMS7000_EXL,
-#endif
+	CPU_COP411,
+	CPU_SM8500,
+	CPU_V30MZ,
+#endif /* MESS */
     CPU_COUNT
 };
 
@@ -258,6 +276,10 @@ enum
 	CPUINFO_INT_ADDRBUS_WIDTH_LAST = CPUINFO_INT_ADDRBUS_WIDTH + ADDRESS_SPACES - 1,
 	CPUINFO_INT_ADDRBUS_SHIFT,							/* R/O: shift applied to addresses each address space (+3 means >>3, -1 means <<1) */
 	CPUINFO_INT_ADDRBUS_SHIFT_LAST = CPUINFO_INT_ADDRBUS_SHIFT + ADDRESS_SPACES - 1,
+	CPUINFO_INT_LOGADDR_WIDTH,							/* R/O: address bus size for logical accesses in each space (0=same as physical) */
+	CPUINFO_INT_LOGADDR_WIDTH_LAST = CPUINFO_INT_LOGADDR_WIDTH + ADDRESS_SPACES - 1,
+	CPUINFO_INT_PAGE_SHIFT,								/* R/O: size of a page log 2 (i.e., 12=4096), or 0 if paging not supported */
+	CPUINFO_INT_PAGE_SHIFT_LAST = CPUINFO_INT_PAGE_SHIFT + ADDRESS_SPACES - 1,
 
 	CPUINFO_INT_SP,										/* R/W: the current stack pointer value */
 	CPUINFO_INT_PC,										/* R/W: the current PC value */
@@ -277,13 +299,18 @@ enum
 	CPUINFO_PTR_SET_INFO = CPUINFO_PTR_FIRST,			/* R/O: void (*set_info)(UINT32 state, INT64 data, void *ptr) */
 	CPUINFO_PTR_GET_CONTEXT,							/* R/O: void (*get_context)(void *buffer) */
 	CPUINFO_PTR_SET_CONTEXT,							/* R/O: void (*set_context)(void *buffer) */
-	CPUINFO_PTR_INIT,									/* R/O: void (*init)(void) */
-	CPUINFO_PTR_RESET,									/* R/O: void (*reset)(void *param) */
+	CPUINFO_PTR_INIT,									/* R/O: void (*init)(int index, int clock, const void *config, int (*irqcallback)(int)) */
+	CPUINFO_PTR_RESET,									/* R/O: void (*reset)(void) */
 	CPUINFO_PTR_EXIT,									/* R/O: void (*exit)(void) */
 	CPUINFO_PTR_EXECUTE,								/* R/O: int (*execute)(int cycles) */
 	CPUINFO_PTR_BURN,									/* R/O: void (*burn)(int cycles) */
-	CPUINFO_PTR_DISASSEMBLE,							/* R/O: void (*disassemble)(char *buffer, offs_t pc) */
-	CPUINFO_PTR_IRQ_CALLBACK,							/* R/W: int (*irqcallback)(int state) */
+	CPUINFO_PTR_DISASSEMBLE,							/* R/O: offs_t (*disassemble)(char *buffer, offs_t pc) */
+	CPUINFO_PTR_DISASSEMBLE_NEW,						/* R/O: offs_t (*disassemble_new)(char *buffer, offs_t pc, UINT8 *oprom, UINT8 *opram, int bytes) */
+	CPUINFO_PTR_TRANSLATE,								/* R/O: int (*translate)(int space, offs_t *address) */
+	CPUINFO_PTR_READ,									/* R/O: int (*read)(int space, UINT32 offset, int size, UINT64 *value) */
+	CPUINFO_PTR_WRITE,									/* R/O: int (*write)(int space, UINT32 offset, int size, UINT64 value) */
+	CPUINFO_PTR_READOP,									/* R/O: int (*readop)(UINT32 offset, int size, UINT64 *value) */
+	CPUINFO_PTR_DEBUG_SETUP_COMMANDS,					/* R/O: void (*setup_commands)(void) */
 	CPUINFO_PTR_INSTRUCTION_COUNTER,					/* R/O: int *icount */
 	CPUINFO_PTR_REGISTER_LAYOUT,						/* R/O: struct debug_register_layout *layout */
 	CPUINFO_PTR_WINDOW_LAYOUT,							/* R/O: struct debug_window_layout *layout */
@@ -319,13 +346,18 @@ union cpuinfo
 	void	(*setinfo)(UINT32 state, union cpuinfo *info);/* CPUINFO_PTR_SET_INFO */
 	void	(*getcontext)(void *context);				/* CPUINFO_PTR_GET_CONTEXT */
 	void	(*setcontext)(void *context);				/* CPUINFO_PTR_SET_CONTEXT */
-	void	(*init)(void);								/* CPUINFO_PTR_INIT */
-	void	(*reset)(void *param);						/* CPUINFO_PTR_RESET */
+	void	(*init)(int index, int clock, const void *config, int (*irqcallback)(int));/* CPUINFO_PTR_INIT */
+	void	(*reset)(void);								/* CPUINFO_PTR_RESET */
 	void	(*exit)(void);								/* CPUINFO_PTR_EXIT */
 	int		(*execute)(int cycles);						/* CPUINFO_PTR_EXECUTE */
 	void	(*burn)(int cycles);						/* CPUINFO_PTR_BURN */
 	offs_t	(*disassemble)(char *buffer, offs_t pc);	/* CPUINFO_PTR_DISASSEMBLE */
-	int		(*irqcallback)(int state);					/* CPUINFO_PTR_IRQCALLBACK */
+	offs_t	(*disassemble_new)(char *buffer, offs_t pc, UINT8 *oprom, UINT8 *opram, int bytes);/* CPUINFO_PTR_DISASSEMBLE_NEW */
+	int 	(*translate)(int space, offs_t *address);	/* CPUINFO_PTR_TRANSLATE */
+	int		(*read)(int space, UINT32 offset, int size, UINT64 *value);/* CPUINFO_PTR_READ */
+	int		(*write)(int space, UINT32 offset, int size, UINT64 value);/* CPUINFO_PTR_WRITE */
+	int		(*readop)(UINT32 offset, int size, UINT64 *value);/* CPUINFO_PTR_READOP */
+	void	(*setup_commands)(void);					/* CPUINFO_PTR_DEBUG_SETUP_COMMANDS */
 	int *	icount;										/* CPUINFO_PTR_INSTRUCTION_COUNTER */
 	construct_map_t internal_map;						/* CPUINFO_PTR_INTERNAL_MEMORY_MAP */
 };
@@ -374,25 +406,28 @@ enum
  *
  *************************************/
 
-struct cpu_interface
+struct _cpu_interface
 {
 	/* table of core functions */
 	void		(*get_info)(UINT32 state, union cpuinfo *info);
 	void		(*set_info)(UINT32 state, union cpuinfo *info);
 	void		(*get_context)(void *buffer);
 	void		(*set_context)(void *buffer);
-	void		(*init)(void);
-	void		(*reset)(void *param);
+	void		(*init)(int index, int clock, const void *config, int (*irqcallback)(int));
+	void		(*reset)(void);
 	void		(*exit)(void);
 	int			(*execute)(int cycles);
 	void		(*burn)(int cycles);
 	offs_t		(*disassemble)(char *buffer, offs_t pc);
+	offs_t		(*disassemble_new)(char *buffer, offs_t pc, UINT8 *oprom, UINT8 *opram, int bytes);
+	int			(*translate)(int space, offs_t *address);
 
 	/* other info */
 	size_t		context_size;
-	int			address_shift;
+	INT8		address_shift;
 	int *		icount;
 };
+typedef struct _cpu_interface cpu_interface;
 
 
 
@@ -403,10 +438,10 @@ struct cpu_interface
  *************************************/
 
 /* reset the internal CPU tracking */
-int cpuintrf_init(void);
+void cpuintrf_init(void);
 
 /* set up the interface for one CPU of a given type */
-int	cpuintrf_init_cpu(int cpunum, int cputype);
+int	cpuintrf_init_cpu(int cpunum, int cputype, int clock, const void *config, int (*irqcallback)(int));
 
 /* clean up the interface for one CPU */
 void cpuintrf_exit_cpu(int cpunum);
@@ -455,16 +490,14 @@ void activecpu_reset_banking(void);
 void activecpu_set_input_line(int irqline, int state);
 
 /* return the PC, corrected to a byte offset, on the active CPU */
-offs_t activecpu_get_pc_byte(void);
+offs_t activecpu_get_physical_pc_byte(void);
 
 /* update the banking on the active CPU */
 void activecpu_set_opbase(offs_t val);
 
 /* disassemble a line at a given PC on the active CPU */
 offs_t activecpu_dasm(char *buffer, offs_t pc);
-
-/* return a string containing the state of the flags on the active CPU */
-const char *activecpu_flags(void);
+offs_t activecpu_dasm_new(char *buffer, offs_t pc, UINT8 *oprom, UINT8 *opram, int bytes);
 
 /* return a string containing the state of the active CPU */
 const char *activecpu_dump_state(void);
@@ -482,8 +515,9 @@ const char *activecpu_dump_state(void);
 #define activecpu_databus_width(space)			activecpu_get_info_int(CPUINFO_INT_DATABUS_WIDTH + (space))
 #define activecpu_addrbus_width(space)			activecpu_get_info_int(CPUINFO_INT_ADDRBUS_WIDTH + (space))
 #define activecpu_addrbus_shift(space)			activecpu_get_info_int(CPUINFO_INT_ADDRBUS_SHIFT + (space))
+#define activecpu_logaddr_width(space)			activecpu_get_info_int(CPUINFO_INT_LOGADDR_WIDTH + (space))
+#define activecpu_page_shift(space)				activecpu_get_info_int(CPUINFO_INT_PAGE_SHIFT + (space))
 #define activecpu_get_reg(reg)					activecpu_get_info_int(CPUINFO_INT_REGISTER + (reg))
-#define activecpu_irq_callback()				activecpu_get_info_fct(CPUINFO_PTR_IRQ_CALLBACK)
 #define activecpu_register_layout()				activecpu_get_info_ptr(CPUINFO_PTR_REGISTER_LAYOUT)
 #define activecpu_window_layout()				activecpu_get_info_ptr(CPUINFO_PTR_WINDOW_LAYOUT)
 #define activecpu_debug_register_list()			activecpu_get_info_ptr(CPUINFO_PTR_DEBUG_REGISTER_LIST)
@@ -497,7 +531,6 @@ const char *activecpu_dump_state(void);
 #define activecpu_reg_string(reg)				activecpu_get_info_string(CPUINFO_STR_REGISTER + (reg))
 
 #define activecpu_set_reg(reg, val)				activecpu_set_info_int(CPUINFO_INT_REGISTER + (reg), (val))
-#define activecpu_set_irq_callback(val)			activecpu_set_info_fct(CPUINFO_PTR_IRQ_CALLBACK, (genf *) (val))
 
 
 
@@ -521,27 +554,28 @@ void cpunum_set_info_fct(int cpunum, UINT32 state, genf *data);
 /* execute the requested cycles on a given CPU */
 int cpunum_execute(int cpunum, int cycles);
 
-/* signal a reset and set the IRQ ack callback for a given CPU */
-void cpunum_reset(int cpunum, void *param, int (*irqack)(int));
+/* signal a reset for a given CPU */
+void cpunum_reset(int cpunum);
 
 /* read a byte from another CPU's memory space */
-data8_t cpunum_read_byte(int cpunum, offs_t address);
+UINT8 cpunum_read_byte(int cpunum, offs_t address);
 
 /* write a byte from another CPU's memory space */
-void cpunum_write_byte(int cpunum, offs_t address, data8_t data);
+void cpunum_write_byte(int cpunum, offs_t address, UINT8 data);
 
 /* return a pointer to the saved context of a given CPU, or NULL if the
    context is active (and contained within the CPU core */
 void *cpunum_get_context_ptr(int cpunum);
 
 /* return the PC, corrected to a byte offset, on a given CPU */
-offs_t cpunum_get_pc_byte(int cpunum);
+offs_t cpunum_get_physical_pc_byte(int cpunum);
 
 /* update the banking on a given CPU */
 void cpunum_set_opbase(int cpunum, offs_t val);
 
 /* disassemble a line at a given PC on a given CPU */
 offs_t cpunum_dasm(int cpunum, char *buffer, offs_t pc);
+offs_t cpunum_dasm_new(int cpunum, char *buffer, offs_t pc, UINT8 *oprom, UINT8 *opram, int bytes);
 
 /* return a string containing the state of a given CPU */
 const char *cpunum_dump_state(int cpunum);
@@ -559,8 +593,9 @@ const char *cpunum_dump_state(int cpunum);
 #define cpunum_databus_width(cpunum, space)		cpunum_get_info_int(cpunum, CPUINFO_INT_DATABUS_WIDTH + (space))
 #define cpunum_addrbus_width(cpunum, space)		cpunum_get_info_int(cpunum, CPUINFO_INT_ADDRBUS_WIDTH + (space))
 #define cpunum_addrbus_shift(cpunum, space)		cpunum_get_info_int(cpunum, CPUINFO_INT_ADDRBUS_SHIFT + (space))
+#define cpunum_logaddr_width(cpunum, space)		cpunum_get_info_int(cpunum, CPUINFO_INT_LOGADDR_WIDTH + (space))
+#define cpunum_page_shift(cpunum, space)		cpunum_get_info_int(cpunum, CPUINFO_INT_PAGE_SHIFT + (space))
 #define cpunum_get_reg(cpunum, reg)				cpunum_get_info_int(cpunum, CPUINFO_INT_REGISTER + (reg))
-#define cpunum_irq_callback(cpunum)				cpunum_get_info_fct(cpunum, CPUINFO_PTR_IRQ_CALLBACK)
 #define cpunum_register_layout(cpunum)			cpunum_get_info_ptr(cpunum, CPUINFO_PTR_REGISTER_LAYOUT)
 #define cpunum_window_layout(cpunum)			cpunum_get_info_ptr(cpunum, CPUINFO_PTR_WINDOW_LAYOUT)
 #define cpunum_debug_register_list(cpunum)		cpunum_get_info_ptr(cpunum, CPUINFO_PTR_DEBUG_REGISTER_LIST)
@@ -574,7 +609,6 @@ const char *cpunum_dump_state(int cpunum);
 #define cpunum_reg_string(cpunum, reg)			cpunum_get_info_string(cpunum, CPUINFO_STR_REGISTER + (reg))
 
 #define cpunum_set_reg(cpunum, reg, val)		cpunum_set_info_int(cpunum, CPUINFO_INT_REGISTER + (reg), (val))
-#define cpunum_set_irq_callback(cpunum, val)	cpunum_set_info_fct(cpunum, CPUINFO_PTR_IRQ_CALLBACK, (val)
 
 
 
@@ -603,7 +637,7 @@ const char *cputype_get_info_string(int cputype, UINT32 state);
 #define cputype_databus_width(cputype, space)	cputype_get_info_int(cputype, CPUINFO_INT_DATABUS_WIDTH + (space))
 #define cputype_addrbus_width(cputype, space)	cputype_get_info_int(cputype, CPUINFO_INT_ADDRBUS_WIDTH + (space))
 #define cputype_addrbus_shift(cputype, space)	cputype_get_info_int(cputype, CPUINFO_INT_ADDRBUS_SHIFT + (space))
-#define cputype_irq_callback(cputype)			cputype_get_info_fct(cputype, CPUINFO_PTR_IRQ_CALLBACK)
+#define cputype_page_shift(cputype, space)		cputype_get_info_int(cputype, CPUINFO_INT_PAGE_SHIFT + (space))
 #define cputype_register_layout(cputype)		cputype_get_info_ptr(cputype, CPUINFO_PTR_REGISTER_LAYOUT)
 #define cputype_window_layout(cputype)			cputype_get_info_ptr(cputype, CPUINFO_PTR_WINDOW_LAYOUT)
 #define cputype_debug_register_list(cputype)	cputype_get_info_ptr(cputype, CPUINFO_PTR_DEBUG_REGISTER_LIST)
@@ -625,6 +659,7 @@ const char *cputype_get_info_string(int cputype, UINT32 state);
 void cpu_dump_states(void);
 
 
+
 /*************************************
  *
  *   Macros
@@ -644,9 +679,9 @@ void cpu_dump_states(void);
  *************************************/
 
 /* return a pointer to the interface struct for a given CPU type */
-INLINE const struct cpu_interface *cputype_get_interface(int cputype)
+INLINE const cpu_interface *cputype_get_interface(int cputype)
 {
-	extern struct cpu_interface cpuintrf[];
+	extern cpu_interface cpuintrf[];
 	return &cpuintrf[cputype];
 }
 
@@ -675,10 +710,11 @@ INLINE int cpu_gettotalcpu(void)
 }
 
 
-
-#ifdef __cplusplus
+/* return the current PC or ~0 if no CPU is active */
+INLINE offs_t safe_activecpu_get_pc(void)
+{
+	return (cpu_getactivecpu() >= 0) ? activecpu_get_pc() : ~0;
 }
-#endif
 
-#endif	/* CPUINTRF_H */
 
+#endif	/* __CPUINTRF_H__ */
