@@ -1,25 +1,27 @@
 /****************************************************************************
- *  window.c
- *  Text mode window engine
- *
- *  Written by Neil Bradley (neil@synthcom.com)
- *  Heavily modified by Juergen Buchmueller (pullmoll@t-online.de)
- *
- *  Designed to fit the needs of the new MAME debugger (a bit more ;)
- *
- *  Warning: This code is still buggy!
- *  Some of the changes I made were contrary to the original design,
- *  so expect 'assertions' for every non common case (ie. window too
- *  big, hanging out of the screen etc.)
- ****************************************************************************/
-#include <stdio.h>
+
+    window.c
+
+    Text mode window engine
+
+    Copyright (c) 1996-2006, Nicola Salmoria and the MAME Team.
+    Visit http://mamedev.org for licensing and usage restrictions.
+
+    Written by Neil Bradley (neil@synthcom.com)
+    Heavily modified by Juergen Buchmueller (pullmoll@t-online.de)
+
+    Designed to fit the needs of the new MAME debugger (a bit more ;)
+
+    Warning: This code is still buggy!
+    Some of the changes I made were contrary to the original design,
+    so expect 'assertions' for every non common case (ie. window too
+    big, hanging out of the screen etc.)
+
+****************************************************************************/
 
 #ifdef MAME_DEBUG
 
-#include <stdlib.h>
-#include <string.h>
 #include <stdarg.h>
-#include <assert.h>
 #include "window.h"
 
 /*
