@@ -219,7 +219,6 @@ Notes - Has jumper setting for 122HZ or 61HZ)
 #include <math.h>
 #include "driver.h"
 #include "cpu/z80/z80.h"
-#include "vidhrdw/generic.h"
 #include "sound/ay8910.h"
 #include "sound/dac.h"
 #include "sound/msm5232.h"
@@ -309,19 +308,16 @@ static WRITE8_HANDLER( fortyl_mcu_w )
 	buggychl_mcu_w(offset,data);
 }
 
-static int banknum = -1;
-
 static WRITE8_HANDLER( bank_select_w )
 {
 
 	if ((data!=0x02) && (data!=0xfd))
 	{
 /*      logerror("WRONG BANK SELECT = %x !!!!\n",data); */
-/*      usrintf_showmessage("WRONG BANK SELECT = %x !!!!\n",data); */
+/*      ui_popup("WRONG BANK SELECT = %x !!!!\n",data); */
 	}
 
-	banknum = data&1;
-	cpu_setbank( 1, memory_region(REGION_CPU1) + (banknum * 0x2000) + 0x10000 );
+	memory_set_bank( 1, data&1 );
 }
 
 
@@ -435,7 +431,7 @@ static const UINT8 mcu_data2[0x80] =
 
 static WRITE8_HANDLER( undoukai_mcu_w )
 {
-	data8_t *RAM = memory_region(REGION_CPU1);
+	UINT8 *RAM = memory_region(REGION_CPU1);
 	UINT16 ram_adr = RAM[0xa1b5]*0x100 + RAM[0xa1b4];
 
 	int d;
@@ -557,7 +553,7 @@ static WRITE8_HANDLER( undoukai_mcu_w )
 						case 0x06: mcu_out[0][0] = 0x14; break;
 						case 0x07: mcu_out[0][0] = 0xb6; break;
 						default:
-						/*  usrintf_showmessage("cmd06: %02x %02x",mcu_in[0][0],mcu_in[0][1]); */
+						/*  ui_popup("cmd06: %02x %02x",mcu_in[0][0],mcu_in[0][1]); */
 							logerror("cmd06: %02x %02x\n",mcu_in[0][0],mcu_in[0][1]);
 					}
 				break;
@@ -586,7 +582,7 @@ static WRITE8_HANDLER( undoukai_mcu_w )
 			default:
 				from_mcu = 0x5d;
 
-/*              usrintf_showmessage("unknown cmd%02x: %02x %02x %02x %02x",data,mcu_in[0][0],mcu_in[0][1],mcu_in[0][2],mcu_in[0][3]); */
+/*              ui_popup("unknown cmd%02x: %02x %02x %02x %02x",data,mcu_in[0][0],mcu_in[0][1],mcu_in[0][2],mcu_in[0][3]); */
 /*              logerror("unknown cmd%02x: %02x %02x %02x %02x\n",data,mcu_in[0][0],mcu_in[0][1],mcu_in[0][2],mcu_in[0][3]); */
 		}
 	}
@@ -611,6 +607,9 @@ static READ8_HANDLER( undoukai_mcu_status_r )
 
 static DRIVER_INIT( undoukai )
 {
+	UINT8 *ROM = memory_region(REGION_CPU1);
+	memory_configure_bank(1, 0, 2, &ROM[0x10000], 0x2000);
+
 	from_mcu = 0xff;
 	mcu_cmd = -1;
 
@@ -622,11 +621,14 @@ static DRIVER_INIT( undoukai )
 
 static DRIVER_INIT( 40love )
 {
+	UINT8 *ROM = memory_region(REGION_CPU1);
+	memory_configure_bank(1, 0, 2, &ROM[0x10000], 0x2000);
+
 	#if 0
 		/* character ROM hack
             to show a white line on the opponent side */
 
-		data8_t *ROM = memory_region(REGION_GFX2);
+		UINT8 *ROM = memory_region(REGION_GFX2);
 		int adr = 0x10 * 0x022b;
 		ROM[adr+0x000a] = 0x00;
 		ROM[adr+0x000b] = 0x00;
@@ -791,7 +793,7 @@ ADDRESS_MAP_END
 
 static int vol_ctrl[16];
 
-static MACHINE_INIT( ta7630 )
+static MACHINE_RESET( ta7630 )
 {
 	int i;
 
@@ -823,7 +825,7 @@ static UINT8 snd_ctrl3=0;
 static WRITE8_HANDLER( sound_control_0_w )
 {
 	snd_ctrl0 = data & 0xff;
-/*  usrintf_showmessage("SND0 0=%02x 1=%02x 2=%02x 3=%02x", snd_ctrl0, snd_ctrl1, snd_ctrl2, snd_ctrl3); */
+/*  ui_popup("SND0 0=%02x 1=%02x 2=%02x 3=%02x", snd_ctrl0, snd_ctrl1, snd_ctrl2, snd_ctrl3); */
 
 	/* this definitely controls main melody voice on 2'-1 and 4'-1 outputs */
 	sndti_set_output_gain(SOUND_MSM5232, 0, 0, vol_ctrl[ (snd_ctrl0>>4) & 15 ] / 100.0);	/* group1 from msm5232 */
@@ -832,7 +834,7 @@ static WRITE8_HANDLER( sound_control_0_w )
 static WRITE8_HANDLER( sound_control_1_w )
 {
 	snd_ctrl1 = data & 0xff;
-/*  usrintf_showmessage("SND1 0=%02x 1=%02x 2=%02x 3=%02x", snd_ctrl0, snd_ctrl1, snd_ctrl2, snd_ctrl3); */
+/*  ui_popup("SND1 0=%02x 1=%02x 2=%02x 3=%02x", snd_ctrl0, snd_ctrl1, snd_ctrl2, snd_ctrl3); */
 	sndti_set_output_gain(SOUND_MSM5232, 0, 1, vol_ctrl[ (snd_ctrl1>>4) & 15 ] / 100.0);	/* group2 from msm5232 */
 }
 
@@ -841,7 +843,7 @@ static WRITE8_HANDLER( sound_control_2_w )
 	int i;
 
 	snd_ctrl2 = data & 0xff;
-/*  usrintf_showmessage("SND2 0=%02x 1=%02x 2=%02x 3=%02x", snd_ctrl0, snd_ctrl1, snd_ctrl2, snd_ctrl3); */
+/*  ui_popup("SND2 0=%02x 1=%02x 2=%02x 3=%02x", snd_ctrl0, snd_ctrl1, snd_ctrl2, snd_ctrl3); */
 
 	for (i=0; i<3; i++)
 		sndti_set_output_gain(SOUND_AY8910, 0, i, vol_ctrl[ (snd_ctrl2>>4) & 15 ] / 100.0);	/* ym2149f all */
@@ -850,7 +852,7 @@ static WRITE8_HANDLER( sound_control_2_w )
 static WRITE8_HANDLER( sound_control_3_w ) /* unknown */
 {
 	snd_ctrl3 = data & 0xff;
-/*  usrintf_showmessage("SND3 0=%02x 1=%02x 2=%02x 3=%02x", snd_ctrl0, snd_ctrl1, snd_ctrl2, snd_ctrl3); */
+/*  ui_popup("SND3 0=%02x 1=%02x 2=%02x 3=%02x", snd_ctrl0, snd_ctrl1, snd_ctrl2, snd_ctrl3); */
 }
 
 static ADDRESS_MAP_START( writemem_sound, ADDRESS_SPACE_PROGRAM, 8 )
@@ -1124,7 +1126,7 @@ INPUT_PORTS_START( undoukai )
 INPUT_PORTS_END
 
 
-static struct GfxLayout char_layout =
+static const gfx_layout char_layout =
 {
 	8,8,
 	0x400,
@@ -1135,7 +1137,7 @@ static struct GfxLayout char_layout =
 	16*8
 };
 
-static struct GfxLayout sprite_layout =
+static const gfx_layout sprite_layout =
 {
 	16,16,
 	RGN_FRAC(1,2),
@@ -1151,7 +1153,7 @@ static struct GfxLayout sprite_layout =
 };
 
 
-static struct GfxDecodeInfo gfxdecodeinfo[] =
+static const gfx_decode gfxdecodeinfo[] =
 {
 	{ REGION_GFX2, 0, &char_layout, 0, 64 },
 	{ REGION_GFX1, 0, &sprite_layout, 0, 64 },
@@ -1191,7 +1193,7 @@ static MACHINE_DRIVER_START( 40love )
 	MDRV_FRAMES_PER_SECOND(60)
 	MDRV_VBLANK_DURATION(DEFAULT_REAL_60HZ_VBLANK_DURATION)
 	MDRV_INTERLEAVE(100)	/* high interleave to ensure proper synchronization of CPUs */
-	MDRV_MACHINE_INIT(ta7630)	/* init machine */
+	MDRV_MACHINE_RESET(ta7630)	/* init machine */
 
 	/* video hardware */
 	MDRV_VIDEO_ATTRIBUTES(VIDEO_TYPE_RASTER)
@@ -1236,7 +1238,7 @@ static MACHINE_DRIVER_START( undoukai )
 
 	MDRV_FRAMES_PER_SECOND(60)
 	MDRV_VBLANK_DURATION(DEFAULT_REAL_60HZ_VBLANK_DURATION)
-	MDRV_MACHINE_INIT(ta7630)	/* init machine */
+	MDRV_MACHINE_RESET(ta7630)	/* init machine */
 
 	/* video hardware */
 	MDRV_VIDEO_ATTRIBUTES(VIDEO_TYPE_RASTER)
@@ -1380,6 +1382,6 @@ ROM_START( undoukai )
 	ROM_LOAD( "a17-18.23v", 0x0c00, 0x0400, CRC(3023a1da) SHA1(08ce4c6e99d04b358d66f0588852311d07183619) )	/* ??? */
 ROM_END
 
-GAMEX( 1984, 40love,   0,        40love,   40love,   40love,   ROT0, "Taito Corporation", "Forty-Love", GAME_IMPERFECT_GRAPHICS )
-GAME ( 1984, fieldday, 0,        undoukai, undoukai, undoukai, ROT0, "Taito Corporation", "Field Day" )
-GAME ( 1984, undoukai, fieldday, undoukai, undoukai, undoukai, ROT0, "Taito Corporation", "The Undoukai (Japan)" )
+GAME( 1984, 40love,   0,        40love,   40love,   40love,   ROT0, "Taito Corporation", "Forty-Love", GAME_IMPERFECT_GRAPHICS )
+GAME( 1984, fieldday, 0,        undoukai, undoukai, undoukai, ROT0, "Taito Corporation", "Field Day", 0 )
+GAME( 1984, undoukai, fieldday, undoukai, undoukai, undoukai, ROT0, "Taito Corporation", "The Undoukai (Japan)", 0 )
