@@ -53,12 +53,11 @@ JALCF1   BIN     1,048,576  02-07-99  1:11a JALCF1.BIN
 *******************************************************************************************/
 
 #include "driver.h"
-#include "vidhrdw/generic.h"
 #include "sound/okim6295.h"
 
 static tilemap *tx_tilemap,*bg_tilemap;
-UINT16 *ac_txvram,*ac_bgvram;
-UINT16 *ac_vregs;
+static UINT16 *ac_txvram,*ac_bgvram;
+static UINT16 *ac_vregs;
 
 static UINT32 bg_scan(UINT32 col,UINT32 row,UINT32 num_cols,UINT32 num_rows)
 {
@@ -156,9 +155,6 @@ VIDEO_START( acommand )
 
 	ac_vregs = auto_malloc(0x80);
 
-	if(!ac_vregs)
-		return 1;
-
 	tilemap_set_transparent_pen(tx_tilemap,15);
 
 	return 0;
@@ -281,7 +277,7 @@ static WRITE16_HANDLER(ac_txscroll_w)
 
 /******************************************************************************************/
 
-UINT16 *ac_devram;
+static UINT16 *ac_devram;
 
 
 static READ16_HANDLER(ac_devices_r)
@@ -497,7 +493,7 @@ INPUT_PORTS_START( acommand )
 	PORT_DIPSETTING(      0x0000, DEF_STR( On ) )
 INPUT_PORTS_END
 
-static gfx_layout charlayout =
+static const gfx_layout charlayout =
 {
 	8,8,
 	RGN_FRAC(1,1),
@@ -508,7 +504,7 @@ static gfx_layout charlayout =
 	32*8
 };
 
-static gfx_layout tilelayout =
+static const gfx_layout tilelayout =
 {
 	16,16,
 	RGN_FRAC(1,1),
@@ -521,7 +517,7 @@ static gfx_layout tilelayout =
 	32*32
 };
 
-static gfx_decode acommand_gfxdecodeinfo[] =
+static const gfx_decode acommand_gfxdecodeinfo[] =
 {
 	{ REGION_GFX1, 0, &charlayout, 0x2700, 16 }, /*???*/
 	{ REGION_GFX2, 0, &tilelayout, 0x1800, 256 },
