@@ -22,7 +22,6 @@ Revisions:
 ****************************************************************************/
 
 #include "driver.h"
-#include "vidhrdw/generic.h"
 #include "sound/ay8910.h"
 
 
@@ -46,7 +45,7 @@ static READ8_HANDLER( aeroboto_201_r )
 {
 	/* if you keep a button pressed during boot, the game will expect this */
 	/* serie of values to be returned from 3004, and display "PASS 201" if it is */
-	int res[4] = { 0xff,0x9f,0x1b,0x03};
+	static const UINT8 res[4] = { 0xff,0x9f,0x1b,0x03};
 	static int count;
 	logerror("PC %04x: read 3004\n",activecpu_get_pc());
 	return res[(count++)&3];
@@ -202,7 +201,7 @@ INPUT_PORTS_END
 
 
 
-static gfx_layout charlayout =
+static const gfx_layout charlayout =
 {
 	8,8,
 	RGN_FRAC(1,2),
@@ -214,7 +213,7 @@ static gfx_layout charlayout =
 };
 /*
 // exact star layout unknown... could be anything
-static gfx_layout starlayout =
+static const gfx_layout starlayout =
 {
     8,8,
     RGN_FRAC(1,1),
@@ -225,7 +224,7 @@ static gfx_layout starlayout =
     8*8
 };
 */
-static gfx_layout spritelayout =
+static const gfx_layout spritelayout =
 {
 	8,16,
 	RGN_FRAC(1,3),
@@ -237,7 +236,7 @@ static gfx_layout spritelayout =
 	16*8
 };
 
-static gfx_decode gfxdecodeinfo[] =
+static const gfx_decode gfxdecodeinfo[] =
 {
 	{ REGION_GFX1, 0, &charlayout,     0,  64 },     /* chars */
 /*  { REGION_GFX2, 0, &starlayout,     0, 128 },        sky    */
