@@ -8,14 +8,13 @@ Preliminary driver by:
 ***************************************************************************/
 
 #include "driver.h"
-#include "vidhrdw/generic.h"
 #include "cpu/konami/konami.h" /* for the callback and the firq irq definition */
 #include "vidhrdw/konamiic.h"
 #include "sound/k007232.h"
 #include "sound/2151intf.h"
 
 /* prototypes */
-static MACHINE_INIT( aliens );
+static MACHINE_RESET( aliens );
 static void aliens_banking( int lines );
 
 
@@ -44,7 +43,7 @@ static READ8_HANDLER( bankedram_r )
 static WRITE8_HANDLER( bankedram_w )
 {
 	if (palette_selected)
-		paletteram_xBBBBBGGGGGRRRRR_swap_w(offset,data);
+		paletteram_xBBBBBGGGGGRRRRR_be_w(offset,data);
 	else
 		ram[offset] = data;
 }
@@ -272,7 +271,7 @@ static MACHINE_DRIVER_START( aliens )
 	MDRV_FRAMES_PER_SECOND(60)
 	MDRV_VBLANK_DURATION(DEFAULT_60HZ_VBLANK_DURATION)
 
-	MDRV_MACHINE_INIT(aliens)
+	MDRV_MACHINE_RESET(aliens)
 
 	/* video hardware */
 	MDRV_VIDEO_ATTRIBUTES(VIDEO_TYPE_RASTER | VIDEO_HAS_SHADOWS)
@@ -514,7 +513,7 @@ static void aliens_banking( int lines )
 	memory_set_bankptr( 1, &RAM[offs] );
 }
 
-static MACHINE_INIT( aliens )
+static MACHINE_RESET( aliens )
 {
 	unsigned char *RAM = memory_region(REGION_CPU1);
 
