@@ -84,7 +84,6 @@ Known issues :
 
 
 #include "driver.h"
-#include "vidhrdw/generic.h"
 #include "sound/2203intf.h"
 
 
@@ -633,7 +632,7 @@ INPUT_PORTS_END
 
 ***************************************************************************/
 
-static gfx_layout charlayout =
+static const gfx_layout charlayout =
 {
 	8,8,    /* 8x8 characters */
 	1024,	/* 1024 characters */
@@ -644,7 +643,7 @@ static gfx_layout charlayout =
 	32*8
 };
 
-static gfx_layout tilelayout_256 =
+static const gfx_layout tilelayout_256 =
 {
 	16,16,  /* 16x16 characters */
 	256,	/* 256 characters */
@@ -657,7 +656,7 @@ static gfx_layout tilelayout_256 =
 	128*8
 };
 
-static gfx_layout tilelayout_512 =
+static const gfx_layout tilelayout_512 =
 {
 	16,16,  /* 16x16 characters */
 	512,	/* 512 characters */
@@ -670,7 +669,7 @@ static gfx_layout tilelayout_512 =
 	128*8
 };
 
-static gfx_layout tilelayout_1024 =
+static const gfx_layout tilelayout_1024 =
 {
 	16,16,  /* 16x16 characters */
 	1024,	/* 1024 characters */
@@ -683,7 +682,7 @@ static gfx_layout tilelayout_1024 =
 	128*8
 };
 
-static gfx_layout tilelayout_2048 =
+static const gfx_layout tilelayout_2048 =
 {
 	16,16,  /* 16x16 characters */
 	2048,	/* 2048 characters */
@@ -696,7 +695,7 @@ static gfx_layout tilelayout_2048 =
 	128*8
 };
 
-static gfx_layout tilelayout_4096 =
+static const gfx_layout tilelayout_4096 =
 {
 	16,16,  /* 16x16 characters */
 	4096,	/* 4096 characters */
@@ -709,7 +708,7 @@ static gfx_layout tilelayout_4096 =
 	128*8
 };
 
-static gfx_decode argus_gfxdecodeinfo[] =
+static const gfx_decode argus_gfxdecodeinfo[] =
 {
 	{ REGION_GFX1, 0, &tilelayout_1024, 0*16,   8 },
 	{ REGION_GFX2, 0, &tilelayout_1024, 8*16,  16 },
@@ -718,7 +717,7 @@ static gfx_decode argus_gfxdecodeinfo[] =
 	{ -1 } /* end of array */
 };
 
-static gfx_decode valtric_gfxdecodeinfo[] =
+static const gfx_decode valtric_gfxdecodeinfo[] =
 {
 	{ REGION_GFX1, 0, &tilelayout_1024, 0*16, 16 },
 	{ REGION_GFX2, 0, &tilelayout_2048, 16*16, 16 },
@@ -726,7 +725,7 @@ static gfx_decode valtric_gfxdecodeinfo[] =
 	{ -1 } /* end of array */
 };
 
-static gfx_decode butasan_gfxdecodeinfo[] =
+static const gfx_decode butasan_gfxdecodeinfo[] =
 {
 	{ REGION_GFX1, 0, &tilelayout_4096, 0*16,  16 },
 	{ REGION_GFX2, 0, &tilelayout_1024, 16*16, 16 },
@@ -752,7 +751,7 @@ static MACHINE_DRIVER_START( argus )
 	MDRV_INTERLEAVE(10)
 
 	/* video hardware */
-	MDRV_VIDEO_ATTRIBUTES(VIDEO_TYPE_RASTER)
+	MDRV_VIDEO_ATTRIBUTES(VIDEO_TYPE_RASTER | VIDEO_NEEDS_6BITS_PER_GUN | VIDEO_RGB_DIRECT)
 	MDRV_SCREEN_SIZE(32*16, 32*16)
 	MDRV_VISIBLE_AREA(0*8, 32*8-1, 2*8, 30*8-1)
 	MDRV_GFXDECODE(argus_gfxdecodeinfo)
@@ -789,7 +788,7 @@ static MACHINE_DRIVER_START( valtric )
 	MDRV_INTERLEAVE(10)
 
 	/* video hardware */
-	MDRV_VIDEO_ATTRIBUTES(VIDEO_TYPE_RASTER)
+	MDRV_VIDEO_ATTRIBUTES(VIDEO_TYPE_RASTER | VIDEO_NEEDS_6BITS_PER_GUN | VIDEO_RGB_DIRECT)
 	MDRV_SCREEN_SIZE(32*16, 32*16)
 	MDRV_VISIBLE_AREA(0*8, 32*8-1, 2*8, 30*8-1)
 	MDRV_GFXDECODE(valtric_gfxdecodeinfo)
@@ -832,7 +831,7 @@ static MACHINE_DRIVER_START( butasan )
 	MDRV_INTERLEAVE(10)
 
 	/* video hardware */
-	MDRV_VIDEO_ATTRIBUTES(VIDEO_TYPE_RASTER)
+	MDRV_VIDEO_ATTRIBUTES(VIDEO_TYPE_RASTER | VIDEO_NEEDS_6BITS_PER_GUN | VIDEO_RGB_DIRECT)
 	MDRV_SCREEN_SIZE(32*16, 32*16)
 	MDRV_VISIBLE_AREA(0*8, 32*8-1, 1*8, 31*8-1)
 	MDRV_GFXDECODE(butasan_gfxdecodeinfo)
