@@ -140,7 +140,6 @@
 ***************************************************************************/
 
 #include "driver.h"
-#include "vidhrdw/generic.h"
 #include "vidhrdw/vector.h"
 #include "vidhrdw/avgdvg.h"
 #include "machine/atari_vg.h"
@@ -203,7 +202,7 @@ static ADDRESS_MAP_START( asteroid_map, ADDRESS_SPACE_PROGRAM, 8 )
 	AM_RANGE(0x3a00, 0x3a00) AM_WRITE(asteroid_thump_w)
 	AM_RANGE(0x3c00, 0x3c05) AM_WRITE(asteroid_sounds_w)
 	AM_RANGE(0x3e00, 0x3e00) AM_WRITE(asteroid_noise_reset_w)
-	AM_RANGE(0x4000, 0x47ff) AM_RAM AM_BASE(&vectorram) AM_SIZE(&vectorram_size)
+	AM_RANGE(0x4000, 0x47ff) AM_RAM AM_BASE(&vectorram) AM_SIZE(&vectorram_size) AM_REGION(REGION_CPU1, 0x4000)
 	AM_RANGE(0x5000, 0x57ff) AM_ROM				/* vector rom */
 	AM_RANGE(0x6800, 0x7fff) AM_ROM
 ADDRESS_MAP_END
@@ -227,7 +226,7 @@ static ADDRESS_MAP_START( astdelux_map, ADDRESS_SPACE_PROGRAM, 8 )
 	AM_RANGE(0x3c04, 0x3c04) AM_WRITE(astdelux_bank_switch_w)
 	AM_RANGE(0x3c05, 0x3c07) AM_WRITE(astdelux_coin_counter_w)
 	AM_RANGE(0x3e00, 0x3e00) AM_WRITE(asteroid_noise_reset_w)
-	AM_RANGE(0x4000, 0x47ff) AM_RAM AM_BASE(&vectorram) AM_SIZE(&vectorram_size)
+	AM_RANGE(0x4000, 0x47ff) AM_RAM AM_BASE(&vectorram) AM_SIZE(&vectorram_size) AM_REGION(REGION_CPU1, 0x4000)
 	AM_RANGE(0x4800, 0x57ff) AM_ROM				/* vector rom */
 	AM_RANGE(0x6000, 0x7fff) AM_ROM
 ADDRESS_MAP_END
@@ -245,7 +244,7 @@ static ADDRESS_MAP_START( llander_map, ADDRESS_SPACE_PROGRAM, 8 )
 	AM_RANGE(0x3400, 0x3400) AM_WRITE(watchdog_reset_w)
 	AM_RANGE(0x3c00, 0x3c00) AM_WRITE(llander_sounds_w)
 	AM_RANGE(0x3e00, 0x3e00) AM_WRITE(llander_snd_reset_w)
-	AM_RANGE(0x4000, 0x47ff) AM_RAM AM_BASE(&vectorram) AM_SIZE(&vectorram_size)
+	AM_RANGE(0x4000, 0x47ff) AM_RAM AM_BASE(&vectorram) AM_SIZE(&vectorram_size) AM_REGION(REGION_CPU1, 0x4000)
 	AM_RANGE(0x4800, 0x5fff) AM_ROM				/* vector rom */
 	AM_RANGE(0x6000, 0x7fff) AM_ROM
 ADDRESS_MAP_END
@@ -604,7 +603,7 @@ static MACHINE_DRIVER_START( asteroid )
 	MDRV_CPU_VBLANK_INT(asteroid_interrupt,4)	/* 250 Hz */
 
 	MDRV_FRAMES_PER_SECOND(60)
-	MDRV_MACHINE_INIT(asteroid)
+	MDRV_MACHINE_RESET(asteroid)
 
 	/* video hardware */
 	MDRV_VIDEO_ATTRIBUTES(VIDEO_TYPE_VECTOR | VIDEO_RGB_DIRECT)
@@ -662,7 +661,7 @@ static MACHINE_DRIVER_START( llander )
 	MDRV_CPU_VBLANK_INT(llander_interrupt,6)	/* 250 Hz */
 
 	MDRV_FRAMES_PER_SECOND(40)
-	MDRV_MACHINE_INIT(NULL)
+	MDRV_MACHINE_RESET(NULL)
 
 	/* video hardware */
 	MDRV_VISIBLE_AREA(0, 1050, 0, 900)
