@@ -69,12 +69,11 @@ OUT:
 ****************************************************************************/
 
 #include "driver.h"
-#include "vidhrdw/generic.h"
 #include "includes/astrocde.h"
 #include "sound/samples.h"
 #include "sound/astrocde.h"
 
-static int game_on = 0;
+static UINT8 game_on = 0;
 
 static WRITE8_HANDLER( seawolf2_lamps_w )
 {
@@ -127,99 +126,83 @@ static WRITE8_HANDLER( seawolf2_sound_2_w )  /* Port 41 */
 	coin_counter_w(0, data & 0x40);    /* Coin Counter */
 }
 
+void astrocade_state_save_register_main(void)
+{
+	state_save_register_global(game_on);
+}
 
-static ADDRESS_MAP_START( seawolf2_readmem, ADDRESS_SPACE_PROGRAM, 8 )
-	AM_RANGE(0x0000, 0x1fff) AM_READ(MRA8_ROM)
-	AM_RANGE(0x4000, 0x7fff) AM_READ(MRA8_RAM)
-	AM_RANGE(0xc000, 0xc3ff) AM_READ(MRA8_RAM)
-ADDRESS_MAP_END
+/*************************************
+ *
+ *  Memory maps
+ *
+ *************************************/
 
-static ADDRESS_MAP_START( seawolf2_writemem, ADDRESS_SPACE_PROGRAM, 8 )
+static ADDRESS_MAP_START( seawolf2_map, ADDRESS_SPACE_PROGRAM, 8 )
+	AM_RANGE(0x0000, 0x1fff) AM_ROM
 	AM_RANGE(0x0000, 0x3fff) AM_WRITE(wow_magicram_w)
-	AM_RANGE(0x4000, 0x7fff) AM_WRITE(wow_videoram_w) AM_BASE(&wow_videoram) AM_SIZE(&videoram_size)
-	AM_RANGE(0xc000, 0xc3ff) AM_WRITE(MWA8_RAM)
+	AM_RANGE(0x4000, 0x7fff) AM_RAM AM_BASE(&wow_videoram)
+	AM_RANGE(0xc000, 0xc3ff) AM_RAM
 ADDRESS_MAP_END
 
-static ADDRESS_MAP_START( readmem, ADDRESS_SPACE_PROGRAM, 8 )
-	AM_RANGE(0x0000, 0x3fff) AM_READ(MRA8_ROM)
-	AM_RANGE(0x4000, 0x7fff) AM_READ(MRA8_RAM)
-	AM_RANGE(0x8000, 0xcfff) AM_READ(MRA8_ROM)
-	AM_RANGE(0xd000, 0xdfff) AM_READ(MRA8_RAM)
-ADDRESS_MAP_END
 
-static ADDRESS_MAP_START( writemem, ADDRESS_SPACE_PROGRAM, 8 )
+static ADDRESS_MAP_START( astrocde_map, ADDRESS_SPACE_PROGRAM, 8 )
+	AM_RANGE(0x0000, 0x3fff) AM_ROM
 	AM_RANGE(0x0000, 0x3fff) AM_WRITE(wow_magicram_w)
-	AM_RANGE(0x4000, 0x7fff) AM_WRITE(wow_videoram_w) AM_BASE(&wow_videoram) AM_SIZE(&videoram_size)	/* ASG */
-	AM_RANGE(0x8000, 0xcfff) AM_WRITE(MWA8_ROM)
-	AM_RANGE(0xd000, 0xdfff) AM_WRITE(MWA8_RAM)
+	AM_RANGE(0x4000, 0x7fff) AM_RAM AM_BASE(&wow_videoram)
+	AM_RANGE(0x8000, 0xcfff) AM_ROM
+	AM_RANGE(0xd000, 0xdfff) AM_RAM
 ADDRESS_MAP_END
 
-static ADDRESS_MAP_START( wow_readmem, ADDRESS_SPACE_PROGRAM, 8 )
-	AM_RANGE(0x0000, 0x3fff) AM_READ(MRA8_ROM)
-	AM_RANGE(0x4000, 0x7fff) AM_READ(MRA8_RAM)
-	AM_RANGE(0x8000, 0xcfff) AM_READ(MRA8_ROM)
-	AM_RANGE(0xd000, 0xd3ff) AM_READ(wow_protected_ram_r)
-	AM_RANGE(0xd400, 0xdfff) AM_READ(MRA8_RAM)
-ADDRESS_MAP_END
 
-static ADDRESS_MAP_START( wow_writemem, ADDRESS_SPACE_PROGRAM, 8 )
+static ADDRESS_MAP_START( wow_map, ADDRESS_SPACE_PROGRAM, 8 )
+	AM_RANGE(0x0000, 0x3fff) AM_ROM
 	AM_RANGE(0x0000, 0x3fff) AM_WRITE(wow_magicram_w)
-	AM_RANGE(0x4000, 0x7fff) AM_WRITE(wow_videoram_w) AM_BASE(&wow_videoram) AM_SIZE(&videoram_size)	/* ASG */
-	AM_RANGE(0x8000, 0xcfff) AM_WRITE(MWA8_ROM)
-	AM_RANGE(0xd000, 0xd3ff) AM_WRITE(wow_protected_ram_w) AM_BASE(&wow_protected_ram) AM_SIZE(&wow_protected_ram_size)
-	AM_RANGE(0xd400, 0xdfff) AM_WRITE(MWA8_RAM)
+	AM_RANGE(0x4000, 0x7fff) AM_RAM AM_BASE(&wow_videoram)
+	AM_RANGE(0x8000, 0xcfff) AM_ROM
+	AM_RANGE(0xd000, 0xd3ff) AM_RAM /*AM_READWRITE(wow_protected_ram_r, wow_protected_ram_w) AM_BASE(&wow_protected_ram) */
+	AM_RANGE(0xd400, 0xdfff) AM_RAM
 ADDRESS_MAP_END
 
-static ADDRESS_MAP_START( robby_readmem, ADDRESS_SPACE_PROGRAM, 8 )
-	AM_RANGE(0x0000, 0x3fff) AM_READ(MRA8_ROM)
-	AM_RANGE(0x4000, 0x7fff) AM_READ(MRA8_RAM)
-	AM_RANGE(0x8000, 0xdfff) AM_READ(MRA8_ROM)
-	AM_RANGE(0xe000, 0xe7ff) AM_READ(robby_nvram_r)
-	AM_RANGE(0xe800, 0xffff) AM_READ(MRA8_RAM)
-ADDRESS_MAP_END
 
-static ADDRESS_MAP_START( robby_writemem, ADDRESS_SPACE_PROGRAM, 8 )
+static ADDRESS_MAP_START( robby_map, ADDRESS_SPACE_PROGRAM, 8 )
+	AM_RANGE(0x0000, 0x3fff) AM_ROM
 	AM_RANGE(0x0000, 0x3fff) AM_WRITE(wow_magicram_w)
-	AM_RANGE(0x4000, 0x7fff) AM_WRITE(wow_videoram_w) AM_BASE(&wow_videoram) AM_SIZE(&videoram_size)
-	AM_RANGE(0x8000, 0xdfff) AM_WRITE(MWA8_ROM)
-  	AM_RANGE(0xe000, 0xe7ff) AM_WRITE(robby_nvram_w)
-  	AM_RANGE(0xe800, 0xffff) AM_WRITE(MWA8_RAM)
+	AM_RANGE(0x4000, 0x7fff) AM_RAM AM_BASE(&wow_videoram)
+	AM_RANGE(0x8000, 0xdfff) AM_ROM
+	AM_RANGE(0xe000, 0xe7ff) AM_READWRITE(robby_nvram_r, robby_nvram_w) AM_BASE(&generic_nvram) AM_SIZE(&generic_nvram_size)
+	AM_RANGE(0xe800, 0xffff) AM_RAM
 ADDRESS_MAP_END
 
-static ADDRESS_MAP_START( demndrgn_readmem, ADDRESS_SPACE_PROGRAM, 8 )
-	AM_RANGE(0x0000, 0x3fff) AM_READ(MRA8_ROM)
-	AM_RANGE(0x4000, 0x7fff) AM_READ(MRA8_BANK1)
-	AM_RANGE(0x8000, 0xbfff) AM_READ(MRA8_BANK2)
-	AM_RANGE(0xc000, 0xdfff) AM_READ(MRA8_ROM)
-  	AM_RANGE(0xe000, 0xe7ff) AM_READ(demndrgn_nvram_r)
-	AM_RANGE(0xe800, 0xffff) AM_READ(MRA8_RAM)
-ADDRESS_MAP_END
 
-static ADDRESS_MAP_START( demndrgn_writemem, ADDRESS_SPACE_PROGRAM, 8 )
+static ADDRESS_MAP_START( demndrgn_map, ADDRESS_SPACE_PROGRAM, 8 )
+	AM_RANGE(0x0000, 0x3fff) AM_ROM
 	AM_RANGE(0x0000, 0x3fff) AM_WRITE(wow_magicram_w)
-	AM_RANGE(0x4000, 0x7fff) AM_WRITE(profpac_videoram_w)
-	AM_RANGE(0x8000, 0xdfff) AM_WRITE(MWA8_ROM)
-  	AM_RANGE(0xe000, 0xe7ff) AM_WRITE(demndrgn_nvram_w)
-  	AM_RANGE(0xe800, 0xffff) AM_WRITE(MWA8_RAM)
+	AM_RANGE(0x4000, 0x7fff) AM_READWRITE(MRA8_BANK1, profpac_videoram_w)
+	AM_RANGE(0x8000, 0xbfff) AM_ROMBANK(2)
+	AM_RANGE(0xc000, 0xdfff) AM_ROM
+  	AM_RANGE(0xe000, 0xe7ff) AM_READWRITE(demndrgn_nvram_r, demndrgn_nvram_w) AM_BASE(&generic_nvram) AM_SIZE(&generic_nvram_size)
+	AM_RANGE(0xe800, 0xffff) AM_RAM
 ADDRESS_MAP_END
 
-static ADDRESS_MAP_START( profpac_readmem, ADDRESS_SPACE_PROGRAM, 8 )
-	AM_RANGE(0x0000, 0x3fff) AM_READ(MRA8_ROM)
-	AM_RANGE(0x4000, 0x7fff) AM_READ(MRA8_BANK1)
-	AM_RANGE(0x8000, 0xbfff) AM_READ(MRA8_BANK2)
-	AM_RANGE(0xc000, 0xdfff) AM_READ(MRA8_ROM)
-  	AM_RANGE(0xe000, 0xe7ff) AM_READ(profpac_nvram_r)
-	AM_RANGE(0xe800, 0xffff) AM_READ(MRA8_RAM)
-ADDRESS_MAP_END
 
-static ADDRESS_MAP_START( profpac_writemem, ADDRESS_SPACE_PROGRAM, 8 )
+static ADDRESS_MAP_START( profpac_map, ADDRESS_SPACE_PROGRAM, 8 )
+	AM_RANGE(0x0000, 0x3fff) AM_ROM
 	AM_RANGE(0x0000, 0x3fff) AM_WRITE(wow_magicram_w)
-	AM_RANGE(0x4000, 0x7fff) AM_WRITE(profpac_videoram_w)
-	AM_RANGE(0x8000, 0xdfff) AM_WRITE(MWA8_ROM)
-  	AM_RANGE(0xe000, 0xe7ff) AM_WRITE(profpac_nvram_w)
-  	AM_RANGE(0xe800, 0xffff) AM_WRITE(MWA8_RAM)
+	AM_RANGE(0x4000, 0x7fff) AM_READWRITE(MRA8_BANK1, profpac_videoram_w)
+	AM_RANGE(0x8000, 0xbfff) AM_ROMBANK(2)
+	AM_RANGE(0xc000, 0xdfff) AM_ROM
+  	AM_RANGE(0xe000, 0xe7ff) AM_READWRITE(profpac_nvram_r, profpac_nvram_w) AM_BASE(&generic_nvram) AM_SIZE(&generic_nvram_size)
+	AM_RANGE(0xe800, 0xffff) AM_RAM
 ADDRESS_MAP_END
 
+
+
+/*************************************
+ *
+ *  Port maps
+ *
+ *************************************/
+
 static ADDRESS_MAP_START( readport, ADDRESS_SPACE_IO, 8 )
 	AM_RANGE(0x08, 0x08) AM_MIRROR(0xff00) AM_READ(wow_intercept_r)
 	AM_RANGE(0x0e, 0x0e) AM_MIRROR(0xff00) AM_READ(wow_video_retrace_r)
@@ -277,6 +260,12 @@ ADDRESS_MAP_END
 
 
 
+/*************************************
+ *
+ *  Input ports
+ *
+ *************************************/
+
 INPUT_PORTS_START( seawolf2 )
 	PORT_START_TAG("IN0")
 	PORT_BIT( 0x3f, 0x20, IPT_PADDLE ) PORT_MINMAX(0,0x3f) PORT_SENSITIVITY(20) PORT_KEYDELTA(5) PORT_CENTERDELTA(0) PORT_REVERSE PORT_PLAYER(1)
@@ -325,6 +314,7 @@ INPUT_PORTS_START( seawolf2 )
 	PORT_SERVICE( 0x80, IP_ACTIVE_LOW )
 INPUT_PORTS_END
 
+
 INPUT_PORTS_START( spacezap )
 	PORT_START_TAG("IN0")
 	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_COIN1 )
@@ -380,6 +370,7 @@ INPUT_PORTS_START( spacezap )
 	PORT_DIPSETTING(    0x80, DEF_STR( On ) )
 INPUT_PORTS_END
 
+
 INPUT_PORTS_START( ebases )
 	PORT_START_TAG("IN0")
 	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_BUTTON1 ) PORT_PLAYER(2)
@@ -448,6 +439,7 @@ INPUT_PORTS_START( ebases )
 	PORT_BIT( 0xff, 0x00, IPT_TRACKBALL_Y ) PORT_SENSITIVITY(50) PORT_KEYDELTA(10) PORT_RESET	\
 INPUT_PORTS_END
 
+
 INPUT_PORTS_START( wow )
 	PORT_START_TAG("IN0")
 	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_COIN1 )
@@ -507,6 +499,7 @@ INPUT_PORTS_START( wow )
 	PORT_DIPSETTING(    0x80, "Always On"  )
 INPUT_PORTS_END
 
+
 INPUT_PORTS_START( gorf )
 	PORT_START_TAG("IN0")
 	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_COIN1 )
@@ -566,6 +559,7 @@ INPUT_PORTS_START( gorf )
 	PORT_DIPSETTING(    0x80, DEF_STR( On ) )
 INPUT_PORTS_END
 
+
 INPUT_PORTS_START( robby )
 	PORT_START_TAG("IN0")
 	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_COIN1 )
@@ -622,6 +616,7 @@ INPUT_PORTS_START( robby )
 	PORT_DIPSETTING(    0x80, DEF_STR( On ) )
 INPUT_PORTS_END
 
+
 INPUT_PORTS_START( demndrgn )
 	PORT_START_TAG("IN0")
 	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_COIN1 )
@@ -648,9 +643,9 @@ INPUT_PORTS_START( demndrgn )
 
 	PORT_START_TAG("IN3")
 	PORT_BIT( 0xff, 0x80, IPT_TRACKBALL_Y ) PORT_SENSITIVITY(50) PORT_KEYDELTA(10) PORT_RESET
-
 INPUT_PORTS_END
 
+
 INPUT_PORTS_START( profpac )
 	PORT_START_TAG("IN0")
 	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_COIN1 )
@@ -702,6 +697,13 @@ INPUT_PORTS_START( profpac )
 INPUT_PORTS_END
 
 
+
+/*************************************
+ *
+ *  Sound definitions
+ *
+ *************************************/
+
 static const char *seawolf_sample_names[] =
 {
 	"*seawolf",
@@ -731,32 +733,27 @@ static struct Samplesinterface gorf_samples_interface =
 	gorf_sample_names
 };
 
-/* For speech */
-static struct CustomSound_interface gorf_custom_interface =
-{
-	gorf_sh_start
-};
-
-/* For speech */
-static struct CustomSound_interface wow_custom_interface =
-{
-	wow_sh_start
-};
-
 
 
+/*************************************
+ *
+ *  Machine drivers
+ *
+ *************************************/
 
 static MACHINE_DRIVER_START( seawolf2 )
 
 	/* basic machine hardware */
 	MDRV_CPU_ADD(Z80, 1789773)	/* 1.789 MHz */
-	MDRV_CPU_PROGRAM_MAP(seawolf2_readmem,seawolf2_writemem)
+	MDRV_CPU_PROGRAM_MAP(seawolf2_map,0)
 	MDRV_CPU_IO_MAP(readport,seawolf2_writeport)
 	MDRV_CPU_VBLANK_INT(wow_interrupt,256)
 
 	MDRV_FRAMES_PER_SECOND(60)
 	MDRV_VBLANK_DURATION(DEFAULT_60HZ_VBLANK_DURATION)
 
+	MDRV_MACHINE_START(astrocde)
+
 	/* video hardware */
 	MDRV_VIDEO_ATTRIBUTES(VIDEO_TYPE_RASTER)
 	MDRV_SCREEN_SIZE(320, 204)
@@ -779,13 +776,15 @@ static MACHINE_DRIVER_START( spacezap )
 
 	/* basic machine hardware */
 	MDRV_CPU_ADD(Z80, 1789773)	/* 1.789 MHz */
-	MDRV_CPU_PROGRAM_MAP(wow_readmem,wow_writemem)
+	MDRV_CPU_PROGRAM_MAP(wow_map,0)
 	MDRV_CPU_IO_MAP(readport,writeport)
 	MDRV_CPU_VBLANK_INT(wow_interrupt,256)
 
 	MDRV_FRAMES_PER_SECOND(60)
 	MDRV_VBLANK_DURATION(DEFAULT_60HZ_VBLANK_DURATION)
 
+	MDRV_MACHINE_START(astrocde)
+
 	/* video hardware */
 	MDRV_VIDEO_ATTRIBUTES(VIDEO_TYPE_RASTER)
 	MDRV_SCREEN_SIZE(320, 204)
@@ -807,13 +806,15 @@ static MACHINE_DRIVER_START( ebases )
 
 	/* basic machine hardware */
 	MDRV_CPU_ADD(Z80, 1789773)	/* 1.789 MHz */
-	MDRV_CPU_PROGRAM_MAP(readmem,writemem)
+	MDRV_CPU_PROGRAM_MAP(astrocde_map,0)
 	MDRV_CPU_IO_MAP(readport,writeport)
 	MDRV_CPU_VBLANK_INT(wow_interrupt,256)
 
 	MDRV_FRAMES_PER_SECOND(60)
 	MDRV_VBLANK_DURATION(DEFAULT_60HZ_VBLANK_DURATION)
 
+	MDRV_MACHINE_START(astrocde)
+
 	/* video hardware */
 	MDRV_VIDEO_ATTRIBUTES(VIDEO_TYPE_RASTER)
 	MDRV_SCREEN_SIZE(320, 204)
@@ -835,13 +836,15 @@ static MACHINE_DRIVER_START( wow )
 
 	/* basic machine hardware */
 	MDRV_CPU_ADD(Z80, 1789773)	/* 1.789 MHz */
-	MDRV_CPU_PROGRAM_MAP(wow_readmem,wow_writemem)
+	MDRV_CPU_PROGRAM_MAP(wow_map,0)
 	MDRV_CPU_IO_MAP(readport,writeport)
 	MDRV_CPU_VBLANK_INT(wow_interrupt,256)
 
 	MDRV_FRAMES_PER_SECOND(60)
 	MDRV_VBLANK_DURATION(DEFAULT_60HZ_VBLANK_DURATION)
 
+	MDRV_MACHINE_START(astrocde)
+
 	/* video hardware */
 	MDRV_VIDEO_ATTRIBUTES(VIDEO_TYPE_RASTER)
 	MDRV_SCREEN_SIZE(320, 204)
@@ -853,9 +856,6 @@ static MACHINE_DRIVER_START( wow )
 	MDRV_VIDEO_UPDATE(astrocde)
 
 	/* sound hardware */
-/* For Gorf, Left is actually Upper Speaker, */
-/*          Right is actually Lower Speaker, */
-/*   and speech is mixed into Upper Speaker */
 	MDRV_SPEAKER_STANDARD_STEREO("left", "right")
 
 	MDRV_SOUND_ADD(ASTROCADE, 1789773)
@@ -868,22 +868,21 @@ static MACHINE_DRIVER_START( wow )
 	MDRV_SOUND_CONFIG(wow_samples_interface)
 	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "left", 0.25)
 	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "right", 0.25)
-
-	MDRV_SOUND_ADD(CUSTOM, 0)
-	MDRV_SOUND_CONFIG(wow_custom_interface)
 MACHINE_DRIVER_END
 
 static MACHINE_DRIVER_START( gorf )
 
 	/* basic machine hardware */
 	MDRV_CPU_ADD(Z80, 1789773)	/* 1.789 MHz */
-	MDRV_CPU_PROGRAM_MAP(wow_readmem,wow_writemem)
+	MDRV_CPU_PROGRAM_MAP(wow_map,0)
 	MDRV_CPU_IO_MAP(readport,writeport)
 	MDRV_CPU_VBLANK_INT(gorf_interrupt,256)
 
 	MDRV_FRAMES_PER_SECOND(60)
 	MDRV_VBLANK_DURATION(DEFAULT_60HZ_VBLANK_DURATION)
 
+	MDRV_MACHINE_START(astrocde)
+
 	/* video hardware */
 	/* it may look like the right hand side of the screen needs clipping, but */
 	/* this isn't the case: cocktail mode would be clipped on the wrong side */
@@ -911,23 +910,22 @@ static MACHINE_DRIVER_START( gorf )
 	MDRV_SOUND_CONFIG(gorf_samples_interface)
 	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "upper", 0.25)
 	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "lower", 0.25)
-
-	MDRV_SOUND_ADD(CUSTOM, 0)
-	MDRV_SOUND_CONFIG(gorf_custom_interface)
 MACHINE_DRIVER_END
 
 static MACHINE_DRIVER_START( robby )
 
 	/* basic machine hardware */
 	MDRV_CPU_ADD(Z80, 1789773)	/* 1.789 MHz */
-	MDRV_CPU_PROGRAM_MAP(robby_readmem,robby_writemem)
+	MDRV_CPU_PROGRAM_MAP(robby_map,0)
 	MDRV_CPU_IO_MAP(readport,writeport)
 	MDRV_CPU_VBLANK_INT(wow_interrupt,256)
 
 	MDRV_FRAMES_PER_SECOND(60)
 	MDRV_VBLANK_DURATION(DEFAULT_60HZ_VBLANK_DURATION)
 
-	MDRV_NVRAM_HANDLER(robby_nvram)
+	MDRV_MACHINE_START(astrocde)
+
+	MDRV_NVRAM_HANDLER(generic_0fill)
 
 	/* video hardware */
 	MDRV_VIDEO_ATTRIBUTES(VIDEO_TYPE_RASTER)
@@ -953,14 +951,16 @@ static MACHINE_DRIVER_START( demndrgn )
 
 	/* basic machine hardware */
 	MDRV_CPU_ADD(Z80, 1789773)	/* 1.789 MHz */
-	MDRV_CPU_PROGRAM_MAP(demndrgn_readmem,demndrgn_writemem)
+	MDRV_CPU_PROGRAM_MAP(demndrgn_map,0)
 	MDRV_CPU_IO_MAP(demndrgn_readport,writeport)
 	MDRV_CPU_VBLANK_INT(wow_interrupt,256)
 
 	MDRV_FRAMES_PER_SECOND(60)
 	MDRV_VBLANK_DURATION(DEFAULT_60HZ_VBLANK_DURATION)
 
-	MDRV_NVRAM_HANDLER(robby_nvram)
+	MDRV_MACHINE_START(profpac)
+
+	MDRV_NVRAM_HANDLER(generic_0fill)
 
 	/* video hardware */
 	MDRV_VIDEO_ATTRIBUTES(VIDEO_TYPE_RASTER)
@@ -977,14 +977,16 @@ static MACHINE_DRIVER_START( profpac )
 
 	/* basic machine hardware */
 	MDRV_CPU_ADD(Z80, 1789773)	/* 1.789 MHz */
-	MDRV_CPU_PROGRAM_MAP(profpac_readmem,profpac_writemem)
+	MDRV_CPU_PROGRAM_MAP(profpac_map,0)
 	MDRV_CPU_IO_MAP(readport,writeport)
 	MDRV_CPU_VBLANK_INT(wow_interrupt,256)
 
 	MDRV_FRAMES_PER_SECOND(60)
 	MDRV_VBLANK_DURATION(DEFAULT_60HZ_VBLANK_DURATION)
 
-	MDRV_NVRAM_HANDLER(robby_nvram)
+	MDRV_MACHINE_START(profpac)
+
+	MDRV_NVRAM_HANDLER(generic_0fill)
 
 	/* video hardware */
 	MDRV_VIDEO_ATTRIBUTES(VIDEO_TYPE_RASTER)
@@ -1008,6 +1010,12 @@ MACHINE_DRIVER_END
 
 
 
+/*************************************
+ *
+ *  ROM definition(s)
+ *
+ *************************************/
+
 ROM_START( seawolf2 )
 	ROM_REGION( 0x10000, REGION_CPU1, 0 )
 	ROM_LOAD( "sw2x1.bin",    0x0000, 0x0800, CRC(ad0103f6) SHA1(c6e411444a824ce54b0eee10f7dc15e4229ec070) )
@@ -1016,6 +1024,7 @@ ROM_START( seawolf2 )
 	ROM_LOAD( "sw2x4.bin",    0x1800, 0x0800, CRC(1a1a14a2) SHA1(57d0ddea9f8bf082f50d0468a726fd91aaabf4e4) )
 ROM_END
 
+
 ROM_START( spacezap )
 	ROM_REGION( 0x10000, REGION_CPU1, 0 )
 	ROM_LOAD( "0662.01",      0x0000, 0x1000, CRC(a92de312) SHA1(784ac67c75c7c101f97ebfd39b2b3f7bf7fa470a) )
@@ -1024,6 +1033,7 @@ ROM_START( spacezap )
 	ROM_LOAD( "0665.xx",      0x3000, 0x1000, CRC(3784228d) SHA1(5aabd720a106158a892368c4920d9cd0f5235e34) )
 ROM_END
 
+
 ROM_START( ebases )
 	ROM_REGION( 0x10000, REGION_CPU1, 0 )
 	ROM_LOAD( "m761a",        0x0000, 0x1000, CRC(34422147) SHA1(6483ca1359b675b0dd739605db2a1dbd4b7fb8cb) )
@@ -1032,6 +1042,7 @@ ROM_START( ebases )
 	ROM_LOAD( "m761d",        0x3000, 0x1000, CRC(5173781a) SHA1(e60c3f4b075f8b811ff6a8637c4aa0b089847a82) )
 ROM_END
 
+
 ROM_START( wow )
 	ROM_REGION( 0x10000, REGION_CPU1, 0 )
 	ROM_LOAD( "wow.x1",       0x0000, 0x1000, CRC(c1295786) SHA1(1e4f30cc15537aed6603b4e664e6e60f4bccb5c5) )
@@ -1044,6 +1055,7 @@ ROM_START( wow )
 /*  ROM_LOAD( "wow.x8",       0xc000, CRC(00001000) , ? )   here would go the foreign language ROM */
 ROM_END
 
+
 ROM_START( gorf )
 	ROM_REGION( 0x10000, REGION_CPU1, 0 )
 	ROM_LOAD( "gorf-a.bin",   0x0000, 0x1000, CRC(5b348321) SHA1(76e2e3ad1a66755f1a369167fdb157690fd44a52) )
@@ -1056,6 +1068,7 @@ ROM_START( gorf )
 	ROM_LOAD( "gorf-h.bin",   0xb000, 0x1000, CRC(fe7b863d) SHA1(5aa8d824814ee1c30eaf0044da78d3aa8220dcaa) )
 ROM_END
 
+
 ROM_START( gorfpgm1 )
 	ROM_REGION( 0x10000, REGION_CPU1, 0 )
 	ROM_LOAD( "873a",         0x0000, 0x1000, CRC(97cb4a6a) SHA1(efdae9a437c665fb861665a38c6cb13fd848ad91) )
@@ -1068,6 +1081,7 @@ ROM_START( gorfpgm1 )
 	ROM_LOAD( "873h",         0xb000, 0x1000, CRC(56d40c7c) SHA1(c7c9a618d9438a76121972ac029ad7036bcf8c6f) )
 ROM_END
 
+
 ROM_START( robby )
 	ROM_REGION( 0x10000, REGION_CPU1, 0 )
 	ROM_LOAD( "rotox1.bin",   0x0000, 0x1000, CRC(a431b85a) SHA1(3478da56addba1cdd98cbef7a15b17fca9aed2cd) )
@@ -1082,6 +1096,7 @@ ROM_START( robby )
 	ROM_LOAD( "rotox10.bin",  0xd000, 0x1000, CRC(e762cbda) SHA1(48c274a859963097a90f80c48366250301eddb5f) )
 ROM_END
 
+
 ROM_START( demndrgn )
 	ROM_REGION( 0x2a000, REGION_CPU1, 0 )
 	ROM_LOAD( "dd-x1.bin",     0x0000, 0x2000, CRC(9aeaf79e) SHA1(c70aa1a31bc085cca904d497c34e55d49fef49b7) )
@@ -1099,6 +1114,7 @@ ROM_START( demndrgn )
 	ROM_LOAD( "dd-x16.bin",    0x28000, 0x2000, CRC(7a4a343b) SHA1(4eb82ae38ce1b14778fb29d8549c61a46bc3ee66) )
 ROM_END
 
+
 ROM_START( profpac )
 	ROM_REGION( 0x2c000, REGION_CPU1, 0 )
 	ROM_LOAD( "pps1",         0x0000, 0x2000, CRC(a244a62d) SHA1(f7a9606ce6d66c3e6d210cc25572904aeab2b6c8) )
@@ -1131,17 +1147,26 @@ ROM_START( profpac )
 ROM_END
 
 
+
+/*************************************
+ *
+ *  Game-specific driver inits
+ *
+ *************************************/
+
 static DRIVER_INIT( seawolf2 )
 {
 	memory_install_read8_handler(0, ADDRESS_SPACE_IO, 0x10, 0x10, 0, 0xff00, seawolf2_controller2_r);
 	memory_install_read8_handler(0, ADDRESS_SPACE_IO, 0x11, 0x11, 0, 0xff00, seawolf2_controller1_r);
 }
+
 static DRIVER_INIT( ebases )
 {
 	memory_install_read8_handler(0, ADDRESS_SPACE_IO, 0x13, 0x13, 0, 0xff00, ebases_trackball_r);
 	memory_install_write8_handler(0, ADDRESS_SPACE_IO, 0x20, 0x20, 0, 0xff00, ebases_io_w);
 	memory_install_write8_handler(0, ADDRESS_SPACE_IO, 0x28, 0x28, 0, 0xff00, ebases_trackball_select_w);
 }
+
 static DRIVER_INIT( wow )
 {
 	memory_install_read8_handler(0, ADDRESS_SPACE_IO, 0x12, 0x12, 0, 0xff00, wow_port_2_r);
@@ -1150,14 +1175,17 @@ static DRIVER_INIT( wow )
 	memory_install_write8_handler(0, ADDRESS_SPACE_IO, 0x50, 0x57, 0, 0xff00, astrocade_sound2_w);
 	memory_install_write8_matchmask_handler(0, ADDRESS_SPACE_IO, 0x58, 0xff, 0, 0, astrocade_soundblock2_w);
 }
+
 static DRIVER_INIT( spacezap )
 {
 	memory_install_read8_matchmask_handler(0, ADDRESS_SPACE_IO, 0x13, 0xff, 0, 0, spacezap_io_r);
 }
+
 static DRIVER_INIT( gorf )
 {
 	/* This is part of the timing/interrupt hack stuff */
-	memory_install_read8_handler(0, ADDRESS_SPACE_PROGRAM, 0xd0a5, 0xd0a5, 0, 0, gorf_timer_r);
+/*  extern UINT8 *gorf_timer_ram; */
+/*  gorf_timer_ram = memory_install_read8_handler(0, ADDRESS_SPACE_PROGRAM, 0xd0a5, 0xd0a5, 0, 0, gorf_timer_r); */
 
 	memory_install_read8_handler(0, ADDRESS_SPACE_IO, 0x12, 0x12, 0, 0xff00, gorf_port_2_r);
 	memory_install_read8_matchmask_handler(0, ADDRESS_SPACE_IO, 0x15, 0xff, 0, 0, gorf_io_1_r);
@@ -1166,12 +1194,14 @@ static DRIVER_INIT( gorf )
 	memory_install_write8_handler(0, ADDRESS_SPACE_IO, 0x50, 0x57, 0, 0xff00, astrocade_sound2_w);
 	memory_install_write8_matchmask_handler(0, ADDRESS_SPACE_IO, 0x58, 0xff, 0, 0, astrocade_soundblock2_w);
 }
+
 static DRIVER_INIT( robby )
 {
 	memory_install_read8_matchmask_handler(0, ADDRESS_SPACE_IO, 0x15, 0xff, 0, 0, robby_io_r);
 	memory_install_write8_handler(0, ADDRESS_SPACE_IO, 0x50, 0x57, 0, 0xff00, astrocade_sound2_w);
 	memory_install_write8_matchmask_handler(0, ADDRESS_SPACE_IO, 0x58, 0xff, 0, 0, astrocade_soundblock2_w);
 }
+
 static DRIVER_INIT( demndrgn )
 {
 	memory_install_read8_handler(0, ADDRESS_SPACE_IO, 0x10, 0x10, 0, 0xff00, input_port_0_r );
@@ -1193,6 +1223,7 @@ static DRIVER_INIT( demndrgn )
 	memory_install_write8_handler(0, ADDRESS_SPACE_IO, 0xc0, 0xc5, 0, 0xff00, profpac_screenram_ctrl_w );
 	memory_install_write8_handler(0, ADDRESS_SPACE_IO, 0xf3, 0xf3, 0, 0xff00, profpac_banksw_w);
 }
+
 static DRIVER_INIT( profpac )
 {
 	memory_install_read8_matchmask_handler(0, ADDRESS_SPACE_IO, 0x14, 0xff, 0, 0, profpac_io_1_r);
@@ -1207,13 +1238,19 @@ static DRIVER_INIT( profpac )
 }
 
 
-/* GAME(YEAR,NAME,PARENT,MACHINE,INPUT,INIT,MONITOR,COMPANY,FULLNAME) */
-GAME( 1978, seawolf2, 0,    seawolf2, seawolf2, seawolf2, ROT0,   "Midway", "Sea Wolf II", GAME_IMPERFECT_SOUND )
-GAME( 1980, spacezap, 0,    spacezap, spacezap, spacezap, ROT0,   "Midway", "Space Zap", 0 )
-GAME( 1980, ebases,   0,    ebases,   ebases,   ebases,   ROT0,   "Midway", "Extra Bases", 0 )
-GAME( 1980, wow,      0,    wow,      wow,      wow,      ROT0,   "Midway", "Wizard of Wor", 0 )
-GAME( 1981, gorf,     0,    gorf,     gorf,     gorf,     ROT270, "Midway", "Gorf", 0 )
-GAME( 1981, gorfpgm1, gorf, gorf,     gorf,     gorf,     ROT270, "Midway", "Gorf (Program 1)", 0 )
-GAME( 1981, robby,    0,    robby,    robby,    robby,    ROT0,   "Bally Midway", "Robby Roto", 0 )
-GAME( 1982, demndrgn, 0,    demndrgn, demndrgn, demndrgn, ROT0,   "Bally Midway", "Demons and Dragons (prototype)", GAME_NO_SOUND )
-GAME( 1983, profpac,  0,    profpac,  profpac,  profpac,  ROT0,   "Bally Midway", "Professor PacMan", 0 )
+
+/*************************************
+ *
+ *  Game driver(s)
+ *
+ *************************************/
+
+GAME( 1978, seawolf2, 0,    seawolf2, seawolf2, seawolf2, ROT0,   "Midway", "Sea Wolf II", GAME_IMPERFECT_SOUND | GAME_SUPPORTS_SAVE )
+GAME( 1980, spacezap, 0,    spacezap, spacezap, spacezap, ROT0,   "Midway", "Space Zap", GAME_SUPPORTS_SAVE )
+GAME( 1980, ebases,   0,    ebases,   ebases,   ebases,   ROT0,   "Midway", "Extra Bases", GAME_SUPPORTS_SAVE )
+GAME( 1980, wow,      0,    wow,      wow,      wow,      ROT0,   "Midway", "Wizard of Wor", GAME_SUPPORTS_SAVE )
+GAME( 1981, gorf,     0,    gorf,     gorf,     gorf,     ROT270, "Midway", "Gorf", GAME_SUPPORTS_SAVE )
+GAME( 1981, gorfpgm1, gorf, gorf,     gorf,     gorf,     ROT270, "Midway", "Gorf (Program 1)", GAME_SUPPORTS_SAVE )
+GAME( 1981, robby,    0,    robby,    robby,    robby,    ROT0,   "Bally Midway", "Robby Roto", GAME_SUPPORTS_SAVE )
+GAME( 1982, demndrgn, 0,    demndrgn, demndrgn, demndrgn, ROT0,   "Bally Midway", "Demons and Dragons (prototype)", GAME_NO_SOUND | GAME_SUPPORTS_SAVE )
+GAME( 1983, profpac,  0,    profpac,  profpac,  profpac,  ROT0,   "Bally Midway", "Professor PacMan", GAME_SUPPORTS_SAVE )
