@@ -57,14 +57,13 @@ I/O C  ;AY-3-8910 Data Read Reg.
 ***************************************************************************/
 
 #include "driver.h"
-#include "vidhrdw/generic.h"
 #include "sound/ay8910.h"
 #include "sound/5110intf.h"
 #include "sound/tms5110.h"
 
 
 extern READ8_HANDLER( bagman_pal16r6_r );
-extern MACHINE_INIT( bagman );
+extern MACHINE_RESET( bagman );
 extern WRITE8_HANDLER( bagman_pal16r6_w );
 
 
@@ -462,7 +461,7 @@ INPUT_PORTS_END
 
 
 
-static gfx_layout charlayout =
+static const gfx_layout charlayout =
 {
 	8,8,	/* 8*8 characters */
 	512,	/* 512 characters */
@@ -472,7 +471,7 @@ static gfx_layout charlayout =
 	{ 0*8, 1*8, 2*8, 3*8, 4*8, 5*8, 6*8, 7*8 },
 	8*8 /* every char takes 8 consecutive bytes */
 };
-static gfx_layout spritelayout =
+static const gfx_layout spritelayout =
 {
 	16,16,	/* 16*16 sprites */
 	128,	/* 128 sprites */
@@ -487,7 +486,7 @@ static gfx_layout spritelayout =
 
 
 
-static gfx_decode gfxdecodeinfo[] =
+static const gfx_decode gfxdecodeinfo[] =
 {
 	{ REGION_GFX1, 0, &charlayout,		0, 16 },	/* char set #1 */
 	{ REGION_GFX1, 0, &spritelayout,	0, 16 },	/* sprites */
@@ -495,7 +494,7 @@ static gfx_decode gfxdecodeinfo[] =
 	{ -1 } /* end of array */
 };
 
-static gfx_decode pickin_gfxdecodeinfo[] =
+static const gfx_decode pickin_gfxdecodeinfo[] =
 {
 	{ REGION_GFX1, 0, &charlayout,		0, 16 },	/* char set #1 */
 	{ REGION_GFX1, 0, &spritelayout,	0, 16 },	/* sprites */
@@ -528,7 +527,7 @@ static MACHINE_DRIVER_START( bagman )
 	MDRV_FRAMES_PER_SECOND(60)
 	MDRV_VBLANK_DURATION(DEFAULT_60HZ_VBLANK_DURATION)
 
-	MDRV_MACHINE_INIT(bagman)
+	MDRV_MACHINE_RESET(bagman)
 
 	/* video hardware */
 	MDRV_VIDEO_ATTRIBUTES(VIDEO_TYPE_RASTER)
@@ -564,7 +563,7 @@ static MACHINE_DRIVER_START( pickin )
 	MDRV_FRAMES_PER_SECOND(60)
 	MDRV_VBLANK_DURATION(DEFAULT_60HZ_VBLANK_DURATION)
 
-	MDRV_MACHINE_INIT(bagman)
+	MDRV_MACHINE_RESET(bagman)
 
 	/* video hardware */
 	MDRV_VIDEO_ATTRIBUTES(VIDEO_TYPE_RASTER)
@@ -614,7 +613,7 @@ static MACHINE_DRIVER_START( botanic )
 	MDRV_FRAMES_PER_SECOND(60)
 	MDRV_VBLANK_DURATION(DEFAULT_60HZ_VBLANK_DURATION)
 
-	MDRV_MACHINE_INIT(bagman)
+	MDRV_MACHINE_RESET(bagman)
 
 	/* video hardware */
 	MDRV_VIDEO_ATTRIBUTES(VIDEO_TYPE_RASTER)
