@@ -101,7 +101,6 @@
 #include "cpu/asap/asap.h"
 #include "machine/atarigen.h"
 #include "sndhrdw/atarijsa.h"
-#include "vidhrdw/generic.h"
 #include "beathead.h"
 
 
@@ -159,7 +158,7 @@ static void scanline_callback(int scanline)
 }
 
 
-static MACHINE_INIT( beathead )
+static MACHINE_RESET( beathead )
 {
 	/* reset the common subsystems */
 	atarigen_eeprom_reset();
@@ -434,7 +433,7 @@ static MACHINE_DRIVER_START( beathead )
 	MDRV_FRAMES_PER_SECOND(60)
 	MDRV_VBLANK_DURATION((int)(((262. - 240.) / 262.) * 1000000. / 60.))
 
-	MDRV_MACHINE_INIT(beathead)
+	MDRV_MACHINE_RESET(beathead)
 	MDRV_NVRAM_HANDLER(generic_1fill)
 
 	/* video hardware */
