@@ -93,7 +93,6 @@ Stephh's notes (based on the games M68000 code and some tests) :
 **************************************************************************/
 
 #include "driver.h"
-#include "vidhrdw/generic.h"
 #include "sndhrdw/seibu.h"
 #include "cpu/z80/z80.h"
 #include "sound/3812intf.h"
@@ -432,7 +431,7 @@ INPUT_PORTS_END
 
 /* Graphics Layouts */
 
-static struct GfxLayout textlayout =
+static const gfx_layout textlayout =
 {
 	8,8,	/* 8*8 characters */
 	4096,	/* 4096 characters */
@@ -443,7 +442,7 @@ static struct GfxLayout textlayout =
 	16*8	/* every char takes 16 consecutive bytes */
 };
 
-static struct GfxLayout backlayout =
+static const gfx_layout backlayout =
 {
 	16,16,	/* 16*16 sprites  */
 	4096,	/* 4096 sprites */
@@ -456,7 +455,7 @@ static struct GfxLayout backlayout =
 	128*8	/* every sprite takes 128 consecutive bytes */
 };
 
-static struct GfxLayout spritelayout =
+static const gfx_layout spritelayout =
 {
 	16,16,	/* 16*16 sprites  */
 	RGN_FRAC(1,1),
@@ -469,7 +468,7 @@ static struct GfxLayout spritelayout =
 	128*8	/* every sprite takes 128 consecutive bytes */
 };
 
-static struct GfxLayout weststry_textlayout =
+static const gfx_layout weststry_textlayout =
 {
 	8,8,	/* 8*8 sprites */
 	4096,	/* 4096 sprites */
@@ -480,7 +479,7 @@ static struct GfxLayout weststry_textlayout =
 	8*8	/* every sprite takes 8 consecutive bytes */
 };
 
-static struct GfxLayout weststry_backlayout =
+static const gfx_layout weststry_backlayout =
 {
 	16,16,	/* 16*16 sprites */
 	4096,	/* 4096 sprites */
@@ -493,7 +492,7 @@ static struct GfxLayout weststry_backlayout =
 	32*8	/* every sprite takes 32 consecutive bytes */
 };
 
-static struct GfxLayout weststry_spritelayout =
+static const gfx_layout weststry_spritelayout =
 {
 	16,16,	/* 16*16 sprites */
 	8192,	/* 8192 sprites */
@@ -508,7 +507,7 @@ static struct GfxLayout weststry_spritelayout =
 
 /* Graphics Decode Info */
 
-static struct GfxDecodeInfo bloodbro_gfxdecodeinfo[] =
+static const gfx_decode bloodbro_gfxdecodeinfo[] =
 {
 	{ REGION_GFX1, 0x00000, &textlayout,   0x70*16,  0x10 }, /* Text */
 	{ REGION_GFX2, 0x00000, &backlayout,   0x40*16,  0x10 }, /* Background */
@@ -517,7 +516,7 @@ static struct GfxDecodeInfo bloodbro_gfxdecodeinfo[] =
 	{ -1 }
 };
 
-static struct GfxDecodeInfo weststry_gfxdecodeinfo[] =
+static const gfx_decode weststry_gfxdecodeinfo[] =
 {
 	{ REGION_GFX1, 0x00000, &weststry_textlayout,     16*16,  0x10 },
 	{ REGION_GFX2, 0x00000, &weststry_backlayout,     48*16,  0x10 },
@@ -544,7 +543,7 @@ static MACHINE_DRIVER_START( bloodbro )
 	MDRV_FRAMES_PER_SECOND(60)
 	MDRV_VBLANK_DURATION(DEFAULT_REAL_60HZ_VBLANK_DURATION)
 
-	MDRV_MACHINE_INIT(seibu_sound_1)
+	MDRV_MACHINE_RESET(seibu_sound_1)
 
 	/* video hardware */
 	MDRV_VIDEO_ATTRIBUTES(VIDEO_TYPE_RASTER)
@@ -722,7 +721,7 @@ static DRIVER_INIT( weststry )
 
 /* Game Drivers */
 
-GAMEX(1990, bloodbro, 0,        bloodbro, bloodbro, 0,        ROT0,   "Tad", "Blood Bros. (set 1)", GAME_NO_COCKTAIL )
-GAMEX(1990, bloodbra, bloodbro, bloodbro, bloodbro, 0,        ROT0,   "Tad", "Blood Bros. (set 2)", GAME_NO_COCKTAIL )
-GAMEX(1990, weststry, bloodbro, weststry, weststry, weststry, ROT0,   "bootleg", "West Story", GAME_NO_COCKTAIL | GAME_NO_SOUND )
-GAME( 1990, skysmash, 0,        skysmash, skysmash, 0,        ROT270, "Nihon System", "Sky Smasher" )
+GAME( 1990, bloodbro, 0,        bloodbro, bloodbro, 0,        ROT0,   "Tad", "Blood Bros. (set 1)", GAME_NO_COCKTAIL )
+GAME( 1990, bloodbra, bloodbro, bloodbro, bloodbro, 0,        ROT0,   "Tad", "Blood Bros. (set 2)", GAME_NO_COCKTAIL )
+GAME( 1990, weststry, bloodbro, weststry, weststry, weststry, ROT0,   "bootleg", "West Story", GAME_NO_COCKTAIL | GAME_NO_SOUND )
+GAME( 1990, skysmash, 0,        skysmash, skysmash, 0,        ROT270, "Nihon System", "Sky Smasher", 0 )
