@@ -9,7 +9,6 @@ driver by Nicola Salmoria
 ***************************************************************************/
 
 #include "driver.h"
-#include "vidhrdw/generic.h"
 #include "cpu/m6809/m6809.h"
 #include "vidhrdw/konamiic.h"
 #include "sound/k007232.h"
@@ -59,7 +58,7 @@ static READ8_HANDLER( bottom9_bankedram2_r )
 static WRITE8_HANDLER( bottom9_bankedram2_w )
 {
 	if (K052109_selected) K052109_051960_w(offset + 0x2000,data);
-	else paletteram_xBBBBBGGGGGRRRRR_swap_w(offset,data);
+	else paletteram_xBBBBBGGGGGRRRRR_be_w(offset,data);
 }
 
 static WRITE8_HANDLER( bankswitch_w )
@@ -68,12 +67,12 @@ static WRITE8_HANDLER( bankswitch_w )
 	int offs;
 
 	/* bit 0 = RAM bank */
-if ((data & 1) == 0) usrintf_showmessage("bankswitch RAM bank 0");
+if ((data & 1) == 0) ui_popup("bankswitch RAM bank 0");
 
 	/* bit 1-4 = ROM bank */
 	if (data & 0x10) offs = 0x20000 + (data & 0x06) * 0x1000;
 	else offs = 0x10000 + (data & 0x0e) * 0x1000;
-	cpu_setbank(1,&RAM[offs]);
+	memory_set_bankptr(1,&RAM[offs]);
 }
 
 static WRITE8_HANDLER( bottom9_1f90_w )
@@ -624,6 +623,6 @@ static DRIVER_INIT( bottom9 )
 
 
 
-GAME( 1989, bottom9,  0,       bottom9, bottom9,  bottom9, ROT0, "Konami", "Bottom of the Ninth (version T)" )
-GAME( 1989, bottom9n, bottom9, bottom9, bottom9,  bottom9, ROT0, "Konami", "Bottom of the Ninth (version N)" )
-GAME( 1989, mstadium, bottom9, bottom9, mstadium, bottom9, ROT0, "Konami", "Main Stadium (Japan)" )
+GAME( 1989, bottom9,  0,       bottom9, bottom9,  bottom9, ROT0, "Konami", "Bottom of the Ninth (version T)", 0 )
+GAME( 1989, bottom9n, bottom9, bottom9, bottom9,  bottom9, ROT0, "Konami", "Bottom of the Ninth (version N)", 0 )
+GAME( 1989, mstadium, bottom9, bottom9, mstadium, bottom9, ROT0, "Konami", "Main Stadium (Japan)", 0 )
