@@ -83,7 +83,7 @@ static PALETTE_INIT( boxer )
 }
 
 
-static MACHINE_INIT( boxer )
+static MACHINE_RESET( boxer )
 {
 	timer_set(cpu_getscanlinetime(0), 0, periodic_callback);
 
@@ -255,7 +255,7 @@ INPUT_PORTS_START( boxer )
 INPUT_PORTS_END
 
 
-static gfx_layout tile_layout =
+static const gfx_layout tile_layout =
 {
 	8, 8,
 	64,
@@ -271,7 +271,7 @@ static gfx_layout tile_layout =
 };
 
 
-static gfx_layout sprite_layout =
+static const gfx_layout sprite_layout =
 {
 	8, 8,
 	64,
@@ -287,7 +287,7 @@ static gfx_layout sprite_layout =
 };
 
 
-static gfx_decode gfxdecodeinfo[] =
+static const gfx_decode gfxdecodeinfo[] =
 {
 	{ REGION_GFX1, 0, &sprite_layout, 0, 1 },
 	{ REGION_GFX2, 0, &sprite_layout, 0, 1 },
@@ -305,7 +305,7 @@ static MACHINE_DRIVER_START(boxer)
 	MDRV_FRAMES_PER_SECOND(60)
 
 	/* video hardware */
-	MDRV_MACHINE_INIT(boxer)
+	MDRV_MACHINE_RESET(boxer)
 
 	MDRV_VIDEO_ATTRIBUTES(VIDEO_TYPE_RASTER)
 	MDRV_SCREEN_SIZE(256, 262)
