@@ -23,7 +23,6 @@ Known issues:
 /* Directives */
 
 #include "driver.h"
-#include "vidhrdw/generic.h"
 #include "cpu/m6809/m6809.h"
 #include "cpu/m6502/m6502.h"
 #include "sound/ay8910.h"
@@ -349,7 +348,7 @@ INPUT_PORTS_END
 /***************************************************************************** */
 /* Graphics Layouts */
 
-static gfx_layout charlayout =
+static const gfx_layout charlayout =
 {
 	8, 8,
 	256,
@@ -360,7 +359,7 @@ static gfx_layout charlayout =
 	8*8
 };
 
-static gfx_layout spritelayout =
+static const gfx_layout spritelayout =
 {
 	16, 16,
 	512,
@@ -373,7 +372,7 @@ static gfx_layout spritelayout =
 };
 
 
-static gfx_decode gfxdecodeinfo[] =
+static const gfx_decode gfxdecodeinfo[] =
 {
 	{ REGION_GFX1,  0, &charlayout,       0x00, 1 }, /* chars */
 	{ REGION_GFX2,  0, &spritelayout,     0x20, 2 }, /* sprites */
@@ -385,7 +384,7 @@ static gfx_decode gfxdecodeinfo[] =
 /***************************************************************************** */
 /* Hardware Definitions */
 
-MACHINE_INIT( bwing )
+MACHINE_RESET( bwing )
 {
 	bwp3_nmimask = 0;
 	fftail = ffhead = ffcount = 0;
