@@ -196,7 +196,6 @@
 ***************************************************************************/
 
 #include "driver.h"
-#include "vidhrdw/generic.h"
 #include "vidhrdw/vector.h"
 #include "vidhrdw/avgdvg.h"
 #include "machine/mathbox.h"
@@ -210,10 +209,34 @@
 #define IN0_VG_HALT (1<<6)
 
 
+static UINT8 analog_data;
+
 UINT8 rb_input_select;
 
 
 
+/*************************************
+ *
+ *  Save state registration
+ *
+ *************************************/
+
+static MACHINE_START( bzone )
+{
+	state_save_register_global(analog_data);
+	return 0;
+}
+
+
+static MACHINE_START( redbaron )
+{
+	state_save_register_global(analog_data);
+	state_save_register_global(rb_input_select);
+	return 0;
+}
+
+
+
 /*************************************
  *
  *  Interrupt handling
@@ -309,7 +332,7 @@ static ADDRESS_MAP_START( bzone_map, ADDRESS_SPACE_PROGRAM, 8 )
 	AM_RANGE(0x1820, 0x182f) AM_READWRITE(pokey1_r, pokey1_w)
 	AM_RANGE(0x1840, 0x1840) AM_WRITE(bzone_sounds_w)
 	AM_RANGE(0x1860, 0x187f) AM_WRITE(mb_go_w)
-	AM_RANGE(0x2000, 0x2fff) AM_RAM AM_BASE(&vectorram) AM_SIZE(&vectorram_size)
+	AM_RANGE(0x2000, 0x2fff) AM_RAM AM_BASE(&vectorram) AM_SIZE(&vectorram_size) AM_REGION(REGION_CPU1, 0x2000)
 	AM_RANGE(0x3000, 0x7fff) AM_ROM
 ADDRESS_MAP_END
 
@@ -333,7 +356,7 @@ static ADDRESS_MAP_START( redbaron_map, ADDRESS_SPACE_PROGRAM, 8 )
 	AM_RANGE(0x1810, 0x181f) AM_READWRITE(pokey1_r, pokey1_w)
 	AM_RANGE(0x1820, 0x185f) AM_READWRITE(atari_vg_earom_r, atari_vg_earom_w)
 	AM_RANGE(0x1860, 0x187f) AM_WRITE(mb_go_w)
-	AM_RANGE(0x2000, 0x2fff) AM_RAM AM_BASE(&vectorram) AM_SIZE(&vectorram_size)
+	AM_RANGE(0x2000, 0x2fff) AM_RAM AM_BASE(&vectorram) AM_SIZE(&vectorram_size) AM_REGION(REGION_CPU1, 0x2000)
 	AM_RANGE(0x3000, 0x7fff) AM_ROM
 ADDRESS_MAP_END
 
@@ -564,6 +587,8 @@ static MACHINE_DRIVER_START( bzone )
 
 	MDRV_FRAMES_PER_SECOND(40)
 
+	MDRV_MACHINE_START(bzone)
+
 	/* video hardware */
 	MDRV_VIDEO_ATTRIBUTES(VIDEO_TYPE_VECTOR | VIDEO_RGB_DIRECT)
 	MDRV_SCREEN_SIZE(400, 300)
@@ -607,6 +632,8 @@ static MACHINE_DRIVER_START( redbaron )
 	MDRV_CPU_PROGRAM_MAP(redbaron_map,0)
 	MDRV_CPU_VBLANK_INT(bzone_interrupt,4) /* 5.4ms */
 
+	MDRV_MACHINE_START(redbaron)
+
 	MDRV_FRAMES_PER_SECOND(45)
 	MDRV_NVRAM_HANDLER(atari_vg)
 
@@ -714,8 +741,6 @@ ROM_END
  *
  *************************************/
 
-static UINT8 analog_data;
-
 static READ8_HANDLER( analog_data_r )
 {
 	return analog_data;
