@@ -41,7 +41,7 @@ COLORRAM (Colors)
 ******************************************************************/
 
 #include "driver.h"
-#include "vidhrdw/generic.h"
+#include "streams.h"
 #include "cpu/z80/z80.h"
 #include "sndhrdw/seibu.h"
 #include "sound/2151intf.h"
@@ -56,7 +56,7 @@ WRITE16_HANDLER( cabal_text_videoram16_w );
 
 static int cabal_sound_command1, cabal_sound_command2;
 
-static MACHINE_INIT( cabalbl )
+static MACHINE_RESET( cabalbl )
 {
 	cabal_sound_command1 = cabal_sound_command2 = 0xff;
 }
@@ -473,7 +473,7 @@ INPUT_PORTS_END
 
 
 
-static gfx_layout text_layout =
+static const gfx_layout text_layout =
 {
 	8,8,
 	RGN_FRAC(1,1),
@@ -484,7 +484,7 @@ static gfx_layout text_layout =
 	16*8
 };
 
-static gfx_layout tile_layout =
+static const gfx_layout tile_layout =
 {
 	16,16,
 	RGN_FRAC(1,1),
@@ -497,7 +497,7 @@ static gfx_layout tile_layout =
 	64*16
 };
 
-static gfx_layout sprite_layout =
+static const gfx_layout sprite_layout =
 {
 	16,16,
 	RGN_FRAC(1,1),
@@ -510,7 +510,7 @@ static gfx_layout sprite_layout =
 	64*16
 };
 
-static gfx_decode cabal_gfxdecodeinfo[] =
+static const gfx_decode cabal_gfxdecodeinfo[] =
 {
 	{ REGION_GFX1, 0, &text_layout,		0, 1024/4 },
 	{ REGION_GFX2, 0, &tile_layout,		32*16, 16 },
@@ -558,7 +558,7 @@ static MACHINE_DRIVER_START( cabal )
 	MDRV_FRAMES_PER_SECOND(60)
 	MDRV_VBLANK_DURATION(DEFAULT_REAL_60HZ_VBLANK_DURATION)
 
-	MDRV_MACHINE_INIT(seibu_sound_1)
+	MDRV_MACHINE_RESET(seibu_sound_1)
 
 	/* video hardware */
 	MDRV_VIDEO_ATTRIBUTES(VIDEO_TYPE_RASTER)
@@ -604,7 +604,7 @@ static MACHINE_DRIVER_START( cabalbl )
 	MDRV_VBLANK_DURATION(DEFAULT_REAL_60HZ_VBLANK_DURATION)
 	MDRV_INTERLEAVE(10)
 
-	MDRV_MACHINE_INIT(cabalbl)
+	MDRV_MACHINE_RESET(cabalbl)
 
 	/* video hardware */
 	MDRV_VIDEO_ATTRIBUTES(VIDEO_TYPE_RASTER)
@@ -644,7 +644,7 @@ ROM_START( cabal )
 	ROM_LOAD16_BYTE( "k7_512.bin",      0x20000, 0x10000, CRC(562031a2) SHA1(ed5ef50a66c7797a7f345e479162cf83d6777f7c) )
 	ROM_LOAD16_BYTE( "k6_512.bin",      0x20001, 0x10000, CRC(4fda2856) SHA1(a213cb7443cdccbad3f2610e8d42b2e149cbedb9) )
 
-	ROM_REGION( 0x10000*2, REGION_CPU2, 0 )	/* 64k for sound cpu code */
+	ROM_REGION( 0x10000, REGION_CPU2, 0 )	/* 64k for sound cpu code */
 	ROM_LOAD( "4-3n",         0x0000, 0x2000, CRC(4038eff2) SHA1(0bcafc1b78c3bef9a0e9b822c482ea4a942fd180) )
 	ROM_LOAD( "3-3p",         0x8000, 0x8000, CRC(d9defcbf) SHA1(f26b10b1dbe5aa6446f70fd18e5f1379455578ec) )
 
@@ -673,7 +673,7 @@ ROM_START( cabal2 )
 	ROM_LOAD16_BYTE( "8-7k",            0x20000, 0x10000, CRC(4c24ed9a) SHA1(f0fc25c3e7dc8ac71fdad3e91ab618cd7a037123) )
 	ROM_LOAD16_BYTE( "6-6k",            0x20001, 0x10000, CRC(681620e8) SHA1(c9eacfb55059986dbecc2fae1339069a852f917b) )
 
-	ROM_REGION( 0x10000*2, REGION_CPU2, 0 )	/* 64k for sound cpu code */
+	ROM_REGION( 0x10000, REGION_CPU2, 0 )	/* 64k for sound cpu code */
 	ROM_LOAD( "4-3n",         0x0000, 0x2000, CRC(4038eff2) SHA1(0bcafc1b78c3bef9a0e9b822c482ea4a942fd180) )
 	ROM_LOAD( "3-3p",         0x8000, 0x8000, CRC(d9defcbf) SHA1(f26b10b1dbe5aa6446f70fd18e5f1379455578ec) )
 
