@@ -78,7 +78,6 @@ Notes:
 */
 
 #include "driver.h"
-#include "vidhrdw/generic.h"
 #include "machine/segacrpt.h"
 #include "sound/ay8910.h"
 
@@ -206,11 +205,12 @@ static WRITE8_HANDLER( bogus_w )
 }
 
 static ADDRESS_MAP_START( calorie_map, ADDRESS_SPACE_PROGRAM, 8 )
-	AM_RANGE(0x0000, 0xbfff) AM_ROM
+	AM_RANGE(0x0000, 0x7fff) AM_ROM
+	AM_RANGE(0x8000, 0xbfff) AM_ROM
 	AM_RANGE(0xc000, 0xcfff) AM_RAM
 	AM_RANGE(0xd000, 0xd7ff) AM_RAM AM_WRITE(calorie_fg_w) AM_BASE(&calorie_fg)
 	AM_RANGE(0xd800, 0xdbff) AM_RAM AM_BASE(&calorie_sprites)
-	AM_RANGE(0xdc00, 0xdcff) AM_RAM AM_WRITE(paletteram_xxxxBBBBGGGGRRRR_w) AM_BASE(&paletteram)
+	AM_RANGE(0xdc00, 0xdcff) AM_RAM AM_WRITE(paletteram_xxxxBBBBGGGGRRRR_le_w) AM_BASE(&paletteram)
 	AM_RANGE(0xde00, 0xde00) AM_WRITE(calorie_bg_w)
 	AM_RANGE(0xf000, 0xf000) AM_READ(input_port_0_r)
 	AM_RANGE(0xf001, 0xf001) AM_READ(input_port_1_r)
@@ -320,7 +320,7 @@ INPUT_PORTS_END
 
 
 
-static gfx_layout tiles8x8_layout =
+static const gfx_layout tiles8x8_layout =
 {
 	8,8,
 	RGN_FRAC(1,3),
@@ -331,7 +331,7 @@ static gfx_layout tiles8x8_layout =
 	8*8
 };
 
-static gfx_layout tiles16x16_layout =
+static const gfx_layout tiles16x16_layout =
 {
 	16,16,
 	RGN_FRAC(1,3),
@@ -343,7 +343,7 @@ static gfx_layout tiles16x16_layout =
 	8*32
 };
 
-static gfx_layout tiles32x32_layout =
+static const gfx_layout tiles32x32_layout =
 {
 	32,32,
 	RGN_FRAC(1,3),
@@ -360,7 +360,7 @@ static gfx_layout tiles32x32_layout =
 	128*8
 };
 
-static gfx_decode gfxdecodeinfo[] =
+static const gfx_decode gfxdecodeinfo[] =
 {
 	{ REGION_GFX2, 0, &tiles8x8_layout,   0, 16 },
 	{ REGION_GFX3, 0, &tiles16x16_layout, 0, 16 },
@@ -408,7 +408,7 @@ MACHINE_DRIVER_END
 
 
 ROM_START( calorie )
-	ROM_REGION( 0x20000, REGION_CPU1, 0 )
+	ROM_REGION( 0x10000, REGION_CPU1, 0 )
 	ROM_LOAD( "epr10072.1j", 0x00000, 0x4000, CRC(ade792c1) SHA1(6ea5afb00a87037d502c17adda7e4060d12680d7) )
 	ROM_LOAD( "epr10073.1k", 0x04000, 0x4000, CRC(b53e109f) SHA1(a41c5affe917232e7adf40d7c15cff778b197e90) )
 	ROM_LOAD( "epr10074.1m", 0x08000, 0x4000, CRC(a08da685) SHA1(69f9cfebc771312dbb1726350c2d9e9e8c46353f) )
@@ -436,13 +436,12 @@ ROM_START( calorie )
 ROM_END
 
 ROM_START( calorieb )
-	ROM_REGION( 0x20000, REGION_CPU1, 0 )
+	ROM_REGION( 0x1c000, REGION_CPU1, 0 )
 	ROM_LOAD( "12.bin",      0x10000, 0x4000, CRC(cf5fa69e) SHA1(520d5652e93a672a1fc147295fbd63b873967885) )
 	ROM_CONTINUE(            0x00000, 0x4000 )
 	ROM_LOAD( "13.bin",      0x14000, 0x4000, CRC(52e7263f) SHA1(4d684c9e3f08ddb18b0b3b982aba82d3c809a633) )
 	ROM_CONTINUE(            0x04000, 0x4000 )
-	ROM_LOAD( "epr10074.1m", 0x18000, 0x4000, CRC(a08da685) SHA1(69f9cfebc771312dbb1726350c2d9e9e8c46353f) )
-	ROM_RELOAD(              0x08000, 0x4000 )
+	ROM_LOAD( "epr10074.1m", 0x08000, 0x4000, CRC(a08da685) SHA1(69f9cfebc771312dbb1726350c2d9e9e8c46353f) )
 
 	ROM_REGION( 0x10000, REGION_CPU2, 0 )
 	ROM_LOAD( "epr10075.4d", 0x0000, 0x4000, CRC(ca547036) SHA1(584a65482f2b92a4c08c37560450d6db68a56c7b) )
@@ -474,10 +473,7 @@ static DRIVER_INIT( calorie )
 
 static DRIVER_INIT( calorieb )
 {
-	unsigned char *rom = memory_region(REGION_CPU1);
-	int diff = memory_region_length(REGION_CPU1) / 2;
-
-	memory_set_opcode_base(0,rom+diff);
+	memory_set_decrypted_region(0, 0x0000, 0x7fff, memory_region(REGION_CPU1) + 0x10000);
 }
 
 
