@@ -8,9 +8,6 @@
         * Millipede
         * Bulls Eye Darts
 
-    Known bugs:
-        * are coins supposed to take over a second to register?
-
     Centipede sync-prom added by HIGHWAYMAN.
     The prom pcb location is:P4 and is 256x4
     (i need to update the dump, this one is read in 8bit-mode)
@@ -278,10 +275,8 @@
 
 #include "driver.h"
 #include "cpu/s2650/s2650.h"
-#include "vidhrdw/generic.h"
 #include "machine/atari_vg.h"
 #include "centiped.h"
-#include "machine/random.h"
 #include "sound/ay8910.h"
 #include "sound/sn76496.h"
 #include "sound/pokey.h"
@@ -313,7 +308,7 @@ static void generate_interrupt(int scanline)
 }
 
 
-static MACHINE_INIT( centiped )
+static MACHINE_RESET( centiped )
 {
 	timer_set(cpu_getscanlinetime(0), 0, generate_interrupt);
 	cpunum_set_input_line(0, 0, CLEAR_LINE);
@@ -321,9 +316,9 @@ static MACHINE_INIT( centiped )
 }
 
 
-static MACHINE_INIT( magworm )
+static MACHINE_RESET( magworm )
 {
-	machine_init_centiped();
+	machine_reset_centiped();
 
 	/* kludge: clear RAM so that magworm can be reset cleanly */
 	memset(rambase, 0, 0x400);
@@ -1033,8 +1028,8 @@ INPUT_PORTS_START( warlords )
 	PORT_SERVICE( 0x20, IP_ACTIVE_LOW )
 	PORT_BIT( 0x40, IP_ACTIVE_HIGH, IPT_VBLANK )
 	PORT_DIPNAME( 0x80, 0x00, DEF_STR( Cabinet ))
-	PORT_DIPSETTING(    0x80, "Upright (no overlay)" )
-	PORT_DIPSETTING(    0x00, "Cocktail (overlay)" )
+	PORT_DIPSETTING(    0x80, "Upright (overlay)" )
+	PORT_DIPSETTING(    0x00, "Cocktail (no overlay)" )
 
 	PORT_START	/* IN1 */
 	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_BUTTON1 ) PORT_PLAYER(1)
@@ -1189,7 +1184,7 @@ INPUT_PORTS_END
  *
  *************************************/
 
-static gfx_layout charlayout =
+static const gfx_layout charlayout =
 {
 	8,8,
 	RGN_FRAC(1,2),
@@ -1200,7 +1195,7 @@ static gfx_layout charlayout =
 	8*8
 };
 
-static gfx_layout spritelayout =
+static const gfx_layout spritelayout =
 {
 	8,16,
 	RGN_FRAC(1,2),
@@ -1212,14 +1207,14 @@ static gfx_layout spritelayout =
 	16*8
 };
 
-static gfx_decode centiped_gfxdecodeinfo[] =
+static const gfx_decode centiped_gfxdecodeinfo[] =
 {
 	{ REGION_GFX1, 0, &charlayout,     0, 1 },
 	{ REGION_GFX1, 0, &spritelayout,   4, 4*4*4 },
 	{ -1 }
 };
 
-static gfx_decode milliped_gfxdecodeinfo[] =
+static const gfx_decode milliped_gfxdecodeinfo[] =
 {
 	{ REGION_GFX1, 0, &charlayout,     0, 4 },
 	{ REGION_GFX1, 0, &spritelayout, 4*4, 4*4*4*4 },
@@ -1234,7 +1229,7 @@ static gfx_decode milliped_gfxdecodeinfo[] =
  *
  *************************************/
 
-static gfx_layout warlords_charlayout =
+static const gfx_layout warlords_charlayout =
 {
 	8,8,
 	RGN_FRAC(1,4),
@@ -1245,7 +1240,7 @@ static gfx_layout warlords_charlayout =
 	8*8
 };
 
-static gfx_decode warlords_gfxdecodeinfo[] =
+static const gfx_decode warlords_gfxdecodeinfo[] =
 {
 	{ REGION_GFX1, 0x000, &warlords_charlayout, 0,   8 },
 	{ REGION_GFX1, 0x200, &warlords_charlayout, 8*4, 8*4 },
@@ -1302,7 +1297,7 @@ static MACHINE_DRIVER_START( centiped )
 	MDRV_FRAMES_PER_SECOND(60)
 	MDRV_VBLANK_DURATION(1460)
 
-	MDRV_MACHINE_INIT(centiped)
+	MDRV_MACHINE_RESET(centiped)
 	MDRV_NVRAM_HANDLER(atari_vg)
 
 	/* video hardware */
@@ -1354,7 +1349,7 @@ static MACHINE_DRIVER_START( magworm )
 
 	/* basic machine hardware */
 	MDRV_IMPORT_FROM(centiped)
-	MDRV_MACHINE_INIT(magworm)
+	MDRV_MACHINE_RESET(magworm)
 
 	/* sound hardware */
 	MDRV_SOUND_REPLACE("pokey", AY8910, 12096000/8)
