@@ -9,8 +9,9 @@
 #include "sound/ay8910.h"
 
 /* machine/chaknpop.c */
+extern UINT8 *chaknpop_ram;
 DRIVER_INIT( chaknpop );
-MACHINE_INIT( chaknpop );
+MACHINE_RESET( chaknpop );
 READ8_HANDLER( chaknpop_mcu_portA_r );
 READ8_HANDLER( chaknpop_mcu_portB_r );
 READ8_HANDLER( chaknpop_mcu_portC_r );
@@ -20,10 +21,10 @@ WRITE8_HANDLER( chaknpop_mcu_portC_w );
 
 
 /* vidhrdw/chaknpop.c */
-extern data8_t *chaknpop_txram;
-extern data8_t *chaknpop_sprram;
+extern UINT8 *chaknpop_txram;
+extern UINT8 *chaknpop_sprram;
 extern size_t chaknpop_sprram_size;
-extern data8_t *chaknpop_attrram;
+extern UINT8 *chaknpop_attrram;
 
 
 PALETTE_INIT( chaknpop );
@@ -88,7 +89,7 @@ ADDRESS_MAP_END
 
 static ADDRESS_MAP_START( writemem, ADDRESS_SPACE_PROGRAM, 8 )
 	AM_RANGE(0x0000, 0x7fff) AM_WRITE(MWA8_ROM)
-	AM_RANGE(0x8000, 0x87ff) AM_WRITE(MWA8_RAM)
+	AM_RANGE(0x8000, 0x87ff) AM_WRITE(MWA8_RAM) AM_BASE(&chaknpop_ram)
 	AM_RANGE(0x8800, 0x8800) AM_WRITE(chaknpop_mcu_portA_w)
 	AM_RANGE(0x8801, 0x8801) AM_WRITE(chaknpop_mcu_portB_w)
 	AM_RANGE(0x8802, 0x8802) AM_WRITE(chaknpop_mcu_portC_w)
@@ -251,7 +252,7 @@ INPUT_PORTS_END
 
 ***************************************************************************/
 
-static struct GfxLayout spritelayout =
+static const gfx_layout spritelayout =
 {
 	16,16,	/* 16*16 characters */
 	256,	/* 256 characters */
@@ -264,7 +265,7 @@ static struct GfxLayout spritelayout =
 	32*8	/* every sprite takes 32 consecutive bytes */
 };
 
-static struct GfxLayout charlayout =
+static const gfx_layout charlayout =
 {
 	8,8,	/* 8*8 characters */
 	1024,	/* 1024 characters */
@@ -275,7 +276,7 @@ static struct GfxLayout charlayout =
 	8*8	/* every char takes 8 consecutive bytes */
 };
 
-static struct GfxDecodeInfo gfxdecodeinfo[] =
+static const gfx_decode gfxdecodeinfo[] =
 {
 	{ REGION_GFX1, 0, &spritelayout, 0,  8 },
 	{ REGION_GFX2, 0, &charlayout,   32, 8 },
@@ -287,14 +288,15 @@ static MACHINE_DRIVER_START( chaknpop )
 	/* basic machine hardware */
 	/* the real board is 3.072MHz, but it is faster for MAME */
 	/*MDRV_CPU_ADD(Z80, 18432000 / 6)      3.072 MHz    */
-	MDRV_CPU_ADD(Z80, 2860000)
+	MDRV_CPU_ADD(Z80, 2350000)
+	/*MDRV_CPU_ADD(Z80, 2760000) */
 	MDRV_CPU_PROGRAM_MAP(readmem,writemem)
 	MDRV_CPU_VBLANK_INT(irq0_line_hold,1)
 
 	MDRV_FRAMES_PER_SECOND(60.606060)
 	MDRV_VBLANK_DURATION(DEFAULT_60HZ_VBLANK_DURATION)
 
-	MDRV_MACHINE_INIT(chaknpop)
+	MDRV_MACHINE_RESET(chaknpop)
 
 	/* video hardware */
 	MDRV_VIDEO_ATTRIBUTES(VIDEO_TYPE_RASTER)
@@ -354,4 +356,4 @@ ROM_END
 
 
 /*  ( YEAR  NAME      PARENT    MACHINE   INPUT     INIT      MONITOR  COMPANY              FULLNAME ) */
-GAME( 1983, chaknpop, 0,        chaknpop, chaknpop, chaknpop, ROT0,    "Taito Corporation", "Chack'n Pop")
+GAME( 1983, chaknpop, 0,        chaknpop, chaknpop, chaknpop, ROT0,    "Taito Corporation", "Chack'n Pop", 0)
