@@ -9,7 +9,6 @@ Tomasz Slanina
 ***************************************************************************/
 
 #include "driver.h"
-#include "vidhrdw/generic.h"
 #include "cpu/z80/z80.h"
 #include "sound/ay8910.h"
 
@@ -28,7 +27,7 @@ static UINT32 address;
 static UINT8 * memory_devices;
 static UINT32  mem_dev_selected; /* an offset within memory_devices area */
 
-MACHINE_INIT (changela)
+MACHINE_RESET (changela)
 {
 	mcu_PC1=0;
 	mcu_PC0=0;
@@ -1074,7 +1073,7 @@ INPUT_PORTS_START( changela )
 INPUT_PORTS_END
 
 
-static gfx_layout tile_layout =
+static const gfx_layout tile_layout =
 {
 	8,16,
 	RGN_FRAC(1,1),
@@ -1086,7 +1085,7 @@ static gfx_layout tile_layout =
 	16*32
 };
 
-static gfx_layout obj1_layout =
+static const gfx_layout obj1_layout =
 {
 	8,8,
 	RGN_FRAC(1,1),
@@ -1097,7 +1096,7 @@ static gfx_layout obj1_layout =
 	8*8*2
 };
 
-static gfx_decode gfxdecodeinfo[] =
+static const gfx_decode gfxdecodeinfo[] =
 {
 	{ REGION_GFX1, 0x0000, &tile_layout, 0, 4 },
 	{ REGION_GFX2, 0x0000, &obj1_layout, 0, 16 },
@@ -1143,7 +1142,7 @@ static MACHINE_DRIVER_START( changela )
 	MDRV_FRAMES_PER_SECOND(60)
 	MDRV_VBLANK_DURATION(DEFAULT_REAL_60HZ_VBLANK_DURATION)
 
-	MDRV_MACHINE_INIT(changela)
+	MDRV_MACHINE_RESET(changela)
 
 	MDRV_VIDEO_ATTRIBUTES(VIDEO_TYPE_RASTER)
 	MDRV_SCREEN_SIZE(32*8, 32*8)
