@@ -69,7 +69,6 @@ Input is unique but has a few similarities to DD2 (the coin inputs)
 
 
 #include "driver.h"
-#include "vidhrdw/generic.h"
 #include "cpu/m6809/m6809.h"
 #include "cpu/z80/z80.h"
 #include "cpu/i8039/i8039.h"
@@ -88,9 +87,9 @@ VIDEO_UPDATE( ddragon );
 
 extern int technos_video_hw;
 extern int ddragon_scrollx_hi, ddragon_scrolly_hi;
-extern data8_t *ddragon_scrollx_lo;
-extern data8_t *ddragon_scrolly_lo;
-extern data8_t *ddragon_bgvideoram,*ddragon_fgvideoram;
+extern UINT8 *ddragon_scrollx_lo;
+extern UINT8 *ddragon_scrolly_lo;
+extern UINT8 *ddragon_bgvideoram,*ddragon_fgvideoram;
 
 /**************** Machine stuff ******************/
 static int sprite_irq, sound_irq, adpcm_sound_irq;
@@ -106,7 +105,7 @@ static int saiyugb1_m5205_clk;
 
 
 
-static MACHINE_INIT( chinagat )
+static MACHINE_RESET( chinagat )
 {
 	technos_video_hw = 1;
 	sprite_irq = M6809_IRQ_LINE;
@@ -130,14 +129,14 @@ WRITE8_HANDLER( chinagat_video_ctrl_w )
 
 static WRITE8_HANDLER( chinagat_bankswitch_w )
 {
-	data8_t *RAM = memory_region(REGION_CPU1);
-	cpu_setbank( 1,&RAM[ 0x10000 + (0x4000 * (data & 7)) ] );
+	UINT8 *RAM = memory_region(REGION_CPU1);
+	memory_set_bankptr( 1,&RAM[ 0x10000 + (0x4000 * (data & 7)) ] );
 }
 
 static WRITE8_HANDLER( chinagat_sub_bankswitch_w )
 {
-	data8_t *RAM = memory_region( REGION_CPU2 );
-	cpu_setbank( 4,&RAM[ 0x10000 + (0x4000 * (data & 7)) ] );
+	UINT8 *RAM = memory_region( REGION_CPU2 );
+	memory_set_bankptr( 4,&RAM[ 0x10000 + (0x4000 * (data & 7)) ] );
 }
 
 static WRITE8_HANDLER( chinagat_sub_IRQ_w )
@@ -183,7 +182,7 @@ static WRITE8_HANDLER( saiyugb1_adpcm_control_w )
 {
 	/* i8748 Port 2 write */
 
-	data8_t *saiyugb1_adpcm_rom = memory_region(REGION_SOUND1);
+	UINT8 *saiyugb1_adpcm_rom = memory_region(REGION_SOUND1);
 
 	if (data & 0x80)	/* Reset m5205 and disable ADPCM ROM outputs */
 	{
@@ -469,7 +468,7 @@ INPUT_PORTS_START( chinagat )
 	PORT_BIT( 0x80, IP_ACTIVE_LOW, IPT_START2 )
 INPUT_PORTS_END
 
-static struct GfxLayout charlayout =
+static const gfx_layout charlayout =
 {
 	8,8,			/* 8*8 chars */
 	RGN_FRAC(1,1),	/* num of characters */
@@ -480,7 +479,7 @@ static struct GfxLayout charlayout =
 	32*8 /* every char takes 32 consecutive bytes */
 };
 
-static struct GfxLayout tilelayout =
+static const gfx_layout tilelayout =
 {
 	16,16,			/* 16x16 chars */
 	RGN_FRAC(1,2),	/* num of Tiles/Sprites */
@@ -492,7 +491,7 @@ static struct GfxLayout tilelayout =
 	64*8 /* every char takes 64 consecutive bytes */
 };
 
-static struct GfxDecodeInfo gfxdecodeinfo[] =
+static const gfx_decode gfxdecodeinfo[] =
 {
 	{ REGION_GFX1, 0, &charlayout,   0,16 },	/*  8x8  chars */
 	{ REGION_GFX2, 0, &tilelayout, 128, 8 },	/* 16x16 sprites */
@@ -550,7 +549,7 @@ static MACHINE_DRIVER_START( chinagat )
 	MDRV_VBLANK_DURATION(DEFAULT_REAL_60HZ_VBLANK_DURATION)
 	MDRV_INTERLEAVE(100) /* heavy interleaving to sync up sprite<->main cpu's */
 
-	MDRV_MACHINE_INIT(chinagat)
+	MDRV_MACHINE_RESET(chinagat)
 
 	/* video hardware */
 	MDRV_VIDEO_ATTRIBUTES(VIDEO_TYPE_RASTER)
@@ -596,7 +595,7 @@ static MACHINE_DRIVER_START( saiyugb1 )
 	MDRV_VBLANK_DURATION(DEFAULT_REAL_60HZ_VBLANK_DURATION)
 	MDRV_INTERLEAVE(100)	/* heavy interleaving to sync up sprite<->main cpu's */
 
-	MDRV_MACHINE_INIT(chinagat)
+	MDRV_MACHINE_RESET(chinagat)
 
 	/* video hardware */
 	MDRV_VIDEO_ATTRIBUTES(VIDEO_TYPE_RASTER)
@@ -638,7 +637,7 @@ static MACHINE_DRIVER_START( saiyugb2 )
 	MDRV_VBLANK_DURATION(DEFAULT_REAL_60HZ_VBLANK_DURATION)
 	MDRV_INTERLEAVE(100) /* heavy interleaving to sync up sprite<->main cpu's */
 
-	MDRV_MACHINE_INIT(chinagat)
+	MDRV_MACHINE_RESET(chinagat)
 
 	/* video hardware */
 	MDRV_VIDEO_ATTRIBUTES(VIDEO_TYPE_RASTER)
@@ -880,7 +879,7 @@ ROM_END
 
 
 /*   ( YEAR  NAME      PARENT    MACHINE   INPUT     INIT    MONITOR COMPANY    FULLNAME     FLAGS ) */
-GAME ( 1988, chinagat, 0,        chinagat, chinagat, 0     , ROT0, "[Technos] (Taito Romstar license)", "China Gate (US)" )
-GAME ( 1988, saiyugou, chinagat, chinagat, chinagat, 0     , ROT0, "Technos", "Sai Yu Gou Ma Roku (Japan)" )
-GAMEX( 1988, saiyugb1, chinagat, saiyugb1, chinagat, 0     , ROT0, "bootleg", "Sai Yu Gou Ma Roku (Japan bootleg 1)", GAME_IMPERFECT_SOUND )
-GAME ( 1988, saiyugb2, chinagat, saiyugb2, chinagat, 0     , ROT0, "bootleg", "Sai Yu Gou Ma Roku (Japan bootleg 2)" )
+GAME( 1988, chinagat, 0,        chinagat, chinagat, 0     , ROT0, "[Technos] (Taito Romstar license)", "China Gate (US)", 0 )
+GAME( 1988, saiyugou, chinagat, chinagat, chinagat, 0     , ROT0, "Technos", "Sai Yu Gou Ma Roku (Japan)", 0 )
+GAME( 1988, saiyugb1, chinagat, saiyugb1, chinagat, 0     , ROT0, "bootleg", "Sai Yu Gou Ma Roku (Japan bootleg 1)", GAME_IMPERFECT_SOUND )
+GAME( 1988, saiyugb2, chinagat, saiyugb2, chinagat, 0     , ROT0, "bootleg", "Sai Yu Gou Ma Roku (Japan bootleg 2)", 0 )
