@@ -29,7 +29,6 @@ D000      Paddle Position and Interrupt Reset
 
 #include "driver.h"
 #include "artwork.h"
-#include "vidhrdw/generic.h"
 #include "sound/samples.h"
 #include "circus.h"
 
@@ -216,7 +215,7 @@ INPUT_PORTS_START( ripcord )
 INPUT_PORTS_END
 
 
-static struct GfxLayout charlayout =
+static const gfx_layout charlayout =
 {
 	8,8,    /* 8*8 characters */
 	256,    /* 256 characters */
@@ -227,7 +226,7 @@ static struct GfxLayout charlayout =
 	8*8     /* every char takes 8 consecutive bytes */
 };
 
-static struct GfxLayout clownlayout =
+static const gfx_layout clownlayout =
 {
 	16,16,  /* 16*16 characters */
 	16,             /* 16 characters */
@@ -240,7 +239,7 @@ static struct GfxLayout clownlayout =
 	16*16   /* every char takes 64 consecutive bytes */
 };
 
-static struct GfxLayout robotlayout =
+static const gfx_layout robotlayout =
 {
 	8,8,  /* 16*16 characters */
 	1,      /* 1 character */
@@ -251,14 +250,14 @@ static struct GfxLayout robotlayout =
 	8
 };
 
-static struct GfxDecodeInfo gfxdecodeinfo[] =
+static const gfx_decode gfxdecodeinfo[] =
 {
 	{ REGION_GFX1, 0, &charlayout,  0, 1 },
 	{ REGION_GFX2, 0, &clownlayout, 0, 1 },
 	{ -1 } /* end of array */
 };
 
-static struct GfxDecodeInfo robotbwl_gfxdecodeinfo[] =
+static const gfx_decode robotbwl_gfxdecodeinfo[] =
 {
 	{ REGION_GFX1, 0, &charlayout,  0, 1 },
 	{ REGION_GFX2, 0, &robotlayout, 0, 1 },
@@ -520,7 +519,7 @@ static DRIVER_INIT( ripcord )
 }
 
 
-GAME ( 1977, circus,   0, circus,   circus,   circus,   ROT0, "Exidy", "Circus" )
-GAMEX( 1977, robotbwl, 0, robotbwl, robotbwl, robotbwl, ROT0, "Exidy", "Robot Bowl", GAME_IMPERFECT_SOUND )
-GAMEX( 1979, crash,    0, crash,    crash,    crash,    ROT0, "Exidy", "Crash", GAME_IMPERFECT_SOUND )
-GAMEX( 1979, ripcord,  0, ripcord,  ripcord,  ripcord,  ROT0, "Exidy", "Rip Cord", GAME_IMPERFECT_SOUND )
+GAME( 1977, circus,   0, circus,   circus,   circus,   ROT0, "Exidy", "Circus", 0 )
+GAME( 1977, robotbwl, 0, robotbwl, robotbwl, robotbwl, ROT0, "Exidy", "Robot Bowl", GAME_IMPERFECT_SOUND )
+GAME( 1979, crash,    0, crash,    crash,    crash,    ROT0, "Exidy", "Crash", GAME_IMPERFECT_SOUND )
+GAME( 1979, ripcord,  0, ripcord,  ripcord,  ripcord,  ROT0, "Exidy", "Rip Cord", GAME_IMPERFECT_SOUND )
