@@ -18,7 +18,6 @@ XTAL        :   18.432 MHz
 ***************************************************************************/
 
 #include "driver.h"
-#include "vidhrdw/generic.h"
 #include "sound/custom.h"
 
 UINT8 *clshroad_sharedram;
@@ -44,7 +43,7 @@ WRITE8_HANDLER( wiping_sound_w );
 
 
 
-MACHINE_INIT( clshroad )
+MACHINE_RESET( clshroad )
 {
 	flip_screen_set(0);
 }
@@ -248,7 +247,7 @@ INPUT_PORTS_START( firebatl )
 INPUT_PORTS_END
 
 
-static gfx_layout layout_8x8x2 =
+static const gfx_layout layout_8x8x2 =
 {
 	8,8,
 	RGN_FRAC(1,1),
@@ -259,7 +258,7 @@ static gfx_layout layout_8x8x2 =
 	8*8*2
 };
 
-static gfx_layout layout_8x8x4 =
+static const gfx_layout layout_8x8x4 =
 {
 	8,8,
 	RGN_FRAC(1,2),
@@ -270,7 +269,7 @@ static gfx_layout layout_8x8x4 =
 	8*8*2
 };
 
-static gfx_layout layout_16x16x4 =
+static const gfx_layout layout_16x16x4 =
 {
 	16,16,
 	RGN_FRAC(1,2),
@@ -281,7 +280,7 @@ static gfx_layout layout_16x16x4 =
 	16*16*2
 };
 
-static gfx_decode firebatl_gfxdecodeinfo[] =
+static const gfx_decode firebatl_gfxdecodeinfo[] =
 {
 	{ REGION_GFX1, 0, &layout_16x16x4,   0, 16 }, /* [0] Sprites */
 	{ REGION_GFX2, 0, &layout_16x16x4,	 16,  1 }, /* [1] Layer 0 */
@@ -289,7 +288,7 @@ static gfx_decode firebatl_gfxdecodeinfo[] =
 	{ -1 }
 };
 
-static gfx_decode clshroad_gfxdecodeinfo[] =
+static const gfx_decode clshroad_gfxdecodeinfo[] =
 {
 	{ REGION_GFX1, 0, &layout_16x16x4, 0, 16 }, /* [0] Sprites */
 	{ REGION_GFX2, 0, &layout_16x16x4, 0x90,  1 }, /* [1] Layer 0 */
@@ -321,7 +320,7 @@ static MACHINE_DRIVER_START( firebatl )
 	MDRV_FRAMES_PER_SECOND(60)
 	MDRV_VBLANK_DURATION(DEFAULT_60HZ_VBLANK_DURATION)
 
-	MDRV_MACHINE_INIT(clshroad)
+	MDRV_MACHINE_RESET(clshroad)
 
 	/* video hardware */
 	MDRV_VIDEO_ATTRIBUTES(VIDEO_TYPE_RASTER)
@@ -358,7 +357,7 @@ static MACHINE_DRIVER_START( clshroad )
 	MDRV_FRAMES_PER_SECOND(60)
 	MDRV_VBLANK_DURATION(DEFAULT_60HZ_VBLANK_DURATION)
 
-	MDRV_MACHINE_INIT(clshroad)
+	MDRV_MACHINE_RESET(clshroad)
 
 	/* video hardware */
 	MDRV_VIDEO_ATTRIBUTES(VIDEO_TYPE_RASTER)
