@@ -122,8 +122,6 @@ e000-e001   YM2203
 #include "sound/2203intf.h"
 #include "sound/upd7759.h"
 
-extern unsigned char* banked_area;
-
 /* from vidhrdw/combasc.c */
 PALETTE_INIT( combasc );
 PALETTE_INIT( combascb );
@@ -134,8 +132,8 @@ VIDEO_START( combascb );
 
 WRITE8_HANDLER( combascb_bankselect_w );
 WRITE8_HANDLER( combasc_bankselect_w );
-MACHINE_INIT( combasc );
-MACHINE_INIT( combascb );
+MACHINE_RESET( combasc );
+MACHINE_RESET( combascb );
 WRITE8_HANDLER( combasc_pf_control_w );
 READ8_HANDLER( combasc_scrollram_r );
 WRITE8_HANDLER( combasc_scrollram_w );
@@ -286,7 +284,7 @@ static ADDRESS_MAP_START( combasc_writemem, ADDRESS_SPACE_PROGRAM, 8 )
 	AM_RANGE(0x0414, 0x0414) AM_WRITE(soundlatch_w)
 	AM_RANGE(0x0418, 0x0418) AM_WRITE(combasc_sh_irqtrigger_w)
 	AM_RANGE(0x041c, 0x041c) AM_WRITE(watchdog_reset_w)			/* watchdog reset? */
-	AM_RANGE(0x0600, 0x06ff) AM_WRITE(paletteram_xBBBBBGGGGGRRRRR_w) AM_BASE(&paletteram)
+	AM_RANGE(0x0600, 0x06ff) AM_WRITE(paletteram_xBBBBBGGGGGRRRRR_le_w) AM_BASE(&paletteram)
 	AM_RANGE(0x0800, 0x1fff) AM_WRITE(MWA8_RAM)					/* RAM */
 	AM_RANGE(0x2000, 0x3fff) AM_WRITE(combasc_video_w)
 	AM_RANGE(0x4000, 0x7fff) AM_WRITE(MWA8_ROM)					/* banked ROM area */
@@ -305,10 +303,10 @@ ADDRESS_MAP_END
 static ADDRESS_MAP_START( combascb_writemem, ADDRESS_SPACE_PROGRAM, 8 )
 	AM_RANGE(0x0000, 0x04ff) AM_WRITE(MWA8_RAM)
 	AM_RANGE(0x0500, 0x0500) AM_WRITE(combascb_bankselect_w)
-	AM_RANGE(0x0600, 0x06ff) AM_WRITE(paletteram_xBBBBBGGGGGRRRRR_w) AM_BASE(&paletteram)
+	AM_RANGE(0x0600, 0x06ff) AM_WRITE(paletteram_xBBBBBGGGGGRRRRR_le_w) AM_BASE(&paletteram)
 	AM_RANGE(0x0800, 0x1fff) AM_WRITE(MWA8_RAM)
 	AM_RANGE(0x2000, 0x3fff) AM_WRITE(combasc_video_w)
-	AM_RANGE(0x4000, 0x7fff) AM_WRITE(MWA8_BANK1) AM_BASE(&banked_area)/* banked ROM/RAM area */
+	AM_RANGE(0x4000, 0x7fff) AM_WRITE(MWA8_BANK1) /* banked ROM/RAM area */
 	AM_RANGE(0x8000, 0xffff) AM_WRITE(MWA8_ROM)				/* ROM */
 ADDRESS_MAP_END
 
@@ -590,7 +588,7 @@ INPUT_PORTS_END
 
 
 
-static gfx_layout gfxlayout =
+static const gfx_layout gfxlayout =
 {
 	8,8,
 	0x4000,
@@ -601,7 +599,7 @@ static gfx_layout gfxlayout =
 	32*8
 };
 
-static gfx_layout tile_layout =
+static const gfx_layout tile_layout =
 {
 	8,8,
 	0x2000, /* number of tiles */
@@ -612,7 +610,7 @@ static gfx_layout tile_layout =
 	8*8
 };
 
-static gfx_layout sprite_layout =
+static const gfx_layout sprite_layout =
 {
 	16,16,
 	0x800,	/* number of sprites */
@@ -629,14 +627,14 @@ static gfx_layout sprite_layout =
 	8*8*4
 };
 
-static gfx_decode combasc_gfxdecodeinfo[] =
+static const gfx_decode combasc_gfxdecodeinfo[] =
 {
 	{ REGION_GFX1, 0x00000, &gfxlayout, 0, 8*16 },
 	{ REGION_GFX2, 0x00000, &gfxlayout, 0, 8*16 },
 	{ -1 }
 };
 
-static gfx_decode combascb_gfxdecodeinfo[] =
+static const gfx_decode combascb_gfxdecodeinfo[] =
 {
 	{ REGION_GFX1, 0x00000, &tile_layout,   0, 8*16 },
 	{ REGION_GFX1, 0x40000, &tile_layout,   0, 8*16 },
@@ -677,7 +675,7 @@ static MACHINE_DRIVER_START( combasc )
 	MDRV_VBLANK_DURATION(DEFAULT_REAL_60HZ_VBLANK_DURATION)
 	MDRV_INTERLEAVE(20)
 
-	MDRV_MACHINE_INIT(combasc)
+	MDRV_MACHINE_RESET(combasc)
 
 	/* video hardware */
 	MDRV_VIDEO_ATTRIBUTES(VIDEO_TYPE_RASTER)
@@ -719,7 +717,7 @@ static MACHINE_DRIVER_START( combascb )
 	MDRV_VBLANK_DURATION(DEFAULT_REAL_60HZ_VBLANK_DURATION)
 	MDRV_INTERLEAVE(20)
 
-	MDRV_MACHINE_INIT(combasc)
+	MDRV_MACHINE_RESET(combasc)
 
 	/* video hardware */
 	MDRV_VIDEO_ATTRIBUTES(VIDEO_TYPE_RASTER)
