@@ -43,7 +43,6 @@ Note : there is an ingame typo bug that doesn't display the bonus life values
 ***************************************************************************/
 
 #include "driver.h"
-#include "vidhrdw/generic.h"
 #include "sound/2203intf.h"
 
 extern UINT8 *commando_videoram2, *commando_colorram2;
@@ -177,7 +176,7 @@ INPUT_PORTS_END
 
 /* Graphics Layouts */
 
-static struct GfxLayout charlayout =
+static const gfx_layout charlayout =
 {
 	8, 8,
 	RGN_FRAC(1,1),
@@ -188,7 +187,7 @@ static struct GfxLayout charlayout =
 	16*8
 };
 
-static struct GfxLayout tilelayout =
+static const gfx_layout tilelayout =
 {
 	16, 16,
 	RGN_FRAC(1,3),
@@ -201,7 +200,7 @@ static struct GfxLayout tilelayout =
 	32*8
 };
 
-static struct GfxLayout spritelayout =
+static const gfx_layout spritelayout =
 {
 	16, 16,
 	RGN_FRAC(1,2),
@@ -216,7 +215,7 @@ static struct GfxLayout spritelayout =
 
 /* Graphics Decode Information */
 
-static struct GfxDecodeInfo gfxdecodeinfo[] =
+static const gfx_decode gfxdecodeinfo[] =
 {
 	{ REGION_GFX1, 0, &charlayout,   192, 16 },	/* colors 192-255 */
 	{ REGION_GFX2, 0, &tilelayout,     0, 16 },	/* colors   0-127 */
@@ -461,30 +460,30 @@ ROM_END
 
 static DRIVER_INIT( commando )
 {
-	int A;
 	UINT8 *rom = memory_region(REGION_CPU1);
-	int diff = memory_region_length(REGION_CPU1) / 2;
+	UINT8 *decrypt = auto_malloc(0xc000);
+	int A;
 
-	memory_set_opcode_base(0, rom + diff);
+	memory_set_decrypted_region(0, 0x0000, 0xbfff, decrypt);
 
 	/* the first opcode is *not* encrypted */
-	rom[0 + diff] = rom[0];
+	decrypt[0] = rom[0];
 	for (A = 1; A < 0xc000; A++)
 	{
 		int src;
 
 		src = rom[A];
-		rom[A + diff] = (src & 0x11) | ((src & 0xe0) >> 4) | ((src & 0x0e) << 4);
+		decrypt[A] = (src & 0x11) | ((src & 0xe0) >> 4) | ((src & 0x0e) << 4);
 	}
 }
 
 static DRIVER_INIT( spaceinv )
 {
-	int A;
 	UINT8 *rom = memory_region(REGION_CPU1);
-	int diff = memory_region_length(REGION_CPU1) / 2;
+	UINT8 *decrypt = auto_malloc(0xc000);
+	int A;
 
-	memory_set_opcode_base(0, rom + diff);
+	memory_set_decrypted_region(0, 0x0000, 0xbfff, decrypt);
 
 	/* the first opcode *is* encrypted */
 	for (A = 0; A < 0xc000; A++)
@@ -492,14 +491,14 @@ static DRIVER_INIT( spaceinv )
 		int src;
 
 		src = rom[A];
-		rom[A + diff] = (src & 0x11) | ((src & 0xe0) >> 4) | ((src & 0x0e) << 4);
+		decrypt[A] = (src & 0x11) | ((src & 0xe0) >> 4) | ((src & 0x0e) << 4);
 	}
 }
 
 /* Game Drivers */
 
-GAME( 1985, commando, 0,        commando, commando, commando, ROT90, "Capcom", "Commando (World)" )
-GAME( 1985, commandu, commando, commando, commandu, commando, ROT90, "Capcom (Data East USA license)", "Commando (US)" )
-GAME( 1985, commandj, commando, commando, commando, commando, ROT90, "Capcom", "Senjou no Ookami" )
-GAME( 1985, sinvasn,  commando, commando, commando, commando, ROT90, "Capcom", "Space Invasion (Europe)" )
-GAME( 1985, sinvasnb, commando, commando, commando, spaceinv, ROT90, "bootleg", "Space Invasion (bootleg)" )
+GAME( 1985, commando, 0,        commando, commando, commando, ROT90, "Capcom", "Commando (World)", 0 )
+GAME( 1985, commandu, commando, commando, commandu, commando, ROT90, "Capcom (Data East USA license)", "Commando (US)", 0 )
+GAME( 1985, commandj, commando, commando, commando, commando, ROT90, "Capcom", "Senjou no Ookami", 0 )
+GAME( 1985, sinvasn,  commando, commando, commando, commando, ROT90, "Capcom", "Space Invasion (Europe)", 0 )
+GAME( 1985, sinvasnb, commando, commando, commando, spaceinv, ROT90, "bootleg", "Space Invasion (bootleg)", 0 )
