@@ -14,7 +14,6 @@ Credits:
 ***************************************************************************/
 
 #include "driver.h"
-#include "vidhrdw/generic.h"
 #include "cpu/m6809/m6809.h"
 #include "sound/2151intf.h"
 
@@ -88,7 +87,7 @@ static ADDRESS_MAP_START( writemem, ADDRESS_SPACE_PROGRAM, 8 )
 	AM_RANGE(0x001c, 0x001c) AM_WRITE(cpu_sound_command_w)
 	AM_RANGE(0x001e, 0x001e) AM_WRITE(MWA8_NOP)	/* ? */
 	AM_RANGE(0x0060, 0x0067) AM_WRITE(contra_K007121_ctrl_1_w)
-	AM_RANGE(0x0c00, 0x0cff) AM_WRITE(paletteram_xBBBBBGGGGGRRRRR_w) AM_BASE(&paletteram)
+	AM_RANGE(0x0c00, 0x0cff) AM_WRITE(paletteram_xBBBBBGGGGGRRRRR_le_w) AM_BASE(&paletteram)
 	AM_RANGE(0x1000, 0x1fff) AM_WRITE(MWA8_RAM)
 	AM_RANGE(0x2000, 0x23ff) AM_WRITE(contra_fg_cram_w) AM_BASE(&contra_fg_cram)
 	AM_RANGE(0x2400, 0x27ff) AM_WRITE(contra_fg_vram_w) AM_BASE(&contra_fg_vram)
@@ -226,7 +225,7 @@ INPUT_PORTS_END
 
 
 
-static gfx_layout gfxlayout =
+static const gfx_layout gfxlayout =
 {
 	8,8,
 	0x4000,
@@ -237,7 +236,7 @@ static gfx_layout gfxlayout =
 	32*8
 };
 
-static gfx_decode gfxdecodeinfo[] =
+static const gfx_decode gfxdecodeinfo[] =
 {
 	{ REGION_GFX1, 0, &gfxlayout,       0, 8*16 },
 	{ REGION_GFX2, 0, &gfxlayout, 8*16*16, 8*16 },
