@@ -50,7 +50,6 @@ Mighty Guy board layout:
 
 ***************************************************************************/
 #include "driver.h"
-#include "vidhrdw/generic.h"
 #include "sound/ay8910.h"
 #include "sound/3812intf.h"
 
@@ -363,7 +362,7 @@ INPUT_PORTS_END
 
 
 
-static gfx_layout charlayout =
+static const gfx_layout charlayout =
 {
 	8,8,
 	RGN_FRAC(1,1),
@@ -374,7 +373,7 @@ static gfx_layout charlayout =
 	32*8
 };
 
-static gfx_layout tilelayout =
+static const gfx_layout tilelayout =
 {
 	8,8,
 	RGN_FRAC(1,1),
@@ -385,7 +384,7 @@ static gfx_layout tilelayout =
 	32*8
 };
 
-static gfx_layout spritelayout =
+static const gfx_layout spritelayout =
 {
 	16,16,
 	RGN_FRAC(1,2),
@@ -404,7 +403,7 @@ static gfx_layout spritelayout =
 	64*8
 };
 
-static gfx_decode gfxdecodeinfo[] =
+static const gfx_decode gfxdecodeinfo[] =
 {
 	{ REGION_GFX1, 0, &charlayout,         0,  1 },
 	{ REGION_GFX2, 0, &tilelayout,        16,  8 },
