@@ -53,7 +53,6 @@
 ***************************************************************************/
 
 #include "driver.h"
-#include "vidhrdw/generic.h"
 #include "artwork.h"
 #include "copsnrob.h"
 
@@ -209,7 +208,7 @@ INPUT_PORTS_END
  *
  *************************************/
 
-static gfx_layout charlayout =
+static const gfx_layout charlayout =
 {
     8,8,
     64,
@@ -221,7 +220,7 @@ static gfx_layout charlayout =
 };
 
 
-static gfx_layout carlayout =
+static const gfx_layout carlayout =
 {
     32,32,
     16,
@@ -239,7 +238,7 @@ static gfx_layout carlayout =
 };
 
 
-static gfx_layout trucklayout =
+static const gfx_layout trucklayout =
 {
     16,32,
     2,
@@ -255,7 +254,7 @@ static gfx_layout trucklayout =
 };
 
 
-static gfx_decode gfxdecodeinfo[] =
+static const gfx_decode gfxdecodeinfo[] =
 {
 	{ REGION_GFX1, 0, &charlayout,  0, 1 },
 	{ REGION_GFX2, 0, &carlayout,   0, 1 },
