@@ -12,7 +12,6 @@ Devil Zone      - 8022
 
 
 #include "driver.h"
-#include "vidhrdw/generic.h"
 #include "cpu/z80/z80.h"
 #include "sound/samples.h"
 #include "sound/dac.h"
@@ -903,7 +902,7 @@ INPUT_PORTS_START( nomnlndg )
 INPUT_PORTS_END
 
 
-static struct GfxLayout cosmic_spritelayout16 =
+static const gfx_layout cosmic_spritelayout16 =
 {
 	16,16,
 	RGN_FRAC(1,2),
@@ -916,7 +915,7 @@ static struct GfxLayout cosmic_spritelayout16 =
 	32*8
 };
 
-static struct GfxLayout cosmic_spritelayout32 =
+static const gfx_layout cosmic_spritelayout32 =
 {
 	32,32,
 	RGN_FRAC(1,2),
@@ -934,14 +933,14 @@ static struct GfxLayout cosmic_spritelayout32 =
 };
 
 
-static struct GfxDecodeInfo panic_gfxdecodeinfo[] =
+static const gfx_decode panic_gfxdecodeinfo[] =
 {
 	{ REGION_GFX1, 0, &cosmic_spritelayout16,  0, 8 },
 	{ REGION_GFX1, 0, &cosmic_spritelayout32,  0, 8 },
 	{ -1 } /* end of array */
 };
 
-static struct GfxDecodeInfo cosmica_gfxdecodeinfo[] =
+static const gfx_decode cosmica_gfxdecodeinfo[] =
 {
 	{ REGION_GFX1, 0, &cosmic_spritelayout16,  0, 16 },
 	{ REGION_GFX1, 0, &cosmic_spritelayout32,  0, 16 },
@@ -1485,9 +1484,9 @@ static DRIVER_INIT( cosmicg )
 
     for (offs =0; offs < memory_region_length(REGION_CPU1); offs++)
 	{
-        data8_t scrambled = memory_region(REGION_CPU1)[offs];
+        UINT8 scrambled = memory_region(REGION_CPU1)[offs];
 
-        data8_t normal = (scrambled >> 3 & 0x11)
+        UINT8 normal = (scrambled >> 3 & 0x11)
                        | (scrambled >> 1 & 0x22)
                        | (scrambled << 1 & 0x44)
                        | (scrambled << 3 & 0x88);
@@ -1518,17 +1517,17 @@ static DRIVER_INIT( nomnlnd )
 }
 
 
-GAMEX(1979, cosmicg,  0,       cosmicg,  cosmicg,  cosmicg, ROT270, "Universal", "Cosmic Guerilla", GAME_NO_COCKTAIL )
-GAMEX(1979, cosmica,  0,       cosmica,  cosmica,  0,       ROT270, "Universal", "Cosmic Alien", GAME_NO_SOUND )
-GAMEX(1979, cosmica2, cosmica, cosmica,  cosmica,  0,       ROT270, "Universal", "Cosmic Alien (older)", GAME_NO_SOUND )
-GAME( 1980, panic,    0,       panic,    panic,    0,       ROT270, "Universal", "Space Panic (version E)" )
-GAME( 1980, panic2,   panic,   panic,    panic,    0,       ROT270, "Universal", "Space Panic (set 2)" )
-GAME( 1980, panic3,   panic,   panic,    panic,    0,       ROT270, "Universal", "Space Panic (set 3)" )
-GAME( 1980, panich,   panic,   panic,    panic,    0,       ROT270, "Universal", "Space Panic (harder)" )
-GAME( 1980, panicger, panic,   panic,    panic,    0,       ROT270, "Universal (ADP Automaten license)", "Space Panic (German)" )
-GAMEX(1980, magspot,  0,	   magspot2, magspot2, 0,       ROT270, "Universal", "Magical Spot", GAME_IMPERFECT_SOUND )
-GAMEX(1980, magspot2, 0,       magspot2, magspot2, 0,       ROT270, "Universal", "Magical Spot II", GAME_IMPERFECT_SOUND )
-GAMEX(1980, devzone,  0,       devzone,  devzone,  devzone, ROT270, "Universal", "Devil Zone", GAME_IMPERFECT_SOUND )
-GAMEX(1980, devzone2, devzone, devzone,  devzone2, devzone, ROT270, "Universal", "Devil Zone (easier)", GAME_IMPERFECT_SOUND )
-GAMEX(1980, nomnlnd,  0,       nomnlnd,  nomnlnd,  nomnlnd, ROT270, "Universal", "No Man's Land", GAME_IMPERFECT_SOUND )
-GAMEX(1980, nomnlndg, nomnlnd, nomnlnd,  nomnlndg, nomnlnd, ROT270, "Universal (Gottlieb license)", "No Man's Land (Gottlieb)", GAME_IMPERFECT_SOUND )
+GAME( 1979, cosmicg,  0,       cosmicg,  cosmicg,  cosmicg, ROT270, "Universal", "Cosmic Guerilla", GAME_NO_COCKTAIL )
+GAME( 1979, cosmica,  0,       cosmica,  cosmica,  0,       ROT270, "Universal", "Cosmic Alien", GAME_NO_SOUND )
+GAME( 1979, cosmica2, cosmica, cosmica,  cosmica,  0,       ROT270, "Universal", "Cosmic Alien (older)", GAME_NO_SOUND )
+GAME( 1980, panic,    0,       panic,    panic,    0,       ROT270, "Universal", "Space Panic (version E)", 0 )
+GAME( 1980, panic2,   panic,   panic,    panic,    0,       ROT270, "Universal", "Space Panic (set 2)", 0 )
+GAME( 1980, panic3,   panic,   panic,    panic,    0,       ROT270, "Universal", "Space Panic (set 3)", 0 )
+GAME( 1980, panich,   panic,   panic,    panic,    0,       ROT270, "Universal", "Space Panic (harder)", 0 )
+GAME( 1980, panicger, panic,   panic,    panic,    0,       ROT270, "Universal (ADP Automaten license)", "Space Panic (German)", 0 )
+GAME( 1980, magspot,  0,	   magspot2, magspot2, 0,       ROT270, "Universal", "Magical Spot", GAME_IMPERFECT_SOUND )
+GAME( 1980, magspot2, 0,       magspot2, magspot2, 0,       ROT270, "Universal", "Magical Spot II", GAME_IMPERFECT_SOUND )
+GAME( 1980, devzone,  0,       devzone,  devzone,  devzone, ROT270, "Universal", "Devil Zone", GAME_IMPERFECT_SOUND )
+GAME( 1980, devzone2, devzone, devzone,  devzone2, devzone, ROT270, "Universal", "Devil Zone (easier)", GAME_IMPERFECT_SOUND )
+GAME( 1980, nomnlnd,  0,       nomnlnd,  nomnlnd,  nomnlnd, ROT270, "Universal", "No Man's Land", GAME_IMPERFECT_SOUND )
+GAME( 1980, nomnlndg, nomnlnd, nomnlnd,  nomnlndg, nomnlnd, ROT270, "Universal (Gottlieb license)", "No Man's Land (Gottlieb)", GAME_IMPERFECT_SOUND )
