@@ -50,28 +50,24 @@ write:
 ***************************************************************************/
 
 #include "driver.h"
-#include "vidhrdw/generic.h"
 #include "sound/sn76477.h"
 #include "sound/custom.h"
+#include "crbaloon.h"
 
 
-extern WRITE8_HANDLER( crbaloon_videoram_w );
-extern WRITE8_HANDLER( crbaloon_colorram_w );
-extern WRITE8_HANDLER( crbaloon_spritectrl_w );
-extern WRITE8_HANDLER( crbaloon_flipscreen_w );
 
-extern PALETTE_INIT( crbaloon );
-extern VIDEO_START( crbaloon );
-extern VIDEO_UPDATE( crbaloon );
+static UINT8 val06,val08,val0a;
 
+static MACHINE_START( crbaloon )
+{
+	state_save_register_global(val06);
+	state_save_register_global(val08);
+	state_save_register_global(val0a);
 
-int val06,val08,val0a;
+	return 0;
+}
 
-static sound_stream *crbaloon_tone_stream;
-static UINT32 crbaloon_tone_step;
-static UINT32 crbaloon_tone_pos;
-
-static MACHINE_INIT( crbaloon )
+static MACHINE_RESET( crbaloon )
 {
 	/* MIXER A = 0, MIXER C = 1 */
 	SN76477_mixer_a_w(0, 0);
@@ -89,44 +85,22 @@ WRITE8_HANDLER( crbaloon_06_w )
 
 	interrupt_enable_w(offset,data & 1);
 
-	/* SOUND STOP high? */
-    if( data & 0x02 )
-	{
+	/* SOUND STOP is really sound enable */
+	sound_global_enable(data & 0x02);
 
-		if( data & 0x08 )
-		{
-			/* enable is connected to EXPLOSION */
-			SN76477_enable_w(0, 1);
-		}
-		else
-		{
-			SN76477_enable_w(0, 0);
-		}
-		if( data & 0x10 )
-		{
-			/* BREATH changes slf_res to 10k (middle of two 10k resistors) */
-			SN76477_set_slf_res(0, RES_K(10));
-			/* it also puts a tantal capacitor agains GND on the output,
-               but this section of the schematics is not readable. */
-		}
-		else
-		{
-			SN76477_set_slf_res(0, RES_K(20));
-		}
+	/* enable is connected to EXPLOSION */
+	SN76477_enable_w(0, (data & 0x08) ? 1 : 0);
 
-		if( data & 0x20 )
-		{
-			/* APPEAR is connected to MIXER B */
-			SN76477_mixer_b_w(0, 1);
-		}
-		else
-		{
-			SN76477_mixer_b_w(0, 4);
-		}
+	/* BREATH changes slf_res to 10k (middle of two 10k resistors) */
+	/* it also puts a tantal capacitor agains GND on the output,
+       but this section of the schematics is not readable. */
+	SN76477_set_slf_res(0, (data & 0x10) ? RES_K(10) : RES_K(20) );
 
-		/* constant: pin1 = hi, pin 28 = lo */
-		SN76477_envelope_w(0, 1);
-	}
+	/* APPEAR is connected to MIXER B */
+	SN76477_mixer_b_w(0, (data & 0x20) ? 1 : 4);
+
+	discrete_sound_w(CRBALOON_MUSIC_EN, data & 0x04);
+	discrete_sound_w(CRBALOON_LAUGH_EN, data & 0x40);
 }
 
 WRITE8_HANDLER( crbaloon_08_w )
@@ -143,8 +117,6 @@ WRITE8_HANDLER( crbaloon_0a_w )
 
 READ8_HANDLER( crbaloon_IN2_r )
 {
-	extern int crbaloon_collision;
-
 	if (crbaloon_collision != 0)
 	{
 		return (input_port_2_r(0) & 0xf0) | 0x08;
@@ -205,13 +177,7 @@ READ8_HANDLER( crbaloon_IN_r )
 
 WRITE8_HANDLER( crbaloon_tone_w )
 {
-	crbaloon_tone_step = 0;
-	if (data && data != 0xff)
-	{
-		double freq = (13630.0 / (256 - data) + (data>=0xea ? 13 : 0))*0.5;
-
-		crbaloon_tone_step = (UINT32)(freq * 65536.0 * 65536.0 / (double)Machine->sample_rate);
-	}
+	discrete_sound_w(CRBALOON_MUSIC_DATA, data);
 }
 
 
@@ -247,7 +213,7 @@ ADDRESS_MAP_END
 
 
 INPUT_PORTS_START( crbaloon )
-	PORT_START_TAG("DSW0")
+	PORT_START_TAG("DSW0") /* 0 */
 	PORT_DIPNAME( 0x01, 0x01, "Test?" )
 	PORT_DIPSETTING(    0x01, "I/O Check?" )
 	PORT_DIPSETTING(    0x00, "RAM Check?" )
@@ -272,7 +238,7 @@ INPUT_PORTS_START( crbaloon )
 	PORT_DIPSETTING(    0xe0, DEF_STR( 1C_4C ) )
 	PORT_DIPSETTING(    0x00, "Disable" )
 
-	PORT_START_TAG("IN0")
+	PORT_START_TAG("IN0") /* 1 */
 	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_JOYSTICK_UP ) PORT_8WAY
 	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_JOYSTICK_DOWN ) PORT_8WAY
 	PORT_BIT( 0x04, IP_ACTIVE_LOW, IPT_JOYSTICK_LEFT ) PORT_8WAY
@@ -282,7 +248,7 @@ INPUT_PORTS_START( crbaloon )
 	PORT_BIT( 0x40, IP_ACTIVE_LOW, IPT_JOYSTICK_LEFT ) PORT_8WAY PORT_COCKTAIL
 	PORT_BIT( 0x80, IP_ACTIVE_LOW, IPT_JOYSTICK_RIGHT ) PORT_8WAY PORT_COCKTAIL
 
-	PORT_START_TAG("DSW1")
+	PORT_START_TAG("DSW1") /* 2 */
 	PORT_BIT( 0x0f, IP_ACTIVE_HIGH, IPT_UNKNOWN )	/* from chip PC3259 */
 	PORT_DIPNAME( 0x10, 0x10, "Invulnerability (Cheat)")
 	PORT_DIPSETTING(    0x10, DEF_STR( Off ) )
@@ -297,7 +263,7 @@ INPUT_PORTS_START( crbaloon )
 	PORT_DIPSETTING(    0x80, DEF_STR( Off ) )
 	PORT_DIPSETTING(    0x00, DEF_STR( On ) )
 
-	PORT_START_TAG("IN1")
+	PORT_START_TAG("IN1") /* 3 */
 	PORT_DIPNAME( 0x01, 0x01, DEF_STR( Unknown ) )
 	PORT_DIPSETTING(    0x01, DEF_STR( Off ) )
 	PORT_DIPSETTING(    0x00, DEF_STR( On ) )
@@ -309,11 +275,18 @@ INPUT_PORTS_START( crbaloon )
 	PORT_BIT( 0x20, IP_ACTIVE_LOW, IPT_START2 )
 	PORT_BIT( 0x40, IP_ACTIVE_HIGH, IPT_COIN1 )
 	PORT_BIT( 0x80, IP_ACTIVE_HIGH, IPT_UNKNOWN )
+
+	PORT_START /* 4 */
+	PORT_ADJUSTER(50, "VR2 - Beep")
+
+	PORT_START /* 5 */
+	PORT_ADJUSTER(50, "VR3 - Music")
+
 INPUT_PORTS_END
 
 
 
-static gfx_layout charlayout =
+static const gfx_layout charlayout =
 {
 	8,8,	/* 8*8 characters */
 	256,	/* 256 characters */
@@ -323,7 +296,7 @@ static gfx_layout charlayout =
 	{ 7*8, 6*8, 5*8, 4*8, 3*8, 2*8, 1*8, 0*8 },
 	8*8	/* every char takes 8 consecutive bytes */
 };
-static gfx_layout spritelayout =
+static const gfx_layout spritelayout =
 {
 	32,32,	/* 32*32 sprites */
 	16,	/* 16 sprites */
@@ -341,7 +314,7 @@ static gfx_layout spritelayout =
 };
 
 
-static gfx_decode gfxdecodeinfo[] =
+static const gfx_decode gfxdecodeinfo[] =
 {
 	{ REGION_GFX1, 0, &charlayout,   0, 16 },
 	{ REGION_GFX2, 0, &spritelayout, 0, 16 },
@@ -370,38 +343,6 @@ static struct SN76477interface sn76477_interface =
 };
 
 
-static void crbaloon_tone_update(void *param, stream_sample_t **inputs, stream_sample_t **outputs, int len)
-{
-	stream_sample_t *buffer = outputs[0];
-
-	memset(buffer, 0, len * sizeof(stream_sample_t));
-
-	if (crbaloon_tone_step)
-	{
-		while (len-- > 0)
-		{
-			*buffer++ = crbaloon_tone_pos & 0x80000000 ? 32767 : -32768;
-			crbaloon_tone_pos += crbaloon_tone_step;
-		}
-	}
-}
-
-static void *crbaloon_sh_start(int clock, const struct CustomSound_interface *config)
-{
-	crbaloon_tone_step = 0;
-	crbaloon_tone_pos = 0;
-
-	crbaloon_tone_stream = stream_create(0, 1, Machine->sample_rate, NULL, crbaloon_tone_update);
-
-	return auto_malloc(1);
-}
-
-struct CustomSound_interface crbaloon_custom_interface =
-{
-	crbaloon_sh_start
-};
-
-
 static MACHINE_DRIVER_START( crbaloon )
 
 	/* basic machine hardware */
@@ -413,7 +354,8 @@ static MACHINE_DRIVER_START( crbaloon )
 	MDRV_FRAMES_PER_SECOND(60)
 	MDRV_VBLANK_DURATION(DEFAULT_60HZ_VBLANK_DURATION)
 
-	MDRV_MACHINE_INIT(crbaloon)
+	MDRV_MACHINE_START(crbaloon)
+	MDRV_MACHINE_RESET(crbaloon)
 
 	/* video hardware */
 	MDRV_VIDEO_ATTRIBUTES(VIDEO_TYPE_RASTER)
@@ -432,11 +374,11 @@ static MACHINE_DRIVER_START( crbaloon )
 
 	MDRV_SOUND_ADD(SN76477, 0)
 	MDRV_SOUND_CONFIG(sn76477_interface)
-	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 1.0)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 2.0)
 
-	MDRV_SOUND_ADD(CUSTOM, 0)
-	MDRV_SOUND_CONFIG(crbaloon_custom_interface)
-	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.10)
+	MDRV_SOUND_ADD_TAG("discrete", DISCRETE, 0)
+	MDRV_SOUND_CONFIG(crbaloon_discrete_interface)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 1.0)
 MACHINE_DRIVER_END
 
 
@@ -481,5 +423,5 @@ ROM_END
 
 
 
-GAME( 1980, crbaloon, 0,		crbaloon, crbaloon, 0, ROT90, "Taito Corporation", "Crazy Balloon (set 1)", GAME_IMPERFECT_SOUND )
-GAME( 1980, crbalon2, crbaloon, crbaloon, crbaloon, 0, ROT90, "Taito Corporation", "Crazy Balloon (set 2)", GAME_IMPERFECT_SOUND )
+GAME( 1980, crbaloon, 0,		crbaloon, crbaloon, 0, ROT90, "Taito Corporation", "Crazy Balloon (set 1)", GAME_IMPERFECT_SOUND | GAME_SUPPORTS_SAVE )
+GAME( 1980, crbalon2, crbaloon, crbaloon, crbaloon, 0, ROT90, "Taito Corporation", "Crazy Balloon (set 2)", GAME_IMPERFECT_SOUND | GAME_SUPPORTS_SAVE )
