@@ -8,7 +8,6 @@ Preliminary driver by:
 ***************************************************************************/
 
 #include "driver.h"
-#include "vidhrdw/generic.h"
 #include "cpu/konami/konami.h" /* for the callback and the firq irq definition */
 #include "vidhrdw/konamiic.h"
 #include "sound/2151intf.h"
@@ -16,7 +15,7 @@ Preliminary driver by:
 
 
 /* prototypes */
-static MACHINE_INIT( crimfght );
+static MACHINE_RESET( crimfght );
 static void crimfght_banking( int lines );
 
 VIDEO_START( crimfght );
@@ -48,26 +47,8 @@ static WRITE8_HANDLER( crimfght_snd_bankswitch_w )
 
 /********************************************/
 
-static READ8_HANDLER( speedup_r )
-{
-	unsigned char *RAM = memory_region(REGION_CPU1);
-
-	int data = ( RAM[0x0414] << 8 ) | RAM[0x0415];
-
-	if ( data < memory_region_length(REGION_CPU1) )
-	{
-		data = ( RAM[data] << 8 ) | RAM[data + 1];
-
-		if ( data == 0xffff )
-			cpu_spinuntil_int();
-	}
-
-	return RAM[0x0414];
-}
-
 static ADDRESS_MAP_START( crimfght_readmem, ADDRESS_SPACE_PROGRAM, 8 )
 	AM_RANGE(0x0000, 0x03ff) AM_READ(MRA8_BANK1)			/* banked RAM */
-	AM_RANGE(0x0414, 0x0414) AM_READ(speedup_r)
 	AM_RANGE(0x0400, 0x1fff) AM_READ(MRA8_RAM)			/* RAM */
 	AM_RANGE(0x3f80, 0x3f80) AM_READ(input_port_7_r)		/* Coinsw */
 	AM_RANGE(0x3f81, 0x3f81) AM_READ(input_port_3_r)		/* 1P controls */
@@ -394,7 +375,7 @@ static MACHINE_DRIVER_START( crimfght )
 	MDRV_FRAMES_PER_SECOND(54)	/* adjusted - compared with PCB speed */
 	MDRV_VBLANK_DURATION(DEFAULT_60HZ_VBLANK_DURATION)
 
-	MDRV_MACHINE_INIT(crimfght)
+	MDRV_MACHINE_RESET(crimfght)
 
 	/* video hardware */
 	MDRV_VIDEO_ATTRIBUTES(VIDEO_TYPE_RASTER | VIDEO_HAS_SHADOWS)
@@ -510,11 +491,11 @@ static void crimfght_banking( int lines )
 	/* bit 5 = select work RAM or palette */
 	if (lines & 0x20){
 		memory_install_read8_handler(0, ADDRESS_SPACE_PROGRAM, 0x0000, 0x03ff, 0, 0, paletteram_r);							/* palette */
-		memory_install_write8_handler(0, ADDRESS_SPACE_PROGRAM, 0x0000, 0x03ff, 0, 0, paletteram_xBBBBBGGGGGRRRRR_swap_w);	/* palette */
+		memory_install_write8_handler(0, ADDRESS_SPACE_PROGRAM, 0x0000, 0x03ff, 0, 0, paletteram_xBBBBBGGGGGRRRRR_be_w);	/* palette */
 	}
 	else{
-		memory_install_read8_handler(0, ADDRESS_SPACE_PROGRAM, 0x0000, 0x03ff, 0, 0, MRA8_RAM);								/* RAM */
-		memory_install_write8_handler(0, ADDRESS_SPACE_PROGRAM, 0x0000, 0x03ff, 0, 0, MWA8_RAM);								/* RAM */
+		memory_install_read8_handler(0, ADDRESS_SPACE_PROGRAM, 0x0000, 0x03ff, 0, 0, MRA8_BANK1);								/* RAM */
+		memory_install_write8_handler(0, ADDRESS_SPACE_PROGRAM, 0x0000, 0x03ff, 0, 0, MWA8_BANK1);								/* RAM */
 	}
 
 	/* bit 6 = enable char ROM reading through the video RAM */
@@ -524,7 +505,7 @@ static void crimfght_banking( int lines )
 	memory_set_bankptr( 2, &RAM[offs] );
 }
 
-static MACHINE_INIT( crimfght )
+static MACHINE_RESET( crimfght )
 {
 	unsigned char *RAM = memory_region(REGION_CPU1);
 
