@@ -21,7 +21,6 @@ some bits by David Haywood
 */
 
 #include "driver.h"
-#include "vidhrdw/generic.h"
 #include "sound/okim6295.h"
 #include "sound/3812intf.h"
 
@@ -172,7 +171,7 @@ INPUT_PORTS_START( crospang )
 	PORT_DIPSETTING(      0x0000, DEF_STR( On ) )
 INPUT_PORTS_END
 
-static gfx_layout layout_16x16x4a =
+static const gfx_layout layout_16x16x4a =
 {
 	16,16,
 	RGN_FRAC(1,4),
@@ -183,7 +182,7 @@ static gfx_layout layout_16x16x4a =
 	8*32
 };
 
-static gfx_layout layout_16x16x4 =
+static const gfx_layout layout_16x16x4 =
 {
 	16,16,
 	RGN_FRAC(1,4),
@@ -194,7 +193,7 @@ static gfx_layout layout_16x16x4 =
 	8*32
 };
 
-static gfx_decode gfxdecodeinfo[] =
+static const gfx_decode gfxdecodeinfo[] =
 {
 	{ REGION_GFX1, 0, &layout_16x16x4a, 0, 0x10 }, /* [0] Sprites */
 	{ REGION_GFX2, 0, &layout_16x16x4,  0, 0x30 }, /* [1] Tiles */
