@@ -1,6 +1,10 @@
-/* Cross Shooter (c) 1987 Seibu */
+/* Cross Shooter (c) 1987 Seibu
+
+ TS 01.05.2006:
+
+ - added sprites, bgmap reading and few ixes here and there
+   airraid and cshootre are a bit "playable" ;) without gfx
 
-/*
 
 Haze's notes :
 
@@ -82,11 +86,33 @@ Stephh's notes (based on the game Z80 code and some tests) :
 #include "driver.h"
 #include "sndhrdw/seibu.h"
 
-
-/* vidhrdw */
-
 UINT8* cshooter_txram;
 static tilemap *cshooter_txtilemap;
+static int coin_stat=0;
+
+static unsigned char *mainram;
+
+static void ar_coin_hack(void)
+{
+	if(input_port_5_r(0)&1)
+	{
+		if(coin_stat==0)
+		{
+			coin_stat=1;
+			if(mainram[0]==0)
+			{
+				mainram[0]=0x80;
+			}
+
+			mainram[0x234]++;
+
+		}
+	}
+	else
+	{
+		coin_stat=0;
+	}
+}
 
 static void get_cstx_tile_info(int tile_index)
 {
@@ -99,8 +125,8 @@ static void get_cstx_tile_info(int tile_index)
 	SET_TILE_INFO(
 
 			rg,
-			code & 0x1ff,
-			attr&0x1f,
+			(code & 0x1ff),
+			0x2c+(attr&0x1f), /*test */
 			0)
 }
 
@@ -112,13 +138,57 @@ WRITE8_HANDLER(cshooter_txram_w)
 
 VIDEO_START(cshooter)
 {
-	cshooter_txtilemap = tilemap_create(get_cstx_tile_info,tilemap_scan_rows,TILEMAP_OPAQUE,8,8,32, 32);
-
+	cshooter_txtilemap = tilemap_create(get_cstx_tile_info,tilemap_scan_rows,TILEMAP_TRANSPARENT,8,8,32, 32);
+	tilemap_set_transparent_pen(cshooter_txtilemap, 3);
 	return 0;
 }
 
 VIDEO_UPDATE(cshooter)
 {
+	fillbitmap(bitmap, 0/*get_black_pen()*/, &Machine->visible_area);
+	tilemap_mark_all_tiles_dirty(cshooter_txtilemap);
+
+	/*sprites */
+	{
+		int i;
+		for(i=0;i<spriteram_size;i+=4)
+		{
+			if(spriteram[i+3]!=0)
+			{
+				int tile=0x30+((spriteram[i]>>2)&0x1f);
+
+				drawgfx(bitmap,Machine->gfx[0],
+							tile,
+							spriteram[i+1],
+							0, 0,
+							spriteram[i+3],spriteram[i+2],
+							cliprect,TRANSPARENCY_PEN,3);
+
+				drawgfx(bitmap,Machine->gfx[0],
+							tile,
+							spriteram[i+1],
+							0, 0,
+							spriteram[i+3]+8,spriteram[i+2],
+							cliprect,TRANSPARENCY_PEN,3);
+
+				drawgfx(bitmap,Machine->gfx[0],
+							tile,
+							spriteram[i+1],
+							0, 0,
+							spriteram[i+3]+8,spriteram[i+2]+8,
+							cliprect,TRANSPARENCY_PEN,3);
+
+				drawgfx(bitmap,Machine->gfx[0],
+							tile,
+							spriteram[i+1],
+							0, 0,
+							spriteram[i+3],spriteram[i+2]+8,
+							cliprect,TRANSPARENCY_PEN,3);
+			}
+		}
+	}
+
+	tilemap_mark_all_tiles_dirty(cshooter_txtilemap);
 	tilemap_draw(bitmap,cliprect,cshooter_txtilemap,0,0);
 }
 
@@ -127,13 +197,26 @@ VIDEO_UPDATE(cshooter)
 
 INTERRUPT_GEN( cshooter_interrupt )
 {
-	cpunum_set_input_line_and_vector(0, 0, HOLD_LINE, 0x08); /* almost certainly wrong? */
+	if(cpu_getiloops())
+	{
+		cpunum_set_input_line_and_vector(0, 0, HOLD_LINE, 0x08);
+	}
+	else
+	{
+      cpunum_set_input_line_and_vector(0, 0, HOLD_LINE, 0x10);
+	}
+
+	if(mainram!=NULL)
+	{
+		ar_coin_hack();
+	}
+
 }
 
 
 static int cshooter_counter;
 
-static MACHINE_INIT( cshooter )
+static MACHINE_RESET( cshooter )
 {
 	cshooter_counter = 0;
 }
@@ -155,12 +238,45 @@ WRITE8_HANDLER ( cshooter_c700_w )
 {
 }
 
+WRITE8_HANDLER ( bank_w )
+{
+	memory_set_bankptr(1,&memory_region(REGION_USER1)[0x4000*((data>>4)&3)]);
+}
+
+
+static WRITE8_HANDLER(pal_w)
+{
+	int r,g,b;
+	paletteram[offset]=data;
+	offset&=0xff;
+	b=paletteram[offset+0x100]&0xf;
+	r=(paletteram[offset])>>4;
+	g=paletteram[offset]&0x0f;
+	palette_set_color(offset, r * 0x11, g * 0x11, b * 0x11);
+
+}
+
+static WRITE8_HANDLER(pal2_w)
+{
+	int r,g,b; /*guess */
+	paletteram[offset]=data;
+	offset&=0x1ff;
+	b=paletteram[offset+0x200]&0xf;
+	r=(paletteram[offset])>>4;
+	g=paletteram[offset]&0x0f;
+	palette_set_color(offset, r * 0x11, g * 0x11, b * 0x11);
+}
+
+static READ8_HANDLER(pal_r)
+{
+	return paletteram[offset];
+}
 
 static ADDRESS_MAP_START( readmem, ADDRESS_SPACE_PROGRAM, 8 )
 	AM_RANGE(0x0000, 0x7fff) AM_READ(MRA8_ROM)
-	AM_RANGE(0x8000, 0x87ff) AM_READ(MRA8_RAM)			/* to be confirmed */
+	AM_RANGE(0x8000, 0xafff) AM_READ(MRA8_BANK1)
 	AM_RANGE(0xb000, 0xb0ff) AM_READ(MRA8_RAM)			/* sound related ? */
-	AM_RANGE(0xc000, 0xc1ff) AM_READ(MRA8_RAM)
+	AM_RANGE(0xc000, 0xc1ff) AM_WRITE(pal_w) AM_READ(pal_r) AM_BASE(&paletteram)
 	AM_RANGE(0xc200, 0xc200) AM_READ(input_port_0_r)
 	AM_RANGE(0xc201, 0xc201) AM_READ(input_port_1_r)
 	AM_RANGE(0xc202, 0xc202) AM_READ(input_port_2_r)
@@ -174,8 +290,7 @@ ADDRESS_MAP_END
 
 static ADDRESS_MAP_START( writemem, ADDRESS_SPACE_PROGRAM, 8 )
 	AM_RANGE(0x0000, 0x7fff) AM_WRITE(MWA8_ROM)
-	AM_RANGE(0x8000, 0x87ff) AM_WRITE(MWA8_RAM)			/* to be confirmed */
-	AM_RANGE(0xc000, 0xc1ff) AM_WRITE(paletteram_BBGGGRRR_w) AM_BASE(&paletteram)	/* guess, maybe not */
+	AM_RANGE(0x8000, 0xafff) AM_WRITE(MWA8_RAM)			/* to be confirmed */
 	AM_RANGE(0xc500, 0xc500) AM_WRITE(cshooter_c500_w)
 	AM_RANGE(0xc600, 0xc600) AM_WRITE(MWA8_NOP)			/* see notes */
 	AM_RANGE(0xc700, 0xc700) AM_WRITE(cshooter_c700_w)
@@ -185,6 +300,38 @@ static ADDRESS_MAP_START( writemem, ADDRESS_SPACE_PROGRAM, 8 )
 	AM_RANGE(0xe000, 0xffff) AM_WRITE(MWA8_RAM)
 ADDRESS_MAP_END
 
+static ADDRESS_MAP_START( arreadmem, ADDRESS_SPACE_PROGRAM, 8 )
+	AM_RANGE(0x0000, 0x7fff) AM_READ(MRA8_ROM)
+	AM_RANGE(0x8000, 0xbfff) AM_READ(MRA8_BANK1)
+	AM_RANGE(0xb000, 0xb0ff) AM_RAM			/* sound related ? */
+	AM_RANGE(0xb100, 0xb1ff) AM_RAM/*READ(MRA8_BANK1)           // sound related ? */
+	AM_RANGE(0xc000, 0xc000) AM_READ(input_port_0_r)
+	AM_RANGE(0xc001, 0xc001) AM_READ(input_port_1_r)
+	AM_RANGE(0xc002, 0xc002) AM_READ(input_port_2_r)
+	AM_RANGE(0xc003, 0xc003) AM_READ(input_port_3_r)
+	AM_RANGE(0xc004, 0xc004) AM_READ(input_port_4_r)
+	AM_RANGE(0xd000, 0xd7ff) AM_READ(MRA8_RAM)
+	AM_RANGE(0xd800, 0xdbff) AM_WRITE(pal2_w) AM_READ(pal_r) AM_BASE(&paletteram)
+	AM_RANGE(0xdc11, 0xdc11) AM_WRITE(bank_w)
+	AM_RANGE(0xdc00, 0xddff) AM_RAM
+	AM_RANGE(0xde00, 0xdeff) AM_RAM
+	AM_RANGE(0xe000, 0xfdff) AM_RAM AM_BASE(&mainram)
+	AM_RANGE(0xfe00, 0xffff) AM_RAM AM_BASE(&spriteram) AM_SIZE(&spriteram_size)
+ADDRESS_MAP_END
+
+static ADDRESS_MAP_START( arwritemem, ADDRESS_SPACE_PROGRAM, 8 )
+	AM_RANGE(0x0000, 0x7fff) AM_WRITE(MWA8_ROM)
+
+
+	AM_RANGE(0xc500, 0xc500) AM_WRITE(cshooter_c500_w)
+	AM_RANGE(0xc600, 0xc600) AM_WRITE(MWA8_NOP)			/* see notes */
+	AM_RANGE(0xc700, 0xc700) AM_WRITE(cshooter_c700_w)
+	AM_RANGE(0xc801, 0xc801) AM_WRITE(MWA8_NOP)			/* see notes */
+	AM_RANGE(0xd000, 0xd7ff) AM_WRITE(cshooter_txram_w) AM_BASE(&cshooter_txram)
+
+ADDRESS_MAP_END
+
+
 static ADDRESS_MAP_START( readport, ADDRESS_SPACE_IO, 8 )
 	ADDRESS_MAP_FLAGS( AMEF_ABITS(8) )
 ADDRESS_MAP_END
@@ -197,12 +344,12 @@ ADDRESS_MAP_END
 /* Sound CPU */
 
 static ADDRESS_MAP_START( s_readmem, ADDRESS_SPACE_PROGRAM, 8 )
-	AM_RANGE(0x0000, 0x3fff) AM_READ(MRA8_ROM)
+	AM_RANGE(0x0000, 0x1fff) AM_READ(MRA8_ROM)
 	AM_RANGE(0xf800, 0xffff) AM_READ(MRA8_RAM)
 ADDRESS_MAP_END
 
 static ADDRESS_MAP_START( s_writemem, ADDRESS_SPACE_PROGRAM, 8 )
-	AM_RANGE(0x0000, 0x3fff) AM_WRITE(MWA8_ROM)
+	AM_RANGE(0x0000, 0x1fff) AM_WRITE(MWA8_ROM)
 	AM_RANGE(0xc000, 0xc000) AM_WRITE(MWA8_NOP) /* YM2203_control_port_0_w ? */
 	AM_RANGE(0xc001, 0xc001) AM_WRITE(MWA8_NOP) /* YM2203_write_port_0_w */
 	AM_RANGE(0xc800, 0xc800) AM_WRITE(MWA8_NOP) /* YM2203_control_port_1_w ? */
@@ -210,6 +357,22 @@ static ADDRESS_MAP_START( s_writemem, ADDRESS_SPACE_PROGRAM, 8 )
 	AM_RANGE(0xf800, 0xffff) AM_WRITE(MWA8_RAM)
 ADDRESS_MAP_END
 
+static ADDRESS_MAP_START( s2_readmem, ADDRESS_SPACE_PROGRAM, 8 )
+	AM_RANGE(0x0000, 0x1fff) AM_ROM
+	AM_RANGE(0x2000, 0x27ff) AM_RAM
+ADDRESS_MAP_END
+
+static ADDRESS_MAP_START( s2_writemem, ADDRESS_SPACE_PROGRAM, 8 )
+
+	AM_RANGE(0x4000, 0x4000) AM_WRITE(MWA8_NOP) /* YM2203_control_port_0_w ? */
+	AM_RANGE(0x4001, 0x4001) AM_WRITE(MWA8_NOP) /* YM2203_write_port_0_w */
+
+	AM_RANGE(0x4008, 0x4008) AM_WRITE(MWA8_NOP) /* YM2203_control_port_0_w ? */
+	AM_RANGE(0x4009, 0x4009) AM_WRITE(MWA8_NOP) /* YM2203_write_port_0_w */
+
+
+ADDRESS_MAP_END
+
 static ADDRESS_MAP_START( s_readport, ADDRESS_SPACE_IO, 8 )
 	ADDRESS_MAP_FLAGS( AMEF_ABITS(8) )
 ADDRESS_MAP_END
@@ -219,6 +382,8 @@ static ADDRESS_MAP_START( s_writeport, ADDRESS_SPACE_IO, 8 )
 ADDRESS_MAP_END
 
 
+
+
 INPUT_PORTS_START( cshooter )
 	PORT_START	/* IN0  (0xc200) */
 	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_JOYSTICK_UP ) PORT_8WAY
@@ -244,8 +409,8 @@ INPUT_PORTS_START( cshooter )
 	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_UNKNOWN )
 	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_UNKNOWN )
 	PORT_BIT( 0x04, IP_ACTIVE_LOW, IPT_UNKNOWN )
-	PORT_BIT( 0x08, IP_ACTIVE_LOW, IPT_START1 ) PORT_IMPULSE(1)
-	PORT_BIT( 0x10, IP_ACTIVE_LOW, IPT_START2 ) PORT_IMPULSE(1)
+	PORT_BIT( 0x08, IP_ACTIVE_LOW, IPT_START2 ) PORT_IMPULSE(1)
+	PORT_BIT( 0x10, IP_ACTIVE_LOW, IPT_START1 ) PORT_IMPULSE(1)
 	PORT_BIT( 0x20, IP_ACTIVE_LOW, IPT_UNKNOWN )
 	PORT_BIT( 0x40, IP_ACTIVE_LOW, IPT_UNKNOWN )
 	PORT_BIT( 0x80, IP_ACTIVE_LOW, IPT_UNKNOWN )
@@ -309,7 +474,7 @@ INPUT_PORTS_START( cshooter )
 INPUT_PORTS_END
 
 
-static gfx_layout cshooter_charlayout =
+static const gfx_layout cshooter_charlayout =
 {
 	8,8,		/* 8*8 characters */
 	RGN_FRAC(1,1),		/* 512 characters */
@@ -320,22 +485,11 @@ static gfx_layout cshooter_charlayout =
 	128*2
 };
 
-static gfx_layout cshooter_unknownlayout =
-{
-	8,8,		/* 8*8 characters */
-	RGN_FRAC(1,1),		/* 512 characters */
-	4,			/* 4 bits per pixel */
-	{ 0,8,16,24 },
-	{ 0,1,2,3,4,5,6,7 },
-	{ 0*32, 1*32, 2*32, 3*32, 4*32, 5*32, 6*32, 7*32 },
-	32*8
-};
 
-static gfx_decode gfxdecodeinfo[] =
+static const gfx_decode gfxdecodeinfo[] =
 {
-	{ REGION_GFX1, 0,     &cshooter_charlayout,   0, 1  },
-	{ REGION_GFX1, 128/8, &cshooter_charlayout,   0, 1  },
-	{ REGION_GFX2, 0,     &cshooter_unknownlayout,   0, 1  },
+	{ REGION_GFX1, 0,     &cshooter_charlayout,   0, 64  },
+	{ REGION_GFX1, 128/8, &cshooter_charlayout,   0, 64  },
 	{ -1 } /* end of array */
 };
 
@@ -343,22 +497,21 @@ static MACHINE_DRIVER_START( cshooter )
 	MDRV_CPU_ADD(Z80,6000000)		 /* ? MHz */
 	MDRV_CPU_PROGRAM_MAP(readmem,writemem)
 	MDRV_CPU_IO_MAP(readport,writeport)
-	MDRV_CPU_VBLANK_INT(cshooter_interrupt,1)
+	MDRV_CPU_VBLANK_INT(cshooter_interrupt,2)
 
 	MDRV_CPU_ADD(Z80,6000000)		 /* ? MHz */
 	MDRV_CPU_PROGRAM_MAP(s_readmem,s_writemem)
 	MDRV_CPU_IO_MAP(s_readport,s_writeport)
-/*  MDRV_CPU_VBLANK_INT(cshooter_interrupt,1) */
 
 	MDRV_FRAMES_PER_SECOND(60)
 	MDRV_VBLANK_DURATION(DEFAULT_60HZ_VBLANK_DURATION)
 
-	MDRV_MACHINE_INIT(cshooter)
+	MDRV_MACHINE_RESET(cshooter)
 
 	/* video hardware */
 	MDRV_VIDEO_ATTRIBUTES(VIDEO_TYPE_RASTER )
 	MDRV_SCREEN_SIZE(256, 256)
-	MDRV_VISIBLE_AREA(0, 256-1, 16, 256-16-1)
+	MDRV_VISIBLE_AREA(0, 256-1, 16, 256-1-16)
 	MDRV_GFXDECODE(gfxdecodeinfo)
 	MDRV_PALETTE_LENGTH(0x1000)
 
@@ -368,6 +521,36 @@ static MACHINE_DRIVER_START( cshooter )
 	/* sound hardware */
 MACHINE_DRIVER_END
 
+static MACHINE_DRIVER_START( airraid )
+	MDRV_CPU_ADD(Z80,6000000)		 /* ? MHz */
+	MDRV_CPU_PROGRAM_MAP(arreadmem,arwritemem)
+	MDRV_CPU_IO_MAP(readport,writeport)
+	MDRV_CPU_VBLANK_INT(cshooter_interrupt,2)
+
+	MDRV_CPU_ADD(Z80,6000000)		 /* ? MHz */
+	MDRV_CPU_PROGRAM_MAP(s2_readmem,s2_writemem)
+	MDRV_CPU_IO_MAP(s_readport,s_writeport)
+
+
+	MDRV_FRAMES_PER_SECOND(60)
+	MDRV_VBLANK_DURATION(DEFAULT_60HZ_VBLANK_DURATION)
+
+	MDRV_MACHINE_RESET(cshooter)
+
+	/* video hardware */
+	MDRV_VIDEO_ATTRIBUTES(VIDEO_TYPE_RASTER )
+	MDRV_SCREEN_SIZE(256, 256)
+	MDRV_VISIBLE_AREA(0, 256-1, 16, 256-1-16)
+	MDRV_GFXDECODE(gfxdecodeinfo)
+	MDRV_PALETTE_LENGTH(0x1000)
+
+	MDRV_VIDEO_START(cshooter)
+	MDRV_VIDEO_UPDATE(cshooter)
+
+	/* sound hardware */
+MACHINE_DRIVER_END
+
+
 
 /*
 
@@ -435,7 +618,10 @@ ROM_START( cshooter )
 	ROM_REGION( 0x02000, REGION_GFX1, 0 )	/* TX Layer */
 	ROM_LOAD( "r3",  0x00000, 0x02000, CRC(67b50a47) SHA1(b1f4aefc9437edbeefba5371149cc08c0b55c741) )	/* only 1 byte difference with 3.f11, bad dump? */
 
-	ROM_REGION( 0x10000, REGION_GFX2, 0 )	/* Sprites & Backgrounds ? */
+	ROM_REGION( 0x10000, REGION_GFX2, 0 )
+	ROM_LOAD( "gfx.bin",    0x0000, 0x10000, NO_DUMP )
+
+	ROM_REGION( 0x10000, REGION_USER1, 0 )	/* Sprites & Backgrounds ? */
 	ROM_LOAD( "r2",  0x00000, 0x10000, CRC(5ddf9f4e) SHA1(69e4d422ca272bf2e9f00edbe7d23760485fdfe6) )
 
 	ROM_REGION( 0x220, REGION_PROMS, 0 )
@@ -476,19 +662,22 @@ Note, all ROMs have official sticker, "(C) SEIBU KAIHATSU INC." and a number.
 */
 
 ROM_START( cshootre )
-	ROM_REGION( 2*0x10000, REGION_CPU1, 0 )	/* Main CPU? */
+	ROM_REGION( 0x10000, REGION_CPU1, 0 )	/* Main CPU? */
 	ROM_LOAD( "1.k19",  0x00000, 0x08000, CRC(71418952) SHA1(9745ca006576381c9e9595d8e42ab276bab80a41) )
 
-	ROM_REGION( 2*0x10000, REGION_CPU2, 0 )	/* Sub/Sound CPU? */
+	ROM_REGION( 0x10000, REGION_CPU2, 0 )	/* Sub/Sound CPU? */
 	ROM_LOAD( "5.6f",  0x00000, 0x02000, CRC(30be398c) SHA1(6c61200ee8888d6270c8cec50423b3b5602c2027) )	/* 5.g6 */
 
-	ROM_REGION( 0x02000, REGION_GFX1, 0 )	/* TX Layer */
+	ROM_REGION( 0x02000, REGION_GFX1,  ROMREGION_INVERT )	/* TX Layer */
 	ROM_LOAD( "3.f11",  0x00000, 0x02000, CRC(704c26d7) SHA1(e5964f409cbc2c4752e3969f3e84ace08d5ad9cb) )	/* only 1 byte difference with R3, bad dump? */
 
-	ROM_REGION( 0x10000, REGION_GFX2, 0 )	/* Sprites & Backgrounds ? */
+	ROM_REGION( 0x10000, REGION_GFX2, 0 )
+	ROM_LOAD( "gfx.bin",    0x0000, 0x10000, NO_DUMP )
+
+	ROM_REGION( 0x10000, REGION_USER1, 0 )	/* Sprites & Backgrounds ? */
 	ROM_LOAD( "2.k20",  0x00000, 0x10000, CRC(5812fe72) SHA1(3b28bff6b62a411d2195bb228952db62ad32ef3d) )
 
-	ROM_REGION( 0x08000, REGION_GFX3, 0 )	/* ?? sound ?? unknown rom */
+	ROM_REGION( 0x08000, REGION_USER2, 0 )	/* ?? sound ?? */
 	ROM_LOAD( "4.7f",  0x00000, 0x08000, CRC(3cd715b4) SHA1(da735fb5d262908ddf7ed7dacdea68899f1723ff) )	/* 4.g8 */
 ROM_END
 
@@ -515,19 +704,22 @@ SEI0030BU          SEI0060BU                             sw1 xx xxxxx
 */
 
 ROM_START( airraid )
-	ROM_REGION( 2*0x10000, REGION_CPU1, 0 )	/* Main CPU? */
+	ROM_REGION( 0x10000, REGION_CPU1, 0 )	/* Main CPU? */
 	ROM_LOAD( "1.16j",  0x00000, 0x08000, CRC(7ac2cedf) SHA1(272831f51a2731e067b5aec6dba6bddd3c5350c9) )
 
-	ROM_REGION( 2*0x10000, REGION_CPU2, 0 )	/* Sub/Sound CPU? */
+	ROM_REGION( 0x10000, REGION_CPU2, 0 )	/* Sub/Sound CPU? */
 	ROM_LOAD( "5.6f",  0x00000, 0x02000, CRC(30be398c) SHA1(6c61200ee8888d6270c8cec50423b3b5602c2027) )
 
-	ROM_REGION( 0x02000, REGION_GFX1, 0 )	/* TX Layer */
+	ROM_REGION( 0x02000, REGION_GFX1, ROMREGION_INVERT )	/* TX Layer */
 	ROM_LOAD( "3.13e",  0x00000, 0x02000, CRC(672ec0e8) SHA1(a11cd90d6494251ceee3bc7c72f4e7b1580b77e2) )
 
-	ROM_REGION( 0x10000, REGION_GFX2, 0 )	/* Sprites & Backgrounds ? */
+	ROM_REGION( 0x10000, REGION_GFX2, 0 )
+	ROM_LOAD( "gfx.bin",    0x0000, 0x10000, NO_DUMP )
+
+	ROM_REGION( 0x10000, REGION_USER1, 0 )	/* bg maps */
 	ROM_LOAD( "2.19j",  0x00000, 0x10000, CRC(842ae6c2) SHA1(0468445e4ab6f42bac786f9a258df3972fd1fde9) )
 
-	ROM_REGION( 0x08000, REGION_GFX3, 0 )	/* ?? sound ?? unknown rom */
+	ROM_REGION( 0x08000, REGION_USER2, 0 )	/* ?? sound ?? */
 	ROM_LOAD( "4.7f",  0x00000, 0x08000, CRC(3cd715b4) SHA1(da735fb5d262908ddf7ed7dacdea68899f1723ff) )
 ROM_END
 
@@ -540,33 +732,33 @@ DRIVER_INIT( cshooter )
 	rom[0xa2] = 0x00;
 	rom[0xa3] = 0x00;
 	rom[0xa4] = 0x00;
-
+	memory_set_bankptr(1,&memory_region(REGION_USER1)[0]);
 }
 
 DRIVER_INIT( cshootre )
 {
 	int A;
-	unsigned char *rom = memory_region(REGION_CPU1);
-	int diff = memory_region_length(REGION_CPU1) / 2;
+	UINT8 *rom = memory_region(REGION_CPU1);
+	UINT8 *decrypt = auto_malloc(0x8000);
 
-	memory_set_opcode_base(0,rom+diff);
+	memory_set_decrypted_region(0, 0x0000, 0x7fff, decrypt);
 
 	for (A = 0x0000;A < 0x8000;A++)
 	{
 		/* decode the opcodes */
-		rom[A+diff] = rom[A];
+		decrypt[A] = rom[A];
 
 		if (BIT(A,5) && !BIT(A,3))
-			rom[A+diff] ^= 0x40;
+			decrypt[A] ^= 0x40;
 
 		if (BIT(A,10) && !BIT(A,9) && BIT(A,3))
-			rom[A+diff] ^= 0x20;
+			decrypt[A] ^= 0x20;
 
 		if ((BIT(A,10) ^ BIT(A,9)) && BIT(A,1))
-			rom[A+diff] ^= 0x02;
+			decrypt[A] ^= 0x02;
 
 		if (BIT(A,9) || !BIT(A,5) || BIT(A,3))
-			rom[A+diff] = BITSWAP8(rom[A+diff],7,6,1,4,3,2,5,0);
+			decrypt[A] = BITSWAP8(decrypt[A],7,6,1,4,3,2,5,0);
 
 		/* decode the data */
 		if (BIT(A,5))
@@ -576,12 +768,12 @@ DRIVER_INIT( cshootre )
 			rom[A] = BITSWAP8(rom[A],7,6,1,4,3,2,5,0);
 	}
 
-
+	memory_set_bankptr(1,&memory_region(REGION_USER1)[0]);
 	seibu_sound_decrypt(REGION_CPU2,0x2000);
 }
 
 
 
 GAME( 1987, cshooter, 0,        cshooter, cshooter, cshooter, ROT270, "[Seibu Kaihatsu] (Taito license)",  "Cross Shooter (not encrypted)", GAME_NOT_WORKING | GAME_NO_SOUND )
-GAME( 1987, cshootre, cshooter, cshooter, cshooter, cshootre, ROT270, "[Seibu Kaihatsu] (J.K.H. license)", "Cross Shooter (encrypted)", GAME_NOT_WORKING | GAME_NO_SOUND )
-GAME( 1987, airraid,  cshooter, cshooter, cshooter, cshootre, ROT270, "Seibu Kaihatsu",                    "Air Raid (encrypted)", GAME_NOT_WORKING | GAME_NO_SOUND )
+GAME( 1987, cshootre, cshooter, airraid, cshooter, cshootre, ROT270, "[Seibu Kaihatsu] (J.K.H. license)", "Cross Shooter (encrypted)", GAME_NOT_WORKING | GAME_NO_SOUND )
+GAME( 1987, airraid,  cshooter, airraid, cshooter, cshootre, ROT270, "Seibu Kaihatsu",                    "Air Raid (encrypted)", GAME_NOT_WORKING | GAME_NO_SOUND )
