@@ -83,11 +83,11 @@ Hardware Info
 ***************************************************************************/
 
 #include "driver.h"
-#include "vidhrdw/generic.h"
 #include "cpu/s2650/s2650.h"
 #include "sound/dac.h"
 #include "sound/5110intf.h"
 #include "sound/tms5110.h"
+#include "vidhrdw/s2636.h"
 
 INTERRUPT_GEN( cvs_interrupt );
 PALETTE_INIT( cvs );
@@ -95,9 +95,6 @@ VIDEO_UPDATE( cvs );
 VIDEO_START( cvs );
 
 extern unsigned char *bullet_ram;
-extern unsigned char *s2636_1_ram;
-extern unsigned char *s2636_2_ram;
-extern unsigned char *s2636_3_ram;
 
 WRITE8_HANDLER( cvs_videoram_w );
 WRITE8_HANDLER( cvs_bullet_w );
@@ -338,7 +335,7 @@ INPUT_PORTS_START( cvs )
 
 INPUT_PORTS_END
 
-static gfx_layout charlayout8colour =
+static const gfx_layout charlayout8colour =
 {
 	8,8,	/* 8*8 characters */
 	256,	/* 256 characters */
@@ -351,7 +348,7 @@ static gfx_layout charlayout8colour =
 
 /* S2636 Mappings */
 
-static gfx_layout s2636_character10 =
+static const gfx_layout s2636_character10 =
 {
 	8,10,
 	5,
@@ -362,7 +359,7 @@ static gfx_layout s2636_character10 =
 	8*16
 };
 
-static gfx_decode cvs_gfxdecodeinfo[] =
+static const gfx_decode cvs_gfxdecodeinfo[] =
 {
 	{ REGION_GFX1, 0x0000, &charlayout8colour, 0, 259 },	/* Rom chars */
 	{ REGION_GFX1, 0x0000, &charlayout8colour, 0, 259 },	/* Ram chars */
@@ -427,6 +424,9 @@ ROM_START( cvs )
 	ROM_REGION( 0x0820, REGION_PROMS, 0 )
     ROM_LOAD( "82s185.10h",        0x0000, 0x0800, CRC(c205bca6) SHA1(ec9bd220e75f7b067ede6139763ef8aca0fb7a29) )
 	ROM_LOAD( "82s123.10k",        0x0800, 0x0020, CRC(b5221cec) SHA1(71d9830b33b1a8140b0fe1a2ba8024ba8e6e48e0) )
+
+	ROM_REGION( 0x1800, REGION_GFX1, ROMREGION_DISPOSE )
+	ROM_FILL(0x000000, 0x1800, 0 )
 ROM_END
 
 
