@@ -119,13 +119,12 @@ lev 7 : 0x7c : 0000 07e0 - input device clear?
 *******************************************************************************************/
 
 #include "driver.h"
-#include "vidhrdw/generic.h"
 #include "sound/3812intf.h"
 
 static tilemap *tx_tilemap;
 static UINT16 *tx_vram;
-UINT16 *slave_data;
-UINT16 *com_ram;
+static UINT16 *slave_data;
+static UINT16 *com_ram;
 /*static UINT16 mux_data; */
 
 #define MASTER_CPU (cpu_getactivecpu() == 0)
@@ -363,7 +362,7 @@ INPUT_PORTS_START( cybertnk )
 	PORT_BIT( 	  0xff00, IP_ACTIVE_LOW, IPT_UNUSED )
 INPUT_PORTS_END
 
-static gfx_layout tile_8x8x4 =
+static const gfx_layout tile_8x8x4 =
 {
 	8,8,
 	RGN_FRAC(1,4),
@@ -374,7 +373,7 @@ static gfx_layout tile_8x8x4 =
     8*8
 };
 
-static gfx_layout tile_16x16x4 =
+static const gfx_layout tile_16x16x4 =
 {
 	16,16,
 	RGN_FRAC(1,4),
@@ -385,7 +384,7 @@ static gfx_layout tile_16x16x4 =
     32*8
 };
 
-static gfx_decode gfxdecodeinfo[] =
+static const gfx_decode gfxdecodeinfo[] =
 {
 	{ REGION_GFX1, 0, &tile_8x8x4,     0x1400, 16 }, /*Pal offset???*/
 	{ REGION_GFX2, 0, &tile_8x8x4,     0,      0x400 },
