@@ -12,7 +12,6 @@
 ******************************************************************************/
 
 #include "driver.h"
-#include "vidhrdw/generic.h"
 
 static UINT8 *bgvideoram,*fgvideoram;
 static int bg_bank = 0;
@@ -242,7 +241,7 @@ VIDEO_UPDATE(dacholer)
 	draw_sprites(bitmap,cliprect);
 }
 
-static gfx_layout charlayout =
+static const gfx_layout charlayout =
 {
 	8,8,
 	RGN_FRAC(1,1),
@@ -253,7 +252,7 @@ static gfx_layout charlayout =
 	32*8
 };
 
-static gfx_layout spritelayout =
+static const gfx_layout spritelayout =
 {
 	16,16,
 	RGN_FRAC(1,1),
@@ -265,7 +264,7 @@ static gfx_layout spritelayout =
 	16*16*4
 };
 
-static gfx_decode gfxdecodeinfo[] =
+static const gfx_decode gfxdecodeinfo[] =
 {
 	{ REGION_GFX1, 0, &charlayout,   0, 16 },
 	{ REGION_GFX2, 0, &charlayout,   0, 16 },
