@@ -2,7 +2,6 @@
 /* 'nothing' driver ;-) */
 
 #include "driver.h"
-#include "vidhrdw/generic.h"
 #include "sound/ay8910.h"
 
 
@@ -39,7 +38,7 @@ ADDRESS_MAP_END
 INPUT_PORTS_START( dambustr )
 INPUT_PORTS_END
 
-static gfx_layout charlayout =
+static const gfx_layout charlayout =
 {
 	8,8,
 	RGN_FRAC(1,2),
@@ -50,7 +49,7 @@ static gfx_layout charlayout =
 	8*8
 };
 
-static gfx_decode gfxdecodeinfo[] =
+static const gfx_decode gfxdecodeinfo[] =
 {
 	{ REGION_GFX1, 0, &charlayout,     0, 8 },
 	{ -1 }	/* end of array */
@@ -114,15 +113,15 @@ ROM_END
 ROM_START( dambust )
 	ROM_REGION( 0x10000, REGION_CPU1, 0 )
 	ROM_LOAD( "db05.bin",   0x4000, 0x1000, CRC(75659ecc) SHA1(b61254fb12f3999607abd88d1cc649dcfbf0384c) )
-	ROM_LOAD( "db06p.bin",   0x5000, 0x1000,  CRC(35dcee01) )
+	ROM_LOAD( "db06p.bin",   0x5000, 0x1000,  CRC(35dcee01) SHA1(2c23c727d9b38322a6d0548dfe6a2a254f3530af) )
 	ROM_LOAD( "db07.bin",   0x6000, 0x1000,  CRC(675b1f5e) SHA1(6a386212a640fb467b6956a4dc5a68476af1cf97) )
 	ROM_LOAD( "db08.bin",   0x7000, 0x1000,  CRC(fd041ff4) SHA1(8d27da7bf0c655633711b960cbc23950c8a371ae) )
 
 	ROM_REGION( 0x10000,REGION_USER1,0)
- 	ROM_LOAD( "db11.bin",   0x0000, 0x1000, CRC(9e6b34fe) )
+ 	ROM_LOAD( "db11.bin",   0x0000, 0x1000, CRC(9e6b34fe) SHA1(5cf47f5a5280ac53490240df220edf6178e87f4f) )
 	ROM_LOAD( "db09.bin",    0x1000, 0x1000, CRC(57164563) SHA1(8471d0660f39511d0afa3cdd63a1e84b0ea80fd0) )
-	ROM_LOAD( "db10p.bin",   0x2000, 0x1000, CRC(c129c57b) )
-	ROM_LOAD( "db12.bin",   0x3000, 0x1000, CRC(ea4c65f5) )
+	ROM_LOAD( "db10p.bin",   0x2000, 0x1000, CRC(c129c57b) SHA1(c25abd7ee97b71941d9fa6acd0d92c116f1ff408) )
+	ROM_LOAD( "db12.bin",   0x3000, 0x1000, CRC(ea4c65f5) SHA1(cb761e0543cacd6b437c6e88615f97df83245a34) )
 
 	ROM_REGION( 0x4000, REGION_GFX1, ROMREGION_DISPOSE )
 	ROM_LOAD( "db1ap.bin",   0x1000, 0x1000, CRC(4cb964cd) SHA1(1c90b14deb201a64b8ed4378b022e9e4574aed94) )
