@@ -119,7 +119,6 @@ Stephh's notes (based on the games M68000 code and some tests) :
 ***************************************************************************/
 
 #include "driver.h"
-#include "vidhrdw/generic.h"
 #include "cpu/h6280/h6280.h"
 #include "deco16ic.h"
 #include "sound/2203intf.h"
@@ -129,7 +128,7 @@ Stephh's notes (based on the games M68000 code and some tests) :
 VIDEO_START( dassault );
 VIDEO_UPDATE( dassault );
 
-static data16_t *dassault_ram,*shared_ram,*dassault_ram2;
+static UINT16 *dassault_ram,*shared_ram,*dassault_ram2;
 
 /**********************************************************************************/
 
@@ -284,7 +283,7 @@ static ADDRESS_MAP_START( sound_writemem, ADDRESS_SPACE_PROGRAM, 8 )
 	AM_RANGE(0x130000, 0x130001) AM_WRITE(OKIM6295_data_1_w)
 	AM_RANGE(0x1f0000, 0x1f1fff) AM_WRITE(MWA8_BANK8)
 	AM_RANGE(0x1fec00, 0x1fec01) AM_WRITE(H6280_timer_w)
-	AM_RANGE(0x1ff402, 0x1ff403) AM_WRITE(H6280_irq_status_w)
+	AM_RANGE(0x1ff400, 0x1ff403) AM_WRITE(H6280_irq_status_w)
 ADDRESS_MAP_END
 
 /**********************************************************************************/
@@ -527,7 +526,7 @@ INPUT_PORTS_END
 
 /**********************************************************************************/
 
-static struct GfxLayout charlayout =
+static const gfx_layout charlayout =
 {
 	8,8,
 	RGN_FRAC(1,2),
@@ -538,7 +537,7 @@ static struct GfxLayout charlayout =
 	16*8
 };
 
-static struct GfxLayout tilelayout =
+static const gfx_layout tilelayout =
 {
 	16,16,
 	RGN_FRAC(1,2),
@@ -551,7 +550,7 @@ static struct GfxLayout tilelayout =
 	64*8
 };
 
-static struct GfxDecodeInfo gfxdecodeinfo[] =
+static const gfx_decode gfxdecodeinfo[] =
 {
 	/* REGION_GFX1 is copied to REGION_GFX2 at runtime */
 	{ REGION_GFX2, 0, &charlayout,     0,  32 },	/* Characters 8x8 */
@@ -569,7 +568,7 @@ static void sound_irq(int state)
 	cpunum_set_input_line(2,1,state);
 }
 
-WRITE8_HANDLER( sound_bankswitch_w )
+static WRITE8_HANDLER( sound_bankswitch_w )
 {
 	/* the second OKIM6295 ROM is bank switched */
 	OKIM6295_set_bank_base(1, (data & 1) * 0x40000);
@@ -829,9 +828,9 @@ static READ16_HANDLER( thndzone_main_skip )
 
 static void init_dassault(void)
 {
-	const data8_t *src = memory_region(REGION_GFX1);
-	data8_t *dst = memory_region(REGION_GFX2);
-	data8_t *tmp = (data8_t *)malloc(0x80000);
+	const UINT8 *src = memory_region(REGION_GFX1);
+	UINT8 *dst = memory_region(REGION_GFX2);
+	UINT8 *tmp = (UINT8 *)malloc(0x80000);
 
 	/* Playfield 4 also has access to the char graphics, make things easier
     by just copying the chars to both banks (if I just used a different gfx
@@ -849,9 +848,9 @@ static void init_dassault(void)
 
 static void init_thndzone(void)
 {
-	const data8_t *src = memory_region(REGION_GFX1);
-	data8_t *dst = memory_region(REGION_GFX2);
-	data8_t *tmp = (data8_t *)malloc(0x80000);
+	const UINT8 *src = memory_region(REGION_GFX1);
+	UINT8 *dst = memory_region(REGION_GFX2);
+	UINT8 *tmp = (UINT8 *)malloc(0x80000);
 
 	/* Playfield 4 also has access to the char graphics, make things easier
     by just copying the chars to both banks (if I just used a different gfx
@@ -869,6 +868,6 @@ static void init_thndzone(void)
 
 /**********************************************************************************/
 
-GAME(1991, thndzone, 0,        dassault, thndzone, thndzone, ROT0, "Data East Corporation", "Thunder Zone (World)" )
-GAME(1991, dassault, thndzone, dassault, dassault, dassault, ROT0, "Data East Corporation", "Desert Assault (US)" )
-GAME(1991, dassaul4, thndzone, dassault, dassaul4, dassault, ROT0, "Data East Corporation", "Desert Assault (US 4 Players)" )
+GAME( 1991, thndzone, 0,        dassault, thndzone, thndzone, ROT0, "Data East Corporation", "Thunder Zone (World)", 0 )
+GAME( 1991, dassault, thndzone, dassault, dassault, dassault, ROT0, "Data East Corporation", "Desert Assault (US)", 0 )
+GAME( 1991, dassaul4, thndzone, dassault, dassaul4, dassault, ROT0, "Data East Corporation", "Desert Assault (US 4 Players)", 0 )
