@@ -12,11 +12,9 @@ the most protected of the DE102 games?
 #include "driver.h"
 #include "cpu/m68000/m68000.h"
 #include "decocrpt.h"
-#include "vidhrdw/generic.h"
 #include "deco16ic.h"
 #include "sound/2151intf.h"
 #include "sound/okim6295.h"
-#include "machine/random.h"
 
 extern void deco102_decrypt(int region, int address_xor, int data_select_xor, int opcode_select_xor);
 
@@ -354,7 +352,7 @@ ADDRESS_MAP_END
 
 
 
-static gfx_layout tile_8x8_layout =
+static const gfx_layout tile_8x8_layout =
 {
 	8,8,
 	RGN_FRAC(1,2),
@@ -365,7 +363,7 @@ static gfx_layout tile_8x8_layout =
 	8*16
 };
 
-static gfx_layout tile_16x16_layout =
+static const gfx_layout tile_16x16_layout =
 {
 	16,16,
 	RGN_FRAC(1,2),
@@ -376,7 +374,7 @@ static gfx_layout tile_16x16_layout =
 	32*16
 };
 
-static gfx_layout spritelayout =
+static const gfx_layout spritelayout =
 {
 	16,16,
 	RGN_FRAC(1,1),
@@ -389,7 +387,7 @@ static gfx_layout spritelayout =
 };
 
 
-static gfx_decode gfxdecodeinfo[] =
+static const gfx_decode gfxdecodeinfo[] =
 {
 	{ REGION_GFX1, 0, &tile_8x8_layout,     0x000, 32 },	/* Tiles (8x8) */
 	{ REGION_GFX1, 0, &tile_16x16_layout,   0x000, 32 },	/* Tiles (16x16) */
