@@ -7,21 +7,22 @@
     Games supported:
         * Double Cheese
         * Lotto Fun 2
-
-    Other games on this hardware:
-        * Flintstones Memory Match?
+        * Fred Flintstones' Memory Match
 
     Known bugs:
         * Test/tilt buttons seem to be swapped compared to test mode
         * Don't know what the opto switches do
 
+    [fredmem]
+    * Controls are set up as a 3 x 3 matrix of buttons that match the 9
+      positions on the screen.
+
 **************************************************************************/
 
 
 #include "driver.h"
 #include "machine/eeprom.h"
 #include "machine/ticket.h"
-#include "vidhrdw/generic.h"
 #include "sound/bsmt2000.h"
 #include "dcheese.h"
 
@@ -97,9 +98,14 @@ static INTERRUPT_GEN( dcheese_vblank )
  *
  *************************************/
 
-static MACHINE_INIT( dcheese )
+static MACHINE_START( dcheese )
 {
-	cpu_set_irq_callback(0, irq_callback);
+	cpunum_set_irq_callback(0, irq_callback);
+
+	state_save_register_global_array(irq_state);
+	state_save_register_global(soundlatch_full);
+
+	return 0;
 }
 
 
@@ -222,11 +228,11 @@ ADDRESS_MAP_END
 
 static ADDRESS_MAP_START( sound_cpu_map, ADDRESS_SPACE_PROGRAM, 8 )
 	ADDRESS_MAP_FLAGS( AMEF_UNMAP(1) )
-	AM_RANGE(0x0100, 0x0100) AM_READWRITE(sound_status_r, sound_control_w)
-	AM_RANGE(0x0800, 0x0800) AM_READ(sound_command_r)
-	AM_RANGE(0x1000, 0x10ff) AM_WRITE(bsmt_data_w)
+	AM_RANGE(0x0000, 0x07ff) AM_READWRITE(sound_status_r, sound_control_w)
+	AM_RANGE(0x0800, 0x0fff) AM_READ(sound_command_r)
+	AM_RANGE(0x1000, 0x10ff) AM_MIRROR(0x0700) AM_WRITE(bsmt_data_w)
 	AM_RANGE(0x1800, 0x1fff) AM_RAM
-	AM_RANGE(0x8000, 0xffff) AM_ROM
+	AM_RANGE(0x2000, 0xffff) AM_ROM
 ADDRESS_MAP_END
 
 
@@ -327,6 +333,51 @@ INPUT_PORTS_START( lottof2 )
 INPUT_PORTS_END
 
 
+INPUT_PORTS_START( fredmem )
+	PORT_START	/* 200000 */
+	PORT_BIT( 0x0001, IP_ACTIVE_LOW, IPT_COIN2 )
+	PORT_BIT( 0x0002, IP_ACTIVE_LOW, IPT_COIN1 )
+	PORT_BIT( 0x000c, IP_ACTIVE_LOW, IPT_UNUSED )
+	PORT_BIT( 0x0010, IP_ACTIVE_LOW, IPT_SERVICE )
+	PORT_BIT( 0x0020, IP_ACTIVE_LOW, IPT_TILT )
+	PORT_BIT( 0x0040, IP_ACTIVE_LOW, IPT_SERVICE1 )
+	PORT_BIT( 0x0080, IP_ACTIVE_LOW, IPT_SPECIAL )		/* EEPROM data */
+	PORT_BIT( 0x1f00, IP_ACTIVE_LOW, IPT_UNUSED )
+	PORT_BIT( 0x2000, IP_ACTIVE_LOW, IPT_BUTTON5 ) PORT_CODE(KEYCODE_5_PAD)
+	PORT_BIT( 0xc000, IP_ACTIVE_LOW, IPT_UNUSED )
+
+	PORT_START	/* 220000 */
+	PORT_BIT( 0xffff, IP_ACTIVE_LOW, IPT_UNKNOWN )
+
+	PORT_START	/* 240000 */
+	PORT_BIT( 0x001f, IP_ACTIVE_LOW, IPT_UNKNOWN )		/* low 5 bits read as a unit */
+	PORT_BIT( 0x0020, IP_ACTIVE_HIGH, IPT_SPECIAL )		/* ticket status */
+	PORT_BIT( 0x0040, IP_ACTIVE_HIGH, IPT_SPECIAL )		/* sound->main buffer status (0=empty) */
+	PORT_BIT( 0x0080, IP_ACTIVE_HIGH, IPT_SPECIAL )		/* main->sound buffer status (1=empty) */
+	PORT_BIT( 0x0100, IP_ACTIVE_LOW, IPT_UNUSED )
+	PORT_BIT( 0x0200, IP_ACTIVE_LOW, IPT_VOLUME_DOWN )
+	PORT_BIT( 0x0400, IP_ACTIVE_LOW, IPT_UNUSED )
+	PORT_BIT( 0x0800, IP_ACTIVE_LOW, IPT_VOLUME_UP )
+	PORT_BIT( 0xf000, IP_ACTIVE_LOW, IPT_UNUSED )
+
+	PORT_START	/* 2a0002 */
+	PORT_BIT( 0x0001, IP_ACTIVE_LOW, IPT_BUTTON6 ) PORT_CODE(KEYCODE_6_PAD)
+	PORT_BIT( 0x0002, IP_ACTIVE_LOW, IPT_BUTTON7 ) PORT_CODE(KEYCODE_1_PAD)
+	PORT_BIT( 0x0004, IP_ACTIVE_LOW, IPT_BUTTON8 ) PORT_CODE(KEYCODE_2_PAD)
+	PORT_BIT( 0x0008, IP_ACTIVE_LOW, IPT_BUTTON9 ) PORT_CODE(KEYCODE_3_PAD)
+	PORT_BIT( 0x0010, IP_ACTIVE_LOW, IPT_BUTTON1 ) PORT_CODE(KEYCODE_7_PAD)
+	PORT_BIT( 0x0020, IP_ACTIVE_LOW, IPT_BUTTON2 ) PORT_CODE(KEYCODE_8_PAD)
+	PORT_BIT( 0x0040, IP_ACTIVE_LOW, IPT_BUTTON3 ) PORT_CODE(KEYCODE_9_PAD)
+	PORT_BIT( 0x0080, IP_ACTIVE_LOW, IPT_BUTTON4 ) PORT_CODE(KEYCODE_4_PAD)
+	PORT_BIT( 0x0100, IP_ACTIVE_LOW, IPT_UNKNOWN )
+	PORT_BIT( 0x0200, IP_ACTIVE_LOW, IPT_SPECIAL )
+	PORT_BIT( 0xfc00, IP_ACTIVE_LOW, IPT_UNKNOWN )
+
+	PORT_START	/* 2a000e */
+	PORT_BIT( 0xffff, IP_ACTIVE_LOW, IPT_UNKNOWN )
+INPUT_PORTS_END
+
+
 
 /*************************************
  *
@@ -357,16 +408,16 @@ static MACHINE_DRIVER_START( dcheese )
 
 	MDRV_CPU_ADD(M6809, SOUND_OSC/16)
 	MDRV_CPU_PROGRAM_MAP(sound_cpu_map,0)
-	MDRV_CPU_PERIODIC_INT(irq1_line_hold,TIME_IN_HZ(500))	/* guess */
+	MDRV_CPU_PERIODIC_INT(irq1_line_hold,TIME_IN_HZ(480))	/* accurate for fredmem */
 
-	MDRV_MACHINE_INIT(dcheese)
+	MDRV_MACHINE_START(dcheese)
 	MDRV_FRAMES_PER_SECOND(60)
 	MDRV_VBLANK_DURATION(DEFAULT_60HZ_VBLANK_DURATION)
 	MDRV_NVRAM_HANDLER(93C46)
 
 	/* video hardware */
 	MDRV_VIDEO_ATTRIBUTES(VIDEO_TYPE_RASTER)
-	MDRV_SCREEN_SIZE(320, 240)
+	MDRV_SCREEN_SIZE(360, 240)
 	MDRV_VISIBLE_AREA(0, 319, 0, 239)
 
 	MDRV_PALETTE_LENGTH(65534)
@@ -385,6 +436,12 @@ static MACHINE_DRIVER_START( dcheese )
 MACHINE_DRIVER_END
 
 
+static MACHINE_DRIVER_START( fredmem )
+	MDRV_IMPORT_FROM(dcheese)
+	MDRV_VISIBLE_AREA(0, 359, 0, 239)
+MACHINE_DRIVER_END
+
+
 
 /*************************************
  *
@@ -417,10 +474,30 @@ ROM_START( dcheese )
 	ROM_LOAD( "dchez.125", 0x80000, 0x40000, CRC(ddf28bab) SHA1(0f3bc86d0db7afebf8c6094b8337e5f343a82f29) )
 
 	ROM_REGION( 0x400000, REGION_SOUND1, 0 )
-	ROM_LOAD( "dchez.ar0", 0x0c0000, 0x40000, CRC(6a9e2b12) SHA1(f7cb4d6b4a459682a68f734b2b2e27e3639b9ed5) )
-	ROM_LOAD( "dchez.ar1", 0x1c0000, 0x40000, CRC(5f3a5f41) SHA1(30e0c7b2ab43a3224432204a9388d509a6a06a11) )
-	ROM_LOAD( "dchez.ar2", 0x2c0000, 0x20000, CRC(d79b0d41) SHA1(cc84ddf6635097ba0aad2f1838ad0606c5bb8166) )
-	ROM_LOAD( "dchez.ar3", 0x3c0000, 0x20000, CRC(2056c1fd) SHA1(4c44930fb87ea6ad71326cc29313f3b817919d08) )
+	ROM_LOAD( "dchez.ar0", 0x000000, 0x40000, CRC(6a9e2b12) SHA1(f7cb4d6b4a459682a68f734b2b2e27e3639b9ed5) )
+	ROM_RELOAD(            0x040000, 0x40000 )
+	ROM_RELOAD(            0x080000, 0x40000 )
+	ROM_RELOAD(            0x0c0000, 0x40000 )
+	ROM_LOAD( "dchez.ar1", 0x100000, 0x40000, CRC(5f3a5f41) SHA1(30e0c7b2ab43a3224432204a9388d509a6a06a11) )
+	ROM_RELOAD(            0x140000, 0x40000 )
+	ROM_RELOAD(            0x180000, 0x40000 )
+	ROM_RELOAD(            0x1c0000, 0x40000 )
+	ROM_LOAD( "dchez.ar2", 0x200000, 0x20000, CRC(d79b0d41) SHA1(cc84ddf6635097ba0aad2f1838ad0606c5bb8166) )
+	ROM_RELOAD(            0x220000, 0x20000 )
+	ROM_RELOAD(            0x240000, 0x20000 )
+	ROM_RELOAD(            0x260000, 0x20000 )
+	ROM_RELOAD(            0x280000, 0x20000 )
+	ROM_RELOAD(            0x2a0000, 0x20000 )
+	ROM_RELOAD(            0x2c0000, 0x20000 )
+	ROM_RELOAD(            0x2e0000, 0x20000 )
+	ROM_LOAD( "dchez.ar3", 0x300000, 0x20000, CRC(2056c1fd) SHA1(4c44930fb87ea6ad71326cc29313f3b817919d08) )
+	ROM_RELOAD(            0x320000, 0x20000 )
+	ROM_RELOAD(            0x340000, 0x20000 )
+	ROM_RELOAD(            0x360000, 0x20000 )
+	ROM_RELOAD(            0x380000, 0x20000 )
+	ROM_RELOAD(            0x3a0000, 0x20000 )
+	ROM_RELOAD(            0x3c0000, 0x20000 )
+	ROM_RELOAD(            0x3e0000, 0x20000 )
 
 	ROM_REGION16_LE( 0x20000, REGION_USER1, 0 )
 	ROM_LOAD16_BYTE( "dchez.144", 0x00000, 0x10000, CRC(52c96252) SHA1(46de465c25e4602aa360336315b3c8e1a9a0b5f3) )
@@ -444,9 +521,33 @@ ROM_START( lottof2 )
 
 	ROM_REGION( 0x400000, REGION_SOUND1, 0 )
 	ROM_LOAD( "arom0.r10", 0x000000, 0x40000, CRC(05e7581b) SHA1(e12be200abfbef269fc085d6c5efea106487e05f) )
-	ROM_LOAD( "arom1.r10", 0x1e0000, 0x20000, CRC(6c4ebbfd) SHA1(2b396d96ce8903e5e8d455ce019422b744f3c4d5) )
-	ROM_LOAD( "arom2.r10", 0x2e0000, 0x20000, CRC(fbe9fbbb) SHA1(457fc3c0d33cf430e5969f4fa11317f1f930351b) )
-	ROM_LOAD( "arom3.r10", 0x3e0000, 0x20000, CRC(ffb6e463) SHA1(1349455d2ce8eb141bc0fa5219f5e7c52ee969dc) )
+	ROM_RELOAD(            0x040000, 0x40000 )
+	ROM_RELOAD(            0x080000, 0x40000 )
+	ROM_RELOAD(            0x0c0000, 0x40000 )
+	ROM_LOAD( "arom1.r10", 0x100000, 0x20000, CRC(6c4ebbfd) SHA1(2b396d96ce8903e5e8d455ce019422b744f3c4d5) )
+	ROM_RELOAD(            0x120000, 0x20000 )
+	ROM_RELOAD(            0x140000, 0x20000 )
+	ROM_RELOAD(            0x160000, 0x20000 )
+	ROM_RELOAD(            0x180000, 0x20000 )
+	ROM_RELOAD(            0x1a0000, 0x20000 )
+	ROM_RELOAD(            0x1c0000, 0x20000 )
+	ROM_RELOAD(            0x1e0000, 0x20000 )
+	ROM_LOAD( "arom2.r10", 0x200000, 0x20000, CRC(fbe9fbbb) SHA1(457fc3c0d33cf430e5969f4fa11317f1f930351b) )
+	ROM_RELOAD(            0x220000, 0x20000 )
+	ROM_RELOAD(            0x240000, 0x20000 )
+	ROM_RELOAD(            0x260000, 0x20000 )
+	ROM_RELOAD(            0x280000, 0x20000 )
+	ROM_RELOAD(            0x2a0000, 0x20000 )
+	ROM_RELOAD(            0x2c0000, 0x20000 )
+	ROM_RELOAD(            0x2e0000, 0x20000 )
+	ROM_LOAD( "arom3.r10", 0x300000, 0x20000, CRC(ffb6e463) SHA1(1349455d2ce8eb141bc0fa5219f5e7c52ee969dc) )
+	ROM_RELOAD(            0x320000, 0x20000 )
+	ROM_RELOAD(            0x340000, 0x20000 )
+	ROM_RELOAD(            0x360000, 0x20000 )
+	ROM_RELOAD(            0x380000, 0x20000 )
+	ROM_RELOAD(            0x3a0000, 0x20000 )
+	ROM_RELOAD(            0x3c0000, 0x20000 )
+	ROM_RELOAD(            0x3e0000, 0x20000 )
 
 	ROM_REGION16_LE( 0x20000, REGION_USER1, 0 )
 	ROM_LOAD16_BYTE( "u144.r10", 0x00000, 0x10000, CRC(3b9d5d9e) SHA1(b3fbfeb41c62c689a825dfe9487917a927a71f58) )
@@ -454,6 +555,39 @@ ROM_START( lottof2 )
 ROM_END
 
 
+ROM_START( fredmem )
+	ROM_REGION( 0x40000, REGION_CPU1, 0 ) /* 68k */
+	ROM_LOAD16_BYTE( "prog0.104", 0x00000, 0x20000, CRC(9e90ebc3) SHA1(ef86e5070ec64772b8e8b9b30910b88bbd46285b) ) /* Program 0 - V2.0 at U104 */
+	ROM_LOAD16_BYTE( "prog1.103", 0x00001, 0x20000, CRC(79cadede) SHA1(bfc04edf6dc3beb942ffba442fe4203d1e1a3c0e) ) /* Program 1 - V2.0 at U103 */
+
+	ROM_REGION( 0x10000, REGION_CPU2, 0 ) /* M6809 */
+	ROM_LOAD( "prog.102", 0x00000, 0x10000, CRC(b1526a1a) SHA1(456c44a0a908b3cd054b7c6741d7a1033c9b12fb) ) /* Sound Program 6809 code at U102 */
+
+	ROM_REGION( 0x200000, REGION_GFX1, 0 )
+	ROM_LOAD( "art-rom.123", 0x000000, 0x80000, CRC(48133505) SHA1(60f69b053e67256928db57e0a5335bbd5a72ddfc) ) /* Graphics / Art at U123 */
+	ROM_LOAD( "art-rom.125", 0x080000, 0x80000, CRC(8181e154) SHA1(4d16b84ad52d8e3d3bcad3fdf5f8da23df198d46) ) /* Graphics / Art at U125 */
+	ROM_LOAD( "art-rom.127", 0x100000, 0x80000, CRC(93095f3b) SHA1(de746829e04bf153024e94e6ef0ceffb1eae2b14) ) /* Graphics / Art at U127 */
+	ROM_LOAD( "art-rom.129", 0x180000, 0x80000, CRC(d5715a02) SHA1(b7d9d29f2fc5d74adff1fefce312e6472c0f7565) ) /* Graphics / Art at U129 */
+
+	ROM_REGION( 0x400000, REGION_SOUND1, 0 )
+	ROM_LOAD( "arom0", 0x000000, 0x80000, CRC(3b85ea34) SHA1(0a68e7df20a2c36e230c7935415dd5068c338669) )
+	ROM_RELOAD(        0x080000, 0x80000 )
+	ROM_LOAD( "arom1", 0x100000, 0x80000, CRC(405df3d4) SHA1(190b928789a879408beadd1647136bd85b018c63) )
+	ROM_RELOAD(        0x180000, 0x80000 )
+	ROM_LOAD( "arom2", 0x200000, 0x80000, CRC(48ecd5c9) SHA1(6aad371db7b658454c5feed548ffd19b81a8fcf4) )
+	ROM_RELOAD(        0x280000, 0x80000 )
+	ROM_LOAD( "arom3", 0x300000, 0x80000, CRC(411900b0) SHA1(ddc5b387c89baab0fd5c654f3768c6e27972c06a) )
+	ROM_RELOAD(        0x380000, 0x80000 )
+
+	ROM_REGION16_LE( 0x20000, REGION_USER1, 0 )
+	ROM_LOAD16_BYTE( "0.144", 0x00000, 0x10000, CRC(793c4bda) SHA1(5a8a2981b48922f4d9e617a9bf9ef6a47ab702b7) ) /* Pallette - 0 at U144 */
+	ROM_LOAD16_BYTE( "1.145", 0x00001, 0x10000, CRC(fe2c3521) SHA1(896e53427c7831620ca565be9c0b76aabc36b9f4) ) /* Pallette - 1 at U145 */
+
+	ROM_REGION( 0x100, REGION_USER2, 0 )
+	ROM_LOAD16_BYTE( "93c46.u158", 0x00000, 0x0080, CRC(a40a7b87) SHA1(3632b7538b3bf41ee0cbe7541a0f5951f70b4a9b) ) /* EEPROM data at U158 */
+ROM_END
+
+
 
 /*************************************
  *
@@ -474,5 +608,6 @@ static DRIVER_INIT( dcheese )
  *
  *************************************/
 
-GAME( 1993, dcheese, 0, dcheese, dcheese, dcheese, ROT90, "HAR", "Double Cheese", 0 )
-GAME( 1993, lottof2, 0, dcheese, lottof2, dcheese, ROT0,  "HAR", "Lotto Fun 2", 0 )
+GAME( 1993, dcheese, 0, dcheese, dcheese, dcheese, ROT90, "HAR", "Double Cheese", GAME_SUPPORTS_SAVE )
+GAME( 1993, lottof2, 0, dcheese, lottof2, dcheese, ROT0,  "HAR", "Lotto Fun 2", GAME_SUPPORTS_SAVE )
+GAME( 1994, fredmem, 0, fredmem, fredmem, dcheese, ROT0,  "Coastal Amusements", "Fred Flintstones' Memory Match", GAME_SUPPORTS_SAVE )
