@@ -1,86 +1,21 @@
 /*
 
     D-DAY   (c)Jaleco 1984
-    preliminary driver by Pierpaolo Prazzoli
-----------------------------------------------
-    Tomasz Slanina 2004.11.12. :
-
-  - correct sprite decoding
-  - DMA  - see below
-  - sound
-  - interrupts
-  - controls
-
- TODO:
-  - everything else
 
+    driver by Pierpaolo Prazzoli and Tomasz Slanina
 
+-------------------------------------------------------
 Is it 1984 or 1987 game ?
 There's text inside rom "1987.07    BY  ELS"
--------------------------------------------------------------
 
-    DMA copy ?
-
-    Writes to adr. in range $e000-$e008 are usually like this:
-
-    ld hl,$e000
-    ld bc,XXxx
-    ld de,YYyy
-    ld (hl),c       ;($e000),xx
-    ld (hl),b       ;($e000),XX
-    inc hl
-    ld (hl),e       ;($e001),yy
-    ld (hl),d       ;($e001),YY
-    inc hl
-    ld bc,ZZzz
-    ld de,QQqq
-    ld (hl),c       ;($e002),zz
-    ld (hl),b       ;($e002),ZZ
-    inc hl
-    ld (hl),e       ;($e003),qq
-    ld (hl),d       ;($e003),QQ
-    ld a,WW
-    ld ($e008),a
-    ld a,1
-    ld ($f803),a
-    xor a
-    ld ($f083),a    ; write latch
-    ld a,1
-    ld ($f083),a
-
-where (my guess):
-
-XXxx = src address
-YYyy = size | $4000
-ZZzz = dst address
-QQqq = size | $8000
-WW = $73 (always)
-
-It's used in (at least) three places :
-
-- $16e6 RAM -> spriteram
-    src = $8d6f
-    dst = $9000
-    size = $200
-
-- $1cb1 RAM -> RAM
-
-    src = $8432
-    dst = $807a
-    size = $364
-
-- $1cf4     RAM -> RAM
-
-    src = $805e
-    dst = $8432
-    size = $380
-
-----------------------------------------------
+$842f = lives
 
+-------------------------------------------------------
 
     CPU  : Z80
     Sound: Z80 AY-3-8910(x2)
     OSC  : 12.000MHz
+    Other: Intel 8257 DMA controller
 
     -------
     DD-8416
@@ -117,55 +52,109 @@ It's used in (at least) three places :
 */
 
 #include "driver.h"
-#include "vidhrdw/generic.h"
 #include "sound/ay8910.h"
 
-static int char_bank = 0;
-static tilemap *bg_tilemap, *fg_tilemap;
+static INT32 char_bank = 0;
+static tilemap *bg_tilemap;
 static UINT8 *bgram;
-static int bgadr=0;
+static UINT8 *mainram;
+static INT32 bgadr=0;
+
+static INT32 sound_nmi_enable=0;
+static INT32 main_nmi_enable=0;
+
+static INT32 e00x_l[4];
+static INT32 e00x_d[4][2];
+
+static UINT8 protAdr;
+
+
+/*
+    Protection device
+
+    24 pin IC with scratched surface, probably a mcu
+
+    Pinout:
+
+     1 - vcc
+     2 - ?
+     3 - I/O (input)
+     4 - I/O (input)
+     5 - I/O (input)
+     6 - I/O (input)
+     7 - vcc
+     8 - xtal
+     9 - ?
+    10 - gnd
+    11 - ?
+    12 - ?
+    13 - I/O (input)
+    14 - ?
+    15 - I/O (input)
+    16 - ?
+    17 - ?
+    18 - I/O (input)
+    19 - ?
+    20 - ?
+    21 - I/O (input)
+    22 - ?
+    23 - ?
+    24 - ?
+
+*/
+
+static const UINT8 protData[0x10]=
+{
+	0x40,0x40,0x40,0x40,
+	0x40,0x00,0x40,0x00,
+	0x40,0x40,0x40,0x00,
+	0x60,0x20,0x00,0x60
+};
+
+static READ8_HANDLER(prot_r)
+{
+	return (input_port_1_r(0)&0x1f)|protData[protAdr];
+}
+
+static WRITE8_HANDLER(prot_w)
+{
+	protAdr=(protAdr&(~(1<<offset)))|((data&1)<<offset);
+}
 
 static WRITE8_HANDLER( char_bank_w )
 {
 	char_bank = data;
-	tilemap_mark_all_tiles_dirty(fg_tilemap);
 }
 
 static WRITE8_HANDLER( ddayjlc_bgram_w )
 {
 	if(!offset)
-		tilemap_set_scrollx(bg_tilemap,0,data);
+		tilemap_set_scrollx(bg_tilemap,0,data+8);
 
 	if( bgram[offset] != data )
 	{
 		bgram[offset] = data;
-		tilemap_mark_tile_dirty(bg_tilemap,offset);
+		tilemap_mark_tile_dirty(bg_tilemap,offset&0x3ff);
 	}
 }
 
 static WRITE8_HANDLER( ddayjlc_videoram_w )
 {
-	if( videoram[offset] != data )
-	{
 		videoram[offset] = data;
-		tilemap_mark_tile_dirty(fg_tilemap,offset);
-	}
 }
-static int sound_nmi_enable=0;
-static int main_nmi_enable=0;
+
 
 static WRITE8_HANDLER(sound_nmi_w)
 {
 	sound_nmi_enable=data;
 }
+
 static WRITE8_HANDLER(main_nmi_w)
 {
 	main_nmi_enable=data;
 }
 
-
-
-static WRITE8_HANDLER(bg2_w)
+static WRITE8_HANDLER(bg0_w)
 {
 	bgadr=(bgadr&0xfe)|(data&1);
 }
@@ -175,69 +164,41 @@ static WRITE8_HANDLER(bg1_w)
 	bgadr=(bgadr&0xfd)|((data&1)<<1);
 }
 
-static WRITE8_HANDLER(bg0_w)
+static WRITE8_HANDLER(bg2_w)
 {
-	bgadr=(bgadr&0xfb)|((data&1)<<1);
+	bgadr=(bgadr&0xfb)|((data&1)<<2);
+	if(bgadr>2)	bgadr=0;
+	memory_set_bankptr( 1, memory_region(REGION_USER1)+bgadr*0x4000 );
 }
 
-static READ8_HANDLER(custom_r)
-{
-	UINT8 *ROM = memory_region(REGION_USER2);
-	return ROM[offset|(bgadr<<11)];
-}
-
-#if 0
-static WRITE8_HANDLER(test_w)
-{
-		/*printf("W %x %x %x\n",offset,data,activecpu_get_previouspc()); */
-}
-
-static READ8_HANDLER(test_r)
-{
-		/*printf("R %x %x\n",offset,activecpu_get_previouspc()); */
-		UINT8 *ROM = memory_region(REGION_USER1);
-		return ROM[offset];
-}
-#endif
-
 static WRITE8_HANDLER( sound_w )
 {
 	soundlatch_w(offset,data);
 	cpunum_set_input_line_and_vector(1,0,HOLD_LINE,0xff);
 }
 
-
-static int e00x_l[4];
-static int e00x_d[4][2];
-static int e008_d;
-
-static WRITE8_HANDLER( e00x_w )
+static WRITE8_HANDLER( i8257_CH0_w )
 {
 	e00x_d[offset][e00x_l[offset]]=data;
 	e00x_l[offset]^=1;
 }
 
-static WRITE8_HANDLER( e008_w )
-{
-	e008_d=data;
-}
-
-static WRITE8_HANDLER( f083_w )
+static WRITE8_HANDLER( i8257_LMSR_w )
 {
 	if(!data)
 	{
-		/*printf("DMA? %.2x%.2x %.2x%.2x %.2x%.2x %.2x%.2x %.2x @%.4x\n", e00x_d[0][1],e00x_d[0][0],e00x_d[1][1],e00x_d[1][0],e00x_d[2][1],e00x_d[2][0],e00x_d[3][1],e00x_d[3][0],e008_d,activecpu_get_previouspc()); */
-		{
-			int src=e00x_d[0][1]*256+e00x_d[0][0];
-			int dst=e00x_d[2][1]*256+e00x_d[2][0];
-			int size=(e00x_d[1][1]*256+e00x_d[1][0])&0x3ff;
+		INT32 src=e00x_d[0][1]*256+e00x_d[0][0];
+		INT32 dst=e00x_d[2][1]*256+e00x_d[2][0];
+		INT32 size=(e00x_d[1][1]*256+e00x_d[1][0])&0x3ff;
+		INT32 i;
 
-			int i;
-			for(i=0;i<size;i++)
-			{
-				program_write_byte(dst++, program_read_byte(src++));
-			}
+		size++; /*?? */
+
+		for(i=0;i<size;i++)
+		{
+			program_write_byte(dst++, program_read_byte(src++));
 		}
+
 		e00x_l[0]=0;
 		e00x_l[1]=0;
 		e00x_l[2]=0;
@@ -247,39 +208,30 @@ static WRITE8_HANDLER( f083_w )
 
 static ADDRESS_MAP_START( main_cpu, ADDRESS_SPACE_PROGRAM, 8 )
 	AM_RANGE(0x0000, 0x7fff) AM_ROM
-	AM_RANGE(0x8000, 0x8fff) AM_RAM
+	AM_RANGE(0x8000, 0x8fff) AM_RAM AM_BASE(&mainram)
 	AM_RANGE(0x9000, 0x93ff) AM_RAM AM_BASE(&spriteram)
 	AM_RANGE(0x9400, 0x97ff) AM_READWRITE(videoram_r, ddayjlc_videoram_w) AM_BASE(&videoram)
 	AM_RANGE(0x9800, 0x9fff) AM_READWRITE(MRA8_RAM, ddayjlc_bgram_w) AM_BASE(&bgram) /* 9800-981f - videoregs */
-	AM_RANGE(0xa000, 0xa7ff) AM_WRITE(MWA8_RAM) AM_READ(custom_r)
-
-	AM_RANGE(0xa800, 0xdfff) AM_RAM /*AM_READ(test_r) AM_WRITE(test_w)  // other ROMs ? */
-
-	AM_RANGE(0xe000, 0xe003) AM_WRITE(e00x_w)
-	AM_RANGE(0xf083, 0xf083) AM_WRITE(f083_w)
-	AM_RANGE(0xe008, 0xe008) AM_WRITE(e008_w)
-
+	AM_RANGE(0xa000, 0xdfff) AM_ROMBANK(1) AM_WRITENOP
+	AM_RANGE(0xe000, 0xe003) AM_WRITE(i8257_CH0_w)
+	AM_RANGE(0xe008, 0xe008) AM_WRITENOP
 	AM_RANGE(0xf000, 0xf000) AM_WRITE(sound_w)
-	AM_RANGE(0xf100, 0xf100) AM_WRITE(MWA8_NOP) /* ff,00,ff,00 */
-
+	AM_RANGE(0xf100, 0xf100) AM_WRITENOP
 	AM_RANGE(0xf080, 0xf080) AM_WRITE(char_bank_w)
-
-	AM_RANGE(0xf081, 0xf081) AM_WRITE(MWA8_NOP) /*1 or 0 */
-
+	AM_RANGE(0xf081, 0xf081) AM_WRITENOP
+	AM_RANGE(0xf083, 0xf083) AM_WRITE(i8257_LMSR_w)
 	AM_RANGE(0xf084, 0xf084) AM_WRITE(bg0_w)
 	AM_RANGE(0xf085, 0xf085) AM_WRITE(bg1_w)
 	AM_RANGE(0xf086, 0xf086) AM_WRITE(bg2_w)
-
 	AM_RANGE(0xf101, 0xf101) AM_WRITE(main_nmi_w)
-	AM_RANGE(0xf102, 0xf105) AM_WRITE(MWA8_NOP) /* $7eac 4 bit value (each bit to one adr ($f102,03,04,05)) top bits of *something* ? */
-
+	AM_RANGE(0xf102, 0xf105) AM_WRITE(prot_w)
 	AM_RANGE(0xf000, 0xf000) AM_READ(input_port_0_r)
-	AM_RANGE(0xf100, 0xf100) AM_READ(input_port_1_r)/*protection ? */
+	AM_RANGE(0xf100, 0xf100) AM_READ(prot_r)
 	AM_RANGE(0xf180, 0xf180) AM_READ(input_port_2_r)
 	AM_RANGE(0xf200, 0xf200) AM_READ(input_port_3_r)
-	AM_RANGE(0xff00, 0xffff) AM_RAM /* $49a */
 ADDRESS_MAP_END
 
+
 static ADDRESS_MAP_START( sound_cpu, ADDRESS_SPACE_PROGRAM, 8 )
 	AM_RANGE(0x0000, 0x1fff) AM_ROM
 	AM_RANGE(0x2000, 0x23ff) AM_RAM
@@ -296,8 +248,8 @@ INPUT_PORTS_START( ddayjlc )
 	PORT_START
 	PORT_BIT( 0x01, IP_ACTIVE_HIGH, IPT_JOYSTICK_UP ) PORT_8WAY PORT_PLAYER(1)
 	PORT_BIT( 0x02, IP_ACTIVE_HIGH, IPT_JOYSTICK_DOWN ) PORT_8WAY PORT_PLAYER(1)
-	PORT_BIT( 0x04, IP_ACTIVE_HIGH, IPT_JOYSTICK_LEFT ) PORT_8WAY PORT_PLAYER(1)
-	PORT_BIT( 0x08, IP_ACTIVE_HIGH, IPT_JOYSTICK_RIGHT ) PORT_8WAY PORT_PLAYER(1)
+	PORT_BIT( 0x04, IP_ACTIVE_HIGH, IPT_JOYSTICK_RIGHT ) PORT_8WAY PORT_PLAYER(1)
+	PORT_BIT( 0x08, IP_ACTIVE_HIGH, IPT_JOYSTICK_LEFT ) PORT_8WAY PORT_PLAYER(1)
 	PORT_BIT( 0x10, IP_ACTIVE_HIGH, IPT_BUTTON1 ) PORT_PLAYER(1)
 	PORT_BIT( 0x20, IP_ACTIVE_HIGH, IPT_BUTTON2 ) PORT_PLAYER(1)
 	PORT_BIT( 0x40, IP_ACTIVE_HIGH, IPT_BUTTON3 ) PORT_PLAYER(1)
@@ -354,7 +306,7 @@ INPUT_PORTS_START( ddayjlc )
 
 INPUT_PORTS_END
 
-static gfx_layout charlayout =
+static const gfx_layout charlayout =
 {
 	8,8,
 	RGN_FRAC(1,2),
@@ -365,7 +317,7 @@ static gfx_layout charlayout =
 	8*8
 };
 
-static gfx_layout spritelayout =
+static const gfx_layout spritelayout =
 {
 	16,16,
 	RGN_FRAC(1,2),
@@ -376,7 +328,7 @@ static gfx_layout spritelayout =
 	16*16,
 };
 
-static gfx_decode gfxdecodeinfo[] =
+static const gfx_decode gfxdecodeinfo[] =
 {
 	{ REGION_GFX1, 0, &spritelayout,   0, 16 },
 	{ REGION_GFX2, 0, &charlayout,     0, 16 },
@@ -387,51 +339,49 @@ static gfx_decode gfxdecodeinfo[] =
 
 static void get_tile_info_bg(int tile_index)
 {
-	int code = bgram[tile_index];
+	int code = bgram[tile_index]+((bgram[tile_index+0x400]&(1<<3))<<(8-3));
+
 	SET_TILE_INFO(2, code, 0, 0)
-	/*tile_index+0x400 = attributes ? */
-}
-
-static void get_tile_info_fg(int tile_index)
-{
-	int code = videoram[tile_index];
-
-	SET_TILE_INFO(1, code + char_bank * 0x100, 0, 0)
 }
 
 VIDEO_START( ddayjlc )
 {
 	bg_tilemap = tilemap_create(get_tile_info_bg,tilemap_scan_rows,TILEMAP_OPAQUE,8,8,32,32);
-	fg_tilemap = tilemap_create(get_tile_info_fg,tilemap_scan_rows,TILEMAP_TRANSPARENT,8,8,32,32);
-
-	if( !bg_tilemap || !fg_tilemap )
-		return 1;
-
-	tilemap_set_transparent_pen(fg_tilemap,0);
 
 	return 0;
 }
 
 VIDEO_UPDATE( ddayjlc )
 {
-	int i;
+	UINT32 i;
 	tilemap_draw(bitmap,cliprect,bg_tilemap,0,0);
 
 	for (i = 0; i < 0x400; i += 4)
 	{
-		int flags = spriteram[i + 2];
-		int y = spriteram[i + 0];/*-3*8 ; */
-		int code = spriteram[i + 1];
-		int x = spriteram[i + 3];/*-8 ; */
-		int xflip = flags&0x80;
-		int yflip = (code&0x80)^0x80;
+		INT32 flags = spriteram[i + 2];
+		INT32 y = 256-spriteram[i + 0]-8;
+		INT32 code = spriteram[i + 1];
+		INT32 x = spriteram[i + 3]-16;
+		INT32 xflip = flags&0x80;
+		INT32 yflip = (code&0x80);
 
-		code=(code&0x7f)|((flags&0x30)<<3);/*0x30 ? 0x10(tested) */
+		code=(code&0x7f)|((flags&0x30)<<3);
 
 		drawgfx(bitmap, Machine->gfx[0], code, 1, xflip, yflip, x, y, cliprect, TRANSPARENCY_PEN, 0);
 	}
 
-	tilemap_draw(bitmap,cliprect,fg_tilemap,0,0);
+	{
+		UINT32 x,y,c;
+		for(y=0;y<32;y++)
+			for(x=0;x<32;x++)
+			{
+				c=videoram[y*32+x];
+				if(x>1&&x<30)
+					drawgfx(bitmap, Machine->gfx[1], c+char_bank*0x100, 1, 0, 0, x*8, y*8, cliprect, TRANSPARENCY_PEN, 0);
+				else
+					drawgfx(bitmap, Machine->gfx[1], c+char_bank*0x100, 1, 0, 0, x*8, y*8, cliprect, TRANSPARENCY_NONE, 0);
+		}
+	}
 }
 
 static struct AY8910interface ay8910_interface =
@@ -452,15 +402,17 @@ static INTERRUPT_GEN( ddayjlc_snd_interrupt )
 }
 
 static MACHINE_DRIVER_START( ddayjlc )
-	MDRV_CPU_ADD(Z80,12000000/3)		 /* ?? */
+	MDRV_CPU_ADD(Z80,12000000/3)
 	MDRV_CPU_PROGRAM_MAP(main_cpu,0)
 	MDRV_CPU_VBLANK_INT(ddayjlc_interrupt,1)
 
-	MDRV_CPU_ADD(Z80, 12000000/3)     /* ? MHz */
+	MDRV_CPU_ADD(Z80, 12000000/4)
 	/* audio CPU */
 	MDRV_CPU_PROGRAM_MAP(sound_cpu,0)
 	MDRV_CPU_VBLANK_INT(ddayjlc_snd_interrupt,1)
 
+	MDRV_INTERLEAVE(100)
+
 	MDRV_FRAMES_PER_SECOND(60)
 	MDRV_VBLANK_DURATION(DEFAULT_60HZ_VBLANK_DURATION)
 
@@ -477,11 +429,11 @@ static MACHINE_DRIVER_START( ddayjlc )
 
 	MDRV_SPEAKER_STANDARD_MONO("mono")
 
-	MDRV_SOUND_ADD(AY8910, 12000000/4)
+	MDRV_SOUND_ADD(AY8910, 12000000/6)
 	MDRV_SOUND_CONFIG(ay8910_interface)
 	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 1.0)
 
-	MDRV_SOUND_ADD(AY8910, 12000000/4)
+	MDRV_SOUND_ADD(AY8910, 12000000/6)
 	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 1.0)
 MACHINE_DRIVER_END
 
@@ -510,15 +462,60 @@ ROM_START( ddayjlc )
 	ROM_LOAD( "12", 0x0000, 0x1000, CRC(7f7afe80) SHA1(e8a549b8a8985c61d3ba452e348414146f2bc77e) )
 	ROM_LOAD( "13", 0x1000, 0x1000, CRC(f169b93f) SHA1(fb0617162542d688503fc6618dd430308e259455) )
 
-	ROM_REGION( 0x08000, REGION_USER1, 0 )
-	ROM_LOAD( "5",  0x0000, 0x2000, CRC(299b05f2) SHA1(3c1804bccb514bada4bed68a6af08db63a8f1b19) )
-	ROM_LOAD( "6",  0x2000, 0x2000, CRC(38ae2616) SHA1(62c96f32532f0d7e2cf1606a303d81ebb4aada7d) ) /* 1xxxxxxxxxxxx = 0xFF */
-	ROM_LOAD( "9",  0x6000, 0x2000, CRC(ccb82f09) SHA1(37c23f13aa0728bae82dba9e2858a8d81fa8afa5) ) /* FIXED BITS (xx00xxxx) */
-	ROM_LOAD( "10", 0x4000, 0x2000, CRC(5452aba1) SHA1(03ef47161d0ab047c8675d6ffd3b7acf81f74721) ) /* FIXED BITS (1xxxxxxx) */
+	ROM_REGION( 0xc0000, REGION_USER1, 0 )
+	ROM_LOAD( "5",  0x00000, 0x2000, CRC(299b05f2) SHA1(3c1804bccb514bada4bed68a6af08db63a8f1b19) )
+	ROM_LOAD( "6",  0x02000, 0x2000, CRC(38ae2616) SHA1(62c96f32532f0d7e2cf1606a303d81ebb4aada7d) )
+	ROM_LOAD( "7",  0x04000, 0x2000, CRC(4210f6ef) SHA1(525d8413afabf97cf1d04ee9a3c3d980b91bde65) )
+	ROM_LOAD( "8",  0x06000, 0x2000, CRC(91a32130) SHA1(cbcd673b47b672b9ce78c7354dacb5964a81db6f) )
+	ROM_LOAD( "9",  0x08000, 0x2000, CRC(ccb82f09) SHA1(37c23f13aa0728bae82dba9e2858a8d81fa8afa5) )
+	ROM_LOAD( "10", 0x0a000, 0x2000, CRC(5452aba1) SHA1(03ef47161d0ab047c8675d6ffd3b7acf81f74721) )
+
+	ROM_REGION( 0x0400, REGION_PROMS, 0 )
+	ROM_LOAD( "prom1",  0x00000, 0x0100, NO_DUMP )
+	ROM_LOAD( "prom2",  0x00100, 0x0100, NO_DUMP )
+	ROM_LOAD( "prom3",  0x00200, 0x0100, NO_DUMP )
+	ROM_LOAD( "prom4",  0x00300, 0x0100, NO_DUMP )
+
+ROM_END
+
+ROM_START( ddayjlca )
+	ROM_REGION( 0x10000, REGION_CPU1, 0 )
+	ROM_LOAD( "1a", 0x0000, 0x2000, CRC(d8e4f3d4) SHA1(78b30b4896a7f718975b1502c6253819bceee922) )
+	ROM_LOAD( "2",  0x2000, 0x2000, CRC(f40ea53e) SHA1(234ef686d3e9fe12aceada7098c4cc53e56eb1a3) )
+	ROM_LOAD( "3",  0x4000, 0x2000, CRC(0780ef60) SHA1(9247af38acbaea0f78892fc50081b2400abbdc1f) )
+	ROM_LOAD( "4",  0x6000, 0x2000, CRC(75991a24) SHA1(175f505da6eb80479a70181d6aed01130f6a64cc) )
+
+	ROM_REGION( 0x10000, REGION_CPU2, 0 )
+	ROM_LOAD( "11", 0x0000, 0x2000, CRC(fe4de019) SHA1(16c5402e1a79756f8227d7e99dd94c5896c57444) )
+
+	ROM_REGION( 0x8000, REGION_GFX1, ROMREGION_DISPOSE )
+	ROM_LOAD( "16", 0x0000, 0x2000, CRC(a167fe9a) SHA1(f2770d93ee5ae4eb9b3bcb052e14e36f53eec707) )
+	ROM_LOAD( "17", 0x2000, 0x2000, CRC(13ffe662) SHA1(2ea7855a14a4b8429751bae2e670e77608f93406) )
+	ROM_LOAD( "18", 0x4000, 0x2000, CRC(debe6531) SHA1(34b3b70a1872527266c664b2a82014d028a4ff1e) )
+	ROM_LOAD( "19", 0x6000, 0x2000, CRC(5816f947) SHA1(2236bed3e82980d3e7de3749aef0fbab042086e6) )
+
+	ROM_REGION( 0x2000, REGION_GFX2, ROMREGION_DISPOSE )
+	ROM_LOAD( "14", 0x0000, 0x1000, CRC(2c0e9bbe) SHA1(e34ab774d2eb17ddf51af513dbcaa0c51f8dcbf7) )
+	ROM_LOAD( "15", 0x1000, 0x1000, CRC(a6eeaa50) SHA1(052cd3e906ca028e6f55d0caa1e1386482684cbf) )
+
+	ROM_REGION( 0x2000, REGION_GFX3, ROMREGION_DISPOSE )
+	ROM_LOAD( "12", 0x0000, 0x1000, CRC(7f7afe80) SHA1(e8a549b8a8985c61d3ba452e348414146f2bc77e) )
+	ROM_LOAD( "13", 0x1000, 0x1000, CRC(f169b93f) SHA1(fb0617162542d688503fc6618dd430308e259455) )
+
+	ROM_REGION( 0xc0000, REGION_USER1, 0 )
+	ROM_LOAD( "5",  0x00000, 0x2000, CRC(299b05f2) SHA1(3c1804bccb514bada4bed68a6af08db63a8f1b19) )
+	ROM_LOAD( "6",  0x02000, 0x2000, CRC(38ae2616) SHA1(62c96f32532f0d7e2cf1606a303d81ebb4aada7d) )
+	ROM_LOAD( "7",  0x04000, 0x2000, CRC(4210f6ef) SHA1(525d8413afabf97cf1d04ee9a3c3d980b91bde65) )
+	ROM_LOAD( "8",  0x06000, 0x2000, CRC(91a32130) SHA1(cbcd673b47b672b9ce78c7354dacb5964a81db6f) )
+	ROM_LOAD( "9",  0x08000, 0x2000, CRC(ccb82f09) SHA1(37c23f13aa0728bae82dba9e2858a8d81fa8afa5) )
+	ROM_LOAD( "10", 0x0a000, 0x2000, CRC(5452aba1) SHA1(03ef47161d0ab047c8675d6ffd3b7acf81f74721) )
+
+	ROM_REGION( 0x0400, REGION_PROMS, 0 )
+	ROM_LOAD( "prom1",  0x00000, 0x0100, NO_DUMP )
+	ROM_LOAD( "prom2",  0x00100, 0x0100, NO_DUMP )
+	ROM_LOAD( "prom3",  0x00200, 0x0100, NO_DUMP )
+	ROM_LOAD( "prom4",  0x00300, 0x0100, NO_DUMP )
 
-	ROM_REGION( 0x04000, REGION_USER2, 0 )
-	ROM_LOAD( "7",  0x0000, 0x2000, CRC(4210f6ef) SHA1(525d8413afabf97cf1d04ee9a3c3d980b91bde65) )
-	ROM_LOAD( "8",  0x2000, 0x2000, CRC(91a32130) SHA1(cbcd673b47b672b9ce78c7354dacb5964a81db6f) )
 ROM_END
 
 
@@ -558,16 +555,6 @@ static DRIVER_INIT( ddayjlc )
 		dst[newadr+30+n] = src[oldaddr+6+0x2008+n];\
 		dst[newadr+31+n] = src[oldaddr+7+0x2008+n];
 
-	UINT8 *ROM = memory_region(REGION_CPU1);
-	/*protection (?) patch */
-	ROM[0x7e5e] = 0;
-	ROM[0x7e5f] = 0;
-	ROM[0x7e60] = 0;
-
-	/*patched cpir (reads from not mapped adresses , whole adr space (000-ffff), REMOVE it) */
-	ROM[0x13de] = 0;
-	ROM[0x13df] = 0;
-
 	{
 		UINT32 oldaddr, newadr, length,j;
 		UINT8 *src, *dst, *temp;
@@ -587,6 +574,9 @@ static DRIVER_INIT( ddayjlc )
 		}
 	}
 
+	memory_set_bankptr( 1, memory_region(REGION_USER1) );
+
 }
 
-GAME( 1984, ddayjlc, 0, ddayjlc, ddayjlc, ddayjlc, ROT90, "Jaleco", "D-Day (Jaleco)", GAME_NOT_WORKING | GAME_IMPERFECT_GRAPHICS | GAME_NO_COCKTAIL )
+GAME( 1984, ddayjlc,  0,       ddayjlc, ddayjlc, ddayjlc, ROT90, "Jaleco", "D-Day (Jaleco - set 1)", GAME_IMPERFECT_GRAPHICS | GAME_WRONG_COLORS | GAME_IMPERFECT_SOUND )
+GAME( 1984, ddayjlca, ddayjlc, ddayjlc, ddayjlc, ddayjlc, ROT90, "Jaleco", "D-Day (Jaleco - set 2)", GAME_IMPERFECT_GRAPHICS | GAME_WRONG_COLORS | GAME_IMPERFECT_SOUND )
