@@ -24,7 +24,6 @@
 
 
 #include "driver.h"
-#include "vidhrdw/generic.h"
 #include "cpu/z80/z80.h"
 #include "cpu/m68000/m68000.h"
 #include "sound/2151intf.h"
@@ -427,9 +426,7 @@ INPUT_PORTS_START( ctribe )
 	PORT_SERVICE( 0x1000, IP_ACTIVE_LOW )
 	PORT_DIPNAME( 0x6000, 0x6000, "Stage Clear Energy" )
 	PORT_DIPSETTING(	  0x6000, DEF_STR( Off ) )
-	PORT_DIPSETTING(	  0x4000, "50" )
-	PORT_DIPSETTING(	  0x2000, "100" )
-	PORT_DIPSETTING(	  0x0000, "150" )
+	PORT_DIPSETTING(	  0x0000, "50" )
 	PORT_BIT( 0x8000, IP_ACTIVE_LOW, IPT_UNUSED )
 
 	PORT_START
@@ -444,7 +441,7 @@ INPUT_PORTS_END
 
 /* Graphics Layouts */
 
-static gfx_layout tile_layout =
+static const gfx_layout tile_layout =
 {
 	16,16,	/* 16*16 tiles */
 	8192,	/* 8192 tiles */
@@ -457,7 +454,7 @@ static gfx_layout tile_layout =
 	32*8	/* every tile takes 32 consecutive bytes */
 };
 
-static gfx_layout sprite_layout = {
+static const gfx_layout sprite_layout = {
 	16,16,	/* 16*16 tiles */
 	0x90000/32, /* 4096 tiles */
 	4,	/* 4 bits per pixel */
@@ -471,7 +468,7 @@ static gfx_layout sprite_layout = {
 
 /* Graphics Decode Info */
 
-static gfx_decode gfxdecodeinfo[] =
+static const gfx_decode gfxdecodeinfo[] =
 {
 	{ REGION_GFX1, 0, &tile_layout,   256, 32 },
 	{ REGION_GFX2, 0, &sprite_layout,	0, 16 },
@@ -536,8 +533,8 @@ static MACHINE_DRIVER_START( ddragon3 )
 
 	MDRV_SOUND_ADD(OKIM6295, 8500)
 	MDRV_SOUND_CONFIG(okim6295_interface_region_1)
-	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "left", 0.50)	/* sound fx */
-	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "right", 0.50)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "left", 1.00)	/* sound fx */
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "right", 1.00)
 MACHINE_DRIVER_END
 
 static MACHINE_DRIVER_START( ddrago3b )
