@@ -32,7 +32,6 @@ Notes:
 ***************************************************************************/
 
 #include "driver.h"
-#include "vidhrdw/generic.h"
 #include "cpu/z80/z80.h"
 #include "sound/okim6295.h"
 #include "sound/3812intf.h"
@@ -72,7 +71,7 @@ static WRITE16_HANDLER( deniam16c_oki_rom_bank_w )
 		OKIM6295_set_bank_base(0,(data & 0x01) ? 0x40000 : 0x00000);
 }
 
-static MACHINE_INIT( deniam )
+static MACHINE_RESET( deniam )
 {
 	/* logicpr2 does not reset the bank base on startup */
 	OKIM6295_set_bank_base(0,0x00000);
@@ -289,7 +288,7 @@ INPUT_PORTS_END
 
 
 
-static gfx_layout charlayout =
+static const gfx_layout charlayout =
 {
 	8,8,
 	RGN_FRAC(1,3),
@@ -301,7 +300,7 @@ static gfx_layout charlayout =
 };
 
 
-static gfx_decode gfxdecodeinfo[] =
+static const gfx_decode gfxdecodeinfo[] =
 {
 	{ REGION_GFX1, 0, &charlayout, 0, 128 },	/* colors 0-1023 */
 												/* sprites use colors 1024-2047 */
@@ -337,7 +336,7 @@ static MACHINE_DRIVER_START( deniam16b )
 	MDRV_FRAMES_PER_SECOND(60)
 	MDRV_VBLANK_DURATION(DEFAULT_60HZ_VBLANK_DURATION)
 
-	MDRV_MACHINE_INIT(deniam)
+	MDRV_MACHINE_RESET(deniam)
 
 	/* video hardware */
 	MDRV_VIDEO_ATTRIBUTES(VIDEO_TYPE_RASTER)
@@ -371,7 +370,7 @@ static MACHINE_DRIVER_START( deniam16c )
 	MDRV_FRAMES_PER_SECOND(60)
 	MDRV_VBLANK_DURATION(DEFAULT_60HZ_VBLANK_DURATION)
 
-	MDRV_MACHINE_INIT(deniam)
+	MDRV_MACHINE_RESET(deniam)
 
 	/* video hardware */
 	MDRV_VIDEO_ATTRIBUTES(VIDEO_TYPE_RASTER)
