@@ -38,7 +38,6 @@
  */
 
 #include "driver.h"
-#include "state.h"
 #include "artwork.h"
 #include "cpu/m68000/m68000.h"
 #include "machine/idectrl.h"
@@ -46,26 +45,27 @@
 #include "vidhrdw/konamiic.h"
 
 
-extern data32_t *djmain_obj_ram;
+extern UINT32 *djmain_obj_ram;
 
 VIDEO_UPDATE( djmain );
 VIDEO_START( djmain );
 
 
 static int sndram_bank;
-static data8_t *sndram;
+static UINT8 *sndram;
 
 static int turntable_select;
-static data8_t turntable_last_pos[2];
-static data16_t turntable_pos[2];
+static UINT8 turntable_last_pos[2];
+static UINT16 turntable_pos[2];
 
-static int pending_vb_int;
-static data16_t v_ctrl;
-static data32_t obj_regs[0xa0/4];
+static UINT8 pending_vb_int;
+static UINT16 v_ctrl;
+static UINT32 obj_regs[0xa0/4];
 
 #define DISABLE_VB_INT	(!(v_ctrl & 0x8000))
 
 
+
 /*************************************
  *
  *  68k CPU memory handlers
@@ -105,7 +105,7 @@ static WRITE32_HANDLER( sndram_bank_w )
 
 static READ32_HANDLER( sndram_r )
 {
-	data32_t data = 0;
+	UINT32 data = 0;
 
 	if ((mem_mask & 0xff000000) == 0)
 		data |= sndram[offset * 4] << 24;
@@ -142,7 +142,7 @@ static WRITE32_HANDLER( sndram_w )
 
 static READ16_HANDLER( dual539_16_r )
 {
-	data16_t ret = 0;
+	UINT16 ret = 0;
 
 	if (ACCESSING_LSB16)
 		ret |= K054539_1_r(offset);
@@ -162,7 +162,7 @@ static WRITE16_HANDLER( dual539_16_w )
 
 static READ32_HANDLER( dual539_r )
 {
-	data32_t data = 0;
+	UINT32 data = 0;
 
 	if (~mem_mask & 0xffff0000)
 		data |= dual539_16_r(offset * 2, mem_mask >> 16) << 16;
@@ -200,7 +200,7 @@ static WRITE32_HANDLER( obj_ctrl_w )
 
 static READ32_HANDLER( obj_rom_r )
 {
-	data8_t *mem8 = memory_region(REGION_GFX1);
+	UINT8 *mem8 = memory_region(REGION_GFX1);
 	int bank = obj_regs[0x28/4] >> 16;
 
 	offset += bank * 0x200;
@@ -236,7 +236,7 @@ static WRITE32_HANDLER( v_ctrl_w )
 
 static READ32_HANDLER( v_rom_r )
 {
-	data8_t *mem8 = memory_region(REGION_GFX2);
+	UINT8 *mem8 = memory_region(REGION_GFX2);
 	int bank = K056832_word_r(0x34/2, 0xffff);
 
 	offset *= 2;
@@ -257,7 +257,7 @@ static READ32_HANDLER( v_rom_r )
 
 static READ32_HANDLER( inp1_r )
 {
-	data32_t result = (readinputport(5)<<24) | (readinputport(2)<<16) | (readinputport(1)<<8) | readinputport(0);
+	UINT32 result = (readinputport(5)<<24) | (readinputport(2)<<16) | (readinputport(1)<<8) | readinputport(0);
 
 	return result;
 }
@@ -269,11 +269,11 @@ static READ32_HANDLER( inp2_r )
 
 static READ32_HANDLER( turntable_r )
 {
-	data32_t result = 0;
+	UINT32 result = 0;
 
 	if (!(mem_mask & 0x0000ff00))
 	{
-		data8_t pos;
+		UINT8 pos;
 		int delta;
 
 		pos = readinputport(6 + turntable_select);
@@ -568,6 +568,29 @@ ADDRESS_MAP_END
 	PORT_DIPSETTING(    (0xf9 & mask) | base, "1P 1C / 2P 1C / Continue 1C" ) \
 	PORT_DIPSETTING(    (0x00 & mask) | base, DEF_STR( Free_Play ) )
 
+#define BM1STMIX_DSW1 \
+	PORT_START      /* IN 3 */ \
+	PORT_BIT( 0xe0, IP_ACTIVE_LOW, IPT_UNKNOWN ) \
+	PORT_DIPNAME( 0x1f, 0x1f, DEF_STR( Coinage ) ) \
+	PORT_DIPSETTING(    0x1e, "1P 3C / 2P 6C / Continue 3C" ) \
+	PORT_DIPSETTING(    0x01, "1P 3C / 2P 6C / Continue 2C" ) \
+	PORT_DIPSETTING(    0x11, "1P 3C / 2P 6C / Continue 1C" ) \
+	PORT_DIPSETTING(    0x15, "1P 3C / 2P 3C / Continue 3C" ) \
+	PORT_DIPSETTING(    0x0d, "1P 3C / 2P 3C / Continue 2C" ) \
+	PORT_DIPSETTING(    0x1d, "1P 3C / 2P 3C / Continue 1C" ) \
+	PORT_DIPSETTING(    0x09, "1P 3C / 2P 4C / Continue 3C" ) \
+	PORT_DIPSETTING(    0x19, "1P 3C / 2P 4C / Continue 2C" ) \
+	PORT_DIPSETTING(    0x05, "1P 3C / 2P 4C / Continue 1C" ) \
+	PORT_DIPSETTING(    0x03, "1P 2C / 2P 4C / Continue 2C" ) \
+	PORT_DIPSETTING(    0x1f, "1P 2C / 2P 4C / Continue 1C" ) \
+	PORT_DIPSETTING(    0x0b, "1P 2C / 2P 3C / Continue 2C" ) \
+	PORT_DIPSETTING(    0x1b, "1P 2C / 2P 3C / Continue 1C" ) \
+	PORT_DIPSETTING(    0x07, "1P 2C / 2P 2C / Continue 2C" ) \
+	PORT_DIPSETTING(    0x17, "1P 2C / 2P 2C / Continue 1C" ) \
+	PORT_DIPSETTING(    0x0f, "1P 1C / 2P 2C / Continue 1C" ) \
+	PORT_DIPSETTING(    0x13, "1P 1C / 2P 1C / Continue 1C" ) \
+	PORT_DIPSETTING(    0x00, DEF_STR( Free_Play ) )
+
 #define BEATMANIA_DSW2 \
 	PORT_START      /* IN 4 */ \
 	PORT_DIPNAME( 0x80, 0x80, "Score Display" ) \
@@ -621,6 +644,18 @@ ADDRESS_MAP_END
 	PORT_DIPSETTING(    0x01, "Level 14" ) \
 	PORT_DIPSETTING(    0x00, "Level 15" )
 
+#define BM1STMIX_DSW2 \
+	PORT_START      /* IN 4 */ \
+	PORT_DIPNAME( 0x80, 0x80, "Enable Expert Mode" ) \
+	PORT_DIPSETTING(    0x00, DEF_STR( No ) ) \
+	PORT_DIPSETTING(    0x80, DEF_STR( Yes ) ) \
+	PORT_DIPNAME( 0x60, 0x60, DEF_STR( Demo_Sounds ) ) \
+	PORT_DIPSETTING(    0x60, "Loud" ) \
+	PORT_DIPSETTING(    0x20, DEF_STR( Medium ) ) \
+	PORT_DIPSETTING(    0x40, DEF_STR( Low ) ) \
+	PORT_DIPSETTING(    0x00, "Silent" ) \
+	PORT_BIT( 0x1f, IP_ACTIVE_LOW, IPT_UNKNOWN ) \
+
 #define BMCOMPMX_DSW2 \
 	PORT_START      /* IN 4 */ \
 	PORT_DIPNAME( 0x80, 0x80, "Score Display" ) \
@@ -656,27 +691,31 @@ ADDRESS_MAP_END
 	PORT_DIPNAME( 0x20, 0x20, "Event Mode" ) \
 	PORT_DIPSETTING(    0x20, DEF_STR( Off ) ) \
 	PORT_DIPSETTING(    0x00, DEF_STR( On ) ) \
-	PORT_DIPNAME( 0x1c, 0x1c, "Normal Mode Stages" ) \
-	PORT_DIPSETTING(    0x10, "3" ) \
-	PORT_DIPSETTING(    0x1c, "4" ) \
-	PORT_DIPSETTING(    0x08, "5" ) \
+	PORT_DIPNAME( 0x1c, 0x1c, "Normal / Event Mode Stages" ) \
+	PORT_DIPSETTING(    0x0c, "4 / 1" ) \
+	PORT_DIPSETTING(    0x14, "4 / 2" ) \
+	PORT_DIPSETTING(    0x10, "3 / 3" ) \
+	PORT_DIPSETTING(    0x1c, "4 / 4" ) \
+	PORT_DIPSETTING(    0x08, "5 / 5" ) \
 	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_UNKNOWN )		/* DSW 3-5 */ \
 	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_UNKNOWN )		/* DSW 3-6 */
 
 #define BM1STMIX_DSW3 \
+	PORT_START      /* IN 5 */ \
+	PORT_BIT( 0xff, IP_ACTIVE_LOW, IPT_UNKNOWN )
+
+#define BM2NDMIX_DSW3 \
 	PORT_START      /* IN 5 */ \
 	PORT_BIT( 0xc0, IP_ACTIVE_LOW, IPT_UNKNOWN ) \
-	PORT_DIPNAME( 0x20, 0x20, "Event Mode" ) \
-	PORT_DIPSETTING(    0x20, DEF_STR( Off ) ) \
-	PORT_DIPSETTING(    0x00, DEF_STR( On ) ) \
-	PORT_DIPNAME( 0x1c, 0x14, "Normal Mode Stages" ) \
-	PORT_DIPSETTING(    0x10, "3" ) \
-	PORT_DIPSETTING(    0x14, "4" ) \
-	PORT_DIPSETTING(    0x00, "5" ) \
+	PORT_DIPNAME( 0x39, 0x39, "Event Mode / Free Hidden Songs" ) \
+	PORT_DIPSETTING(    0x39, "Off / Off" ) \
+	PORT_DIPSETTING(    0x20, "Off / On" ) \
+	PORT_DIPSETTING(    0x19, "1 Stages / On" ) \
+	PORT_DIPSETTING(    0x09, "2 Stages / On" ) \
+	PORT_DIPSETTING(    0x11, "3 Stages / On" ) \
+	PORT_DIPSETTING(    0x01, "4 Stages / On" ) \
+	PORT_BIT( 0x04, IP_ACTIVE_LOW, IPT_UNKNOWN )		/* DSW 3-4 */ \
 	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_UNKNOWN )		/* DSW 3-5 */ \
-	PORT_DIPNAME( 0x01, 0x01, "Free Hidden Songs" )		/* DSW 3-6 */ \
-	PORT_DIPSETTING(    0x01, DEF_STR( Off ) ) \
-	PORT_DIPSETTING(    0x00, DEF_STR( On ) )
 
 #define BMCOMPMX_DSW3 \
 	PORT_START      /* IN 5 */ \
@@ -684,10 +723,12 @@ ADDRESS_MAP_END
 	PORT_DIPNAME( 0x20, 0x20, "Event Mode" ) \
 	PORT_DIPSETTING(    0x20, DEF_STR( Off ) ) \
 	PORT_DIPSETTING(    0x00, DEF_STR( On ) ) \
-	PORT_DIPNAME( 0x1c, 0x1c, "Normal Mode Stages" ) \
-	PORT_DIPSETTING(    0x10, "3" ) \
-	PORT_DIPSETTING(    0x1c, "4" ) \
-	PORT_DIPSETTING(    0x08, "5" ) \
+	PORT_DIPNAME( 0x1c, 0x1c, "Normal / Event Mode Stages" ) \
+	PORT_DIPSETTING(    0x0c, "4 / 1" ) \
+	PORT_DIPSETTING(    0x14, "4 / 2" ) \
+	PORT_DIPSETTING(    0x10, "3 / 3" ) \
+	PORT_DIPSETTING(    0x1c, "4 / 4" ) \
+	PORT_DIPSETTING(    0x08, "5 / 5" ) \
 	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_UNKNOWN )		/* DSW 3-5 */ \
 	PORT_DIPNAME( 0x01, 0x01, "Secret Expert Course" )	/* DSW 3-6 */ \
 	PORT_DIPSETTING(    0x01, DEF_STR( Off ) ) \
@@ -699,10 +740,12 @@ ADDRESS_MAP_END
 	PORT_DIPNAME( 0x20, 0x20, "Event Mode" ) \
 	PORT_DIPSETTING(    0x20, DEF_STR( Off ) ) \
 	PORT_DIPSETTING(    0x00, DEF_STR( On ) ) \
-	PORT_DIPNAME( 0x1c, 0x1c, "Normal Mode Stages" ) \
-	PORT_DIPSETTING(    0x10, "3" ) \
-	PORT_DIPSETTING(    0x1c, "4" ) \
-	PORT_DIPSETTING(    0x08, "5" ) \
+	PORT_DIPNAME( 0x1c, 0x1c, "Normal / Event Mode Stages" ) \
+	PORT_DIPSETTING(    0x0c, "4 / 1" ) \
+	PORT_DIPSETTING(    0x14, "4 / 2" ) \
+	PORT_DIPSETTING(    0x10, "3 / 3" ) \
+	PORT_DIPSETTING(    0x1c, "4 / 4" ) \
+	PORT_DIPSETTING(    0x08, "5 / 5" ) \
 	PORT_DIPNAME( 0x02, 0x02, "Secret Expert Course" )	/* DSW 3-5 */ \
 	PORT_DIPSETTING(    0x02, DEF_STR( Off ) ) \
 	PORT_DIPSETTING(    0x00, DEF_STR( On ) ) \
@@ -714,10 +757,12 @@ ADDRESS_MAP_END
 	PORT_DIPNAME( 0x20, 0x20, "Event Mode" ) \
 	PORT_DIPSETTING(    0x20, DEF_STR( Off ) ) \
 	PORT_DIPSETTING(    0x00, DEF_STR( On ) ) \
-	PORT_DIPNAME( 0x1c, 0x1c, "Normal Mode Stages" ) \
-	PORT_DIPSETTING(    0x10, "3" ) \
-	PORT_DIPSETTING(    0x1c, "4" ) \
-	PORT_DIPSETTING(    0x08, "5" ) \
+	PORT_DIPNAME( 0x1c, 0x1c, "Normal / Event Mode Stages" ) \
+	PORT_DIPSETTING(    0x0c, "4 / 1" ) \
+	PORT_DIPSETTING(    0x14, "4 / 2" ) \
+	PORT_DIPSETTING(    0x10, "3 / 3" ) \
+	PORT_DIPSETTING(    0x1c, "4 / 4" ) \
+	PORT_DIPSETTING(    0x08, "5 / 5" ) \
 	PORT_DIPNAME( 0x02, 0x02, "Game Over Mode" ) \
 	PORT_DIPSETTING(    0x02, "On Stage Middle" ) \
 	PORT_DIPSETTING(    0x00, "On Stage Last" ) \
@@ -747,10 +792,18 @@ INPUT_PORTS_START( beatmania )
 INPUT_PORTS_END
 
 INPUT_PORTS_START( bm1stmix )
+	BEATMANIA_INPUT			/* IN 0-2 */
+	BM1STMIX_DSW1			/* IN 3 */
+	BM1STMIX_DSW2			/* IN 4 */
+	BM1STMIX_DSW3			/* IN 5 */
+	BEATMANIA_TURNTABLE		/* IN 6-7 */
+INPUT_PORTS_END
+
+INPUT_PORTS_START( bm2ndmix )
 	BEATMANIA_INPUT			/* IN 0-2 */
 	BEATMANIA_DSW1(0x00, 0xff)	/* IN 3 */
 	BEATMANIA_DSW2_OLD_LEVEL	/* IN 4 */
-	BM1STMIX_DSW3			/* IN 5 */
+	BM2NDMIX_DSW3			/* IN 5 */
 	BEATMANIA_TURNTABLE		/* IN 6-7 */
 INPUT_PORTS_END
 
@@ -794,7 +847,7 @@ INPUT_PORTS_END
  *
  *************************************/
 
-static struct GfxLayout spritelayout =
+static const gfx_layout spritelayout =
 {
 	16, 16,	/* 16x16 characters */
 	0x200000 / 128,	/* 16384 characters */
@@ -807,7 +860,7 @@ static struct GfxLayout spritelayout =
 	16*16*4
 };
 
-static struct GfxDecodeInfo gfxdecodeinfo[] =
+static const gfx_decode gfxdecodeinfo[] =
 {
 	{ REGION_GFX1, 0, &spritelayout, 0,  (0x4440/4)/16 },
 	{ -1 } /* end of array */
@@ -847,7 +900,22 @@ static struct K054539interface k054539_interface =
  *
  *************************************/
 
-static MACHINE_INIT( djmain )
+static MACHINE_START( djmain )
+{
+	UINT8 *region = memory_region(REGION_SOUND1);
+
+	state_save_register_global(sndram_bank);
+	state_save_register_global_pointer(region, 0x80000 * 32);
+	state_save_register_global(pending_vb_int);
+	state_save_register_global(v_ctrl);
+	state_save_register_global_array(obj_regs);
+
+	state_save_register_func_postload(sndram_set_bank);
+	return 0;
+}
+
+
+static MACHINE_RESET( djmain )
 {
 	/* reset sound ram bank */
 	sndram_bank = 0;
@@ -882,7 +950,8 @@ static MACHINE_DRIVER_START( djmain )
 	MDRV_FRAMES_PER_SECOND(58)
 	MDRV_VBLANK_DURATION(DEFAULT_60HZ_VBLANK_DURATION)
 
-	MDRV_MACHINE_INIT(djmain)
+	MDRV_MACHINE_START(djmain)
+	MDRV_MACHINE_RESET(djmain)
 
 	/* video hardware */
 	MDRV_VIDEO_ATTRIBUTES(VIDEO_TYPE_RASTER | VIDEO_NEEDS_6BITS_PER_GUN | VIDEO_RGB_DIRECT)
@@ -1177,19 +1246,14 @@ ROM_END
 
 static DRIVER_INIT( beatmania )
 {
-	if (new_memory_region(REGION_SOUND1, 0x80000 * 32, 0))
+	UINT8 *region;
+
+	if (new_memory_region(REGION_SOUND1, 0x80000 * 32, 0) != 0)
 		return;
+	region = memory_region(REGION_SOUND1);
 
 	/* spin up the hard disk */
 	ide_controller_init(0, &ide_intf);
-
-	state_save_register_int   ("djmain", 0, "sndram_bank",    &sndram_bank);
-	state_save_register_UINT8 ("djmain", 0, "sndram",         memory_region(REGION_SOUND1), 0x80000 * 32);
-	state_save_register_int   ("djmain", 0, "pending_vb_int", &pending_vb_int);
-	state_save_register_UINT16("djmain", 0, "v_ctrl",         &v_ctrl,  1);
-	state_save_register_UINT32("djmain", 0, "obj_regs",       obj_regs, sizeof (obj_regs) / sizeof (UINT32));
-
-	state_save_register_func_postload(sndram_set_bank);
 }
 
 static UINT8 beatmania_master_password[2 + 32] =
@@ -1343,15 +1407,15 @@ static DRIVER_INIT( bm6thmix )
  *
  *************************************/
 
-GAME( 1997, bm1stmix, 0,        djmain,   bm1stmix,  beatmania, ROT0, "Konami", "beatmania (ver JA-B)" )
-GAME( 1998, bm2ndmix, 0,        djmain,   bm1stmix,  beatmania, ROT0, "Konami", "beatmania 2nd MIX (ver JA-B)" )
-GAME( 1998, bm2ndmxa, bm2ndmix, djmain,   bm1stmix,  beatmania, ROT0, "Konami", "beatmania 2nd MIX (ver JA-A)" )
-GAME( 1999, bmcompmx, 0,        djmain,   bmcompmx,  beatmania, ROT0, "Konami", "beatmania complete MIX (ver JA-B)" )
-GAME( 1999, hmcompmx, bmcompmx, djmain,   bmcompmx,  hmcompmx,  ROT0, "Konami", "hiphopmania complete MIX (ver UA-B)" )
-GAME( 1999, bm4thmix, 0,        djmain,   bm4thmix,  bm4thmix,  ROT0, "Konami", "beatmania 4th MIX (ver JA-A)" )
-GAME( 1999, bm5thmix, 0,        djmain,   beatmania, bm5thmix,  ROT0, "Konami", "beatmania 5th MIX (ver JA-A)" )
-GAME( 2000, bmcompm2, 0,        djmain,   beatmania, bmcompm2,  ROT0, "Konami", "beatmania complete MIX 2 (ver JA-A)" )
-GAME( 2000, hmcompm2, bmcompm2, djmain,   hmcompm2,  hmcompm2,  ROT0, "Konami", "hiphopmania complete MIX 2 (ver UA-A)" )
-GAME( 2000, bmdct,    0,        djmain,   bmdct,     bmdct,     ROT0, "Konami", "beatmania f. Dreams Come True (ver JA-A)" )
-GAME( 2000, bmcorerm, 0,        djmain,   beatmania, bmcorerm,  ROT0, "Konami", "beatmania CORE REMIX (ver JA-A)" )
-GAME( 2001, bm6thmix, 0,        djmain,   beatmania, bm6thmix,  ROT0, "Konami", "beatmania 6th MIX (ver JA-A)" )
+GAME( 1997, bm1stmix, 0,        djmain,   bm1stmix,  beatmania, ROT0, "Konami", "beatmania (ver JA-B)", 0 )
+GAME( 1998, bm2ndmix, 0,        djmain,   bm2ndmix,  beatmania, ROT0, "Konami", "beatmania 2nd MIX (ver JA-B)", 0 )
+GAME( 1998, bm2ndmxa, bm2ndmix, djmain,   bm2ndmix,  beatmania, ROT0, "Konami", "beatmania 2nd MIX (ver JA-A)", 0 )
+GAME( 1999, bmcompmx, 0,        djmain,   bmcompmx,  beatmania, ROT0, "Konami", "beatmania complete MIX (ver JA-B)", 0 )
+GAME( 1999, hmcompmx, bmcompmx, djmain,   bmcompmx,  hmcompmx,  ROT0, "Konami", "hiphopmania complete MIX (ver UA-B)", 0 )
+GAME( 1999, bm4thmix, 0,        djmain,   bm4thmix,  bm4thmix,  ROT0, "Konami", "beatmania 4th MIX (ver JA-A)", 0 )
+GAME( 1999, bm5thmix, 0,        djmain,   beatmania, bm5thmix,  ROT0, "Konami", "beatmania 5th MIX (ver JA-A)", 0 )
+GAME( 2000, bmcompm2, 0,        djmain,   beatmania, bmcompm2,  ROT0, "Konami", "beatmania complete MIX 2 (ver JA-A)", 0 )
+GAME( 2000, hmcompm2, bmcompm2, djmain,   hmcompm2,  hmcompm2,  ROT0, "Konami", "hiphopmania complete MIX 2 (ver UA-A)", 0 )
+GAME( 2000, bmdct,    0,        djmain,   bmdct,     bmdct,     ROT0, "Konami", "beatmania f. Dreams Come True (ver JA-A)", 0 )
+GAME( 2000, bmcorerm, 0,        djmain,   beatmania, bmcorerm,  ROT0, "Konami", "beatmania CORE REMIX (ver JA-A)", 0 )
+GAME( 2001, bm6thmix, 0,        djmain,   beatmania, bm6thmix,  ROT0, "Konami", "beatmania 6th MIX (ver JA-A)", 0 )
