@@ -1,8 +1,7 @@
 /* the way I hooked up the CTC is most likely completely wrong */
 
 #include "driver.h"
-#include "vidhrdw/generic.h"
-#include "machine/z80fmly.h"
+#include "machine/z80ctc.h"
 #include "cpu/z80/z80daisy.h"
 
 
@@ -125,21 +124,20 @@ static void ctc_interrupt (int state)
 
 static z80ctc_interface ctc_intf =
 {
-	1,                  /* 1 chip */
-	{ 0 },              /* clock (filled in from the CPU 0 clock */
-	{ 0 },              /* timer disables */
-	{ ctc_interrupt },  /* interrupt handler */
-	{ 0 },              /* ZC/TO0 callback */
-	{ 0 },              /* ZC/TO1 callback */
-	{ 0 }               /* ZC/TO2 callback */
+	0,              /* clock (filled in from the CPU 0 clock */
+	0,              /* timer disables */
+	ctc_interrupt,  /* interrupt handler */
+	0,              /* ZC/TO0 callback */
+	0,              /* ZC/TO1 callback */
+	0               /* ZC/TO2 callback */
 };
 
 
-MACHINE_INIT( dlair )
+MACHINE_RESET( dlair )
 {
    /* initialize the CTC */
-   ctc_intf.baseclock[0] = Machine->drv->cpu[0].cpu_clock;
-   z80ctc_init(&ctc_intf);
+   ctc_intf.baseclock = Machine->drv->cpu[0].cpu_clock;
+   z80ctc_init(0, &ctc_intf);
 }
 
 
@@ -192,7 +190,7 @@ INPUT_PORTS_END
 
 
 
-static gfx_layout charlayout =
+static const gfx_layout charlayout =
 {
 	8,16,
 	512,
@@ -205,7 +203,7 @@ static gfx_layout charlayout =
 };
 
 
-static gfx_decode gfxdecodeinfo[] =
+static const gfx_decode gfxdecodeinfo[] =
 {
 	{ REGION_GFX1, 0x0000, &charlayout,  0, 8 },
 	{ -1 } /* end of array */
@@ -232,7 +230,7 @@ static MACHINE_DRIVER_START( dlair )
 	MDRV_FRAMES_PER_SECOND(60)
 	MDRV_VBLANK_DURATION(DEFAULT_60HZ_VBLANK_DURATION)
 
-	MDRV_MACHINE_INIT(dlair)
+	MDRV_MACHINE_RESET(dlair)
 
 	/* video hardware */
 	MDRV_VIDEO_ATTRIBUTES(VIDEO_TYPE_RASTER)
