@@ -9,7 +9,6 @@ unico used for zero point etc.
 */
 
 #include "driver.h"
-#include "vidhrdw/generic.h"
 #include "cpu/pic16c5x/pic16c5x.h"
 #include "sound/okim6295.h"
 
@@ -37,7 +36,12 @@ VIDEO_START(drgnmst);
 VIDEO_UPDATE(drgnmst);
 
 
-
+static WRITE16_HANDLER( drgnmst_coin_w )
+{
+	coin_counter_w(0,data & 0x100);
+	coin_lockout_w(0,~data & 0x400);
+	coin_lockout_w(1,~data & 0x800);
+}
 
 static WRITE16_HANDLER( drgnmst_snd_command_w )
 {
@@ -168,20 +172,20 @@ static READ8_HANDLER( PIC16C5X_T0_clk_r )
 /***************************** 68000 Memory Map *****************************/
 
 static ADDRESS_MAP_START( drgnmst_main_map, ADDRESS_SPACE_PROGRAM, 16 )
-	AM_RANGE(0x000000, 0x0fffff) AM_RAM
+	AM_RANGE(0x000000, 0x0fffff) AM_ROM
 	AM_RANGE(0x800000, 0x800001) AM_READ(input_port_0_word_r)
 	AM_RANGE(0x800018, 0x800019) AM_READ(input_port_1_word_r)
 	AM_RANGE(0x80001a, 0x80001b) AM_READ(input_port_2_word_r)
 	AM_RANGE(0x80001c, 0x80001d) AM_READ(input_port_3_word_r)
-/*  AM_RANGE(0x800030, 0x800031) AM_NOP */
+	AM_RANGE(0x800030, 0x800031) AM_WRITE(drgnmst_coin_w)
 	AM_RANGE(0x800100, 0x80011f) AM_WRITE(MWA16_RAM) AM_BASE(&drgnmst_vidregs)
-/*  AM_RANGE(0x800120, 0x800121) AM_NOP */
-/*  AM_RANGE(0x80014a, 0x80014b) AM_NOP */
+	AM_RANGE(0x800120, 0x800121) AM_WRITENOP
+	AM_RANGE(0x80014a, 0x80014b) AM_WRITENOP
 	AM_RANGE(0x800154, 0x800155) AM_WRITE(MWA16_RAM) AM_BASE(&drgnmst_vidregs2) /* seems to be priority control */
 	AM_RANGE(0x800176, 0x800177) AM_READ(input_port_4_word_r)
 	AM_RANGE(0x800180, 0x800181) AM_WRITE(drgnmst_snd_command_w)
 	AM_RANGE(0x800188, 0x800189) AM_WRITE(drgnmst_snd_flag_w)
-/*  AM_RANGE(0x8001e0, 0x8001e1) AM_NOP */
+	AM_RANGE(0x8001e0, 0x8001e1) AM_WRITENOP
 	AM_RANGE(0x900000, 0x903fff) AM_READWRITE(MRA16_RAM, paletteram16_xxxxRRRRGGGGBBBB_word_w) AM_BASE(&paletteram16)
 	AM_RANGE(0x904000, 0x907fff) AM_READWRITE(MRA16_RAM, drgnmst_md_videoram_w) AM_BASE(&drgnmst_md_videoram)
 	AM_RANGE(0x908000, 0x90bfff) AM_READWRITE(MRA16_RAM, drgnmst_bg_videoram_w) AM_BASE(&drgnmst_bg_videoram)
@@ -299,7 +303,7 @@ INPUT_PORTS_START( drgnmst )
 INPUT_PORTS_END
 
 
-static gfx_layout drgnmst_char8x8_layout =
+static const gfx_layout drgnmst_char8x8_layout =
 {
 	8,8,
 	RGN_FRAC(1,1),
@@ -311,7 +315,7 @@ static gfx_layout drgnmst_char8x8_layout =
 };
 
 
-static gfx_layout drgnmst_char16x16_layout =
+static const gfx_layout drgnmst_char16x16_layout =
 {
 	16,16,
 	RGN_FRAC(1,2),
@@ -326,7 +330,7 @@ static gfx_layout drgnmst_char16x16_layout =
 
 
 
-static gfx_layout drgnmst_char32x32_layout =
+static const gfx_layout drgnmst_char32x32_layout =
 {
 	32,32,
 	RGN_FRAC(1,2),
@@ -345,7 +349,7 @@ static gfx_layout drgnmst_char32x32_layout =
 };
 
 
-static gfx_decode gfxdecodeinfo[] =
+static const gfx_decode gfxdecodeinfo[] =
 {
 	{ REGION_GFX1, 0, &drgnmst_char16x16_layout,   0,      0x200  }, /* sprite tiles */
 	{ REGION_GFX2, 0, &drgnmst_char8x8_layout,     0x200,  0x200  }, /* fg tiles */
@@ -397,7 +401,7 @@ ROM_START( drgnmst )
 	ROM_LOAD16_BYTE( "dm1000e", 0x00000, 0x80000, CRC(29467dac) SHA1(42ca42340ffd9b04be23853ca4e936d0528a66ee) )
 	ROM_LOAD16_BYTE( "dm1000o", 0x00001, 0x80000, CRC(ba48e9cf) SHA1(1107f927424107918bb10ff23f40c50579b23836) )
 
-	ROM_REGION( 0x400, REGION_CPU2, 0 ) /* PIC16C55 Code */
+	ROM_REGION( 0x400, REGION_CPU2, ROMREGION_ERASE00 ) /* PIC16C55 Code */
 /*  ROM_LOAD( "pic16c55", 0x0000, 0x400, CRC(531c9f8d) SHA1(8ec180b0566f2ce1e08f0347e5ad402c73b44049) ) */
 	/* ROM will be copied here by the init code from the USER1 region */
 
