@@ -18,6 +18,7 @@ Year + Game            PCB             Notes
 98  Multi Champ        ESD 11-09-98
 99  Multi Champ Deluxe ESD 08-26-1999
 00  Head Panic         ESD 08-26-1999 (with Fuuki)
+00  Tang Tang          ESD            (no date is marked on PCB)
 ---------------------------------------------------------------------------
 
 Head Panic
@@ -29,7 +30,6 @@ Head Panic
 ***************************************************************************/
 
 #include "driver.h"
-#include "vidhrdw/generic.h"
 #include "machine/eeprom.h"
 #include "sound/okim6295.h"
 #include "sound/3812intf.h"
@@ -38,22 +38,22 @@ Head Panic
 
 extern UINT16 *esd16_vram_0, *esd16_scroll_0;
 extern UINT16 *esd16_vram_1, *esd16_scroll_1;
+extern UINT16 *head_layersize;
 extern tilemap *esdtilemap_1_16x16;
 
 /* Functions defined in vidhrdw: */
 
 WRITE16_HANDLER( esd16_vram_0_w );
 WRITE16_HANDLER( esd16_vram_1_w );
+WRITE16_HANDLER( esd16_tilemap0_color_w );
 
 VIDEO_START( esd16 );
 VIDEO_UPDATE( esd16 );
 VIDEO_UPDATE( hedpanic );
 
-UINT16 *head_layersize;
-UINT16* headpanic_platform_x;
-UINT16* headpanic_platform_y;
-
 
+static UINT16 *headpanic_platform_x;
+static UINT16 *headpanic_platform_y;
 
 /***************************************************************************
 
@@ -65,16 +65,6 @@ UINT16* headpanic_platform_y;
 
 WRITE16_HANDLER( esd16_spriteram_w ) {	COMBINE_DATA(&spriteram16[offset]);	}
 
-WRITE16_HANDLER( esd16_flip_screen_w )
-{
-	if (ACCESSING_LSB && !(data & 0x7e))
-	{
-		flip_screen_set( data & 0x80 );
-		/*               data & 0x01 ?? always 1 */
-	}
-	else	logerror("CPU #0 - PC %06X: unknown flip screen bits: %02X\n",activecpu_get_pc(),data);
-}
-
 WRITE16_HANDLER( esd16_sound_command_w )
 {
 	if (ACCESSING_LSB)
@@ -121,7 +111,7 @@ static ADDRESS_MAP_START( multchmp_writemem, ADDRESS_SPACE_PROGRAM, 16 )
 	AM_RANGE(0x500008, 0x50000b) AM_WRITE(MWA16_RAM						)	/* ? 0 */
 	AM_RANGE(0x50000c, 0x50000f) AM_WRITE(MWA16_RAM						)	/* ? 0 */
 	AM_RANGE(0x600000, 0x600001) AM_WRITE(MWA16_NOP						)	/* IRQ Ack */
-	AM_RANGE(0x600008, 0x600009) AM_WRITE(esd16_flip_screen_w			)	/* Flip Screen + ? */
+	AM_RANGE(0x600008, 0x600009) AM_WRITE(esd16_tilemap0_color_w		)	/* Flip Screen + Tileamp0 palette banking */
 	AM_RANGE(0x60000a, 0x60000b) AM_WRITE(MWA16_NOP						)	/* ? 2 */
 	AM_RANGE(0x60000c, 0x60000d) AM_WRITE(esd16_sound_command_w			)	/* To Sound CPU */
 ADDRESS_MAP_END
@@ -164,7 +154,6 @@ static WRITE16_HANDLER( esd_eeprom_w )
 /*  logerror("(0x%06x) Unk EEPROM write: %04x %04x\n", activecpu_get_pc(), data, mem_mask); */
 }
 
-
 static ADDRESS_MAP_START( hedpanic_readmem, ADDRESS_SPACE_PROGRAM, 16 )
 	AM_RANGE(0x000000, 0x07ffff) AM_READ(MRA16_ROM				)	/* ROM */
 	AM_RANGE(0x100000, 0x10ffff) AM_READ(MRA16_RAM)
@@ -187,11 +176,11 @@ static ADDRESS_MAP_START( hedpanic_writemem, ADDRESS_SPACE_PROGRAM, 16 )
 	AM_RANGE(0xb00004, 0xb00007) AM_WRITE(MWA16_RAM) AM_BASE(&esd16_scroll_1	)	/* */
 	AM_RANGE(0xb00008, 0xb00009) AM_WRITE(MWA16_RAM) AM_BASE(&headpanic_platform_x)
 	AM_RANGE(0xb0000a, 0xb0000b) AM_WRITE(MWA16_RAM) AM_BASE(&headpanic_platform_y)
-/*  AM_RANGE(0xb0000c, 0xb0000d) AM_WRITE(MWA16_RAM) AM_BASE(&head_unknown1) // ?? */
+	AM_RANGE(0xb0000c, 0xb0000d) AM_WRITE(MWA16_NOP) /* ?? */
 	AM_RANGE(0xb0000e, 0xb0000f) AM_WRITE(MWA16_RAM) AM_BASE(&head_layersize) /* ?? */
-/*  AM_RANGE(0xc00000, 0xc00001) AM_WRITE(MWA16_RAM) AM_BASE(&head_unknown3 )   // IRQ Ack */
-/*  AM_RANGE(0xc00008, 0xc00009) AM_WRITE(MWA16_RAM) AM_BASE(&head_unknown5     )   // Flip Screen + ? // not checked */
-/*  AM_RANGE(0xc0000a, 0xc0000b) AM_WRITE(MWA16_RAM) AM_BASE(&head_unknown4 )   // ? 2 not checked */
+	AM_RANGE(0xc00000, 0xc00001) AM_WRITE(MWA16_NOP) /* IRQ Ack */
+	AM_RANGE(0xc00008, 0xc00009) AM_WRITE(esd16_tilemap0_color_w)	/* Flip Screen + Tileamp0 palette banking */
+	AM_RANGE(0xc0000a, 0xc0000b) AM_WRITE(MWA16_NOP)	/* ? 2 not checked */
 	AM_RANGE(0xc0000c, 0xc0000d) AM_WRITE(esd16_sound_command_w			)	/* To Sound CPU // ok */
 	AM_RANGE(0xc0000e, 0xc0000f) AM_WRITE(esd_eeprom_w)
 	AM_RANGE(0xd00008, 0xd00009) AM_WRITE(hedpanic_platform_w)
@@ -215,9 +204,9 @@ static ADDRESS_MAP_START( mchampdx_writemem, ADDRESS_SPACE_PROGRAM, 16 )
 	AM_RANGE(0x320000, 0x323fff) AM_WRITE(esd16_vram_1_w) AM_BASE(&esd16_vram_1	)	/* */
 	AM_RANGE(0x324000, 0x327fff) AM_WRITE(esd16_vram_1_w) AM_BASE(&esd16_vram_1	)	/* mirror? */
 	AM_RANGE(0x400000, 0x400fff) AM_WRITE(paletteram16_xRRRRRGGGGGBBBBB_word_w) AM_BASE(&paletteram16)
-    AM_RANGE(0x500000, 0x500001) AM_WRITE(MWA16_NOP)/*AM_WRITE(MWA16_RAM) AM_BASE(&head_unknown3 )   // IRQ Ack */
-/*  AM_RANGE(0x500008, 0x500009) AM_WRITE(MWA16_RAM) AM_BASE(&head_unknown5     )   // Flip Screen + ? // not checked */
-/*  AM_RANGE(0x50000a, 0x50000b) AM_WRITE(MWA16_RAM) AM_BASE(&head_unknown4 )   // ? 2 not checked */
+    AM_RANGE(0x500000, 0x500001) AM_WRITE(MWA16_NOP)	/* IRQ Ack */
+	AM_RANGE(0x500008, 0x500009) AM_WRITE(esd16_tilemap0_color_w)   /* Flip Screen + Tileamp0 palette banking */
+	AM_RANGE(0x50000a, 0x50000b) AM_WRITE(MWA16_NOP)	/* ? 2 not checked */
 	AM_RANGE(0x50000c, 0x50000d) AM_WRITE(esd16_sound_command_w			)	/* To Sound CPU // ok */
 	AM_RANGE(0x50000e, 0x50000f) AM_WRITE(esd_eeprom_w)
 	AM_RANGE(0x600000, 0x6007ff) AM_WRITE(MWA16_RAM) AM_BASE(&spriteram16) AM_SIZE(&spriteram_size	)	/* Sprites */
@@ -226,11 +215,45 @@ static ADDRESS_MAP_START( mchampdx_writemem, ADDRESS_SPACE_PROGRAM, 16 )
 	AM_RANGE(0x700004, 0x700007) AM_WRITE(MWA16_RAM) AM_BASE(&esd16_scroll_1	)	/* */
 	AM_RANGE(0x700008, 0x700009) AM_WRITE(MWA16_RAM) AM_BASE(&headpanic_platform_x) /* not used in mchampdx? */
 	AM_RANGE(0x70000a, 0x70000b) AM_WRITE(MWA16_RAM) AM_BASE(&headpanic_platform_y) /* not used in mchampdx? */
-/*  AM_RANGE(0x70000c, 0x70000d) AM_WRITE(MWA16_RAM) AM_BASE(&head_unknown1) // ?? */
+	AM_RANGE(0x70000c, 0x70000d) AM_WRITE(MWA16_NOP) /* ?? */
 	AM_RANGE(0x70000e, 0x70000f) AM_WRITE(MWA16_RAM) AM_BASE(&head_layersize) /* ?? */
 	AM_RANGE(0xd00008, 0xd00009) AM_WRITE(hedpanic_platform_w) /* not used in mchampdx? */
 ADDRESS_MAP_END
 
+/* Tang Tang - like the others but again with different addresses */
+
+static ADDRESS_MAP_START( tangtang_readmem, ADDRESS_SPACE_PROGRAM, 16 )
+	AM_RANGE(0x000000, 0x07ffff) AM_READ(MRA16_ROM				)	/* ROM */
+	AM_RANGE(0x100000, 0x100fff) AM_READ(MRA16_RAM)
+	AM_RANGE(0x500002, 0x500003) AM_READ(input_port_0_word_r	)	/* Inputs */
+	AM_RANGE(0x500004, 0x500005) AM_READ(input_port_1_word_r	)	/* */
+	AM_RANGE(0x500006, 0x500007) AM_READ(esd_eeprom_r	)
+	AM_RANGE(0x700000, 0x70ffff) AM_READ(MRA16_RAM) /* main ram */
+ADDRESS_MAP_END
+
+static ADDRESS_MAP_START( tangtang_writemem, ADDRESS_SPACE_PROGRAM, 16 )
+	AM_RANGE(0x000000, 0x07ffff) AM_WRITE(MWA16_ROM						)	/* ROM */
+	AM_RANGE(0x100000, 0x100fff) AM_WRITE(paletteram16_xRRRRRGGGGGBBBBB_word_w) AM_BASE(&paletteram16)
+	AM_RANGE(0x200000, 0x2007ff) AM_WRITE(MWA16_RAM) AM_BASE(&spriteram16) AM_SIZE(&spriteram_size	)	/* Sprites */
+	AM_RANGE(0x200800, 0x200807) AM_WRITE(esd16_spriteram_w				)	/* Sprites (Mirrored) */
+	AM_RANGE(0x300000, 0x303fff) AM_WRITE(esd16_vram_0_w) AM_BASE(&esd16_vram_0	)	/* Layers */
+	AM_RANGE(0x320000, 0x323fff) AM_WRITE(esd16_vram_1_w) AM_BASE(&esd16_vram_1	)	/* */
+	AM_RANGE(0x324000, 0x327fff) AM_WRITE(esd16_vram_1_w) AM_BASE(&esd16_vram_1	)	/* mirror? */
+	AM_RANGE(0x400000, 0x400003) AM_WRITE(MWA16_RAM) AM_BASE(&esd16_scroll_0	)	/* Scroll */
+	AM_RANGE(0x400004, 0x400007) AM_WRITE(MWA16_RAM) AM_BASE(&esd16_scroll_1	)	/* */
+	AM_RANGE(0x400008, 0x400009) AM_WRITE(MWA16_RAM) AM_BASE(&headpanic_platform_x) /* not used in mchampdx? */
+	AM_RANGE(0x40000a, 0x40000b) AM_WRITE(MWA16_RAM) AM_BASE(&headpanic_platform_y) /* not used in mchampdx? */
+	AM_RANGE(0x40000c, 0x40000d) AM_WRITE(MWA16_NOP) /* ?? */
+	AM_RANGE(0x40000e, 0x40000f) AM_WRITE(MWA16_RAM) AM_BASE(&head_layersize) /* ?? */
+	AM_RANGE(0x500000, 0x500001) AM_WRITE(MWA16_NOP)	/* IRQ Ack */
+	AM_RANGE(0x500008, 0x500009) AM_WRITE(esd16_tilemap0_color_w)   /* Flip Screen + Tileamp0 palette banking */
+	AM_RANGE(0x50000a, 0x50000b) AM_WRITE(MWA16_NOP)	/* ? 2 not checked */
+	AM_RANGE(0x50000c, 0x50000d) AM_WRITE(esd16_sound_command_w			)	/* To Sound CPU // ok */
+	AM_RANGE(0x50000e, 0x50000f) AM_WRITE(esd_eeprom_w)
+	AM_RANGE(0x600008, 0x600009) AM_WRITE(hedpanic_platform_w)
+	AM_RANGE(0x700000, 0x70ffff) AM_WRITE(MWA16_RAM)
+ADDRESS_MAP_END
+
 /***************************************************************************
 
 
@@ -400,7 +423,6 @@ INPUT_PORTS_START( hedpanic )
 	PORT_BIT(  0x0020, IP_ACTIVE_LOW, IPT_UNKNOWN )
 	PORT_SERVICE_NO_TOGGLE( 0x0040, IP_ACTIVE_LOW)
 	PORT_BIT(  0xff00, IP_ACTIVE_LOW, IPT_UNKNOWN )
-
 INPUT_PORTS_END
 
 /***************************************************************************
@@ -412,7 +434,7 @@ INPUT_PORTS_END
 ***************************************************************************/
 
 /* 16x16x5, made of four 8x8 tiles */
-static gfx_layout layout_16x16x5 =
+static const gfx_layout layout_16x16x5 =
 {
 	16,16,
 	RGN_FRAC(1,5),
@@ -424,7 +446,7 @@ static gfx_layout layout_16x16x5 =
 };
 
 /* 8x8x8 */
-static gfx_layout layout_8x8x8 =
+static const gfx_layout layout_8x8x8 =
 {
 	8,8,
 	RGN_FRAC(1,4),
@@ -436,7 +458,7 @@ static gfx_layout layout_8x8x8 =
 	8*8*2,
 };
 
-static gfx_decode esd16_gfxdecodeinfo[] =
+static const gfx_decode esd16_gfxdecodeinfo[] =
 {
 	{ REGION_GFX1, 0, &layout_16x16x5, 0x200, 8 }, /* [0] Sprites */
 	{ REGION_GFX2, 0, &layout_8x8x8,   0x000, 2 }, /* [1] Layers */
@@ -444,7 +466,7 @@ static gfx_decode esd16_gfxdecodeinfo[] =
 	{ -1 }
 };
 
-static gfx_layout hedpanic_layout_8x8x8 =
+static const gfx_layout hedpanic_layout_8x8x8 =
 {
 	8,8,
 	RGN_FRAC(1,1),
@@ -455,7 +477,7 @@ static gfx_layout hedpanic_layout_8x8x8 =
 	64*8,
 };
 
-static gfx_layout hedpanic_layout_16x16x8 =
+static const gfx_layout hedpanic_layout_16x16x8 =
 {
 	16,16,
 	RGN_FRAC(1,1),
@@ -470,7 +492,7 @@ static gfx_layout hedpanic_layout_16x16x8 =
 };
 
 
-static gfx_layout hedpanic_sprite_16x16x5 =
+static const gfx_layout hedpanic_sprite_16x16x5 =
 {
 	16,16,
 	RGN_FRAC(1,3),
@@ -482,14 +504,21 @@ static gfx_layout hedpanic_sprite_16x16x5 =
 };
 
 
-static gfx_decode hedpanic_gfxdecodeinfo[] =
+static const gfx_decode hedpanic_gfxdecodeinfo[] =
 {
 	{ REGION_GFX1, 0, &hedpanic_sprite_16x16x5, 0x200, 8 }, /* [0] Sprites */
-	{ REGION_GFX2, 0, &hedpanic_layout_8x8x8,   0x000, 2 }, /* [1] Layers */
-	{ REGION_GFX2, 0, &hedpanic_layout_16x16x8, 0x000, 2 }, /* [1] Layers */
+	{ REGION_GFX2, 0, &hedpanic_layout_8x8x8,   0x000, 4 }, /* [1] Layers */
+	{ REGION_GFX2, 0, &hedpanic_layout_16x16x8, 0x000, 4 }, /* [2] Layers */
 	{ -1 }
 };
 
+static const gfx_decode tangtang_gfxdecodeinfo[] =
+{
+	{ REGION_GFX1, 0, &layout_16x16x5, 0x200, 8 }, /* [0] Sprites */
+	{ REGION_GFX2, 0, &hedpanic_layout_8x8x8,   0x000, 4 }, /* [1] Layers */
+	{ REGION_GFX2, 0, &hedpanic_layout_16x16x8, 0x000, 4 }, /* [2] Layers */
+	{ -1 }
+};
 
 /***************************************************************************
 
@@ -562,6 +591,17 @@ static MACHINE_DRIVER_START( mchampdx )
 	MDRV_CPU_PROGRAM_MAP(mchampdx_readmem,mchampdx_writemem)
 MACHINE_DRIVER_END
 
+static MACHINE_DRIVER_START( tangtang )
+
+	/* basic machine hardware */
+	MDRV_IMPORT_FROM(hedpanic)
+
+	MDRV_CPU_MODIFY("main")
+	MDRV_CPU_PROGRAM_MAP(tangtang_readmem,tangtang_writemem)
+
+	MDRV_GFXDECODE(tangtang_gfxdecodeinfo)
+MACHINE_DRIVER_END
+
 /***************************************************************************
 
 
@@ -577,7 +617,7 @@ MACHINE_DRIVER_END
 (C) ESD 1998
 PCB No. ESD 11-09-98    (Probably the manufacture date)
 CPU: MC68HC000FN16 (68000, 68 pin square socketed)
-SND: Z80, U6612 (Probably YM3812), AD-65 (OKI 6295), U6614 (YM3014)
+SND: Z80, U6612 (YM3812), AD-65 (OKI 6295), U6614 (YM3014)
 OSC: 16.000MHz, 14.000MHz
 RAM: 4 x 62256, 9 x 6116
 DIPS: 2 x 8 position
@@ -609,12 +649,42 @@ MULTCHMP.U39 -/                    MX27C2000
 ***************************************************************************/
 
 ROM_START( multchmp )
+	ROM_REGION( 0x080000, REGION_CPU1, 0 )		/* 68000 Code */
+	ROM_LOAD16_BYTE( "esd2.cu02", 0x000000, 0x040000,  CRC(2d1b098a) SHA1(c2f3991f02c611c258219da2c61cad22c9a21f7d) )
+	ROM_LOAD16_BYTE( "esd1.cu03", 0x000001, 0x040000,  CRC(10974063) SHA1(854b38b4d4cb529e9928aae4212c86a220615e04) )
+
+	ROM_REGION( 0x24000, REGION_CPU2, 0 )		/* Z80 Code */
+	ROM_LOAD( "esd3.su06", 0x00000, 0x0c000, CRC(7c178bd7) SHA1(8754d3c70d9b2bf369a5ce0cce4cc0696ed22750) )
+	ROM_CONTINUE(             0x10000, 0x14000             )
+
+	ROM_REGION( 0x140000, REGION_GFX1, ROMREGION_DISPOSE )	/* Sprites, 16x16x5 */
+	ROM_LOAD( "esd14.ju03", 0x000000, 0x040000, CRC(a6122225) SHA1(cbcf2b31c4c011daba21f0ae5fd3be63c9a87c00) )
+	ROM_LOAD( "esd15.ju04", 0x040000, 0x040000, CRC(88b7a97c) SHA1(0a57ec8f6a44c8e3aa3ef35499a415d6a2b7eb16) )
+	ROM_LOAD( "esd16.ju05", 0x080000, 0x040000, CRC(e670a6da) SHA1(47cbe45b6d5d0ca70d0c6787d589dde5d14fdba4) )
+	ROM_LOAD( "esd17.ju06", 0x0c0000, 0x040000, CRC(a69d4399) SHA1(06ae6c07cc6b7313e2e2aa3b994f7532d6994e1b) )
+	ROM_LOAD( "esd13.ju07", 0x100000, 0x040000, CRC(22071594) SHA1(c79102b250780d1da8c290d065d61fbbfa193366) )
+
+	ROM_REGION( 0x400000, REGION_GFX2, ROMREGION_DISPOSE )	/* Layers, 16x16x8 */
+	ROM_LOAD( "esd5.fu27",  0x000000, 0x080000, CRC(299f32c2) SHA1(274752444f6ddba16eeefc02c3e78525c079b3d8) )
+	ROM_LOAD( "esd6.fu32",  0x080000, 0x080000, CRC(e2689bb2) SHA1(1da9b1f7335d5c2d1c2f8353fccf91c0109d2e9d) )
+	ROM_LOAD( "esd11.fu29", 0x100000, 0x080000, CRC(9bafd8ee) SHA1(db18be05431d4b6d4207e19fa4ed8701621aaa19) )
+	ROM_LOAD( "esd12.fu33", 0x180000, 0x080000, CRC(c6b86001) SHA1(11a63b56df30ab7b85ce4568d2a24e96a125735a) )
+	ROM_LOAD( "esd7.fu26",  0x200000, 0x080000, CRC(a783a003) SHA1(1ff61a049485c5b599c458a8bf7f48027d14f8e0) )
+	ROM_LOAD( "esd8.fu30",  0x280000, 0x080000, CRC(22861af2) SHA1(1e74e85517cb8fd5fb4bda6e9d9d54046e31f653) )
+	ROM_LOAD( "esd9.fu28",  0x300000, 0x080000, CRC(6652c04a) SHA1(178e1d42847506d869ef79db2f7e10df05e9ef76) )
+	ROM_LOAD( "esd10.fu31", 0x380000, 0x080000, CRC(d815974b) SHA1(3e528a5df79fa7dc0f38b0ee7f2f3a0ebc97a369) )
+
+	ROM_REGION( 0x20000, REGION_SOUND1, 0 )	/* Samples */
+	ROM_LOAD( "esd4.su10", 0x00000, 0x20000, CRC(6e741fcd) SHA1(742e0952916c00f67dd9f8d01e721a9a538d2fc4) )
+ROM_END
+
+ROM_START( multchmk )
 	ROM_REGION( 0x080000, REGION_CPU1, 0 )		/* 68000 Code */
 	ROM_LOAD16_BYTE( "multchmp.u02", 0x000000, 0x040000, CRC(7da8c0df) SHA1(763a3240554a02d8a9a0b13b6bfcd384825a6c57) )
 	ROM_LOAD16_BYTE( "multchmp.u03", 0x000001, 0x040000, CRC(5dc62799) SHA1(ff7882985efc20309c3f901a622f1beffa0c47be) )
 
 	ROM_REGION( 0x24000, REGION_CPU2, 0 )		/* Z80 Code */
-	ROM_LOAD( "multchmp.u06", 0x00000, 0x0c000, CRC(7c178bd7) SHA1(8754d3c70d9b2bf369a5ce0cce4cc0696ed22750) )
+	ROM_LOAD( "esd3.su06", 0x00000, 0x0c000, CRC(7c178bd7) SHA1(8754d3c70d9b2bf369a5ce0cce4cc0696ed22750) )
 	ROM_CONTINUE(             0x10000, 0x14000             )
 
 	ROM_REGION( 0x140000, REGION_GFX1, ROMREGION_DISPOSE )	/* Sprites, 16x16x5 */
@@ -634,8 +704,8 @@ ROM_START( multchmp )
 	ROM_LOAD( "multchmp.u31", 0x300000, 0x080000, CRC(b1e4e9e3) SHA1(1a7393e9073b028b4170393b3788ad8cb86c0c78) )
 	ROM_LOAD( "multchmp.u32", 0x380000, 0x080000, CRC(f05cb5b4) SHA1(1b33e60942238e39d61ae59e9317b99e83595ab1) )
 
-	ROM_REGION( 0x20000, REGION_SOUND1, ROMREGION_SOUNDONLY )	/* Samples */
-	ROM_LOAD( "multchmp.u10", 0x00000, 0x20000, CRC(6e741fcd) SHA1(742e0952916c00f67dd9f8d01e721a9a538d2fc4) )
+	ROM_REGION( 0x20000, REGION_SOUND1, 0 )	/* Samples */
+	ROM_LOAD( "esd4.su10", 0x00000, 0x20000, CRC(6e741fcd) SHA1(742e0952916c00f67dd9f8d01e721a9a538d2fc4) )
 ROM_END
 
 /*
@@ -686,9 +756,35 @@ Notes:
 
 */
 
+
 ROM_START( mchampdx )
 	ROM_REGION( 0x080000, REGION_CPU1, 0 )		/* 68000 Code */
-	ROM_LOAD16_BYTE( "esd2.cu02", 0x000000, 0x040000, CRC(4cca802c) SHA1(5e6e81febbb56b7c4630b530e546e7ab59c6c6c1))
+	ROM_LOAD16_BYTE( "ver0106_esd2.cu02", 0x000000, 0x040000, CRC(ea98b3fd) SHA1(107ee8adea246141fd6fa9209541ce0a7ed1e24c) )
+	ROM_LOAD16_BYTE( "ver0106_esd1.cu03", 0x000001, 0x040000, CRC(c6e4546b) SHA1(af9a8edffe94d035f92b36b1cd145c2a5ee66f48) )
+
+	ROM_REGION( 0x84000, REGION_CPU2, 0 )		/* Z80 Code */
+	ROM_LOAD( "ver0106_desd3.su06", 0x00000, 0x0c000,  CRC(1b22568c) SHA1(5458e1a798357a6785f8ea1fe9da37768cd4761d) )
+	ROM_CONTINUE(             0x10000, 0x34000             )
+
+	/* this has additional copyright sprites in the flash roms for the (c)2000 message.. */
+	ROM_REGION( 0x600000, REGION_GFX1, ROMREGION_DISPOSE )	/* Sprites, 16x16x5 */
+	ROM_LOAD( "ver0106_ju01.bin", 0x200000, 0x200000, CRC(55841d90) SHA1(52ba3ee9393dcddf28e2d20a50151bc739faaaa4) )
+	ROM_LOAD( "ver0106_ju02.bin", 0x000000, 0x200000, CRC(b27a4977) SHA1(b7f94bb04d0046538b3938335e6b0cce330ad79c) )
+	/* expand this to take up 0x200000 bytes too so we can decode it */
+	ROM_LOAD16_BYTE( "ver0106_esd5.ju07", 0x400000, 0x040000, CRC(7a3ac887) SHA1(3c759f9bed396bbaf6bd7298a8bd2bd76df3aa6f) )
+	ROM_FILL( 0x500000, 0x100000, 0 )
+
+	ROM_REGION( 0x400000, REGION_GFX2, ROMREGION_DISPOSE )	/* Layers, 16x16x8 */
+	ROM_LOAD16_BYTE( "rom.fu35", 0x000000, 0x200000, CRC(ba46f3dc) SHA1(4ac7695bdf4237654481f7f74f8650d70a51e691) )
+	ROM_LOAD16_BYTE( "rom.fu34", 0x000001, 0x200000, CRC(2895cf09) SHA1(88756fcd589af1986c3881d4080f086afc11b498) )
+
+	ROM_REGION( 0x80000, REGION_SOUND1, 0 )	/* Samples */
+	ROM_LOAD( "ver0106_esd4.su10", 0x00000, 0x40000, CRC(ac8ae009) SHA1(2c1c30cc4b3e34a5f14d7dfb6f6e18ff21f526f5) )
+ROM_END
+
+ROM_START( mchampda )
+	ROM_REGION( 0x080000, REGION_CPU1, 0 )		/* 68000 Code */
+	ROM_LOAD16_BYTE( "esd2.cu02", 0x000000, 0x040000, CRC(4cca802c) SHA1(5e6e81febbb56b7c4630b530e546e7ab59c6c6c1) )
 	ROM_LOAD16_BYTE( "esd1.cu03", 0x000001, 0x040000, CRC(0af1cd0a) SHA1(d2befcb596d83d523317d17b4c1c71f99de0d33e) )
 
 	ROM_REGION( 0x84000, REGION_CPU2, 0 )		/* Z80 Code */
@@ -706,11 +802,89 @@ ROM_START( mchampdx )
 	ROM_LOAD16_BYTE( "rom.fu35", 0x000000, 0x200000, CRC(ba46f3dc) SHA1(4ac7695bdf4237654481f7f74f8650d70a51e691) )
 	ROM_LOAD16_BYTE( "rom.fu34", 0x000001, 0x200000, CRC(2895cf09) SHA1(88756fcd589af1986c3881d4080f086afc11b498) )
 
-	ROM_REGION( 0x80000, REGION_SOUND1, ROMREGION_SOUNDONLY )	/* Samples */
+	ROM_REGION( 0x80000, REGION_SOUND1, 0 )	/* Samples */
 	ROM_LOAD( "esd4.su10", 0x00000, 0x80000, CRC(14c4a30d) SHA1(d8eb2f08d5293f729cbec1897e3b92b675cc2814) )
 ROM_END
 
 
+
+/* Tang Tang
+
+Tang Tang (ESD)
+------------------------
+
+PCB Layout
+----------
+
+ESD made in Korea
+|-----------------------------------------|
+| U6614 U6612 6116   AD65   ESD4.SU10     |
+|VOL      ESD3.SU06  Z80          ROM.JU04|
+|             PAL                         |
+|                            6116 ROM.JU05|
+|       6116            PAL  6116         |
+|       6116           |-------|  ROM.JU06|
+|J                PAL  | ESD   |          |
+|A                PAL  |CRTC99 |  ROM.JU07|
+|M     PAL             | 0016  |          |
+|M     PAL             |-------|  ROM.JU08|
+|A    68000    ESD1.CU03                  |
+|              ESD2.CU02  |-------|       |
+|                         |ACTEL  | 6116  |
+|                         |A40MX04| 6116  |
+|              MCM6206    |  0008 | 6116  |
+|              MCM6206    |-------| 6116  |
+| 16MHz   PAL  MCM6206                    |
+| 14MHz   PAL  MCM6206  ROM.FU35 ROM.FU34 |
+|-----------------------------------------|
+
+Notes:
+      68000 (MC68HC000FN16-2E60R-QQJU9508)
+      Z80 (Z84C00006FEC-Z80CPU-9618Z3)
+      OKI6295 label AD65 (sound)
+      YM3014 label U6614 (sound)
+      YM3812 label U6612 (sound)
+      MCM6206 - 32k x8 SRAM (SOJ28)
+      6116    - 2k x8 SRAM (SOP28)
+      A40MX04 - Actel A40MX04-F FPGA (PLCC84)
+      CRTC99  - ESD CRTC99 Graphics Controller (QFP240)
+      ESD1-2  - 27C2001
+      ESD3-4  - 27C2000
+      JU04-8  - MX27C2000PC
+      FU34,FU35  -  MX29F1610MC
+1x connector JAMMA
+1x trimmer (volume)
+2x pushbutton
+
+      * : Board has positions for 6x standard 32 pin EPROMs but only 5 positions are populated
+          with an EPROM.
+
+*/
+
+ROM_START( tangtang )
+	ROM_REGION( 0x080000, REGION_CPU1, 0 )		/* 68000 Code */
+	ROM_LOAD16_BYTE( "esd2.cu02", 0x000000, 0x040000,  CRC(b6dd6e3d) SHA1(44d2663827c45267eb154c873f3bd2e9e2bf3d3f) )
+	ROM_LOAD16_BYTE( "esd1.cu03", 0x000001, 0x040000,  CRC(b6c0f2f4) SHA1(68ad76e7e380c728dda200a852729e034d9c9f4c) )
+
+	ROM_REGION( 0x84000, REGION_CPU2, 0 )		/* Z80 Code */
+	ROM_LOAD( "esd3.su06", 0x00000, 0x0c000, CRC(d48ecc5c) SHA1(5015dd775980542eb29a08bffe1a09ea87d56272) )
+	ROM_CONTINUE(             0x10000, 0x34000             )
+
+	ROM_REGION( 0x140000, REGION_GFX1, ROMREGION_DISPOSE )	/* Sprites, 16x16x5 */
+	ROM_LOAD( "xju04.bin", 0x000000, 0x040000, CRC(f999b9d7) SHA1(9e4d0e68cdc429c7563b8ad51c072d68ffed09dc) )
+	ROM_LOAD( "xju05.bin", 0x040000, 0x040000, CRC(679302cf) SHA1(911c2f7e0e809ee28e4f2364788fd51d2bcef24e) )
+	ROM_LOAD( "xju06.bin", 0x080000, 0x040000, CRC(01f59ff7) SHA1(a62a2d5c2d107f67fecfc08fdb5d801ee39c3875) )
+	ROM_LOAD( "xju07.bin", 0x0c0000, 0x040000, CRC(556acac3) SHA1(10e919e63b434da80fb261db1d8967cb11e95e00) )
+	ROM_LOAD( "xju08.bin", 0x100000, 0x040000, CRC(ecc2d8c7) SHA1(1aabdf7204fcdff8d46cb50de8b097e3775dddf3) )
+
+	ROM_REGION( 0x400000, REGION_GFX2, ROMREGION_DISPOSE )	/* Layers, 16x16x8 */
+	ROM_LOAD16_BYTE( "fu35.bin", 0x000000, 0x200000, CRC(84f3f833) SHA1(f84e41d93dc47a58ada800b921a7e5902b7631cd) )
+	ROM_LOAD16_BYTE( "fu34.bin", 0x000001, 0x200000, CRC(bf91f543) SHA1(7c149fed8b8044850cd6b798622a91c45336cd47) )
+
+	ROM_REGION( 0x80000, REGION_SOUND1, 0 )	/* Samples */
+	ROM_LOAD( "esd4.su10", 0x00000, 0x20000, CRC(f2dfb02d) SHA1(04001488697aad3e5b2d15c9f5a81dc2b7d0952c) )
+ROM_END
+
 /***************************************************************************
 
 PCB Layout (Head Panic)
@@ -767,7 +941,7 @@ ROM_START( hedpanic )
 	ROM_LOAD16_BYTE( "esd8", 0x000000, 0x200000, CRC(23aceb4f) SHA1(35d9ebc33b9e1515e47750cfcdfc0bf8bf44b71d) )
 	ROM_LOAD16_BYTE( "esd9", 0x000001, 0x200000, CRC(76b46cd2) SHA1(679cbf50ae5935e8848868081ecef4ec66424f6c) )
 
-	ROM_REGION( 0x80000, REGION_SOUND1, ROMREGION_SOUNDONLY )	/* Samples */
+	ROM_REGION( 0x80000, REGION_SOUND1, 0 )	/* Samples */
 	ROM_LOAD( "esd4", 0x000000, 0x080000, CRC(5692fe92) SHA1(4423039cb437ab36d198b212ef394bf1704be404) ) /* 0x020000 of data repeated 4x */
 ROM_END
 
@@ -780,8 +954,13 @@ ROM_END
 ***************************************************************************/
 
 /* ESD 11-09-98 */
-GAME( 1998, multchmp, 0, multchmp, multchmp, 0, ROT0, "ESD", "Multi Champ (Korea)", 0 )
+GAME( 1999, multchmp, 0,        multchmp, multchmp, 0, ROT0, "ESD",         "Multi Champ (World)", 0 )
+GAME( 1998, multchmk, multchmp, multchmp, multchmp, 0, ROT0, "ESD",         "Multi Champ (Korea)", 0 )
 
 /* ESD 08-26-1999 */
-GAME( 1999, mchampdx, 0, mchampdx, hedpanic, 0, ROT0, "ESD", "Multi Champ Deluxe", 0 )
-GAME( 2000, hedpanic, 0, hedpanic, hedpanic, 0, ROT0, "ESD / Fuuki", "Head Panic (Korea?)", 0 )
+GAME( 2000, mchampdx, 0,        mchampdx, hedpanic, 0, ROT0, "ESD",         "Multi Champ Deluxe (ver. 0106, 06/01/2000)", 0 ) /* 06/01/2000 ? */
+GAME( 1999, mchampda, mchampdx, mchampdx, hedpanic, 0, ROT0, "ESD",         "Multi Champ Deluxe (ver. 1126, 26/11/1999)", 0 ) /* 26/11/1999 ? */
+GAME( 2000, hedpanic, 0,        hedpanic, hedpanic, 0, ROT0, "ESD / Fuuki", "Head Panic (ver. 0315, 15/03/2000)", 0 ) /* 15/03/2000 ? */
+
+/* ESD */
+GAME( 2000, tangtang, 0,        tangtang, hedpanic, 0, ROT0, "ESD",         "Tang Tang (ver. 0526, 26/05/2000)", 0 ) /* 26/05/2000 ? */
