@@ -125,7 +125,6 @@
 ***************************************************************************/
 
 #include "driver.h"
-#include "vidhrdw/generic.h"
 #include "machine/6821pia.h"
 #include "exidy.h"
 #include "sound/custom.h"
@@ -647,7 +646,7 @@ INPUT_PORTS_END
  *
  *************************************/
 
-static gfx_layout charlayout_1bpp =
+static const gfx_layout charlayout_1bpp =
 {
 	8,8,
 	256,
@@ -658,7 +657,7 @@ static gfx_layout charlayout_1bpp =
 	8*8
 };
 
-static gfx_layout charlayout_2bpp =
+static const gfx_layout charlayout_2bpp =
 {
 	8,8,
 	256,
@@ -669,7 +668,7 @@ static gfx_layout charlayout_2bpp =
 	8*8
 };
 
-static gfx_layout spritelayout =
+static const gfx_layout spritelayout =
 {
 	16,16,
 	RGN_FRAC(1,1),
@@ -681,7 +680,7 @@ static gfx_layout spritelayout =
 };
 
 
-static gfx_decode gfxdecodeinfo_1bpp[] =
+static const gfx_decode gfxdecodeinfo_1bpp[] =
 {
 	{ REGION_CPU1, 0x4800, &charlayout_1bpp, 0, 4 },	/* the game dynamically modifies this */
 	{ REGION_GFX1, 0x0000, &spritelayout,    8, 2 },
@@ -689,7 +688,7 @@ static gfx_decode gfxdecodeinfo_1bpp[] =
 };
 
 
-static gfx_decode gfxdecodeinfo_2bpp[] =
+static const gfx_decode gfxdecodeinfo_2bpp[] =
 {
 	{ REGION_CPU1, 0x6000, &charlayout_2bpp, 0, 4 },	/* the game dynamically modifies this */
 	{ REGION_GFX1, 0x0000, &spritelayout,   16, 2 },
@@ -1226,7 +1225,7 @@ ROM_END
  *
  *************************************/
 
-static void common_init(UINT8 palette[], UINT16 colortable[], UINT8 cmask, UINT8 cinvert)
+static void exidy_common_init(UINT8 palette[], UINT16 colortable[], UINT8 cmask, UINT8 cinvert)
 {
 	exidy_palette 			= palette;
 	exidy_colortable 		= colortable;
@@ -1238,7 +1237,7 @@ static void common_init(UINT8 palette[], UINT16 colortable[], UINT8 cmask, UINT8
 
 DRIVER_INIT( sidetrac )
 {
-	common_init(sidetrac_palette, exidy_1bpp_colortable, 0x00, 0x00);
+	exidy_common_init(sidetrac_palette, exidy_1bpp_colortable, 0x00, 0x00);
 
 	/* ROM in place of character RAM */
 	memory_install_write8_handler(0, ADDRESS_SPACE_PROGRAM, 0x4800, 0x4bff, 0, 0, MWA8_ROM);
@@ -1247,19 +1246,19 @@ DRIVER_INIT( sidetrac )
 
 DRIVER_INIT( targ )
 {
-	common_init(targ_palette, exidy_1bpp_colortable, 0x00, 0x00);
+	exidy_common_init(targ_palette, exidy_1bpp_colortable, 0x00, 0x00);
 	targ_spec_flag = 1;
 }
 
 
 DRIVER_INIT( spectar )
 {
-	common_init(spectar_palette, exidy_1bpp_colortable, 0x00, 0x00);
+	exidy_common_init(spectar_palette, exidy_1bpp_colortable, 0x00, 0x00);
 }
 
 DRIVER_INIT( rallys )
 {
-	common_init(spectar_palette, exidy_1bpp_colortable, 0x00, 0x00);
+	exidy_common_init(spectar_palette, exidy_1bpp_colortable, 0x00, 0x00);
 
 	/* sprite locations are slightly different */
 	memory_install_write8_handler(0, ADDRESS_SPACE_PROGRAM, 0x5000, 0x5000, 0, 0, exidy_sprite1_xpos_w);
@@ -1270,7 +1269,7 @@ DRIVER_INIT( rallys )
 
 DRIVER_INIT( phantoma )
 {
-	common_init(spectar_palette, exidy_1bpp_colortable, 0x00, 0x00);
+	exidy_common_init(spectar_palette, exidy_1bpp_colortable, 0x00, 0x00);
 
 	/* sprite locations are slightly different */
 	memory_install_write8_handler(0, ADDRESS_SPACE_PROGRAM, 0x5000, 0x5000, 0, 0, exidy_sprite1_xpos_w);
@@ -1279,25 +1278,26 @@ DRIVER_INIT( phantoma )
 	memory_install_write8_handler(0, ADDRESS_SPACE_PROGRAM, 0x5301, 0x5301, 0, 0, exidy_sprite2_ypos_w);
 
 	/* the ROM is actually mapped high */
-	memory_install_read8_handler(0, ADDRESS_SPACE_PROGRAM, 0xf800, 0xffff, 0, 0, MRA8_ROM);
+	memory_install_read8_handler(0, ADDRESS_SPACE_PROGRAM, 0xf800, 0xffff, 0, 0, MRA8_BANK1);
+	memory_set_bankptr(1, memory_region(REGION_CPU1) + 0xf800);
 }
 
 
 DRIVER_INIT( mtrap )
 {
-	common_init(NULL, exidy_1bpp_colortable, 0x14, 0x00);
+	exidy_common_init(NULL, exidy_1bpp_colortable, 0x14, 0x00);
 }
 
 
 DRIVER_INIT( venture )
 {
-	common_init(NULL, exidy_1bpp_colortable, 0x04, 0x04);
+	exidy_common_init(NULL, exidy_1bpp_colortable, 0x04, 0x04);
 }
 
 
 DRIVER_INIT( pepper2 )
 {
-	common_init(NULL, exidy_2bpp_colortable, 0x14, 0x04);
+	exidy_common_init(NULL, exidy_2bpp_colortable, 0x14, 0x04);
 
 	/* two 6116 character RAMs */
 	exidy_characterram = memory_install_read8_handler(0, ADDRESS_SPACE_PROGRAM, 0x6000, 0x6fff, 0, 0, MRA8_RAM);
@@ -1309,7 +1309,7 @@ DRIVER_INIT( pepper2 )
 
 DRIVER_INIT( fax )
 {
-	common_init(NULL, exidy_2bpp_colortable, 0x04, 0x04);
+	exidy_common_init(NULL, exidy_2bpp_colortable, 0x04, 0x04);
 
 	/* reset the ROM bank */
 	fax_bank_select_w(0,0);
