@@ -498,7 +498,7 @@ INPUT_PORTS_START( imago )
 	PORT_DIPSETTING(    0x00, DEF_STR( On ) )
 INPUT_PORTS_END
 
-static gfx_layout charlayout =
+static const gfx_layout charlayout =
 {
 	8,8,
 	RGN_FRAC(1,3),
@@ -509,7 +509,7 @@ static gfx_layout charlayout =
 	8*8
 };
 
-static gfx_layout spritelayout =
+static const gfx_layout spritelayout =
 {
 	16,16,
 	RGN_FRAC(1,3),
@@ -522,7 +522,7 @@ static gfx_layout spritelayout =
 	32*8
 };
 
-static gfx_layout imago_char_1bpp =
+static const gfx_layout imago_char_1bpp =
 {
 	8,8,
 	RGN_FRAC(1,1),
@@ -533,21 +533,21 @@ static gfx_layout imago_char_1bpp =
 	8*8
 };
 
-static gfx_decode fastfred_gfxdecodeinfo[] =
+static const gfx_decode fastfred_gfxdecodeinfo[] =
 {
 	{ REGION_GFX1, 0, &charlayout,   0, 32 },
 	{ REGION_GFX2, 0, &spritelayout, 0, 32 },
 	{ -1 } /* end of array */
 };
 
-static gfx_decode jumpcoas_gfxdecodeinfo[] =
+static const gfx_decode jumpcoas_gfxdecodeinfo[] =
 {
 	{ REGION_GFX1, 0, &charlayout,   0, 32 },
 	{ REGION_GFX1, 0, &spritelayout, 0, 32 },
 	{ -1 } /* end of array */
 };
 
-static gfx_decode imago_gfxdecodeinfo[] =
+static const gfx_decode imago_gfxdecodeinfo[] =
 {
 	{ REGION_GFX1, 0, &charlayout,	        0, 32 },
 	{ REGION_GFX2, 0, &spritelayout,        0, 32 },
