@@ -30,7 +30,6 @@ inputs + notes by stephh
 */
 
 #include "driver.h"
-#include "vidhrdw/generic.h"
 #include "sound/ay8910.h"
 PALETTE_INIT( fcombat );
 VIDEO_START( fcombat );
@@ -249,7 +248,7 @@ ADDRESS_MAP_END
  *
  *************************************/
 
-static gfx_layout charlayout =
+static const gfx_layout charlayout =
 {
 	8,8,
 	RGN_FRAC(1,1),
@@ -262,7 +261,7 @@ static gfx_layout charlayout =
 
 
 /* 16 x 16 sprites -- requires reorganizing characters in init_exerion() */
-static gfx_layout spritelayout =
+static const gfx_layout spritelayout =
 {
 	16,16,
 	RGN_FRAC(1,1),
@@ -276,7 +275,7 @@ static gfx_layout spritelayout =
 };
 
 
-static gfx_decode gfxdecodeinfo[] =
+static const gfx_decode gfxdecodeinfo[] =
 {
 	{ REGION_GFX1, 0, &charlayout,         0, 64 },
 	{ REGION_GFX2, 0, &spritelayout,     256, 64 },
