@@ -57,7 +57,6 @@ write:
 ***************************************************************************/
 
 #include "driver.h"
-#include "vidhrdw/generic.h"
 #include "cpu/m6502/m6502.h"
 #include "sound/3812intf.h"
 #include "sound/msm5205.h"
@@ -107,7 +106,7 @@ static READ8_HANDLER( firetrap_8751_bootleg_r )
 
 static int i8751_return,i8751_current_command;
 
-static MACHINE_INIT( firetrap )
+static MACHINE_RESET( firetrap )
 {
 	i8751_current_command=0;
 }
@@ -488,7 +487,7 @@ INPUT_PORTS_START( firetpbl )
 INPUT_PORTS_END
 
 
-static gfx_layout charlayout =
+static const gfx_layout charlayout =
 {
 	8,8,
 	RGN_FRAC(1,2),
@@ -498,7 +497,7 @@ static gfx_layout charlayout =
 	{ 7*8, 6*8, 5*8, 4*8, 3*8, 2*8, 1*8, 0*8 },
 	8*8
 };
-static gfx_layout tilelayout =
+static const gfx_layout tilelayout =
 {
 	16,16,
 	RGN_FRAC(1,4),
@@ -510,7 +509,7 @@ static gfx_layout tilelayout =
 			7*8, 6*8, 5*8, 4*8, 3*8, 2*8, 1*8, 0*8 },
 	32*8
 };
-static gfx_layout spritelayout =
+static const gfx_layout spritelayout =
 {
 	16,16,
 	RGN_FRAC(1,4),
@@ -523,7 +522,7 @@ static gfx_layout spritelayout =
 	32*8
 };
 
-static gfx_decode gfxdecodeinfo[] =
+static const gfx_decode gfxdecodeinfo[] =
 {
 	{ REGION_GFX1, 0, &charlayout,   0x00, 16 },	/* colors 0x00-0x3f */
 	{ REGION_GFX2, 0, &tilelayout,   0x80,  4 },	/* colors 0x80-0xbf */
@@ -587,7 +586,7 @@ static MACHINE_DRIVER_START( firetrap )
 							/* NMIs are caused by the main CPU */
 	MDRV_FRAMES_PER_SECOND(60)
 	MDRV_VBLANK_DURATION(DEFAULT_REAL_60HZ_VBLANK_DURATION)
-	MDRV_MACHINE_INIT(firetrap)
+	MDRV_MACHINE_RESET(firetrap)
 
 	/* video hardware */
 	MDRV_VIDEO_ATTRIBUTES(VIDEO_TYPE_RASTER)
