@@ -32,7 +32,7 @@ CHIP #  POSITION   TYPE
 14       19E         "       "
 */
 
-#include "vidhrdw/generic.h"
+#include "driver.h"
 #include "sound/custom.h"
 
 extern UINT8 *flower_textram, *flower_bg0ram, *flower_bg1ram, *flower_bg0_scroll, *flower_bg1_scroll;
@@ -196,7 +196,7 @@ INPUT_PORTS_START( flower )
 	PORT_BIT( 0x80, IP_ACTIVE_LOW, IPT_UNKNOWN )
 INPUT_PORTS_END
 
-static gfx_layout flower_charlayout =
+static const gfx_layout flower_charlayout =
 {
 	8,8,
 	RGN_FRAC(1,1),
@@ -207,7 +207,7 @@ static gfx_layout flower_charlayout =
 	8*8*2
 };
 
-static gfx_layout flower_tilelayout =
+static const gfx_layout flower_tilelayout =
 {
 	16,16,
 	RGN_FRAC(1,2),
@@ -218,7 +218,7 @@ static gfx_layout flower_tilelayout =
 	16*16*2
 };
 
-static gfx_decode flower_gfxdecodeinfo[] =
+static const gfx_decode flower_gfxdecodeinfo[] =
 {
 	{ REGION_GFX1, 0, &flower_charlayout, 0,  64 },
 	{ REGION_GFX2, 0, &flower_tilelayout, 0,  16 },
