@@ -24,7 +24,6 @@ Memo:
 #include "driver.h"
 #include "cpu/m68000/m68000.h"
 #include "cpu/z80/z80.h"
-#include "vidhrdw/generic.h"
 #include "machine/eeprom.h"
 #include "sound/2610intf.h"
 
@@ -85,17 +84,17 @@ static UINT8 fromanc2_sndcpu_nmi_flag;
 /*  MACHINE INITIALYZE */
 /* ---------------------------------------------------------------------------- */
 
-static MACHINE_INIT( fromanc2 )
+static MACHINE_RESET( fromanc2 )
 {
 	/* */
 }
 
-static MACHINE_INIT( fromancr )
+static MACHINE_RESET( fromancr )
 {
 	/* */
 }
 
-static MACHINE_INIT( fromanc4 )
+static MACHINE_RESET( fromanc4 )
 {
 	/* */
 }
@@ -146,15 +145,15 @@ static INTERRUPT_GEN( fromanc2_interrupt )
 	if (fromanc2_playerside_old != fromanc2_playerside) {
 		fromanc2_playerside_old = fromanc2_playerside;
 
-		usrintf_showmessage("PLAYER-%01X SIDE", fromanc2_playerside + 1);
+		ui_popup("PLAYER-%01X SIDE", fromanc2_playerside + 1);
 
 		if (!fromanc2_playerside) {
-/*          mixer_set_stereo_volume(3, 75, 75); // 1P (LEFT) */
-/*          mixer_set_stereo_volume(4,  0,  0); // 2P (RIGHT) */
+		sound_set_user_gain(1, 0.75); /* 1P (LEFT) */
+		sound_set_user_gain(2, 0.00); /* 2P (RIGHT) */
 		}
 		else {
-/*          mixer_set_stereo_volume(3,  0,  0); // 1P (LEFT) */
-/*          mixer_set_stereo_volume(4, 75, 75); // 2P (RIGHT) */
+		sound_set_user_gain(1, 0.00); /* 1P (LEFT) */
+		sound_set_user_gain(2, 0.75); /* 2P (RIGHT) */
 		}
 
 		fromanc2_set_dispvram_w(fromanc2_playerside);
@@ -334,11 +333,11 @@ static WRITE8_HANDLER( fromanc2_subcpu_rombank_w )
 	int rambank = (data & 0x0c) >> 2;
 
 	/* Change ROM BANK */
-	cpu_setbank(1, &RAM[rombank * 0x4000]);
+	memory_set_bankptr(1, &RAM[rombank * 0x4000]);
 
 	/* Change RAM BANK */
-	if (rambank != 0) cpu_setbank(2, &RAM[0x10000 + (rambank * 0x4000)]);
-	else cpu_setbank(2, &RAM[0x8000]);
+	if (rambank != 0) memory_set_bankptr(2, &RAM[0x10000 + (rambank * 0x4000)]);
+	else memory_set_bankptr(2, &RAM[0x8000]);
 }
 
 
@@ -680,7 +679,7 @@ INPUT_PORTS_END
 /* */
 /* ---------------------------------------------------------------------------- */
 
-static struct GfxLayout fromanc2_tilelayout =
+static const gfx_layout fromanc2_tilelayout =
 {
 	8, 8,
 	RGN_FRAC(1, 1),
@@ -691,7 +690,7 @@ static struct GfxLayout fromanc2_tilelayout =
 	32*8
 };
 
-static struct GfxDecodeInfo fromanc2_gfxdecodeinfo[] =
+static const gfx_decode fromanc2_gfxdecodeinfo[] =
 {
 	{ REGION_GFX1, 0, &fromanc2_tilelayout, (  0 * 2), (256 * 2) },
 	{ REGION_GFX2, 0, &fromanc2_tilelayout, (256 * 2), (256 * 2) },
@@ -700,7 +699,7 @@ static struct GfxDecodeInfo fromanc2_gfxdecodeinfo[] =
 	{ -1 } /* end of array */
 };
 
-static struct GfxLayout fromancr_tilelayout =
+static const gfx_layout fromancr_tilelayout =
 {
 	8, 8,
 	RGN_FRAC(1, 1),
@@ -711,7 +710,7 @@ static struct GfxLayout fromancr_tilelayout =
 	64*8
 };
 
-static struct GfxDecodeInfo fromancr_gfxdecodeinfo[] =
+static const gfx_decode fromancr_gfxdecodeinfo[] =
 {
 	{ REGION_GFX1, 0, &fromancr_tilelayout, (512 * 2), 2 },
 	{ REGION_GFX2, 0, &fromancr_tilelayout, (256 * 2), 2 },
@@ -760,7 +759,7 @@ static MACHINE_DRIVER_START( fromanc2 )
 	MDRV_FRAMES_PER_SECOND(60)
 	MDRV_VBLANK_DURATION(DEFAULT_60HZ_VBLANK_DURATION)
 
-	MDRV_MACHINE_INIT(fromanc2)
+	MDRV_MACHINE_RESET(fromanc2)
 	MDRV_NVRAM_HANDLER(93C46)
 
 	/* video hardware */
@@ -802,7 +801,7 @@ static MACHINE_DRIVER_START( fromancr )
 	MDRV_FRAMES_PER_SECOND(60)
 	MDRV_VBLANK_DURATION(DEFAULT_60HZ_VBLANK_DURATION)
 
-	MDRV_MACHINE_INIT(fromancr)
+	MDRV_MACHINE_RESET(fromancr)
 	MDRV_NVRAM_HANDLER(93C46)
 
 	/* video hardware */
@@ -840,7 +839,7 @@ static MACHINE_DRIVER_START( fromanc4 )
 	MDRV_FRAMES_PER_SECOND(60)
 	MDRV_VBLANK_DURATION(DEFAULT_60HZ_VBLANK_DURATION)
 
-	MDRV_MACHINE_INIT(fromanc4)
+	MDRV_MACHINE_RESET(fromanc4)
 	MDRV_NVRAM_HANDLER(93C46)
 
 	/* video hardware */
@@ -969,6 +968,6 @@ ROM_START( fromanc4 )
 ROM_END
 
 
-GAME( 1995, fromanc2, 0, fromanc2, fromanc2, fromanc2, ROT0, "Video System Co.", "Taisen Idol-Mahjong Final Romance 2 (Japan)" )
-GAME( 1995, fromancr, 0, fromancr, fromanc2, fromancr, ROT0, "Video System Co.", "Taisen Mahjong FinalRomance R (Japan)" )
-GAME( 1998, fromanc4, 0, fromanc4, fromanc4, fromanc4, ROT0, "Video System Co.", "Taisen Mahjong FinalRomance 4 (Japan)" )
+GAME( 1995, fromanc2, 0, fromanc2, fromanc2, fromanc2, ROT0, "Video System Co.", "Taisen Idol-Mahjong Final Romance 2 (Japan)", 0 )
+GAME( 1995, fromancr, 0, fromancr, fromanc2, fromancr, ROT0, "Video System Co.", "Taisen Mahjong FinalRomance R (Japan)", 0 )
+GAME( 1998, fromanc4, 0, fromanc4, fromanc4, fromanc4, ROT0, "Video System Co.", "Taisen Mahjong FinalRomance 4 (Japan)", 0 )
