@@ -41,7 +41,6 @@ Memo:
 
 #include "driver.h"
 #include "cpu/z80/z80.h"
-#include "vidhrdw/generic.h"
 #include "fromance.h"
 #include "sound/ay8910.h"
 #include "sound/2413intf.h"
@@ -65,7 +64,7 @@ static UINT8 fromance_vclk_left;
  *
  *************************************/
 
-static MACHINE_INIT( fromance )
+static MACHINE_RESET( fromance )
 {
 	fromance_directionflag = 0;
 	fromance_commanddata = 0;
@@ -1017,7 +1016,7 @@ INPUT_PORTS_END
  *
  *************************************/
 
-static gfx_layout bglayout =
+static const gfx_layout bglayout =
 {
 	8,4,
 	RGN_FRAC(1,1),
@@ -1029,7 +1028,7 @@ static gfx_layout bglayout =
 };
 
 
-static gfx_decode fromance_gfxdecodeinfo[] =
+static const gfx_decode fromance_gfxdecodeinfo[] =
 {
 	{ REGION_GFX1, 0, &bglayout,   0, 128 },
 	{ REGION_GFX2, 0, &bglayout,   0, 128 },
@@ -1071,7 +1070,7 @@ static MACHINE_DRIVER_START( nekkyoku )
 	MDRV_FRAMES_PER_SECOND(60)
 	MDRV_VBLANK_DURATION(DEFAULT_60HZ_VBLANK_DURATION)
 
-	MDRV_MACHINE_INIT(fromance)
+	MDRV_MACHINE_RESET(fromance)
 
 	/* video hardware */
 	MDRV_VIDEO_ATTRIBUTES(VIDEO_TYPE_RASTER)
@@ -1109,7 +1108,7 @@ static MACHINE_DRIVER_START( idolmj )
 	MDRV_FRAMES_PER_SECOND(60)
 	MDRV_VBLANK_DURATION(DEFAULT_60HZ_VBLANK_DURATION)
 
-	MDRV_MACHINE_INIT(fromance)
+	MDRV_MACHINE_RESET(fromance)
 
 	/* video hardware */
 	MDRV_VIDEO_ATTRIBUTES(VIDEO_TYPE_RASTER)
@@ -1147,7 +1146,7 @@ static MACHINE_DRIVER_START( fromance )
 	MDRV_FRAMES_PER_SECOND(60)
 	MDRV_VBLANK_DURATION(DEFAULT_60HZ_VBLANK_DURATION)
 
-	MDRV_MACHINE_INIT(fromance)
+	MDRV_MACHINE_RESET(fromance)
 
 	/* video hardware */
 	MDRV_VIDEO_ATTRIBUTES(VIDEO_TYPE_RASTER)
