@@ -23,8 +23,8 @@ convert to tilemaps
 #include "sound/okim6295.h"
 
 /* vidhrdw/funybubl.c */
-extern data8_t* funybubl_banked_videoram;
-extern data8_t *funybubl_paletteram;
+extern UINT8* funybubl_banked_videoram;
+extern UINT8 *funybubl_paletteram;
 WRITE8_HANDLER ( funybubl_paldatawrite );
 VIDEO_START(funybubl);
 VIDEO_UPDATE(funybubl);
@@ -34,16 +34,16 @@ VIDEO_UPDATE(funybubl);
 static WRITE8_HANDLER ( funybubl_vidram_bank_w )
 {
 	if ((data&1) == 0)
-		cpu_setbank(1,&funybubl_banked_videoram[0x000000]);
+		memory_set_bankptr(1,&funybubl_banked_videoram[0x000000]);
 	else
-		cpu_setbank(1,&funybubl_banked_videoram[0x001000]);
+		memory_set_bankptr(1,&funybubl_banked_videoram[0x001000]);
 }
 
 static WRITE8_HANDLER ( funybubl_cpurombank_w )
 {
 	unsigned char *rom = memory_region(REGION_CPU1);
 
-		cpu_setbank(2,&rom[0x10000+0x4000*(data&0x3f)]);
+		memory_set_bankptr(2,&rom[0x10000+0x4000*(data&0x3f)]);
 }
 
 
@@ -175,7 +175,7 @@ INPUT_PORTS_END
 
 
 
-static struct GfxLayout tiles16x16x8_1_layout =
+static const gfx_layout tiles16x16x8_1_layout =
 {
 	8,8,
 	RGN_FRAC(1,8),
@@ -186,7 +186,7 @@ static struct GfxLayout tiles16x16x8_1_layout =
 	8*8
 };
 
-static struct GfxLayout tiles16x16x8_2_layout =
+static const gfx_layout tiles16x16x8_2_layout =
 {
 	16,16,
 	RGN_FRAC(1,4),
@@ -199,7 +199,7 @@ static struct GfxLayout tiles16x16x8_2_layout =
 };
 
 
-static struct GfxDecodeInfo gfxdecodeinfo[] =
+static const gfx_decode gfxdecodeinfo[] =
 {
 	{ REGION_GFX1, 0, &tiles16x16x8_1_layout, 0, 16 },
 	{ REGION_GFX2, 0, &tiles16x16x8_2_layout, 0, 16 },
@@ -212,7 +212,7 @@ DRIVER_INIT( funybubl )
 {
 	funybubl_banked_videoram = auto_malloc (0x2000);
 
-	cpu_setbank(1,&funybubl_banked_videoram[0x000000]);
+	memory_set_bankptr(1,&funybubl_banked_videoram[0x000000]);
 }
 
 
@@ -285,4 +285,4 @@ ROM_START( funybubl )
 ROM_END
 
 
-GAME( 1999, funybubl, 0, funybubl, funybubl, funybubl, ROT0, "Comad", "Funny Bubble" )
+GAME( 1999, funybubl, 0, funybubl, funybubl, funybubl, ROT0, "Comad", "Funny Bubble", 0 )
