@@ -88,7 +88,6 @@ FG-3J ROM-J 507KA0301P04       Rev:1.3
 ***************************************************************************/
 
 #include "driver.h"
-#include "vidhrdw/generic.h"
 #include "sound/262intf.h"
 #include "sound/ymf278b.h"
 
@@ -414,7 +413,7 @@ INPUT_PORTS_END
 ***************************************************************************/
 
 /* 8x8x4 */
-static gfx_layout layout_8x8x4 =
+static const gfx_layout layout_8x8x4 =
 {
 	8,8,
 	RGN_FRAC(1,1),
@@ -426,7 +425,7 @@ static gfx_layout layout_8x8x4 =
 };
 
 /* 16x16x4 */
-static gfx_layout layout_16x16x4 =
+static const gfx_layout layout_16x16x4 =
 {
 	16,16,
 	RGN_FRAC(1,1),
@@ -439,7 +438,7 @@ static gfx_layout layout_16x16x4 =
 };
 
 /* 16x16x8 */
-static gfx_layout layout_16x16x8 =
+static const gfx_layout layout_16x16x8 =
 {
 	16,16,
 	RGN_FRAC(1,2),
@@ -451,7 +450,7 @@ static gfx_layout layout_16x16x8 =
 	16*16*4
 };
 
-static gfx_decode fuuki32_gfxdecodeinfo[] =
+static const gfx_decode fuuki32_gfxdecodeinfo[] =
 {
 	{ REGION_GFX1, 0, &layout_16x16x4, 0x400*2, 0x40 }, /* [0] Sprites */
 	{ REGION_GFX2, 0, &layout_16x16x8, 0x400*0, 0x40 }, /* [1] Layer 1 */
