@@ -125,7 +125,6 @@ Notes:
 
 
 #include "driver.h"
-#include "vidhrdw/generic.h"
 #include "cpu/m68000/m68000.h"
 #include "cpu/z80/z80.h"
 #include "sound/2203intf.h"
@@ -314,7 +313,7 @@ static int jumppoints_other[0x100] =
 
 static int *raiga_jumppoints = jumppoints_00;
 
-static MACHINE_INIT ( raiga )
+static MACHINE_RESET ( raiga )
 {
 	raiga_jumppoints = jumppoints_00;
 }
@@ -877,7 +876,7 @@ INPUT_PORTS_END
 
 
 
-static gfx_layout tilelayout =
+static const gfx_layout tilelayout =
 {
 	8,8,	/* tile size */
 	RGN_FRAC(1,1),	/* number of tiles */
@@ -888,7 +887,7 @@ static gfx_layout tilelayout =
 	32*8	/* offset to next tile */
 };
 
-static gfx_layout tile2layout =
+static const gfx_layout tile2layout =
 {
 	16,16,	/* tile size */
 	RGN_FRAC(1,1),	/* number of tiles */
@@ -902,7 +901,7 @@ static gfx_layout tile2layout =
 	128*8	/* offset to next tile */
 };
 
-static gfx_layout spritelayout =
+static const gfx_layout spritelayout =
 {
 	8,8,	/* sprites size */
 	RGN_FRAC(1,2),	/* number of sprites */
@@ -913,7 +912,7 @@ static gfx_layout spritelayout =
 	16*8	/* offset to next sprite */
 };
 
-static gfx_decode gfxdecodeinfo[] =
+static const gfx_decode gfxdecodeinfo[] =
 {
 	{ REGION_GFX1, 0, &tilelayout,        256, 4096 - 256 },	/* tiles 8x8  */
 	{ REGION_GFX2, 0, &tile2layout,       768, 4096 - 768 },	/* tiles 16x16 */
@@ -922,7 +921,7 @@ static gfx_decode gfxdecodeinfo[] =
 	{ -1 } /* end of array */
 };
 
-static gfx_layout drgnbowl_tile2layout =
+static const gfx_layout drgnbowl_tile2layout =
 {
 	16,16,
 	RGN_FRAC(1,8),
@@ -933,7 +932,7 @@ static gfx_layout drgnbowl_tile2layout =
 	32*8
 };
 
-static gfx_layout drgnbowl_spritelayout =
+static const gfx_layout drgnbowl_spritelayout =
 {
 	16,16,
 	RGN_FRAC(1,4),
@@ -944,7 +943,7 @@ static gfx_layout drgnbowl_spritelayout =
 	32*8
 };
 
-static gfx_decode drgnbowl_gfxdecodeinfo[] =
+static const gfx_decode drgnbowl_gfxdecodeinfo[] =
 {
 	{ REGION_GFX1, 0,       &tilelayout,                0, 16 },	/* tiles 8x8  */
 	{ REGION_GFX2, 0x00000, &drgnbowl_tile2layout,  0x300, 16 },	/* tiles 16x16 */
@@ -978,7 +977,7 @@ static MACHINE_DRIVER_START( shadoww )
 	MDRV_FRAMES_PER_SECOND(60)
 	MDRV_VBLANK_DURATION(DEFAULT_60HZ_VBLANK_DURATION)
 
-	MDRV_MACHINE_INIT(raiga)
+	MDRV_MACHINE_RESET(raiga)
 
 	/* video hardware */
 	MDRV_VIDEO_ATTRIBUTES(VIDEO_TYPE_RASTER)
