@@ -2,9 +2,11 @@
 
 Gals Panic       1990 Kaneko
 Fantasia         1994 Comad
+Super Model      1994 Comad
 New Fantasia     1995 Comad
 Fantasy '95      1995 Hi-max Technology Inc. (Running on a Comad PCB)
 Miss World '96   1996 Comad
+Ms/Mr World '96  1996 Comad
 Fantasia II      1997 Comad
 Gals Hustler     1997 Ace International
 
@@ -103,21 +105,42 @@ There's probably a third tilemap at 0x580000 - 0x583fff used for the title logo.
 
 The roms are piggy-backed in the same way.
 
+
+-- Zip Zap notes ---
+
+Bg for select screens seems to be corrupt
+
+-- General Notes --
+
+Fantasia etc. games are locking up when the girl 'changes' due to not liking
+the way we handle OKI status reads.. however these reads are correct according to
+tests done with a real chip so there must be something odd going on on this hardware
+
+From Miss World 96 manual/dipswitch sheet:
+
+A/B/C Three Versions depending on nude grade
+ A-Version is the extreme hottest nude models
+ B-Version is the more attractive nude models
+ C-Version is very beautiful bikini models
+
+An example of this can be seen in Fantasia II with type A & B
+ The current set of Super Model is an example of type C
+
 ***************************************************************************/
 
 #include "driver.h"
-#include "machine/kaneko16.h"
-#include "machine/random.h"
-#include "vidhrdw/generic.h"
+#include "includes/kaneko16.h"
 #include "sound/okim6295.h"
 
 
-extern data16_t *galpanic_bgvideoram,*galpanic_fgvideoram;
+extern UINT16 *galpanic_bgvideoram,*galpanic_fgvideoram;
 extern size_t galpanic_fgvideoram_size;
+extern int galpanic_clear_sprites;
 
 PALETTE_INIT( galpanic );
 WRITE16_HANDLER( galpanic_bgvideoram_w );
 WRITE16_HANDLER( galpanic_paletteram_w );
+VIDEO_START( galpanic );
 VIDEO_UPDATE( galpanic );
 VIDEO_UPDATE( comad );
 
@@ -151,9 +174,42 @@ static WRITE16_HANDLER( galpanic_6295_bankswitch_w )
 		UINT8 *rom = memory_region(REGION_SOUND1);
 
 		memcpy(&rom[0x30000],&rom[0x40000 + ((data >> 8) & 0x0f) * 0x10000],0x10000);
+
+		galpanic_clear_sprites = data & 0x8000;
 	}
 }
 
+static WRITE16_HANDLER( galpania_6295_bankswitch_w )
+{
+	if (ACCESSING_MSB)
+	{
+		UINT8 *rom = memory_region(REGION_SOUND1);
+
+		memcpy(&rom[0x30000],&rom[0x40000 + ((data >> 8) & 0x0f) * 0x10000],0x10000);
+	}
+}
+
+static WRITE16_HANDLER( galpania_misc_w )
+{
+	if (ACCESSING_LSB)
+	{
+		galpanic_clear_sprites = data & 0x0004;
+	}
+
+	/* other bits unknown ! */
+}
+
+static WRITE16_HANDLER( galpanic_coin_w )
+{
+	if (ACCESSING_MSB)
+	{
+		coin_counter_w(0, data & 0x100);
+		coin_counter_w(1, data & 0x200);
+
+		coin_lockout_w(0, ~data & 0x400);
+		coin_lockout_w(1, ~data & 0x800);
+	}
+}
 
 static WRITE16_HANDLER( galpanic_bgvideoram_mirror_w )
 {
@@ -176,7 +232,7 @@ static ADDRESS_MAP_START( galpanic, ADDRESS_SPACE_PROGRAM, 16 )
 	AM_RANGE(0x800002, 0x800003) AM_READ(input_port_1_word_r)
 	AM_RANGE(0x800004, 0x800005) AM_READ(input_port_2_word_r)
 	AM_RANGE(0x900000, 0x900001) AM_WRITE(galpanic_6295_bankswitch_w)
-	AM_RANGE(0xa00000, 0xa00001) AM_WRITE(MWA16_NOP)	/* ??? */
+	AM_RANGE(0xa00000, 0xa00001) AM_WRITE(galpanic_coin_w)	/* coin counters */
 	AM_RANGE(0xb00000, 0xb00001) AM_WRITE(MWA16_NOP)	/* ??? */
 	AM_RANGE(0xc00000, 0xc00001) AM_WRITE(MWA16_NOP)	/* ??? */
 	AM_RANGE(0xd00000, 0xd00001) AM_WRITE(MWA16_NOP)	/* ??? */
@@ -193,7 +249,7 @@ static ADDRESS_MAP_START( galpanib, ADDRESS_SPACE_PROGRAM, 16 )
 	AM_RANGE(0x800002, 0x800003) AM_READ(input_port_1_word_r)
 	AM_RANGE(0x800004, 0x800005) AM_READ(input_port_2_word_r)
 	AM_RANGE(0x900000, 0x900001) AM_WRITE(galpanic_6295_bankswitch_w)
-	AM_RANGE(0xa00000, 0xa00001) AM_WRITE(MWA16_NOP)	/* ??? */
+	AM_RANGE(0xa00000, 0xa00001) AM_WRITE(galpanic_coin_w)	/* coin counters */
 	AM_RANGE(0xb00000, 0xb00001) AM_WRITE(MWA16_NOP)	/* ??? */
 	AM_RANGE(0xc00000, 0xc00001) AM_WRITE(MWA16_NOP)	/* ??? */
 	AM_RANGE(0xd00000, 0xd00001) AM_WRITE(MWA16_NOP)	/* ??? */
@@ -209,12 +265,13 @@ static ADDRESS_MAP_START( galpania, ADDRESS_SPACE_PROGRAM, 16 )
 	AM_RANGE(0x600000, 0x600fff) AM_READWRITE(MRA16_RAM,galpanic_paletteram_w) AM_BASE(&paletteram16)	/* 1024 colors, but only 512 seem to be used */
 	AM_RANGE(0x680000, 0x68001f) AM_WRITE(MWA16_NOP)	/* ??? */
 	AM_RANGE(0x700000, 0x700fff) AM_RAM AM_BASE(&spriteram16) AM_SIZE(&spriteram_size)
-	AM_RANGE(0x780000, 0x78001f) AM_WRITE(MWA16_NOP)	/* ??? */
+	AM_RANGE(0x780000, 0x780001) AM_WRITE(galpania_misc_w)
+	AM_RANGE(0x780002, 0x78001f) AM_WRITE(MWA16_NOP)	/* ??? */
 	AM_RANGE(0x800000, 0x800001) AM_READ(input_port_0_word_r)
 	AM_RANGE(0x800002, 0x800003) AM_READ(input_port_1_word_r)
 	AM_RANGE(0x800004, 0x800005) AM_READ(input_port_2_word_r)
-	AM_RANGE(0x900000, 0x900001) AM_WRITE(galpanic_6295_bankswitch_w)
-	AM_RANGE(0xa00000, 0xa00001) AM_WRITE(MWA16_NOP)	/* ??? */
+	AM_RANGE(0x900000, 0x900001) AM_WRITE(galpania_6295_bankswitch_w)
+	AM_RANGE(0xa00000, 0xa00001) AM_WRITE(galpanic_coin_w)	/* coin counters */
 	AM_RANGE(0xc80000, 0xc8ffff) AM_RAM	/* work RAM */
 	AM_RANGE(0xd80000, 0xd80001) AM_WRITE(MWA16_NOP)	/* ??? */
 	AM_RANGE(0xe00000, 0xe00015) AM_READWRITE(galpanib_calc_r,galpanib_calc_w)
@@ -226,6 +283,17 @@ static READ16_HANDLER( kludge )
 	return mame_rand() & 0x0700;
 }
 
+/* a kludge! */
+READ16_HANDLER( comad_OKIM6295_status_0_msb_r )
+{
+	UINT16 retvalue;
+
+/*  retvalue = OKIM6295_status_0_msb_r(offset,mem_mask); // doesn't work, causes lockups when girls change.. */
+	retvalue = mame_rand();
+
+	return retvalue;
+}
+
 static ADDRESS_MAP_START( comad_readmem, ADDRESS_SPACE_PROGRAM, 16 )
 	AM_RANGE(0x000000, 0x4fffff) AM_READ(MRA16_ROM)
 	AM_RANGE(0x500000, 0x51ffff) AM_READ(MRA16_RAM)
@@ -240,8 +308,8 @@ static ADDRESS_MAP_START( comad_readmem, ADDRESS_SPACE_PROGRAM, 16 )
 	AM_RANGE(0x80000c, 0x80000d) AM_READ(kludge)	/* missw96 bits 8-a = timer? palette update code waits for them to be 111 */
 	AM_RANGE(0xc00000, 0xc0ffff) AM_READ(MRA16_RAM)	/* missw96 */
 	AM_RANGE(0xc80000, 0xc8ffff) AM_READ(MRA16_RAM)	/* fantasia, newfant */
-	AM_RANGE(0xf00000, 0xf00001) AM_READ(OKIM6295_status_0_msb_r)	/* fantasia, missw96 */
-	AM_RANGE(0xf80000, 0xf80001) AM_READ(OKIM6295_status_0_msb_r)	/* newfant */
+	AM_RANGE(0xf00000, 0xf00001) AM_READ(comad_OKIM6295_status_0_msb_r)	/* fantasia, missw96 */
+	AM_RANGE(0xf80000, 0xf80001) AM_READ(comad_OKIM6295_status_0_msb_r)	/* newfant */
 ADDRESS_MAP_END
 
 static ADDRESS_MAP_START( comad_writemem, ADDRESS_SPACE_PROGRAM, 16 )
@@ -250,7 +318,7 @@ static ADDRESS_MAP_START( comad_writemem, ADDRESS_SPACE_PROGRAM, 16 )
 	AM_RANGE(0x520000, 0x53ffff) AM_WRITE(galpanic_bgvideoram_w) AM_BASE(&galpanic_bgvideoram)	/* + work RAM */
 	AM_RANGE(0x600000, 0x6007ff) AM_WRITE(galpanic_paletteram_w) AM_BASE(&paletteram16)	/* 1024 colors, but only 512 seem to be used */
 	AM_RANGE(0x700000, 0x700fff) AM_WRITE(MWA16_RAM) AM_BASE(&spriteram16) AM_SIZE(&spriteram_size)
-	AM_RANGE(0x900000, 0x900001) AM_WRITE(galpanic_6295_bankswitch_w)	/* not sure */
+	AM_RANGE(0x900000, 0x900001) AM_WRITE(galpania_6295_bankswitch_w)	/* not sure */
 	AM_RANGE(0xc00000, 0xc0ffff) AM_WRITE(MWA16_RAM)	/* missw96 */
 	AM_RANGE(0xc80000, 0xc8ffff) AM_WRITE(MWA16_RAM)	/* fantasia, newfant */
 	AM_RANGE(0xf00000, 0xf00001) AM_WRITE(OKIM6295_data_0_msb_w)	/* fantasia, missw96 */
@@ -269,7 +337,7 @@ static ADDRESS_MAP_START( fantsia2_readmem, ADDRESS_SPACE_PROGRAM, 16 )
 /*  AM_RANGE(0x800006, 0x800007)    ?? */
 	AM_RANGE(0x800008, 0x800009) AM_READ(kludge)	/* bits 8-a = timer? palette update code waits for them to be 111 */
 	AM_RANGE(0xf80000, 0xf8ffff) AM_READ(MRA16_RAM)
-	AM_RANGE(0xc80000, 0xc80001) AM_READ(OKIM6295_status_0_msb_r)
+	AM_RANGE(0xc80000, 0xc80001) AM_READ(comad_OKIM6295_status_0_msb_r)
 ADDRESS_MAP_END
 
 static ADDRESS_MAP_START( fantsia2_writemem, ADDRESS_SPACE_PROGRAM, 16 )
@@ -278,7 +346,7 @@ static ADDRESS_MAP_START( fantsia2_writemem, ADDRESS_SPACE_PROGRAM, 16 )
 	AM_RANGE(0x520000, 0x53ffff) AM_WRITE(galpanic_bgvideoram_w) AM_BASE(&galpanic_bgvideoram)	/* + work RAM */
 	AM_RANGE(0x600000, 0x6007ff) AM_WRITE(galpanic_paletteram_w) AM_BASE(&paletteram16)	/* 1024 colors, but only 512 seem to be used */
 	AM_RANGE(0x700000, 0x700fff) AM_WRITE(MWA16_RAM) AM_BASE(&spriteram16) AM_SIZE(&spriteram_size)
-	AM_RANGE(0x900000, 0x900001) AM_WRITE(galpanic_6295_bankswitch_w)	/* not sure */
+	AM_RANGE(0x900000, 0x900001) AM_WRITE(galpania_6295_bankswitch_w)	/* not sure */
 	AM_RANGE(0xf80000, 0xf8ffff) AM_WRITE(MWA16_RAM)
 	AM_RANGE(0xa00000, 0xa00001) AM_WRITE(MWA16_NOP)	/* coin counters, + ? */
 	AM_RANGE(0xc80000, 0xc80001) AM_WRITE(OKIM6295_data_0_msb_w)
@@ -312,46 +380,121 @@ static ADDRESS_MAP_START( galhustl_writemem, ADDRESS_SPACE_PROGRAM, 16 )
 	AM_RANGE(0x700000, 0x700fff) AM_WRITE(MWA16_RAM) AM_BASE(&spriteram16) AM_SIZE(&spriteram_size)
 	AM_RANGE(0x780000, 0x78001f) AM_WRITE(MWA16_RAM) /* regs? */
 	AM_RANGE(0xa00000, 0xa00001) AM_WRITE(MWA16_NOP) /* ? */
-	AM_RANGE(0x900000, 0x900001) AM_WRITE(galpanic_6295_bankswitch_w)
+	AM_RANGE(0x900000, 0x900001) AM_WRITE(galpania_6295_bankswitch_w)
 	AM_RANGE(0xd00000, 0xd00001) AM_WRITE(OKIM6295_data_0_msb_w)
 	AM_RANGE(0xe80000, 0xe8ffff) AM_WRITE(MWA16_RAM)
 ADDRESS_MAP_END
 
+/*
+READ16_HANDLER( zipzap_random_read )
+{
+    return mame_rand();
+}
+*/
+static ADDRESS_MAP_START( zipzap_readmem, ADDRESS_SPACE_PROGRAM, 16 )
+	AM_RANGE(0x000000, 0x4fffff) AM_READ(MRA16_ROM)
+	AM_RANGE(0x500000, 0x51ffff) AM_READ(MRA16_RAM)
+	AM_RANGE(0x520000, 0x53ffff) AM_READ(MRA16_RAM)
+	AM_RANGE(0x580000, 0x583fff) AM_READ(MRA16_RAM)
+	AM_RANGE(0x600000, 0x600fff) AM_READ(MRA16_RAM)
+	AM_RANGE(0x680000, 0x68001f) AM_READ(MRA16_RAM)
+	AM_RANGE(0x700000, 0x71ffff) AM_READ(MRA16_RAM)
+	AM_RANGE(0x780000, 0x78001f) AM_READ(MRA16_RAM)
+	AM_RANGE(0x800000, 0x800001) AM_READ(input_port_0_word_r)
+	AM_RANGE(0x800002, 0x800003) AM_READ(input_port_1_word_r)
+	AM_RANGE(0x800004, 0x800005) AM_READ(input_port_2_word_r)
+
+	AM_RANGE(0xc00000, 0xc00001) AM_READ(comad_OKIM6295_status_0_msb_r)
+
+	AM_RANGE(0xc80000, 0xc8ffff) AM_READ(MRA16_RAM)
+ADDRESS_MAP_END
+
+static ADDRESS_MAP_START( zipzap_writemem, ADDRESS_SPACE_PROGRAM, 16 )
+	AM_RANGE(0x000000, 0x4fffff) AM_WRITE(MWA16_ROM)
+	AM_RANGE(0x500000, 0x51ffff) AM_WRITE(MWA16_RAM) AM_BASE(&galpanic_fgvideoram) AM_SIZE(&galpanic_fgvideoram_size)
+	AM_RANGE(0x520000, 0x53ffff) AM_WRITE(galpanic_bgvideoram_w) AM_BASE(&galpanic_bgvideoram)
+	AM_RANGE(0x580000, 0x583fff) AM_WRITE(galpanic_bgvideoram_mirror_w)
+	AM_RANGE(0x600000, 0x600fff) AM_WRITE(galpanic_paletteram_w) AM_BASE(&paletteram16)	/* 1024 colors, but only 512 seem to be used */
+	AM_RANGE(0x680000, 0x68001f) AM_WRITE(MWA16_RAM)
+	AM_RANGE(0x700000, 0x700fff) AM_WRITE(MWA16_RAM) AM_BASE(&spriteram16) AM_SIZE(&spriteram_size)
+	AM_RANGE(0x701000, 0x71ffff) AM_WRITE(MWA16_RAM)
+	AM_RANGE(0x780000, 0x78001f) AM_WRITE(MWA16_RAM)
+	AM_RANGE(0x900000, 0x900001) AM_WRITE(galpania_6295_bankswitch_w)
+	AM_RANGE(0xc00000, 0xc00001) AM_WRITE(OKIM6295_data_0_msb_w)
+	AM_RANGE(0xc80000, 0xc8ffff) AM_WRITE(MWA16_RAM) /* main ram */
+ADDRESS_MAP_END
+
+static ADDRESS_MAP_START( supmodel_readmem, ADDRESS_SPACE_PROGRAM, 16 )
+	AM_RANGE(0x000000, 0x4fffff) AM_READ(MRA16_ROM)
+	AM_RANGE(0x500000, 0x51ffff) AM_READ(MRA16_RAM)
+	AM_RANGE(0x520000, 0x53ffff) AM_READ(MRA16_RAM)
+/*  AM_RANGE(0x580000, 0x583fff) AM_READ(MRA16_RAM) */
+	AM_RANGE(0x600000, 0x600fff) AM_READ(MRA16_RAM)
+	AM_RANGE(0x680000, 0x68001f) AM_READ(MRA16_RAM)
+	AM_RANGE(0x700000, 0x700fff) AM_READ(MRA16_RAM)
+	AM_RANGE(0x780000, 0x78001f) AM_READ(MRA16_RAM)
+	AM_RANGE(0x800000, 0x800001) AM_READ(input_port_0_word_r)
+	AM_RANGE(0x800002, 0x800003) AM_READ(input_port_1_word_r)
+	AM_RANGE(0x800004, 0x800005) AM_READ(input_port_2_word_r)
+	AM_RANGE(0x800006, 0x800007) AM_READ(kludge)
+	AM_RANGE(0x800008, 0x800009) AM_READ(kludge)
+	AM_RANGE(0xc80000, 0xc8ffff) AM_READ(MRA16_RAM)
+	AM_RANGE(0xf80000, 0xf80001) AM_READ(comad_OKIM6295_status_0_msb_r)
+ADDRESS_MAP_END
+
+static ADDRESS_MAP_START( supmodel_writemem, ADDRESS_SPACE_PROGRAM, 16 )
+	AM_RANGE(0x000000, 0x4fffff) AM_WRITE(MWA16_ROM)
+	AM_RANGE(0x500000, 0x51ffff) AM_WRITE(MWA16_RAM) AM_BASE(&galpanic_fgvideoram) AM_SIZE(&galpanic_fgvideoram_size)
+	AM_RANGE(0x520000, 0x53ffff) AM_WRITE(galpanic_bgvideoram_w) AM_BASE(&galpanic_bgvideoram)
+/*  AM_RANGE(0x580000, 0x583fff) AM_WRITE(galpanic_bgvideoram_mirror_w) // can't be right, causes half the display to vanish at times! */
+	AM_RANGE(0x600000, 0x600fff) AM_WRITE(galpanic_paletteram_w) AM_BASE(&paletteram16)	/* 1024 colors, but only 512 seem to be used */
+	AM_RANGE(0x680000, 0x68001f) AM_WRITE(MWA16_RAM)
+	AM_RANGE(0x700000, 0x700fff) AM_WRITE(MWA16_RAM) AM_BASE(&spriteram16) AM_SIZE(&spriteram_size)
+	AM_RANGE(0x780000, 0x78001f) AM_WRITE(MWA16_RAM)
+	AM_RANGE(0x900000, 0x900001) AM_WRITE(galpania_6295_bankswitch_w)	/* not sure */
+	AM_RANGE(0xa00000, 0xa00001) AM_WRITE(MWA16_NOP)
+	AM_RANGE(0xc80000, 0xc8ffff) AM_WRITE(MWA16_RAM) /* main ram */
+	AM_RANGE(0xd80000, 0xd80001) AM_WRITE(MWA16_NOP)
+	AM_RANGE(0xe00012, 0xe00013) AM_WRITE(MWA16_NOP)
+	AM_RANGE(0xe80000, 0xe80001) AM_WRITE(MWA16_NOP)
+	AM_RANGE(0xf80000, 0xf80001) AM_WRITE(OKIM6295_data_0_msb_w)
+ADDRESS_MAP_END
+
 #define COMMON_COIN0\
 	PORT_DIPNAME( 0x0030, 0x0030, DEF_STR( Coin_A ) )\
 	PORT_DIPSETTING(      0x0020, DEF_STR( 2C_1C ) )\
 	PORT_DIPSETTING(      0x0030, DEF_STR( 1C_1C ) )\
-	PORT_DIPSETTING(      0x0010, DEF_STR( 1C_2C ) )	PORT_DIPCONDITION(0,0x0008,PORTCOND_EQUALS,0x0008)\
-	PORT_DIPSETTING(      0x0010, DEF_STR( 1C_3C ) )	PORT_DIPCONDITION(0,0x0008,PORTCOND_EQUALS,0x0000)\
-	PORT_DIPSETTING(      0x0000, DEF_STR( 1C_4C ) )	PORT_DIPCONDITION(0,0x0008,PORTCOND_EQUALS,0x0000)\
-	PORT_DIPSETTING(      0x0000, DEF_STR( 1C_6C ) )	PORT_DIPCONDITION(0,0x0008,PORTCOND_EQUALS,0x0008)\
+	PORT_DIPSETTING(      0x0010, DEF_STR( 1C_2C ) )	PORT_CONDITION("DSW1",0x0008,PORTCOND_EQUALS,0x0008)\
+	PORT_DIPSETTING(      0x0010, DEF_STR( 1C_3C ) )	PORT_CONDITION("DSW1",0x0008,PORTCOND_EQUALS,0x0000)\
+	PORT_DIPSETTING(      0x0000, DEF_STR( 1C_4C ) )	PORT_CONDITION("DSW1",0x0008,PORTCOND_EQUALS,0x0000)\
+	PORT_DIPSETTING(      0x0000, DEF_STR( 1C_6C ) )	PORT_CONDITION("DSW1",0x0008,PORTCOND_EQUALS,0x0008)\
 	PORT_DIPNAME( 0x00c0, 0x00c0, DEF_STR( Coin_B ) )\
 	PORT_DIPSETTING(      0x0080, DEF_STR( 2C_1C ) )\
 	PORT_DIPSETTING(      0x00c0, DEF_STR( 1C_1C ) )\
-	PORT_DIPSETTING(      0x0040, DEF_STR( 1C_2C ) )	PORT_DIPCONDITION(0,0x0008,PORTCOND_EQUALS,0x0008)\
-	PORT_DIPSETTING(      0x0040, DEF_STR( 1C_3C ) )	PORT_DIPCONDITION(0,0x0008,PORTCOND_EQUALS,0x0000)\
-	PORT_DIPSETTING(      0x0000, DEF_STR( 1C_4C ) )	PORT_DIPCONDITION(0,0x0008,PORTCOND_EQUALS,0x0000)\
-	PORT_DIPSETTING(      0x0000, DEF_STR( 1C_6C ) )	PORT_DIPCONDITION(0,0x0008,PORTCOND_EQUALS,0x0008)
+	PORT_DIPSETTING(      0x0040, DEF_STR( 1C_2C ) )	PORT_CONDITION("DSW1",0x0008,PORTCOND_EQUALS,0x0008)\
+	PORT_DIPSETTING(      0x0040, DEF_STR( 1C_3C ) )	PORT_CONDITION("DSW1",0x0008,PORTCOND_EQUALS,0x0000)\
+	PORT_DIPSETTING(      0x0000, DEF_STR( 1C_4C ) )	PORT_CONDITION("DSW1",0x0008,PORTCOND_EQUALS,0x0000)\
+	PORT_DIPSETTING(      0x0000, DEF_STR( 1C_6C ) )	PORT_CONDITION("DSW1",0x0008,PORTCOND_EQUALS,0x0008)
 
 #define COMMON_COIN1\
 	PORT_DIPNAME( 0x0030, 0x0030, DEF_STR( Coin_A ) )\
 	PORT_DIPSETTING(      0x0020, DEF_STR( 2C_1C ) )\
 	PORT_DIPSETTING(      0x0030, DEF_STR( 1C_1C ) )\
-	PORT_DIPSETTING(      0x0010, DEF_STR( 1C_2C ) )	PORT_DIPCONDITION(1,0x0008,PORTCOND_EQUALS,0x0008)\
-	PORT_DIPSETTING(      0x0010, DEF_STR( 1C_3C ) )	PORT_DIPCONDITION(1,0x0008,PORTCOND_EQUALS,0x0000)\
-	PORT_DIPSETTING(      0x0000, DEF_STR( 1C_4C ) )	PORT_DIPCONDITION(1,0x0008,PORTCOND_EQUALS,0x0000)\
-	PORT_DIPSETTING(      0x0000, DEF_STR( 1C_6C ) )	PORT_DIPCONDITION(1,0x0008,PORTCOND_EQUALS,0x0008)\
+	PORT_DIPSETTING(      0x0010, DEF_STR( 1C_2C ) )	PORT_CONDITION("DSW2",0x0008,PORTCOND_EQUALS,0x0008)\
+	PORT_DIPSETTING(      0x0010, DEF_STR( 1C_3C ) )	PORT_CONDITION("DSW2",0x0008,PORTCOND_EQUALS,0x0000)\
+	PORT_DIPSETTING(      0x0000, DEF_STR( 1C_4C ) )	PORT_CONDITION("DSW2",0x0008,PORTCOND_EQUALS,0x0000)\
+	PORT_DIPSETTING(      0x0000, DEF_STR( 1C_6C ) )	PORT_CONDITION("DSW2",0x0008,PORTCOND_EQUALS,0x0008)\
 	PORT_DIPNAME( 0x00c0, 0x00c0, DEF_STR( Coin_B ) )\
 	PORT_DIPSETTING(      0x0080, DEF_STR( 2C_1C ) )\
 	PORT_DIPSETTING(      0x00c0, DEF_STR( 1C_1C ) )\
-	PORT_DIPSETTING(      0x0040, DEF_STR( 1C_2C ) )	PORT_DIPCONDITION(1,0x0008,PORTCOND_EQUALS,0x0008)\
-	PORT_DIPSETTING(      0x0040, DEF_STR( 1C_3C ) )	PORT_DIPCONDITION(1,0x0008,PORTCOND_EQUALS,0x0000)\
-	PORT_DIPSETTING(      0x0000, DEF_STR( 1C_4C ) )	PORT_DIPCONDITION(1,0x0008,PORTCOND_EQUALS,0x0000)\
-	PORT_DIPSETTING(      0x0000, DEF_STR( 1C_6C ) )	PORT_DIPCONDITION(1,0x0008,PORTCOND_EQUALS,0x0008)
+	PORT_DIPSETTING(      0x0040, DEF_STR( 1C_2C ) )	PORT_CONDITION("DSW2",0x0008,PORTCOND_EQUALS,0x0008)\
+	PORT_DIPSETTING(      0x0040, DEF_STR( 1C_3C ) )	PORT_CONDITION("DSW2",0x0008,PORTCOND_EQUALS,0x0000)\
+	PORT_DIPSETTING(      0x0000, DEF_STR( 1C_4C ) )	PORT_CONDITION("DSW2",0x0008,PORTCOND_EQUALS,0x0000)\
+	PORT_DIPSETTING(      0x0000, DEF_STR( 1C_6C ) )	PORT_CONDITION("DSW2",0x0008,PORTCOND_EQUALS,0x0008)
 
 
 INPUT_PORTS_START( galpanic )
-	PORT_START
+	PORT_START_TAG("DSW1")
 	PORT_DIPNAME( 0x0001, 0x0001, DEF_STR( Unused ) )
 	PORT_DIPSETTING(      0x0001, DEF_STR( Off ) )
 	PORT_DIPSETTING(      0x0000, DEF_STR( On ) )
@@ -439,7 +582,7 @@ INPUT_PORTS_START( galpanic )
 INPUT_PORTS_END
 
 INPUT_PORTS_START( galpanib )
-	PORT_START
+	PORT_START_TAG("DSW1")
 	PORT_DIPNAME( 0x0001, 0x0001, DEF_STR( Unused ) )
 	PORT_DIPSETTING(      0x0001, DEF_STR( Off ) )
 	PORT_DIPSETTING(      0x0000, DEF_STR( On ) )
@@ -550,7 +693,7 @@ INPUT_PORTS_START( fantasia )
 	PORT_BIT( 0x4000, IP_ACTIVE_LOW, IPT_UNKNOWN )
 	PORT_BIT( 0x8000, IP_ACTIVE_LOW, IPT_UNKNOWN )
 
-	PORT_START
+	PORT_START_TAG("DSW2")
 	PORT_DIPNAME( 0x0001, 0x0001, DEF_STR( Unused ) )
 	PORT_DIPSETTING(      0x0001, DEF_STR( Off ) )
 	PORT_DIPSETTING(      0x0000, DEF_STR( On ) )
@@ -617,7 +760,7 @@ INPUT_PORTS_START( missw96 )
 	PORT_BIT( 0x4000, IP_ACTIVE_LOW, IPT_UNKNOWN )
 	PORT_BIT( 0x8000, IP_ACTIVE_LOW, IPT_UNKNOWN )
 
-	PORT_START
+	PORT_START_TAG("DSW2")
 	PORT_DIPNAME( 0x0001, 0x0001, DEF_STR( Unused ) )
 	PORT_DIPSETTING(      0x0001, DEF_STR( Off ) )
 	PORT_DIPSETTING(      0x0000, DEF_STR( On ) )
@@ -728,8 +871,87 @@ INPUT_PORTS_START( galhustl )
 	PORT_BIT( 0x8000, IP_ACTIVE_LOW, IPT_UNKNOWN )
 INPUT_PORTS_END
 
+INPUT_PORTS_START( zipzap )
+	PORT_START
+	PORT_DIPNAME( 0x0001, 0x0001, DEF_STR( Unknown ) )
+	PORT_DIPSETTING(      0x0001, DEF_STR( Off ) )
+	PORT_DIPSETTING(      0x0000, DEF_STR( On ) )
+	PORT_DIPNAME( 0x0002, 0x0002, "Additional Obsticals" ) /* Adds 4 Blocker/Bumpers to playing field */
+	PORT_DIPSETTING(      0x0002, DEF_STR( Off ) )
+	PORT_DIPSETTING(      0x0000, DEF_STR( On ) )
+	PORT_DIPNAME( 0x000c, 0x000c, DEF_STR( Lives ) )
+	PORT_DIPSETTING(      0x0000, "1" )
+	PORT_DIPSETTING(      0x0008, "2" )
+	PORT_DIPSETTING(      0x000c, "3" )
+	PORT_DIPSETTING(      0x0004, "4" )
+	PORT_DIPNAME( 0x0010, 0x0010, DEF_STR( Unknown ) )
+	PORT_DIPSETTING(      0x0010, DEF_STR( Off ) )
+	PORT_DIPSETTING(      0x0000, DEF_STR( On ) )
+	PORT_DIPNAME( 0x0020, 0x0020, DEF_STR( Unknown ) )
+	PORT_DIPSETTING(      0x0020, DEF_STR( Off ) )
+	PORT_DIPSETTING(      0x0000, DEF_STR( On ) )
+	PORT_DIPNAME( 0x0040, 0x0040, DEF_STR( Unknown ) )
+	PORT_DIPSETTING(      0x0040, DEF_STR( Off ) )
+	PORT_DIPSETTING(      0x0000, DEF_STR( On ) )
+	PORT_DIPNAME( 0x0080, 0x0080, DEF_STR( Unknown ) )
+	PORT_DIPSETTING(      0x0080, DEF_STR( Off ) )
+	PORT_DIPSETTING(      0x0000, DEF_STR( On ) )
+	PORT_BIT( 0x0100, IP_ACTIVE_LOW, IPT_JOYSTICK_UP ) PORT_8WAY PORT_PLAYER(1)
+	PORT_BIT( 0x0200, IP_ACTIVE_LOW, IPT_JOYSTICK_DOWN ) PORT_8WAY PORT_PLAYER(1)
+	PORT_BIT( 0x0400, IP_ACTIVE_LOW, IPT_JOYSTICK_LEFT ) PORT_8WAY PORT_PLAYER(1)
+	PORT_BIT( 0x0800, IP_ACTIVE_LOW, IPT_JOYSTICK_RIGHT ) PORT_8WAY PORT_PLAYER(1)
+	PORT_BIT( 0x1000, IP_ACTIVE_LOW, IPT_BUTTON1 ) PORT_PLAYER(1)
+	PORT_BIT( 0x2000, IP_ACTIVE_LOW, IPT_BUTTON2 ) PORT_PLAYER(1)
+	PORT_BIT( 0x4000, IP_ACTIVE_LOW, IPT_BUTTON3 ) PORT_PLAYER(1)
+	PORT_BIT( 0x8000, IP_ACTIVE_LOW, IPT_UNKNOWN )
 
-static struct GfxLayout spritelayout =
+	PORT_START
+	PORT_DIPNAME( 0x0003, 0x0003, DEF_STR( Coinage ) )
+	PORT_DIPSETTING(      0x0000, DEF_STR( 3C_1C ) )
+	PORT_DIPSETTING(      0x0001, DEF_STR( 2C_1C ) )
+	PORT_DIPSETTING(      0x0003, DEF_STR( 1C_1C ) )
+	PORT_DIPSETTING(      0x0002, DEF_STR( 1C_2C ) )
+	PORT_DIPNAME( 0x0004, 0x0004, "Select Player Mode" ) /* Amateur, Normal & Exelent Modes */
+	PORT_DIPSETTING(      0x0000, DEF_STR( Off ) )
+	PORT_DIPSETTING(      0x0004, DEF_STR( On ) )
+	PORT_DIPNAME( 0x0008, 0x0008, DEF_STR( Demo_Sounds ) )
+	PORT_DIPSETTING(      0x0000, DEF_STR( Off ) )
+	PORT_DIPSETTING(      0x0008, DEF_STR( On ) )
+	PORT_DIPNAME( 0x0010, 0x0010, DEF_STR( Unknown ) )
+	PORT_DIPSETTING(      0x0010, DEF_STR( Off ) )
+	PORT_DIPSETTING(      0x0000, DEF_STR( On ) )
+	PORT_DIPNAME( 0x0020, 0x0020, DEF_STR( Unknown ) )
+	PORT_DIPSETTING(      0x0020, DEF_STR( Off ) )
+	PORT_DIPSETTING(      0x0000, DEF_STR( On ) )
+	PORT_DIPNAME( 0x0040, 0x0040, DEF_STR( Unknown ) )
+	PORT_DIPSETTING(      0x0040, DEF_STR( Off ) )
+	PORT_DIPSETTING(      0x0000, DEF_STR( On ) )
+	PORT_DIPNAME( 0x0080, 0x0080, DEF_STR( Unknown ) )
+	PORT_DIPSETTING(      0x0080, DEF_STR( Off ) )
+	PORT_DIPSETTING(      0x0000, DEF_STR( On ) )
+	PORT_BIT( 0x0100, IP_ACTIVE_LOW, IPT_JOYSTICK_UP ) PORT_8WAY PORT_PLAYER(2)
+	PORT_BIT( 0x0200, IP_ACTIVE_LOW, IPT_JOYSTICK_DOWN ) PORT_8WAY PORT_PLAYER(2)
+	PORT_BIT( 0x0400, IP_ACTIVE_LOW, IPT_JOYSTICK_LEFT ) PORT_8WAY PORT_PLAYER(2)
+	PORT_BIT( 0x0800, IP_ACTIVE_LOW, IPT_JOYSTICK_RIGHT ) PORT_8WAY PORT_PLAYER(2)
+	PORT_BIT( 0x1000, IP_ACTIVE_LOW, IPT_BUTTON1 ) PORT_PLAYER(2)
+	PORT_BIT( 0x2000, IP_ACTIVE_LOW, IPT_BUTTON2 ) PORT_PLAYER(2)
+	PORT_BIT( 0x4000, IP_ACTIVE_LOW, IPT_BUTTON3 ) PORT_PLAYER(2)
+	PORT_BIT( 0x8000, IP_ACTIVE_LOW, IPT_UNKNOWN )
+
+	PORT_START
+	PORT_BIT( 0x00ff, IP_ACTIVE_LOW, IPT_UNKNOWN )
+	PORT_BIT( 0x0100, IP_ACTIVE_LOW, IPT_START1 )
+	PORT_BIT( 0x0200, IP_ACTIVE_LOW, IPT_START2 )
+	PORT_BIT( 0x0400, IP_ACTIVE_LOW, IPT_COIN1 )
+	PORT_BIT( 0x0800, IP_ACTIVE_LOW, IPT_COIN2 )
+	PORT_BIT( 0x1000, IP_ACTIVE_LOW, IPT_UNKNOWN )
+	PORT_BIT( 0x2000, IP_ACTIVE_LOW, IPT_UNKNOWN )
+	PORT_BIT( 0x4000, IP_ACTIVE_LOW, IPT_UNKNOWN )
+	PORT_BIT( 0x8000, IP_ACTIVE_LOW, IPT_UNKNOWN )
+INPUT_PORTS_END
+
+
+static const gfx_layout spritelayout =
 {
 	16,16,
 	RGN_FRAC(1,1),
@@ -742,7 +964,7 @@ static struct GfxLayout spritelayout =
 	128*8
 };
 
-static struct GfxDecodeInfo gfxdecodeinfo[] =
+static const gfx_decode gfxdecodeinfo[] =
 {
 	{ REGION_GFX1, 0, &spritelayout,  256, 16 },
 	{ -1 } /* end of array */
@@ -769,7 +991,7 @@ static MACHINE_DRIVER_START( galpanic )
 	MDRV_COLORTABLE_LENGTH(1024)
 
 	MDRV_PALETTE_INIT(galpanic)
-	MDRV_VIDEO_START(generic_bitmapped)
+	MDRV_VIDEO_START(galpanic)
 	MDRV_VIDEO_UPDATE(galpanic)
 
 	/* sound hardware */
@@ -817,6 +1039,23 @@ static MACHINE_DRIVER_START( comad )
 	MDRV_VIDEO_UPDATE(comad)
 MACHINE_DRIVER_END
 
+static MACHINE_DRIVER_START( supmodel )
+
+	/* basic machine hardware */
+	MDRV_IMPORT_FROM(comad)
+	MDRV_CPU_REPLACE("main", M68000, 12000000)	/* ? */
+	MDRV_CPU_PROGRAM_MAP(supmodel_readmem,supmodel_writemem)
+	MDRV_CPU_VBLANK_INT(galpanic_interrupt,2)
+
+	/* video hardware */
+	MDRV_VIDEO_UPDATE(comad)
+
+	/* sound hardware */
+	MDRV_SOUND_REPLACE("oki", OKIM6295, 12000)
+	MDRV_SOUND_CONFIG(okim6295_interface_region_1)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 1.0)
+MACHINE_DRIVER_END
+
 
 static MACHINE_DRIVER_START( fantsia2 )
 
@@ -839,6 +1078,22 @@ static MACHINE_DRIVER_START( galhustl )
 
 	/* video hardware */
 	MDRV_VIDEO_UPDATE(comad)
+MACHINE_DRIVER_END
+
+
+
+
+
+static MACHINE_DRIVER_START( zipzap )
+
+	/* basic machine hardware */
+	MDRV_IMPORT_FROM(comad)
+	MDRV_CPU_REPLACE("main", M68000, 12000000)	/* ? */
+	MDRV_CPU_PROGRAM_MAP(zipzap_readmem,zipzap_writemem)
+	MDRV_CPU_VBLANK_INT(galhustl_interrupt,3)
+
+	/* video hardware */
+	MDRV_VIDEO_UPDATE(comad)
 
 	/* sound hardware */
 	MDRV_SOUND_REPLACE("oki", OKIM6295, 8000)
@@ -846,6 +1101,7 @@ static MACHINE_DRIVER_START( galhustl )
 	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 1.0)
 MACHINE_DRIVER_END
 
+
 /***************************************************************************
 
   Game driver(s)
@@ -1029,7 +1285,7 @@ ROM_START( missmw96 )
 	ROM_LOAD16_BYTE( "mmw96_08.bin",  0x200000, 0x80000, CRC(1dc72b07) SHA1(fdbdf8298fe98d74ed2a76abf60f60af1c27a65d) )
 	ROM_LOAD16_BYTE( "mmw96_04.bin",  0x200001, 0x80000, CRC(fc3e18fa) SHA1(b3ad254aab982dc75a10c2cf2b3815c2fdbba914) )
 	ROM_LOAD16_BYTE( "mmw96_07.bin",  0x300000, 0x80000, CRC(001572bf) SHA1(cdf59c624baaeaea70985ee6f2f2fed08a8dfa61) )
-	ROM_LOAD16_BYTE( "mmw96_03.bin",  0x300001, 0x80000, BAD_DUMP CRC(8ad14003) SHA1(4bd2ef31956f5d9d4e592ac9786cd1a17e6a9b06) ) /* one of them is bad anyway .. */
+	ROM_LOAD16_BYTE( "mmw96_03.bin",  0x300001, 0x80000, CRC(22204025) SHA1(442e7f754c65c598983d6f897a60870d7759c823) )
 
 	ROM_REGION( 0x80000, REGION_GFX1, ROMREGION_DISPOSE )	/* sprites */
 	ROM_LOAD( "mmw96_11.bin",  0x00000, 0x80000, CRC(7d491f8c) SHA1(63f580bd65579cac70b90eaa0e7f2413ef1597b8) )
@@ -1065,6 +1321,30 @@ ROM_START( fantsia2 )
 	ROM_LOAD( "music1.1a",    0xc0000, 0x80000, CRC(864167c2) SHA1(c454b26b6dea993e6bd64546f92beef05e46d7d7) )
 ROM_END
 
+ROM_START( fntsia2a )
+	ROM_REGION( 0x500000, REGION_CPU1, 0 )	/* 68000 code */
+	ROM_LOAD16_BYTE( "fnt2-22.bin",    0x000000, 0x80000, CRC(a3a92c4b) SHA1(6affdcb57e1e0a77c7cc33135dafe86843e9e3d8) )
+	ROM_LOAD16_BYTE( "fnt2-17.bin",    0x000001, 0x80000, CRC(d0ce4493) SHA1(9cec088e6630555b6d584df23236c279909820cf) )
+	ROM_LOAD16_BYTE( "fnt2-21.bin",    0x100000, 0x80000, CRC(e989c2e7) SHA1(c9eea2a89843cdd9db4a4a0539d0315c125e3e02) )
+	ROM_LOAD16_BYTE( "fnt2-16.bin",    0x100001, 0x80000, CRC(8c06d372) SHA1(14fe2c8450f0f2e11e204dd524bfe32a72ddc144) )
+	ROM_LOAD16_BYTE( "fnt2-20.bin",    0x200000, 0x80000, CRC(6e9f1e65) SHA1(b6f1eb1a52de18ed5b17de3ef365e5c041d15314) )
+	ROM_LOAD16_BYTE( "fnt2-15.bin",    0x200001, 0x80000, CRC(85cbeb2b) SHA1(a213b461019ddb3b319b9815a76c6fb2ecfbe937) )
+	ROM_LOAD16_BYTE( "fnt2-19.bin",    0x300000, 0x80000, CRC(7953226a) SHA1(955c779eae496688be2ed416d879d6e83c888368) )
+	ROM_LOAD16_BYTE( "fnt2-14.bin",    0x300001, 0x80000, CRC(10d8ccff) SHA1(bf4c49d85556edf49289631ee6178d3fb7dea2cc) )
+	ROM_LOAD16_BYTE( "fnt2-18.bin",    0x400000, 0x80000, CRC(4cdaeda3) SHA1(f5b478e49b59496865982409517654f48296565d) )
+	ROM_LOAD16_BYTE( "fnt2-13.bin",    0x400001, 0x80000, CRC(68c7f042) SHA1(ed3c864f3d91377fec78f19897ba0b0d2bcf0d2b) )
+
+	ROM_REGION( 0x100000, REGION_GFX1, ROMREGION_DISPOSE )	/* sprites */
+	ROM_LOAD( "obj1.1i",      0x00000, 0x80000, CRC(52e6872a) SHA1(7e5274b9a415ee0e536cd3b87f73d3eae9644669) )
+	ROM_LOAD( "obj2.2i",      0x80000, 0x80000, CRC(ea6e3861) SHA1(463b40f5441231a0451571a0b8afe1ed0fd4b164) )
+
+	ROM_REGION( 0x140000, REGION_SOUND1, 0 )	/* OKIM6295 samples */
+	/* 00000-2ffff is fixed, 30000-3ffff is bank switched from all the ROMs */
+	ROM_LOAD( "music2.1b",    0x00000, 0x80000, CRC(23cc4f9c) SHA1(06b5342c25de966ce590917c571e5b19af1fef7d) )
+	ROM_RELOAD(               0x40000, 0x80000 )
+	ROM_LOAD( "music1.1a",    0xc0000, 0x80000, CRC(864167c2) SHA1(c454b26b6dea993e6bd64546f92beef05e46d7d7) )
+ROM_END
+
 ROM_START( galhustl )
 	ROM_REGION( 0x100000, REGION_CPU1, 0 ) /* 68000 Code */
 	ROM_LOAD16_BYTE( "ue17.3", 0x00000, 0x80000, CRC(b2583dbb) SHA1(536f4aa2246ec816c4f270f9d42acc090718ee8b) )
@@ -1080,13 +1360,82 @@ ROM_START( galhustl )
 	ROM_LOAD( "galhstl5.u5", 0x00000, 0x80000, CRC(44a18f15) SHA1(1217cf7fbbb442358b15016099efeface5dcbd22) )
 ROM_END
 
-GAMEX( 1990, galpanic, 0,        galpanic, galpanic, 0, ROT90, "Kaneko", "Gals Panic (set 1)", GAME_NO_COCKTAIL )
-GAMEX( 1990, galpanib, galpanic, galpanib, galpanib, 0, ROT90, "Kaneko", "Gals Panic (set 2)", GAME_NO_COCKTAIL )
-GAMEX( 1990, galpania, galpanic, galpania, galpanib, 0, ROT90, "Kaneko", "Gals Panic (set 3)", GAME_NO_COCKTAIL | GAME_IMPERFECT_GRAPHICS )
-GAMEX( 1994, fantasia, 0,        comad,    fantasia, 0, ROT90, "Comad & New Japan System", "Fantasia", GAME_NO_COCKTAIL )
-GAMEX( 1995, newfant,  0,        comad,    fantasia, 0, ROT90, "Comad & New Japan System", "New Fantasia", GAME_NO_COCKTAIL )
-GAMEX( 1995, fantsy95, 0,        comad,    fantasia, 0, ROT90, "Hi-max Technology Inc.", "Fantasy '95", GAME_NO_COCKTAIL )
-GAMEX( 1996, missw96,  0,        comad,    missw96,  0, ROT0,  "Comad", "Miss World '96 Nude", GAME_NO_COCKTAIL )
-GAMEX( 1996, missmw96, missw96,  comad,    missw96,  0, ROT0,  "Comad", "Miss Mister World '96 Nude", GAME_NO_COCKTAIL )
-GAMEX( 1997, fantsia2, 0,        fantsia2, missw96,  0, ROT0,  "Comad", "Fantasia II", GAME_NO_COCKTAIL )
-GAME(  1997, galhustl, 0,        galhustl, galhustl, 0, ROT0,  "ACE International", "Gals Hustler" )
+/*
+
+Zip & Zap
+
+Zip Zap (pcb marked Barko Corp 950509)
+
+1x 68k
+1x Oki m6295
+1x osc 12mhz
+1x osc 16mhz
+1x fpga
+2x dipswitch banks
+
+*/
+
+ROM_START( zipzap )
+	ROM_REGION( 0x500000, REGION_CPU1, 0 ) /* 68000 Code */
+	/* all the roms for this game could do with checking on another board, this one was in pretty bad condition
+       and reads weren't always consistent */
+	ROM_LOAD16_BYTE( "ud17.bin", 0x000001, 0x40000, BAD_DUMP CRC(2901fae1) SHA1(0d6ca6d48c5586c05f3c02aee51a95da38b3751f) )
+	ROM_LOAD16_BYTE( "ue17.bin", 0x000000, 0x40000, BAD_DUMP CRC(da6c3fc8) SHA1(4bc01bc6f62553f6ac4f7252f7d9bf0d639f6935) )
+	/* gfx bitmaps */
+	ROM_LOAD16_BYTE( "938.bin",  0x400000, 0x80000, CRC(61c06b60) SHA1(b3abae020009a48b99862766e0981e1118159a47) ) /* good title backgruond */
+	ROM_LOAD16_BYTE( "942.bin",  0x400001, 0x80000, CRC(282413b8) SHA1(e2ecaaa3c5b2355eadc016b73d7d658f25e1e0db) ) /* (and corrupt gfx on select mode screen) */
+
+	ROM_LOAD16_BYTE( "934.bin",  0x300000, 0x80000, CRC(1e65988a) SHA1(64d6f8cbdb28755515d9bbf52f589ce1176fed58) ) /* good, girls */
+	ROM_LOAD16_BYTE( "939.bin",  0x300001, 0x80000, CRC(8790a6a3) SHA1(94f39e48b75144cab191e2de4284c28d18b8f1c7))
+
+	ROM_LOAD16_BYTE( "936.bin",  0x200000, 0x80000, CRC(596543cc) SHA1(10a0eab4ca4a8749f1703ff6fcc80d731d07d087) ) /* good, girls */
+	ROM_LOAD16_BYTE( "940.bin",  0x200001, 0x80000, CRC(0c9dfb53) SHA1(541bd8c79408b7415713b517eacdd565d0ac5cb8) )
+
+	ROM_LOAD16_BYTE( "937.bin",  0x100000, 0x80000, CRC(61dd653f) SHA1(68b5ae3423363cc64d933836bf6881431dad021a) ) /* good, girls */
+	ROM_LOAD16_BYTE( "941.bin",  0x100001, 0x80000, CRC(320321ed) SHA1(00b52cd34cd86c105ff6dbd0248ff239de31c851) )
+
+	ROM_REGION( 0x100000, REGION_GFX1, 0 ) /* sprites */
+	ROM_LOAD( "u5.bin",  0x000000, 0x80000,  CRC(c274d8b5) SHA1(2c45961aaf8311f027a734df7e33fe085dfdd099) )
+
+	ROM_REGION( 0x140000, REGION_SOUND1, 0 ) /* Samples */
+	ROM_LOAD( "snd.bin", 0x00000, 0x80000,  CRC(bc20423e) SHA1(1f4bd52ec4f9b3b3e6b10ac2b3afaadf76a2c7c9) )
+	ROM_RELOAD(          0x40000, 0x80000 )
+	ROM_RELOAD(          0xc0000, 0x80000 )
+ROM_END
+
+ROM_START( supmodel )
+	ROM_REGION( 0x500000, REGION_CPU1, 0 )	/* 68000 code */
+	ROM_LOAD16_BYTE( "prog2.12",  0x000000, 0x80000, CRC(714b7e74) SHA1(a4f7754a4b04729084ccb1359f9bdfbad6150222) )
+	ROM_LOAD16_BYTE( "prog1.7",   0x000001, 0x80000, CRC(0bb858de) SHA1(bd2039fa46fce89289e99a790400bd567f90105e) )
+	ROM_LOAD16_BYTE( "i-scr2.10", 0x100000, 0x80000, CRC(d07ec0ce) SHA1(88997254ea2bffa83ab4a77087905cf646ee3c12) )
+	ROM_LOAD16_BYTE( "i-scr1.5",  0x100001, 0x80000, CRC(a96a8bde) SHA1(e93de2df1391a8e94d655e1c9e148196e692e661) )
+	ROM_LOAD16_BYTE( "i-scr4.9",  0x200000, 0x80000, CRC(e959cab5) SHA1(13d744aa71d9485a4530418536c38a542a269e27) )
+	ROM_LOAD16_BYTE( "i-scr3.4",  0x200001, 0x80000, CRC(4bf5e082) SHA1(14ab9ebe0c7a2154275b0aeb76f99d73552d862f) )
+	ROM_LOAD16_BYTE( "i-scr6.8",  0x300000, 0x80000, CRC(e71337c2) SHA1(be1b532e66e70f7d30b657a88c1f9b154187636e) )
+	ROM_LOAD16_BYTE( "i-scr5.3",  0x300001, 0x80000, CRC(641ccdfb) SHA1(f48dc0461bc49cfe4adcf769e9abfe83efa077a1) )
+	ROM_LOAD16_BYTE( "i-scr8.11", 0x400000, 0x80000, CRC(7c1813c8) SHA1(80fe97ac640847360529edfb728955e1067b0c14) )
+	ROM_LOAD16_BYTE( "i-scr7.6",  0x400001, 0x80000, CRC(19c73268) SHA1(aa6dc8c817a2e9707ea74e219ab34cf826223741) )
+
+	ROM_REGION( 0x80000, REGION_GFX1, ROMREGION_DISPOSE )	/* sprites */
+	ROM_LOAD( "obj1.13",  0x00000, 0x80000, CRC(832cd451) SHA1(29dfab1d4b7a15f3fe9fbedef41d405a40235a77) )
+
+	ROM_REGION( 0x140000, REGION_SOUND1, 0 )	/* OKIM6295 samples */
+	/* 00000-2ffff is fixed, 30000-3ffff is bank switched from all the ROMs */
+	ROM_LOAD( "music1.1", 0x00000, 0x80000, CRC(2b1f6655) SHA1(e7b52cf4bd16590c598c375d5a97b724bc9ef631) )
+	ROM_RELOAD(               0x40000, 0x80000 )
+	ROM_LOAD( "music2.2", 0xc0000, 0x80000, CRC(cccae65a) SHA1(5e4e2e51884eaf191f103aa189ff33371fc91d6d) )
+ROM_END
+
+GAME( 1990, galpanic, 0,        galpanic, galpanic, 0, ROT90, "Kaneko", "Gals Panic (set 1)", GAME_NO_COCKTAIL )
+GAME( 1990, galpanib, galpanic, galpanib, galpanib, 0, ROT90, "Kaneko", "Gals Panic (set 2)", GAME_NO_COCKTAIL )
+GAME( 1990, galpania, galpanic, galpania, galpanib, 0, ROT90, "Kaneko", "Gals Panic (set 3)", GAME_NO_COCKTAIL | GAME_IMPERFECT_GRAPHICS )
+GAME( 1994, fantasia, 0,        comad,    fantasia, 0, ROT90, "Comad & New Japan System", "Fantasia", GAME_NO_COCKTAIL )
+GAME( 1994, supmodel, 0,        supmodel, fantasia, 0, ROT90, "Comad & New Japan System", "Super Model",GAME_NO_COCKTAIL ) /* 'official' or hack of fantasia? */
+GAME( 1995, newfant,  0,        comad,    fantasia, 0, ROT90, "Comad & New Japan System", "New Fantasia", GAME_NO_COCKTAIL )
+GAME( 1995, fantsy95, 0,        comad,    fantasia, 0, ROT90, "Hi-max Technology Inc.", "Fantasy '95", GAME_NO_COCKTAIL )
+GAME( 1996, missw96,  0,        comad,    missw96,  0, ROT0,  "Comad", "Miss World '96 (Nude)", GAME_NO_COCKTAIL )
+GAME( 1996, missmw96, missw96,  comad,    missw96,  0, ROT0,  "Comad", "Miss Mister World '96 (Nude)", GAME_NO_COCKTAIL )
+GAME( 1997, fantsia2, 0,        fantsia2, missw96,  0, ROT0,  "Comad", "Fantasia II (Explicit)", GAME_NO_COCKTAIL )
+GAME( 1997, fntsia2a, fantsia2, fantsia2, missw96,  0, ROT0,  "Comad", "Fantasia II (Less Explicit)", GAME_NO_COCKTAIL )
+GAME( 1997, galhustl, 0,        galhustl, galhustl, 0, ROT0,  "ACE International", "Gals Hustler", 0 )
+GAME( 1995, zipzap,   0,        zipzap,   zipzap,   0, ROT90, "Barko Corp", "Zip & Zap", GAME_IMPERFECT_GRAPHICS|GAME_IMPERFECT_SOUND )
