@@ -182,7 +182,6 @@ TODO:
 ***************************************************************************/
 
 #include "driver.h"
-#include "vidhrdw/generic.h"
 #include "machine/tait8741.h"
 #include "cpu/z80/z80.h"
 #include "sound/2203intf.h"
@@ -265,7 +264,7 @@ static struct TAITO8741interface gsword_8741interface=
 	{gladiator_dsw1_r,gladiator_dsw2_r,gladiator_button3_r,gladiator_controll_r}	/* port handler */
 };
 
-static MACHINE_INIT( gladiator )
+static MACHINE_RESET( gladiator )
 {
 	TAITO8741_start(&gsword_8741interface);
 	/* 6809 bank memory set */
@@ -600,7 +599,7 @@ INPUT_PORTS_END
 
 /*******************************************************************/
 
-static gfx_layout charlayout  =
+static const gfx_layout charlayout  =
 {
 	8,8,
 	RGN_FRAC(1,1),
@@ -611,7 +610,7 @@ static gfx_layout charlayout  =
 	8*8
 };
 
-static gfx_layout tilelayout  =
+static const gfx_layout tilelayout  =
 {
 	8,8,
 	RGN_FRAC(1,2),
@@ -622,7 +621,7 @@ static gfx_layout tilelayout  =
 	16*8
 };
 
-static gfx_layout spritelayout  =
+static const gfx_layout spritelayout  =
 {
 	16,16,
 	RGN_FRAC(1,2),
@@ -635,7 +634,7 @@ static gfx_layout spritelayout  =
 	64*8
 };
 
-static gfx_decode ppking_gfxdecodeinfo[] =
+static const gfx_decode ppking_gfxdecodeinfo[] =
 {
 	{ REGION_GFX1, 0, &charlayout, 0, 1 },
 	{ REGION_GFX2, 0, &tilelayout, 0, 32 },
@@ -643,7 +642,7 @@ static gfx_decode ppking_gfxdecodeinfo[] =
 	{ -1 }
 };
 
-static gfx_decode gladiatr_gfxdecodeinfo[] =
+static const gfx_decode gladiatr_gfxdecodeinfo[] =
 {
 	{ REGION_GFX1, 0, &charlayout,   0x200, 1 },
 	{ REGION_GFX2, 0, &tilelayout,   0x000, 32 },
@@ -749,7 +748,7 @@ static MACHINE_DRIVER_START( gladiatr )
 	MDRV_VBLANK_DURATION(DEFAULT_60HZ_VBLANK_DURATION)
 	MDRV_INTERLEAVE(10)
 
-	MDRV_MACHINE_INIT(gladiator)
+	MDRV_MACHINE_RESET(gladiator)
 	MDRV_NVRAM_HANDLER(generic_0fill)
 
 	/* video hardware */
