@@ -5,13 +5,9 @@
     driver by Pierpaolo Prazzoli
     and some bits by David Haywood
 
-    TODO:
-    - Add ADPCM emulation
-
 ***************************************************************************/
 
 #include "driver.h"
-#include "vidhrdw/generic.h"
 #include "sound/2203intf.h"
 #include "sound/okim6295.h"
 #include "sound/msm5205.h"
@@ -24,8 +20,11 @@ extern READ16_HANDLER( goal92_fg_bank_r );
 
 extern VIDEO_START( goal92 );
 extern VIDEO_UPDATE( goal92 );
+extern VIDEO_EOF( goal92 );
 
-extern data16_t *goal92_back_data,*goal92_fore_data,*goal92_textram,*goal92_scrollram16;
+extern UINT16 *goal92_back_data,*goal92_fore_data,*goal92_textram,*goal92_scrollram16;
+
+static int msm5205next;
 
 static WRITE16_HANDLER( goal92_sound_command_w )
 {
@@ -85,10 +84,28 @@ ADDRESS_MAP_END
 
 /* Sound CPU */
 
+static WRITE8_HANDLER( adpcm_control_w )
+{
+	int bankaddress;
+	unsigned char *RAM = memory_region(REGION_CPU2);
+
+	/* the code writes either 2 or 3 in the bottom two bits */
+	bankaddress = 0x10000 + (data & 0x01) * 0x4000;
+	memory_set_bankptr(1,&RAM[bankaddress]);
+
+	MSM5205_reset_w(0,data & 0x08);
+}
+
+static WRITE8_HANDLER( adpcm_data_w )
+{
+	msm5205next = data;
+}
+
 static ADDRESS_MAP_START( sound_cpu, ADDRESS_SPACE_PROGRAM, 8 )
-	AM_RANGE(0x0000, 0xdfff) AM_ROM
-	AM_RANGE(0xe000, 0xe000) AM_WRITE(MWA8_NOP) /* adpcm write ? */
-	AM_RANGE(0xe400, 0xe400) AM_WRITE(MWA8_NOP) /* adpcm write ? */
+	AM_RANGE(0x0000, 0x7fff) AM_ROM
+	AM_RANGE(0x8000, 0xbfff) AM_ROMBANK(1)
+	AM_RANGE(0xe000, 0xe000) AM_WRITE(adpcm_control_w)
+	AM_RANGE(0xe400, 0xe400) AM_WRITE(adpcm_data_w)
 	AM_RANGE(0xe800, 0xe800) AM_READWRITE(YM2203_status_port_0_r, YM2203_control_port_0_w)
 	AM_RANGE(0xe801, 0xe801) AM_READWRITE(YM2203_read_port_0_r, YM2203_write_port_0_w)
 	AM_RANGE(0xec00, 0xec00) AM_READWRITE(YM2203_status_port_1_r, YM2203_control_port_1_w)
@@ -175,13 +192,13 @@ INPUT_PORTS_START( goal92 )
 	PORT_BIT( 0x0020, IP_ACTIVE_LOW,  IPT_BUTTON2 ) PORT_PLAYER(3)
 	PORT_BIT( 0x0040, IP_ACTIVE_LOW,  IPT_BUTTON3 ) PORT_PLAYER(3)
 	PORT_BIT( 0x0080, IP_ACTIVE_LOW,  IPT_COIN3 )
-	PORT_BIT( 0x0100, IP_ACTIVE_LOW,  IPT_JOYSTICK_UP ) PORT_8WAY PORT_PLAYER(3)
-	PORT_BIT( 0x0200, IP_ACTIVE_LOW,  IPT_JOYSTICK_DOWN ) PORT_8WAY PORT_PLAYER(3)
-	PORT_BIT( 0x0400, IP_ACTIVE_LOW,  IPT_JOYSTICK_LEFT ) PORT_8WAY PORT_PLAYER(3)
-	PORT_BIT( 0x0800, IP_ACTIVE_LOW,  IPT_JOYSTICK_RIGHT ) PORT_8WAY PORT_PLAYER(3)
-	PORT_BIT( 0x1000, IP_ACTIVE_LOW,  IPT_BUTTON1 ) PORT_PLAYER(3)
-	PORT_BIT( 0x2000, IP_ACTIVE_LOW,  IPT_BUTTON2 ) PORT_PLAYER(3)
-	PORT_BIT( 0x4000, IP_ACTIVE_LOW,  IPT_BUTTON3 ) PORT_PLAYER(3)
+	PORT_BIT( 0x0100, IP_ACTIVE_LOW,  IPT_JOYSTICK_UP ) PORT_8WAY PORT_PLAYER(4)
+	PORT_BIT( 0x0200, IP_ACTIVE_LOW,  IPT_JOYSTICK_DOWN ) PORT_8WAY PORT_PLAYER(4)
+	PORT_BIT( 0x0400, IP_ACTIVE_LOW,  IPT_JOYSTICK_LEFT ) PORT_8WAY PORT_PLAYER(4)
+	PORT_BIT( 0x0800, IP_ACTIVE_LOW,  IPT_JOYSTICK_RIGHT ) PORT_8WAY PORT_PLAYER(4)
+	PORT_BIT( 0x1000, IP_ACTIVE_LOW,  IPT_BUTTON1 ) PORT_PLAYER(4)
+	PORT_BIT( 0x2000, IP_ACTIVE_LOW,  IPT_BUTTON2 ) PORT_PLAYER(4)
+	PORT_BIT( 0x4000, IP_ACTIVE_LOW,  IPT_BUTTON3 ) PORT_PLAYER(4)
 	PORT_BIT( 0x8000, IP_ACTIVE_LOW,  IPT_COIN4 )
 
 	PORT_START_TAG("IN3")
@@ -231,7 +248,14 @@ static struct YM2203interface ym2203_interface =
 
 static void goal92_adpcm_int(int data)
 {
-	cpunum_set_input_line(1, INPUT_LINE_NMI, PULSE_LINE);
+	static int toggle = 0;
+
+	MSM5205_data_w (0,msm5205next);
+	msm5205next>>=4;
+
+	toggle ^= 1;
+	if(toggle)
+		cpunum_set_input_line(1, INPUT_LINE_NMI, PULSE_LINE);
 }
 
 static struct MSM5205interface msm5205_interface =
@@ -240,7 +264,7 @@ static struct MSM5205interface msm5205_interface =
 	MSM5205_S96_4B		/* 4KHz 4-bit */
 };
 
-static struct GfxLayout layout_8x8x4 =
+static const gfx_layout layout_8x8x4 =
 {
 	8,8,
 	RGN_FRAC(1,4),
@@ -251,7 +275,7 @@ static struct GfxLayout layout_8x8x4 =
 	8*8
 };
 
-static struct GfxLayout layout_16x16x4 =
+static const gfx_layout layout_16x16x4 =
 {
 	16,16,
 	RGN_FRAC(1,4),
@@ -262,7 +286,7 @@ static struct GfxLayout layout_16x16x4 =
 	16*16
 };
 
-static struct GfxLayout layout_16x16x4_2 =
+static const gfx_layout layout_16x16x4_2 =
 {
 	16,16,
 	RGN_FRAC(1,1),
@@ -275,7 +299,7 @@ static struct GfxLayout layout_16x16x4_2 =
 	1024
 };
 
-static struct GfxDecodeInfo goal92_gfxdecodeinfo[] =
+static const gfx_decode goal92_gfxdecodeinfo[] =
 {
 	{ REGION_GFX1, 0, &layout_16x16x4,		   0*16, 8*16 }, /* Sprites */
 	{ REGION_GFX2, 0, &layout_8x8x4,		  48*16,   16 }, /* Text Layer */
@@ -285,7 +309,7 @@ static struct GfxDecodeInfo goal92_gfxdecodeinfo[] =
 	{ -1 } /* end of array */
 };
 
-static struct GfxDecodeInfo cupsocbl_gfxdecodeinfo[] =
+static const gfx_decode cupsocbl_gfxdecodeinfo[] =
 {
 	{ REGION_GFX1, 0, &layout_16x16x4_2,	   0*16, 8*16 }, /* Sprites */
 	{ REGION_GFX2, 0, &layout_8x8x4,	      48*16,   16 }, /* Text Layer */
@@ -319,6 +343,7 @@ static MACHINE_DRIVER_START( goal92 )
 
 	MDRV_VIDEO_START(goal92)
 	MDRV_VIDEO_UPDATE(goal92)
+	MDRV_VIDEO_EOF(goal92)
 
 	/* sound hardware */
 	MDRV_SPEAKER_STANDARD_MONO("mono")
@@ -330,9 +355,9 @@ static MACHINE_DRIVER_START( goal92 )
 	MDRV_SOUND_ADD(YM2203, 2500000/2)
 	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.25)
 
-	MDRV_SOUND_ADD(MSM5205, 400000)
+	MDRV_SOUND_ADD(MSM5205, 384000)
 	MDRV_SOUND_CONFIG(msm5205_interface)
-	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.25)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.60)
 MACHINE_DRIVER_END
 
 static MACHINE_DRIVER_START( cupsocbl )
@@ -412,8 +437,9 @@ ROM_START( goal92 )
 	ROM_LOAD16_BYTE( "2.bin", 0x00000, 0x80000, CRC(db0a6c7c) SHA1(b609db7806b99bc921806d8b3e5e515b4651c375) )
 	ROM_LOAD16_BYTE( "3.bin", 0x00001, 0x80000, CRC(e4c45dee) SHA1(542749bd1ff51220a151fe66acdadac83df8f0ee) )
 
-	ROM_REGION( 0x10000, REGION_CPU2, 0 )	/* Z80 code */
-	ROM_LOAD( "1.bin",        0x00000, 0x10000, CRC(3d317622) SHA1(ae4e8c5247bc215a2769786cb8639bce2f80db22) )
+	ROM_REGION( 0x18000, REGION_CPU2, 0 )	/* Z80 code */
+	ROM_LOAD( "1.bin",        0x00000, 0x8000, CRC(3d317622) SHA1(ae4e8c5247bc215a2769786cb8639bce2f80db22) )
+	ROM_CONTINUE(             0x10000, 0x8000 ) /* banked at 8000-bfff */
 
 	ROM_REGION( 0x100000, REGION_GFX1, ROMREGION_DISPOSE )
 	ROM_LOAD( "6.bin",        0x000000, 0x040000, CRC(83cadc8f) SHA1(1d3309750347c5d6d661f5cf452235e5a83a7483) )
@@ -492,5 +518,5 @@ ROM_START( cupsocbl )
 	ROM_LOAD( "sc_03.bin",    0x000000, 0x080000, CRC(6e254d12) SHA1(857779dbd276b688201a8ea3afd5817e38acad2e) )
 ROM_END
 
-GAMEX( 1992, goal92,   cupsoc, goal92,   goal92, 0, ROT0, "bootleg", "Goal! '92", GAME_IMPERFECT_SOUND )
-GAMEX( 1992, cupsocbl, cupsoc, cupsocbl, goal92, 0, ROT0, "bootleg", "Seibu Cup Soccer (bootleg)", GAME_NOT_WORKING | GAME_NO_SOUND )
+GAME( 1992, goal92,   cupsoc, goal92,   goal92, 0, ROT0, "bootleg", "Goal! '92", GAME_IMPERFECT_SOUND )
+GAME( 1992, cupsocbl, cupsoc, cupsocbl, goal92, 0, ROT0, "bootleg", "Seibu Cup Soccer (bootleg)", GAME_NOT_WORKING | GAME_NO_SOUND )
