@@ -18,7 +18,6 @@ Notes:
 ***************************************************************************/
 
 #include "driver.h"
-#include "vidhrdw/generic.h"
 #include "sound/2203intf.h"
 
 VIDEO_START( goindol );
@@ -30,8 +29,6 @@ extern UINT8 *goindol_fg_scrollx;
 extern UINT8 *goindol_fg_scrolly;
 extern UINT8 *goindol_fg_videoram;
 extern UINT8 *goindol_bg_videoram;
-extern UINT8 *spriteram_1;
-extern UINT8 *spriteram_2;
 extern size_t goindol_fg_videoram_size;
 extern size_t goindol_bg_videoram_size;
 extern int goindol_char_bank;
@@ -252,7 +249,7 @@ GOINDOL_DSW1
 INPUT_PORTS_END
 
 
-static gfx_layout charlayout =
+static const gfx_layout charlayout =
 {
 	8,8,
 	RGN_FRAC(1,3),
@@ -263,7 +260,7 @@ static gfx_layout charlayout =
 	8*8
 };
 
-static gfx_decode gfxdecodeinfo[] =
+static const gfx_decode gfxdecodeinfo[] =
 {
 	{ REGION_GFX1, 0, &charlayout, 0, 32 },
 	{ REGION_GFX2, 0, &charlayout, 0, 32 },
