@@ -16,7 +16,6 @@ konamiic.c. They don't seem to be used by this game.
 ***************************************************************************/
 
 #include "driver.h"
-#include "vidhrdw/generic.h"
 #include "vidhrdw/konamiic.h"
 #include "cpu/m68000/m68000.h"
 #include "cpu/z80/z80.h"
@@ -24,7 +23,7 @@ konamiic.c. They don't seem to be used by this game.
 #include "sound/k007232.h"
 
 
-extern data16_t *gradius3_gfxram;
+extern UINT16 *gradius3_gfxram;
 extern int gradius3_priority;
 VIDEO_START( gradius3 );
 READ16_HANDLER( gradius3_gfxrom_r );
@@ -77,7 +76,7 @@ static WRITE16_HANDLER( K051960_halfword_w )
 static int irqAen,irqBmask;
 
 
-static MACHINE_INIT( gradius3 )
+static MACHINE_RESET( gradius3 )
 {
 	/* start with cpu B halted */
 	cpunum_set_input_line(1, INPUT_LINE_RESET, ASSERT_LINE);
@@ -85,7 +84,7 @@ static MACHINE_INIT( gradius3 )
 	irqBmask = 0;
 }
 
-static data16_t *sharedram;
+static UINT16 *sharedram;
 
 static READ16_HANDLER( sharedram_r )
 {
@@ -269,9 +268,9 @@ INPUT_PORTS_START( gradius3 )
 	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_JOYSTICK_RIGHT ) PORT_8WAY
 	PORT_BIT( 0x04, IP_ACTIVE_LOW, IPT_JOYSTICK_UP ) PORT_8WAY
 	PORT_BIT( 0x08, IP_ACTIVE_LOW, IPT_JOYSTICK_DOWN ) PORT_8WAY
-	PORT_BIT( 0x10, IP_ACTIVE_LOW, IPT_BUTTON3 )
-	PORT_BIT( 0x20, IP_ACTIVE_LOW, IPT_BUTTON1 )
-	PORT_BIT( 0x40, IP_ACTIVE_LOW, IPT_BUTTON2 )
+	PORT_BIT( 0x10, IP_ACTIVE_LOW, IPT_BUTTON1 )	/* power-up */
+	PORT_BIT( 0x20, IP_ACTIVE_LOW, IPT_BUTTON2 )	/* shoot */
+	PORT_BIT( 0x40, IP_ACTIVE_LOW, IPT_BUTTON3 )	/* missile */
 	PORT_BIT( 0x80, IP_ACTIVE_LOW, IPT_UNKNOWN )
 
 	PORT_START      /* PLAYER 2 */
@@ -279,9 +278,9 @@ INPUT_PORTS_START( gradius3 )
 	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_JOYSTICK_RIGHT ) PORT_8WAY PORT_COCKTAIL
 	PORT_BIT( 0x04, IP_ACTIVE_LOW, IPT_JOYSTICK_UP ) PORT_8WAY PORT_COCKTAIL
 	PORT_BIT( 0x08, IP_ACTIVE_LOW, IPT_JOYSTICK_DOWN ) PORT_8WAY PORT_COCKTAIL
-	PORT_BIT( 0x10, IP_ACTIVE_LOW, IPT_BUTTON3 ) PORT_COCKTAIL
-	PORT_BIT( 0x20, IP_ACTIVE_LOW, IPT_BUTTON1 ) PORT_COCKTAIL
-	PORT_BIT( 0x40, IP_ACTIVE_LOW, IPT_BUTTON2 ) PORT_COCKTAIL
+	PORT_BIT( 0x10, IP_ACTIVE_LOW, IPT_BUTTON1 ) PORT_COCKTAIL
+	PORT_BIT( 0x20, IP_ACTIVE_LOW, IPT_BUTTON2 ) PORT_COCKTAIL
+	PORT_BIT( 0x40, IP_ACTIVE_LOW, IPT_BUTTON3 ) PORT_COCKTAIL
 	PORT_BIT( 0x80, IP_ACTIVE_LOW, IPT_UNKNOWN )
 
 	PORT_START	/* DSW1 */
@@ -393,7 +392,7 @@ static MACHINE_DRIVER_START( gradius3 )
 	MDRV_VBLANK_DURATION(DEFAULT_60HZ_VBLANK_DURATION)
 	MDRV_INTERLEAVE(100)
 
-	MDRV_MACHINE_INIT(gradius3)
+	MDRV_MACHINE_RESET(gradius3)
 
 	/* video hardware */
 	MDRV_VIDEO_ATTRIBUTES(VIDEO_TYPE_RASTER | VIDEO_HAS_SHADOWS)
@@ -445,7 +444,7 @@ ROM_START( gradius3 )
 	ROM_REGION( 0x10000, REGION_CPU3, 0 )	/* 64k for the audio CPU */
 	ROM_LOAD( "945_m05.d9",				0x00000, 0x10000, CRC(c8c45365) SHA1(b9a7b736b52bca42c7b8c8ed64c8df73e0116158) )
 
-	ROM_REGION( 0x20000, REGION_GFX1, 0 )	/* fake */
+	ROM_REGION( 0x20000, REGION_GFX1, ROMREGION_ERASE00 )	/* fake */
 	/* gfx data is dynamically generated in RAM */
 
 	ROM_REGION( 0x200000, REGION_GFX2, 0 )	/* graphics (addressable by the main CPU) */
@@ -487,7 +486,7 @@ ROM_START( grdius3a )
 	ROM_REGION( 0x10000, REGION_CPU3, 0 )	/* 64k for the audio CPU */
 	ROM_LOAD( "945_m05.d9",				0x00000, 0x10000, CRC(c8c45365) SHA1(b9a7b736b52bca42c7b8c8ed64c8df73e0116158) )
 
-	ROM_REGION( 0x20000, REGION_GFX1, 0 )	/* fake */
+	ROM_REGION( 0x20000, REGION_GFX1, ROMREGION_ERASE00 )	/* fake */
 	/* gfx data is dynamically generated in RAM */
 
 	ROM_REGION( 0x200000, REGION_GFX2, 0 )	/* graphics (addressable by the main CPU) */
@@ -529,7 +528,7 @@ ROM_START( grdius3e )
 	ROM_REGION( 0x10000, REGION_CPU3, 0 )	/* 64k for the audio CPU */
 	ROM_LOAD( "945_m05.d9",				0x00000, 0x10000, CRC(c8c45365) SHA1(b9a7b736b52bca42c7b8c8ed64c8df73e0116158) ) /* 945_r05.d9 */
 
-	ROM_REGION( 0x20000, REGION_GFX1, 0 )	/* fake */
+	ROM_REGION( 0x20000, REGION_GFX1, ROMREGION_ERASE00 )	/* fake */
 	/* gfx data is dynamically generated in RAM */
 
 	ROM_REGION( 0x200000, REGION_GFX2, 0 )	/* graphics (addressable by the main CPU) */
@@ -561,6 +560,6 @@ static DRIVER_INIT( gradius3 )
 
 
 
-GAME( 1989, gradius3, 0,        gradius3, gradius3, gradius3, ROT0, "Konami", "Gradius III (Japan)" )
-GAME( 1989, grdius3a, gradius3, gradius3, gradius3, gradius3, ROT0, "Konami", "Gradius III (Asia)" )
-GAME( 1989, grdius3e, gradius3, gradius3, gradius3, gradius3, ROT0, "Konami", "Gradius III (World ?)" )
+GAME( 1989, gradius3, 0,        gradius3, gradius3, gradius3, ROT0, "Konami", "Gradius III (Japan)", 0 )
+GAME( 1989, grdius3a, gradius3, gradius3, gradius3, gradius3, ROT0, "Konami", "Gradius III (Asia)", 0 )
+GAME( 1989, grdius3e, gradius3, gradius3, gradius3, gradius3, ROT0, "Konami", "Gradius III (World ?)", 0 )
