@@ -231,7 +231,7 @@ static WRITE8_HANDLER( gs_sh_bankswitch_w )
 
 /*** GFX DECODE **************************************************************/
 
-static gfx_layout gs_8x8x4_layout =
+static const gfx_layout gs_8x8x4_layout =
 {
 	8,8,
 	RGN_FRAC(1,1),
@@ -243,7 +243,7 @@ static gfx_layout gs_8x8x4_layout =
 };
 
 
-static gfx_layout gs_16x16x4_layout =
+static const gfx_layout gs_16x16x4_layout =
 {
 	16,16,
 	RGN_FRAC(1,1),
@@ -259,7 +259,7 @@ static gfx_layout gs_16x16x4_layout =
 	16*64
 };
 
-static gfx_decode gfxdecodeinfo[] =
+static const gfx_decode gfxdecodeinfo[] =
 {
 	{ REGION_GFX1, 0, &gs_8x8x4_layout,     0, 256 },
 	{ REGION_GFX2, 0, &gs_16x16x4_layout,   0, 256 },
@@ -477,7 +477,7 @@ MACHINE_DRIVER_END
 /*** ROM LOADING *************************************************************/
 
 ROM_START( gstriker )
-	ROM_REGION( 0x80000, REGION_CPU1, 0 )
+	ROM_REGION( 0x100000, REGION_CPU1, 0 )
 	ROM_LOAD16_WORD_SWAP( "human-1.u58",  0x00000, 0x80000, CRC(45cf4857) SHA1(8133a9a7bdd547cc3d69140a68a1a5a7341e9f5b) )
 
 	ROM_REGION( 0x40000, REGION_CPU2, 0 )
@@ -506,7 +506,7 @@ ROM_START( gstriker )
 ROM_END
 
 ROM_START( vgoalsoc )
-	ROM_REGION( 0x80000, REGION_CPU1, 0 )
+	ROM_REGION( 0x100000, REGION_CPU1, 0 )
 	ROM_LOAD16_WORD_SWAP( "c16_u37.u37",  0x00000, 0x80000, CRC(18c05440) SHA1(0fc78ee0ba6d7817d4a93a80f668f193c352c00d) )
 
 	ROM_REGION( 0x40000, REGION_CPU2, 0 )
@@ -531,7 +531,7 @@ ROM_START( vgoalsoc )
 ROM_END
 
 ROM_START( vgoalsca )
-	ROM_REGION( 0x80000, REGION_CPU1, 0 )
+	ROM_REGION( 0x100000, REGION_CPU1, 0 )
 	ROM_LOAD16_WORD_SWAP( "vgoalc16.u37", 0x00000, 0x80000, CRC(775ef300) SHA1(d0ab1c13a19ce646c6edfc25a0c0994989560cbc) )
 
 	ROM_REGION( 0x40000, REGION_CPU2, 0 )
@@ -556,7 +556,7 @@ ROM_START( vgoalsca )
 ROM_END
 
 ROM_START( twrldc94 )
-	ROM_REGION( 0x80000, REGION_CPU1, 0 )
+	ROM_REGION( 0x100000, REGION_CPU1, 0 )
 	ROM_LOAD16_WORD_SWAP( "13.u37",           0x00000, 0x80000, CRC(42adb463) SHA1(ec7bcb684489b56f81ab851a9d8f42d54679363b) )
 
 	ROM_REGION( 0x40000, REGION_CPU2, 0 )
@@ -583,7 +583,7 @@ ROM_START( twrldc94 )
 ROM_END
 
 ROM_START( twrdc94a )
-	ROM_REGION( 0x80000, REGION_CPU1, 0 )
+	ROM_REGION( 0x100000, REGION_CPU1, 0 )
 	ROM_LOAD16_WORD_SWAP( "twrdc94a_13.u37",           0x00000, 0x80000, CRC(08f314ee) SHA1(3fca5050f5bcd60533d3bd9dea81ba631a98bfd6) )
 
 	ROM_REGION( 0x40000, REGION_CPU2, 0 )
