@@ -11,7 +11,6 @@ TODO:
 */
 
 #include "driver.h"
-#include "vidhrdw/generic.h"
 #include "sound/ay8910.h"
 
 /* vidhrdw */
@@ -42,7 +41,7 @@ VIDEO_START(hanaroku)
 	return 0;
 }
 
-static void hanaroku_draw_sprites( struct mame_bitmap *bitmap, const struct rectangle *cliprect )
+static void hanaroku_draw_sprites( mame_bitmap *bitmap, const rectangle *cliprect )
 {
 	int i;
 
@@ -208,7 +207,7 @@ INPUT_PORTS_START( hanaroku )
 INPUT_PORTS_END
 
 
-static struct GfxLayout hanaroku_charlayout =
+static const gfx_layout hanaroku_charlayout =
 {
 	16,16,
 	RGN_FRAC(1,4),
@@ -223,7 +222,7 @@ static struct GfxLayout hanaroku_charlayout =
 
 
 
-static struct GfxDecodeInfo gfxdecodeinfo[] =
+static const gfx_decode gfxdecodeinfo[] =
 {
 	{ REGION_GFX1, 0, &hanaroku_charlayout,   0, 32  },
 
@@ -282,4 +281,4 @@ ROM_START( hanaroku )
 ROM_END
 
 
-GAMEX( 1988, hanaroku, 0,        hanaroku, hanaroku, 0, ROT0, "Alba", "Hanaroku", GAME_NO_COCKTAIL | GAME_IMPERFECT_GRAPHICS | GAME_IMPERFECT_COLORS )
+GAME( 1988, hanaroku, 0,        hanaroku, hanaroku, 0, ROT0, "Alba", "Hanaroku", GAME_NO_COCKTAIL | GAME_IMPERFECT_GRAPHICS | GAME_IMPERFECT_COLORS )
