@@ -7,7 +7,6 @@
 ***************************************************************************/
 
 #include "driver.h"
-#include "vidhrdw/generic.h"
 #include "cpu/konami/konami.h"
 #include "cpu/z80/z80.h"
 #include "sound/3812intf.h"
@@ -47,23 +46,6 @@ static WRITE8_HANDLER( hcastle_coin_w )
 	coin_counter_w(1,data & 0x80);
 }
 
-static READ8_HANDLER( speedup_r )
-{
-	unsigned char *RAM = memory_region(REGION_CPU1);
-
-	int data = ( RAM[0x18dc] << 8 ) | RAM[0x18dd];
-
-	if ( data < memory_region_length(REGION_CPU1) )
-	{
-		data = ( RAM[data] << 8 ) | RAM[data + 1];
-
-		if ( data == 0xffff )
-			cpu_spinuntil_int();
-	}
-
-	return RAM[0x18dc];
-}
-
 
 
 static ADDRESS_MAP_START( readmem, ADDRESS_SPACE_PROGRAM, 8 )
@@ -77,7 +59,6 @@ static ADDRESS_MAP_START( readmem, ADDRESS_SPACE_PROGRAM, 8 )
 	AM_RANGE(0x0415, 0x0415) AM_READ(input_port_3_r) /* Dip 1 */
 	AM_RANGE(0x0418, 0x0418) AM_READ(hcastle_gfxbank_r)
 	AM_RANGE(0x0600, 0x06ff) AM_READ(paletteram_r)
-	AM_RANGE(0x18dc, 0x18dc) AM_READ(speedup_r)
 	AM_RANGE(0x0700, 0x5fff) AM_READ(MRA8_RAM)
 	AM_RANGE(0x6000, 0x7fff) AM_READ(MRA8_BANK1)
 	AM_RANGE(0x8000, 0xffff) AM_READ(MRA8_ROM)
@@ -94,7 +75,7 @@ static ADDRESS_MAP_START( writemem, ADDRESS_SPACE_PROGRAM, 8 )
 	AM_RANGE(0x040c, 0x040c) AM_WRITE(watchdog_reset_w)
 	AM_RANGE(0x0410, 0x0410) AM_WRITE(hcastle_coin_w)
 	AM_RANGE(0x0418, 0x0418) AM_WRITE(hcastle_gfxbank_w)
-	AM_RANGE(0x0600, 0x06ff) AM_WRITE(paletteram_xBBBBBGGGGGRRRRR_swap_w) AM_BASE(&paletteram)
+	AM_RANGE(0x0600, 0x06ff) AM_WRITE(paletteram_xBBBBBGGGGGRRRRR_be_w) AM_BASE(&paletteram)
 	AM_RANGE(0x0700, 0x1fff) AM_WRITE(MWA8_RAM)
 	AM_RANGE(0x2000, 0x2fff) AM_WRITE(hcastle_pf1_video_w) AM_BASE(&hcastle_pf1_videoram)
 	AM_RANGE(0x3000, 0x3fff) AM_WRITE(MWA8_RAM) AM_BASE(&spriteram) AM_SIZE(&spriteram_size)
@@ -242,7 +223,7 @@ INPUT_PORTS_END
 
 /*****************************************************************************/
 
-static gfx_layout charlayout =
+static const gfx_layout charlayout =
 {
 	8,8,
 	32768,
@@ -253,7 +234,7 @@ static gfx_layout charlayout =
 	32*8
 };
 
-static gfx_decode gfxdecodeinfo[] =
+static const gfx_decode gfxdecodeinfo[] =
 {
 	{ REGION_GFX1, 0, &charlayout,       0, 8*16 },	/* 007121 #0 */
 	{ REGION_GFX2, 0, &charlayout, 8*16*16, 8*16 },	/* 007121 #1 */
