@@ -93,7 +93,7 @@ static WRITE8_HANDLER( adpcm_reset_inv_w )
 	MSM5205_reset_w(0,~data & 1);
 }
 
-static MACHINE_INIT( hnayayoi )
+static MACHINE_RESET( hnayayoi )
 {
 	/* start with the MSM5205 reset */
 	MSM5205_reset_w(0,1);
@@ -597,7 +597,7 @@ INPUT_PORTS_END
 
 static void irqhandler(int irq)
 {
-usrintf_showmessage("irq");
+ui_popup("irq");
 /*  cpunum_set_input_line(2,0,irq ? ASSERT_LINE : CLEAR_LINE); */
 }
 
@@ -625,11 +625,11 @@ static MACHINE_DRIVER_START( hnayayoi )
 	MDRV_CPU_PROGRAM_MAP(hnayayoi_readmem,hnayayoi_writemem)
 	MDRV_CPU_IO_MAP(hnayayoi_readport,hnayayoi_writeport)
 	MDRV_CPU_VBLANK_INT(irq0_line_hold,1)
-	MDRV_CPU_PERIODIC_INT(nmi_line_pulse,8000)
+	MDRV_CPU_PERIODIC_INT(nmi_line_pulse,TIME_IN_HZ(8000))
 
 	MDRV_FRAMES_PER_SECOND(60)
 	MDRV_VBLANK_DURATION(DEFAULT_REAL_60HZ_VBLANK_DURATION)
-	MDRV_MACHINE_INIT(hnayayoi)
+	MDRV_MACHINE_RESET(hnayayoi)
 
 	MDRV_NVRAM_HANDLER(generic_0fill)
 
@@ -766,6 +766,6 @@ static DRIVER_INIT( hnfubuki )
 }
 
 
-GAME( 1987, hnayayoi, 0,        hnayayoi, hnayayoi, 0,        ROT0, "Dyna Electronics", "Hana Yayoi (Japan)" )
-GAME( 1987, hnfubuki, hnayayoi, hnfubuki, hnfubuki, hnfubuki, ROT0, "Dynax", "Hana Fubuki [BET] (Japan)" )
-GAME( 1987, untoucha, 0,        untoucha, untoucha, 0,        ROT0, "Dynax", "Untouchable (Japan)" )
+GAME( 1987, hnayayoi, 0,        hnayayoi, hnayayoi, 0,        ROT0, "Dyna Electronics", "Hana Yayoi (Japan)", 0 )
+GAME( 1987, hnfubuki, hnayayoi, hnfubuki, hnfubuki, hnfubuki, ROT0, "Dynax", "Hana Fubuki [BET] (Japan)", 0 )
+GAME( 1987, untoucha, 0,        untoucha, untoucha, 0,        ROT0, "Dynax", "Untouchable (Japan)", 0 )
