@@ -217,7 +217,6 @@ Custom: GX61A01
 ***************************************************************************/
 
 #include "driver.h"
-#include "vidhrdw/generic.h"
 #include "cpu/m6809/m6809.h"
 #include "cpu/upd7810/upd7810.h"
 #include "homedata.h"
@@ -389,7 +388,7 @@ static WRITE8_HANDLER( reikaids_upd7807_portc_w )
 	upd7807_portc = data;
 }
 
-static MACHINE_INIT( reikaids_upd7807 )
+static MACHINE_RESET( reikaids_upd7807 )
 {
 	/* on reset, ports are set as input (high impedance), therefore 0xff output */
 	reikaids_which=homedata_priority;
@@ -534,7 +533,7 @@ static WRITE8_HANDLER( pteacher_upd7807_portc_w )
 	upd7807_portc = data;
 }
 
-static MACHINE_INIT( pteacher_upd7807 )
+static MACHINE_RESET( pteacher_upd7807 )
 {
 	/* on reset, ports are set as input (high impedance), therefore 0xff output */
 	pteacher_upd7807_portc_w(0,0xff);
@@ -1178,7 +1177,7 @@ INPUT_PORTS_END
 /**************************************************************************/
 
 
-static gfx_layout char_layout =
+static const gfx_layout char_layout =
 {
 	8,8,
 	RGN_FRAC(1,1),
@@ -1189,14 +1188,14 @@ static gfx_layout char_layout =
 	32*8
 };
 
-static gfx_decode mrokumei_gfxdecodeinfo[] =
+static const gfx_decode mrokumei_gfxdecodeinfo[] =
 {
 	{ REGION_GFX1, 0, &char_layout, 0x6000, 0x100 },
 	{ REGION_GFX2, 0, &char_layout, 0x7000, 0x100 },
 	{ -1 }
 };
 
-static gfx_layout tile_layout =
+static const gfx_layout tile_layout =
 {
 	8,8,
 	RGN_FRAC(1,1),
@@ -1207,7 +1206,7 @@ static gfx_layout tile_layout =
 	64*8
 };
 
-static gfx_decode reikaids_gfxdecodeinfo[] =
+static const gfx_decode reikaids_gfxdecodeinfo[] =
 {
 	{ REGION_GFX1, 0, &tile_layout, 0x6000, 0x20 },
 	{ REGION_GFX2, 0, &tile_layout, 0x4000, 0x20 },
@@ -1216,14 +1215,14 @@ static gfx_decode reikaids_gfxdecodeinfo[] =
 	{ -1 }
 };
 
-static gfx_decode pteacher_gfxdecodeinfo[] =
+static const gfx_decode pteacher_gfxdecodeinfo[] =
 {
 	{ REGION_GFX1, 0, &tile_layout, 0x0000, 0x40 },
 	{ REGION_GFX2, 0, &tile_layout, 0x4000, 0x40 },
 	{ -1 }
 };
 
-static gfx_layout tile_layout_4bpp_hi =
+static const gfx_layout tile_layout_4bpp_hi =
 {
 	8,8,
 	RGN_FRAC(1,1),
@@ -1234,7 +1233,7 @@ static gfx_layout tile_layout_4bpp_hi =
 	64*8
 };
 
-static gfx_layout tile_layout_4bpp_lo =
+static const gfx_layout tile_layout_4bpp_lo =
 {
 	8,8,
 	RGN_FRAC(1,1),
@@ -1245,7 +1244,7 @@ static gfx_layout tile_layout_4bpp_lo =
 	64*8
 };
 
-static gfx_decode lemnangl_gfxdecodeinfo[] =
+static const gfx_decode lemnangl_gfxdecodeinfo[] =
 {
 	{ REGION_GFX1, 0, &tile_layout_4bpp_hi, 0x0000, 0x200 },
 	{ REGION_GFX1, 0, &tile_layout_4bpp_lo, 0x2000, 0x200 },
@@ -1330,7 +1329,7 @@ static MACHINE_DRIVER_START( reikaids )
 	MDRV_FRAMES_PER_SECOND(59)
 	MDRV_VBLANK_DURATION(DEFAULT_60HZ_VBLANK_DURATION)
 
-	MDRV_MACHINE_INIT(reikaids_upd7807)
+	MDRV_MACHINE_RESET(reikaids_upd7807)
 
 	/* video hardware */
 	MDRV_VIDEO_ATTRIBUTES(VIDEO_TYPE_RASTER)
@@ -1379,7 +1378,7 @@ static MACHINE_DRIVER_START( pteacher )
 	MDRV_FRAMES_PER_SECOND(59)
 	MDRV_VBLANK_DURATION(DEFAULT_60HZ_VBLANK_DURATION)
 
-	MDRV_MACHINE_INIT(pteacher_upd7807)
+	MDRV_MACHINE_RESET(pteacher_upd7807)
 
 	/* video hardware */
 	MDRV_VIDEO_ATTRIBUTES(VIDEO_TYPE_RASTER)
