@@ -44,8 +44,8 @@ so it could be by them instead
 #include "driver.h"
 #include "sound/ay8910.h"
 
-static data8_t *hotblock_ram;
-static data8_t *hotblock_pal;
+static UINT8 *hotblock_ram;
+static UINT8 *hotblock_pal;
 static int hotblock_port0;
 static int hotblock_port4;
 
@@ -74,7 +74,7 @@ static READ8_HANDLER( hotblock_port4_r )
 static WRITE8_HANDLER( hotblock_port4_w )
 {
 /*  printf("port4_w: pc = %06x : data %04x\n",activecpu_get_pc(),data); */
-/*  usrintf_showmessage("port4_w: pc = %06x : data %04x",activecpu_get_pc(),data); */
+/*  ui_popup("port4_w: pc = %06x : data %04x",activecpu_get_pc(),data); */
 	hotblock_port4=data;
 }
 
@@ -82,7 +82,7 @@ static WRITE8_HANDLER( hotblock_port4_w )
 
 WRITE8_HANDLER( hotblock_port0_w )
 {
-/*  usrintf_showmessage("port4_w: pc = %06x : data %04x",activecpu_get_pc(),data); */
+/*  ui_popup("port4_w: pc = %06x : data %04x",activecpu_get_pc(),data); */
 	hotblock_port0=data;
 }
 
@@ -221,4 +221,4 @@ ROM_START( hotblock )
 	ROM_LOAD( "hotblk6.ic5", 0x080000, 0x080000, CRC(3176d231) SHA1(ac22fd0e9820c6714f51a3d8315eb5d43ef91eeb) )
 ROM_END
 
-GAME( 1993, hotblock, 0,        hotblock, hotblock, 0, ROT0,  "Nics? / Nix?", "Hot Blocks - Tetrix II" )
+GAME( 1993, hotblock, 0,        hotblock, hotblock, 0, ROT0,  "Nics? / Nix?", "Hot Blocks - Tetrix II", 0 )
