@@ -5,7 +5,6 @@ Based on drivers from Juno First emulator by Chris Hardy (chrish@kcbbs.gen.nz)
 ***************************************************************************/
 
 #include "driver.h"
-#include "vidhrdw/generic.h"
 #include "cpu/m6809/m6809.h"
 #include "sound/vlm5030.h"
 #include "sound/dac.h"
@@ -390,7 +389,7 @@ INPUT_PORTS_END
 
 
 
-static gfx_layout hyperspt_charlayout =
+static const gfx_layout hyperspt_charlayout =
 {
 	8,8,	/* 8*8 sprites */
 	1024,	/* 1024 characters */
@@ -401,7 +400,7 @@ static gfx_layout hyperspt_charlayout =
 	16*8	/* every sprite takes 64 consecutive bytes */
 };
 
-static gfx_layout hyperspt_spritelayout =
+static const gfx_layout hyperspt_spritelayout =
 {
 	16,16,	/* 16*16 sprites */
 	512,	/* 512 sprites */
@@ -414,7 +413,7 @@ static gfx_layout hyperspt_spritelayout =
 	64*8	/* every sprite takes 64 consecutive bytes */
 };
 
-static gfx_decode hyperspt_gfxdecodeinfo[] =
+static const gfx_decode hyperspt_gfxdecodeinfo[] =
 {
 	{ REGION_GFX1, 0, &hyperspt_charlayout, 	  0, 16 },
 	{ REGION_GFX2, 0, &hyperspt_spritelayout, 16*16, 16 },
@@ -422,7 +421,7 @@ static gfx_decode hyperspt_gfxdecodeinfo[] =
 };
 
 
-static gfx_layout roadf_charlayout =
+static const gfx_layout roadf_charlayout =
 {
 	8,8,	/* 8*8 sprites */
 	1536,	/* 1536 characters */
@@ -433,7 +432,7 @@ static gfx_layout roadf_charlayout =
 	16*8	/* every sprite takes 64 consecutive bytes */
 };
 
-static gfx_layout roadf_spritelayout =
+static const gfx_layout roadf_spritelayout =
 {
 	16,16,	/* 16*16 sprites */
 	256,	/* 256 sprites */
@@ -446,7 +445,7 @@ static gfx_layout roadf_spritelayout =
 	64*8	/* every sprite takes 64 consecutive bytes */
 };
 
-static gfx_decode roadf_gfxdecodeinfo[] =
+static const gfx_decode roadf_gfxdecodeinfo[] =
 {
 	{ REGION_GFX1, 0, &roadf_charlayout,	   0, 16 },
 	{ REGION_GFX2, 0, &roadf_spritelayout, 16*16, 16 },
@@ -520,7 +519,7 @@ MACHINE_DRIVER_END
 ***************************************************************************/
 
 ROM_START( hyperspt )
-	ROM_REGION( 2*0x10000, REGION_CPU1, 0 )	 /* 64k for code + 64k for decrypted opcodes */
+	ROM_REGION( 0x10000, REGION_CPU1, 0 )	 /* 64k for code */
 	ROM_LOAD( "c01",          0x4000, 0x2000, CRC(0c720eeb) SHA1(cc0719db7e59c72e603ab2ca42565303bc41d281) )
 	ROM_LOAD( "c02",          0x6000, 0x2000, CRC(560258e0) SHA1(788d0d3cbbd97fb54eceb3281ccf84a31e5e3e98) )
 	ROM_LOAD( "c03",          0x8000, 0x2000, CRC(9b01c7e6) SHA1(0106f94b38ad62e7514e56aab35581968074bbe0) )
@@ -558,7 +557,7 @@ ROM_START( hyperspt )
 ROM_END
 
 ROM_START( hpolym84 )
-	ROM_REGION( 2*0x10000, REGION_CPU1, 0 )	 /* 64k for code + 64k for decrypted opcodes */
+	ROM_REGION( 0x10000, REGION_CPU1, 0 )	 /* 64k for code */
 	ROM_LOAD( "c01",          0x4000, 0x2000, CRC(0c720eeb) SHA1(cc0719db7e59c72e603ab2ca42565303bc41d281) )
 	ROM_LOAD( "c02",          0x6000, 0x2000, CRC(560258e0) SHA1(788d0d3cbbd97fb54eceb3281ccf84a31e5e3e98) )
 	ROM_LOAD( "c03",          0x8000, 0x2000, CRC(9b01c7e6) SHA1(0106f94b38ad62e7514e56aab35581968074bbe0) )
@@ -596,7 +595,7 @@ ROM_START( hpolym84 )
 ROM_END
 
 ROM_START( roadf )
-	ROM_REGION( 2*0x10000, REGION_CPU1, 0 )	 /* 64k for code + 64k for decrypted opcodes */
+	ROM_REGION( 0x10000, REGION_CPU1, 0 )	 /* 64k for code */
 	ROM_LOAD( "g05_g01.bin",  0x4000, 0x2000, CRC(e2492a06) SHA1(e03895b83f1529dd7bb20e1380cb60c7606db3e4) )
 	ROM_LOAD( "g07_f02.bin",  0x6000, 0x2000, CRC(0bf75165) SHA1(d3d16d63ca15c8f6b05c37b4e37e41785334ffff) )
 	ROM_LOAD( "g09_g03.bin",  0x8000, 0x2000, CRC(dde401f8) SHA1(aa1810290c14d15d14e2f82a6780fc82d06d437b) )
@@ -624,7 +623,7 @@ ROM_START( roadf )
 ROM_END
 
 ROM_START( roadf2 )
-	ROM_REGION( 2*0x10000, REGION_CPU1, 0 )	 /* 64k for code + 64k for decrypted opcodes */
+	ROM_REGION( 0x10000, REGION_CPU1, 0 )	 /* 64k for code */
 	ROM_LOAD( "5g",           0x4000, 0x2000, CRC(d8070d30) SHA1(334e4586686c29d33c3281cc446c13d2d96301dd) )
 	ROM_LOAD( "6g",           0x6000, 0x2000, CRC(8b661672) SHA1(bdc983d1ad88372ea1fc8263d4c254d26079ece7) )
 	ROM_LOAD( "8g",           0x8000, 0x2000, CRC(714929e8) SHA1(0176e4199a091485af30e00777678e51664dee23) )
