@@ -9,7 +9,6 @@ Ikki (c) 1985 Sun Electronics
 *****************************************************************************/
 
 #include "driver.h"
-#include "vidhrdw/generic.h"
 #include "sound/sn76496.h"
 
 PALETTE_INIT( ikki );
@@ -154,7 +153,7 @@ INPUT_PORTS_END
 
 /****************************************************************************/
 
-static gfx_layout charlayout =
+static const gfx_layout charlayout =
 {
 	8,8,    /* 8*8 characters */
 	2048,   /* 2048 characters */
@@ -165,7 +164,7 @@ static gfx_layout charlayout =
 	8*8
 };
 
-static gfx_layout spritelayout =
+static const gfx_layout spritelayout =
 {
 	16,32,  /* 16*32 characters */
 	256,    /* 256 characters */
@@ -180,7 +179,7 @@ static gfx_layout spritelayout =
 	8*8*8
 };
 
-static gfx_decode gfxdecodeinfo[] =
+static const gfx_decode gfxdecodeinfo[] =
 {
 	{ REGION_GFX2, 0x0000, &charlayout,   512, 64 },
 	{ REGION_GFX1, 0x0000, &spritelayout, 0,   64 },
