@@ -21,14 +21,13 @@ TODO:
 ***************************************************************************/
 
 #include "driver.h"
-#include "vidhrdw/generic.h"
 #include "cpu/m6809/m6809.h"
 #include "sound/2151intf.h"
 
 
 extern UINT8 *jackal_videoctrl;
 
-extern MACHINE_INIT( jackal );
+extern MACHINE_RESET( jackal );
 
 extern READ8_HANDLER( jackal_zram_r );
 extern READ8_HANDLER( jackal_voram_r );
@@ -82,7 +81,7 @@ ADDRESS_MAP_END
 static ADDRESS_MAP_START( slave_map, ADDRESS_SPACE_PROGRAM, 8 )
 	AM_RANGE(0x2000, 0x2000) AM_WRITE(YM2151_register_port_0_w)
 	AM_RANGE(0x2001, 0x2001) AM_READWRITE(YM2151_status_port_0_r, YM2151_data_port_0_w)
-	AM_RANGE(0x4000, 0x43ff) AM_RAM AM_WRITE(paletteram_xBBBBBGGGGGRRRRR_w) AM_BASE(&paletteram)	/* COLOR RAM (Self test only check 0x4000-0x423f) */
+	AM_RANGE(0x4000, 0x43ff) AM_RAM AM_WRITE(paletteram_xBBBBBGGGGGRRRRR_le_w) AM_BASE(&paletteram)	/* COLOR RAM (Self test only check 0x4000-0x423f) */
 	AM_RANGE(0x6000, 0x605f) AM_RAM																	/* SOUND RAM (Self test check 0x6000-605f, 0x7c00-0x7fff) */
 	AM_RANGE(0x6060, 0x7fff) AM_RAM AM_SHARE(1)
 	AM_RANGE(0x8000, 0xffff) AM_ROM
@@ -197,7 +196,7 @@ INPUT_PORTS_END
 
 /* Graphics Layouts */
 
-static gfx_layout charlayout =
+static const gfx_layout charlayout =
 {
 	8, 8,
 	RGN_FRAC(1,4),
@@ -208,7 +207,7 @@ static gfx_layout charlayout =
 	32*8
 };
 
-static gfx_layout spritelayout =
+static const gfx_layout spritelayout =
 {
 	16, 16,
 	RGN_FRAC(1,4),
@@ -221,7 +220,7 @@ static gfx_layout spritelayout =
 	32*32
 };
 
-static gfx_layout spritelayout8 =
+static const gfx_layout spritelayout8 =
 {
 	8, 8,
 	RGN_FRAC(1,4),
@@ -234,7 +233,7 @@ static gfx_layout spritelayout8 =
 
 /* Graphics Decode Information */
 
-static gfx_decode gfxdecodeinfo[] =
+static const gfx_decode gfxdecodeinfo[] =
 {
 	{ REGION_GFX1, 0x00000, &charlayout,               0, 16 },	/* colors 256-511 with lookup */
 	{ REGION_GFX1, 0x20000, &spritelayout,        256*16, 16 },	/* colors   0- 15 with lookup */
@@ -267,7 +266,7 @@ static MACHINE_DRIVER_START( jackal )
 	MDRV_VBLANK_DURATION(DEFAULT_60HZ_VBLANK_DURATION)
 	MDRV_INTERLEAVE(10)	/* 10 CPU slices per frame - seems enough to keep the CPUs in sync */
 
-	MDRV_MACHINE_INIT(jackal)
+	MDRV_MACHINE_RESET(jackal)
 
 	/* video hardware */
 	MDRV_VIDEO_ATTRIBUTES(VIDEO_TYPE_RASTER)
