@@ -101,15 +101,13 @@ OSC:    12.000MHz
 *******************************************************************************************/
 
 #include "driver.h"
-#include "vidhrdw/generic.h"
 #include "cpu/m68000/m68000.h"
-#include "machine/random.h"
 #include "sound/okim6295.h"
 
-static struct tilemap *sc3_tilemap, *sc0_tilemap,*sc1_tilemap,*sc2_tilemap;
-data16_t *sc3_vram, *sc0_vram,*sc1_vram,*sc2_vram;
-data16_t *jm_regs,*jm_ram,*jm_mcu_code;
-data16_t *jm_scrollram,*jm_vregs;
+static tilemap *sc3_tilemap, *sc0_tilemap,*sc1_tilemap,*sc2_tilemap;
+static UINT16 *sc3_vram, *sc0_vram,*sc1_vram,*sc2_vram;
+static UINT16 *jm_regs,*jm_ram,*jm_mcu_code;
+static UINT16 *jm_scrollram,*jm_vregs;
 static UINT16 sc0bank,pri;
 /*
 MCU program number,different for each game(n.b. the numbering scheme is *mine*,do not
@@ -380,8 +378,8 @@ VIDEO_UPDATE( jalmah )
 		sc_db--;
 	if(sc_db > 3)
 		sc_db = 3;
-	/*usrintf_showmessage("%04x %04x %04x %04x %04x %04x",jm_vregs[0],jm_vregs[1],jm_vregs[2],jm_vregs[3],sc0bank,pri); */
-	usrintf_showmessage("%04d %04d %04x %02x %01x",jm_scrollram[0+sc_db],jm_scrollram[4+sc_db],jm_vregs[0+sc_db],sc_db,pri);
+	/*ui_popup("%04x %04x %04x %04x %04x %04x",jm_vregs[0],jm_vregs[1],jm_vregs[2],jm_vregs[3],sc0bank,pri); */
+	ui_popup("%04d %04d %04x %02x %01x",jm_scrollram[0+sc_db],jm_scrollram[4+sc_db],jm_vregs[0+sc_db],sc_db,pri);
 	#endif
 	/*
     Case by case priorities:
@@ -419,7 +417,7 @@ VIDEO_UPDATE( jalmah )
 }
 
 
-WRITE16_HANDLER( sc0_vram_w )
+static WRITE16_HANDLER( sc0_vram_w )
 {
 	int oldword = sc0_vram[offset];
 	int newword = oldword;
@@ -432,7 +430,7 @@ WRITE16_HANDLER( sc0_vram_w )
 	}
 }
 
-WRITE16_HANDLER( sc1_vram_w )
+static WRITE16_HANDLER( sc1_vram_w )
 {
 	int oldword = sc1_vram[offset];
 	int newword = oldword;
@@ -445,7 +443,7 @@ WRITE16_HANDLER( sc1_vram_w )
 	}
 }
 
-WRITE16_HANDLER( sc3_vram_w )
+static WRITE16_HANDLER( sc3_vram_w )
 {
 	int oldword = sc3_vram[offset];
 	int newword = oldword;
@@ -458,7 +456,7 @@ WRITE16_HANDLER( sc3_vram_w )
 	}
 }
 
-WRITE16_HANDLER( sc2_vram_w )
+static WRITE16_HANDLER( sc2_vram_w )
 {
 	int oldword = sc2_vram[offset];
 	int newword = oldword;
@@ -478,7 +476,7 @@ WRITE16_HANDLER( jalmah_tilebank_w )
      xxxx ---- fg bank (used by suchipi)
      ---- xxxx Priority number (trusted,see mjzoomin)
     */
-	/*usrintf_showmessage("Write to tilebank %02x",data); */
+	/*ui_popup("Write to tilebank %02x",data); */
 	if (ACCESSING_LSB)
 	{
 		if (sc0bank != ((data & 0xf0) >> 4))
@@ -519,7 +517,7 @@ static WRITE16_HANDLER( jalmah_scroll_w )
 		case (0x2a/2): jm_scrollram[5] = data; break;
 		case (0x32/2): jm_scrollram[6] = data; break;
 		case (0x3a/2): jm_scrollram[7] = data; break;
-		/*default:    usrintf_showmessage("[%04x]<-%04x",offset+0x10,data); */
+		/*default:    ui_popup("[%04x]<-%04x",offset+0x10,data); */
 	}
 }
 
@@ -529,7 +527,7 @@ WRITE16_HANDLER( jalmah_okirom_w )
 {
 	if(ACCESSING_LSB)
 	{
-		data8_t *oki = memory_region(REGION_SOUND1);
+		UINT8 *oki = memory_region(REGION_SOUND1);
 		oki_rom = data & 1;
 		memcpy(&oki[0x20000], &oki[(oki_rom * 0x80000) + (oki_bank * 0x20000) + 0x40000], 0x20000);
 	}
@@ -543,7 +541,7 @@ static WRITE16_HANDLER( jalmah_okibank_w )
 {
 	if(ACCESSING_LSB)
 	{
-		data8_t *oki = memory_region(REGION_SOUND1);
+		UINT8 *oki = memory_region(REGION_SOUND1);
 		oki_bank = data & 3;
 		memcpy(&oki[0x20000], &oki[(oki_rom * 0x80000) + (oki_bank * 0x20000) + 0x40000], 0x20000);
 	}
@@ -554,7 +552,7 @@ WRITE16_HANDLER( jalmah_flip_screen_w )
 	/*---- ----x flip screen*/
 	flip_screen_set(data & 1);
 
-/*  usrintf_showmessage("%04x",data); */
+/*  ui_popup("%04x",data); */
 }
 
 static ADDRESS_MAP_START( jalmah, ADDRESS_SPACE_PROGRAM, 16 )
@@ -871,7 +869,7 @@ INPUT_PORTS_START( jalmah2 )
 	PORT_BIT( 0xe1e1, IP_ACTIVE_LOW, IPT_UNUSED )
 INPUT_PORTS_END
 
-static struct GfxLayout charlayout =
+static const gfx_layout charlayout =
 {
 	8,8,
 	RGN_FRAC(1,1),
@@ -882,7 +880,7 @@ static struct GfxLayout charlayout =
 	32*8
 };
 
-static struct GfxLayout tilelayout =
+static const gfx_layout tilelayout =
 {
 	16,16,
 	RGN_FRAC(1,1),
@@ -895,7 +893,7 @@ static struct GfxLayout tilelayout =
 	32*32
 };
 
-static struct GfxDecodeInfo jalmah_gfxdecodeinfo[] =
+static const gfx_decode jalmah_gfxdecodeinfo[] =
 {
 	{ REGION_GFX1, 0, &charlayout, 0x300, 16 },
 	{ REGION_GFX2, 0, &tilelayout, 0x200, 16 },
@@ -904,7 +902,7 @@ static struct GfxDecodeInfo jalmah_gfxdecodeinfo[] =
 	{ -1 } /* end of array */
 };
 
-static MACHINE_INIT (daireika)
+static MACHINE_RESET (daireika)
 {
 	respcount = 0;
 }
@@ -923,7 +921,7 @@ static MACHINE_DRIVER_START( jalmah )
 	MDRV_SCREEN_SIZE(32*8, 32*8)
 	MDRV_VISIBLE_AREA(0*8, 32*8-1, 2*8, 30*8-1)
 	MDRV_PALETTE_LENGTH(0x400)
-	MDRV_MACHINE_INIT(daireika)
+	MDRV_MACHINE_RESET(daireika)
 
 	MDRV_VIDEO_START(jalmah)
 	MDRV_VIDEO_UPDATE(jalmah)
@@ -1231,7 +1229,7 @@ static WRITE16_HANDLER( urashima_mcu_w )
 	{
 		/*jm_regs[0x30e/2] = ? */
 
-		/*usrintf_showmessage("%04x %02x",jm_regs[0x030e/2],data); */
+		/*ui_popup("%04x %02x",jm_regs[0x030e/2],data); */
 
 		/*******************************************************
         1st M68k code uploaded by the MCU (sound prg)
@@ -1765,7 +1763,7 @@ static READ16_HANDLER( kakumei_mcu_r )
 	res = resp[respcount++];
 	if (respcount >= sizeof(resp)/sizeof(resp[0])) respcount = 0;
 
-	/*usrintf_showmessage("%04x: mcu_r %02x",activecpu_get_pc(),res); */
+	/*ui_popup("%04x: mcu_r %02x",activecpu_get_pc(),res); */
 
 	return res;
 }
@@ -1786,7 +1784,7 @@ static READ16_HANDLER( suchipi_mcu_r )
 	res = resp[respcount++];
 	if (respcount >= sizeof(resp)/sizeof(resp[0])) respcount = 0;
 
-	/*usrintf_showmessage("%04x: mcu_r %02x",activecpu_get_pc(),res); */
+	/*ui_popup("%04x: mcu_r %02x",activecpu_get_pc(),res); */
 
 	return res;
 }
@@ -1852,13 +1850,13 @@ static DRIVER_INIT( suchipi )
 
 /*First version of the MCU*/
 /*Pseudo-random stuff is not 100% working*/
-GAMEX( 1989, daireika, 0, jalmah, jalmah, daireika, ROT0, "Jaleco / NMK", "Mahjong Daireikai",			        GAME_UNEMULATED_PROTECTION | GAME_NOT_WORKING )
+GAME( 1989, daireika, 0, jalmah, jalmah, daireika, ROT0, "Jaleco / NMK", "Mahjong Daireikai",			        GAME_UNEMULATED_PROTECTION | GAME_NOT_WORKING )
 /*Protection controls tilemap scrolling on this,you can't see anything unless you use fake scroll register values...*/
-GAMEX( 1989, urashima, 0, jalmah, jalmah, urashima, ROT0, "UPL",	      "Urashima Mahjong", 					GAME_UNEMULATED_PROTECTION | GAME_NOT_WORKING )
+GAME( 1989, urashima, 0, jalmah, jalmah, urashima, ROT0, "UPL",	      "Urashima Mahjong", 					GAME_UNEMULATED_PROTECTION | GAME_NOT_WORKING )
 
 /*No known gameplay bugs for the following games:*/
-GAMEX( 1990, mjzoomin, 0, jalmah, jalmah, mjzoomin, ROT0, "Jaleco",       "Mahjong Channel Zoom In",            GAME_IMPERFECT_GRAPHICS )
+GAME( 1990, mjzoomin, 0, jalmah, jalmah, mjzoomin, ROT0, "Jaleco",       "Mahjong Channel Zoom In",            GAME_IMPERFECT_GRAPHICS )
 /*Second version of the MCU*/
-GAMEX( 1990, kakumei,  0, jalmah, jalmah2, kakumei,  ROT0, "Jaleco",       "Mahjong Kakumei",                      GAME_IMPERFECT_GRAPHICS )
-GAMEX( 1992, kakumei2, 0, jalmah, jalmah2, kakumei2, ROT0, "Jaleco",       "Mahjong Kakumei 2 - Princess League",  GAME_IMPERFECT_GRAPHICS )
-GAMEX( 1993, suchipi,  0, jalmah, jalmah2, suchipi,  ROT0, "Jaleco",       "Idol Janshi Su-Chi-Pie Special",       GAME_IMPERFECT_GRAPHICS )
+GAME( 1990, kakumei,  0, jalmah, jalmah2, kakumei,  ROT0, "Jaleco",       "Mahjong Kakumei",                      GAME_IMPERFECT_GRAPHICS )
+GAME( 1992, kakumei2, 0, jalmah, jalmah2, kakumei2, ROT0, "Jaleco",       "Mahjong Kakumei 2 - Princess League",  GAME_IMPERFECT_GRAPHICS )
+GAME( 1993, suchipi,  0, jalmah, jalmah2, suchipi,  ROT0, "Jaleco",       "Idol Janshi Su-Chi-Pie Special",       GAME_IMPERFECT_GRAPHICS )
