@@ -218,7 +218,6 @@ there are 9 PALS on the pcb (not dumped)
  */
 
 #include "driver.h"
-#include "vidhrdw/generic.h"
 #include "sound/ymz280b.h"
 
 extern UINT32* skns_spc_regs;
@@ -238,9 +237,6 @@ This will benefit galpani3 and other kaneko16 games with TOYBOX MCU.
 ***************************************************************************/
 static UINT16 *mcu_ram, jchan_mcu_com[4];
 
-extern const game_driver driver_jchan;
-extern const game_driver driver_jchan2;
-
 void jchan_mcu_run(void)
 {
 	UINT16 mcu_command = mcu_ram[0x0010/2];		/* command nb */
@@ -271,7 +267,7 @@ void jchan_mcu_run(void)
 					mcu_ram[mcu_offset + 6] = 0x3939; mcu_ram[mcu_offset + 7] = 0x3420;
 					break;
 				case 0x3e:
-					if ( (Machine->gamedrv == &driver_jchan) ) /* $f72 ($f6a-$fc6) */
+					if ( strcmp(Machine->gamedrv->name, "jchan") == 0 ) /* $f72 ($f6a-$fc6) */
 					{
 						/* MCU writes the string "1995/05/24 The kung-Fu Master Jackie Chan   " to shared ram */
 						mcu_ram[mcu_offset +  0] = 0x3139; mcu_ram[mcu_offset +  1] = 0x3935;
@@ -286,7 +282,7 @@ void jchan_mcu_run(void)
 						mcu_ram[mcu_offset + 18] = 0x2043; mcu_ram[mcu_offset + 19] = 0x6861;
 						mcu_ram[mcu_offset + 20] = 0x6E20; mcu_ram[mcu_offset + 21] = 0x2020;
 					}
-					else if ( (Machine->gamedrv == &driver_jchan2) )
+					else if ( strcmp(Machine->gamedrv->name, "jchan2") == 0 )
 					{
 						/* MCU writes the string "1995/10/24 Fists Of Fire" to shared ram */
 						mcu_ram[mcu_offset +  0] = 0x3139; mcu_ram[mcu_offset +  1] = 0x3935;
@@ -670,7 +666,7 @@ cpu #1 (PC=000007B6): unmapped program memory word write to 00600006 = 0140 & FF
 
 
 /* gfx decode , this one seems ok */
-static gfx_layout tilelayout =
+static const gfx_layout tilelayout =
 {
 	16,16,
 	RGN_FRAC(1,1),
@@ -683,7 +679,7 @@ static gfx_layout tilelayout =
 
 /* we don't decode the sprites, they are non-tile based and RLE encoded!, see suprnova.c    */
 
-static gfx_decode gfxdecodeinfo[] =
+static const gfx_decode gfxdecodeinfo[] =
 {
 /*  { REGION_GFX1, 0, &char2layout,   0, 512  }, */
 /*  { REGION_GFX2, 0, &char2layout,   0, 512  }, */
