@@ -38,7 +38,6 @@
 *******************************************************************************/
 
 #include "driver.h"
-#include "vidhrdw/generic.h"
 #include "sound/2203intf.h"
 #include "sound/3812intf.h"
 
@@ -601,7 +600,7 @@ INPUT_PORTS_END
 
 /******************************************************************************/
 
-static gfx_layout chars =
+static const gfx_layout chars =
 {
 	8,8,
 	1024,
@@ -612,7 +611,7 @@ static gfx_layout chars =
 	8*8	/* every sprite takes 8 consecutive bytes */
 };
 
-static gfx_layout sprites =
+static const gfx_layout sprites =
 {
 	16,16,
 	4096,
@@ -626,7 +625,7 @@ static gfx_layout sprites =
 
 
 /* 16x16 tiles, 4 Planes, each plane is 0x10000 bytes */
-static gfx_layout tiles =
+static const gfx_layout tiles =
 {
 	16,16,
 	2048,
@@ -638,7 +637,7 @@ static gfx_layout tiles =
 	16*16
 };
 
-static gfx_decode karnov_gfxdecodeinfo[] =
+static const gfx_decode karnov_gfxdecodeinfo[] =
 {
 	{ REGION_GFX1, 0, &chars,     0,  4 },	/* colors 0-31 */
 	{ REGION_GFX2, 0, &tiles,   512, 16 },	/* colors 512-767 */
@@ -681,7 +680,7 @@ static struct YM3526interface ym3526_interface =
 
 /******************************************************************************/
 
-static MACHINE_INIT( karnov )
+static MACHINE_RESET( karnov )
 {
 	memset(karnov_ram,0,0x4000/2); /* Chelnov likes ram clear on reset.. */
 }
@@ -699,7 +698,7 @@ static MACHINE_DRIVER_START( karnov )
 
 	MDRV_FRAMES_PER_SECOND(60)
 	MDRV_VBLANK_DURATION(DEFAULT_REAL_60HZ_VBLANK_DURATION)
-	MDRV_MACHINE_INIT(karnov)
+	MDRV_MACHINE_RESET(karnov)
 
 	/* video hardware */
 	MDRV_VIDEO_ATTRIBUTES(VIDEO_TYPE_RASTER | VIDEO_BUFFERS_SPRITERAM)
@@ -738,7 +737,7 @@ static MACHINE_DRIVER_START( wndrplnt )
 
 	MDRV_FRAMES_PER_SECOND(60)
 	MDRV_VBLANK_DURATION(DEFAULT_REAL_60HZ_VBLANK_DURATION)
-	MDRV_MACHINE_INIT(karnov)
+	MDRV_MACHINE_RESET(karnov)
 
 	/* video hardware */
 	MDRV_VIDEO_ATTRIBUTES(VIDEO_TYPE_RASTER | VIDEO_BUFFERS_SPRITERAM)
