@@ -36,7 +36,6 @@ lev 7 : 0x7c : 0000 0000 - x
 
 #include "driver.h"
 #include "cpu/pic16c5x/pic16c5x.h"
-#include "vidhrdw/generic.h"
 #include "machine/eeprom.h"
 #include "sound/okim6295.h"
 
@@ -569,7 +568,7 @@ INPUT_PORTS_END
 
 /* GFX Decodes ***************************************************************/
 
-static gfx_layout fg816_charlayout =
+static const gfx_layout fg816_charlayout =
 {
 	8,16,
 	RGN_FRAC(1,4),
@@ -581,7 +580,7 @@ static gfx_layout fg816_charlayout =
 	16*8
 };
 
-static gfx_layout bg1632_charlayout =
+static const gfx_layout bg1632_charlayout =
 {
 	16,32,
 	RGN_FRAC(1,4),
@@ -593,23 +592,32 @@ static gfx_layout bg1632_charlayout =
 	16*16
 };
 
-static gfx_layout bg3264_charlayout =
+static const UINT32 bg3264_charlayout_yoffset[64] =
+{
+	0*32,  0*32,  1*32,  1*32,  2*32,  2*32,  3*32,  3*32,  4*32,  4*32,  5*32,  5*32,  6*32,  6*32,  7*32,  7*32,
+	8*32,  8*32,  9*32,  9*32,  10*32, 10*32, 11*32, 11*32, 12*32, 12*32, 13*32, 13*32, 14*32, 14*32, 15*32, 15*32,
+	16*32, 16*32, 17*32, 17*32, 18*32, 18*32, 19*32, 19*32, 20*32, 20*32, 21*32, 21*32, 22*32, 22*32, 23*32, 23*32,
+	24*32, 24*32, 25*32, 25*32, 26*32, 26*32, 27*32, 27*32, 28*32, 28*32, 29*32, 29*32, 30*32, 30*32, 31*32, 31*32
+};
+
+static const gfx_layout bg3264_charlayout =
 {
 	32,64,
 	RGN_FRAC(1,4),
 	4,
 	{ RGN_FRAC(3,4), RGN_FRAC(2,4), RGN_FRAC(1,4), RGN_FRAC(0,4) },
-	{ 0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15,
-	  16, 17, 18, 19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31 },
-	{ 0*32,  0*32,  1*32,  1*32,  2*32,  2*32,  3*32,  3*32,  4*32,  4*32,  5*32,  5*32,  6*32,  6*32,  7*32,  7*32,
-	  8*32,  8*32,  9*32,  9*32,  10*32, 10*32, 11*32, 11*32, 12*32, 12*32, 13*32, 13*32, 14*32, 14*32, 15*32, 15*32,
-	  16*32, 16*32, 17*32, 17*32, 18*32, 18*32, 19*32, 19*32, 20*32, 20*32, 21*32, 21*32, 22*32, 22*32, 23*32, 23*32,
-	  24*32, 24*32, 25*32, 25*32, 26*32, 26*32, 27*32, 27*32, 28*32, 28*32, 29*32, 29*32, 30*32, 30*32, 31*32, 31*32 },
-	32*32
+	{
+		0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15,
+		16, 17, 18, 19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31
+	},
+	EXTENDED_YOFFS,
+	32*32,
+	NULL,
+	bg3264_charlayout_yoffset
 };
 
 
-static gfx_decode gfxdecodeinfo[] =
+static const gfx_decode gfxdecodeinfo[] =
 {
 	{ REGION_GFX1, 0, &fg816_charlayout,   0x000, 0x40 },
 	{ REGION_GFX1, 0, &bg1632_charlayout,  0x000, 0x40 },
@@ -617,7 +625,7 @@ static gfx_decode gfxdecodeinfo[] =
 	{ -1 } /* end of array */
 };
 
-static gfx_layout actionhw_fg88_alt_charlayout =
+static const gfx_layout actionhw_fg88_alt_charlayout =
 {
 	8,8,
 	RGN_FRAC(1,4),
@@ -629,7 +637,7 @@ static gfx_layout actionhw_fg88_alt_charlayout =
 };
 
 
-static gfx_layout actionhw_bg1616_charlayout =
+static const gfx_layout actionhw_bg1616_charlayout =
 {
 	16,16,
 	RGN_FRAC(1,4),
@@ -643,7 +651,7 @@ static gfx_layout actionhw_bg1616_charlayout =
 
 
 
-static gfx_decode actionhw_gfxdecodeinfo[] =
+static const gfx_decode actionhw_gfxdecodeinfo[] =
 {
 	{ REGION_GFX1, 0, &actionhw_fg88_alt_charlayout,   0x000, 0x40 },
 	{ REGION_GFX1, 0, &actionhw_bg1616_charlayout,  0x000, 0x40 },
@@ -728,7 +736,7 @@ MACHINE_DRIVER_END
 /* Rom Loading ***************************************************************/
 
 ROM_START( kickgoal )
-	ROM_REGION( 0x80000, REGION_CPU1, 0 )	/* 68000 code */
+	ROM_REGION( 0x100000, REGION_CPU1, 0 )	/* 68000 code */
 	ROM_LOAD16_BYTE( "ic6",   0x000000, 0x40000, CRC(498ca792) SHA1(c638c3a1755870010c5961b58bcb02458ff4e238) )
 	ROM_LOAD16_BYTE( "ic5",   0x000001, 0x40000, CRC(d528740a) SHA1(d56a71004aabc839b0833a6bf383e5ef9d4948fa) )
 
