@@ -26,45 +26,61 @@
 #include "sound/ay8910.h"
 
 
+static UINT8 *shared_ram;
+
+
+/*************************************
+ *
+ *  Machine initialization
+ *
+ *************************************/
+
+MACHINE_RESET( kyugo )
+{
+	/* must start with interrupts and sub CPU disabled */
+	cpu_interrupt_enable(0, 0);
+	kyugo_sub_cpu_control_w(0, 0);
+}
+
+
+WRITE8_HANDLER( kyugo_sub_cpu_control_w )
+{
+	cpunum_set_input_line(1, INPUT_LINE_HALT, data ? CLEAR_LINE : ASSERT_LINE);
+}
+
+
 /*************************************
  *
  *  Main CPU memory handlers
  *
  *************************************/
 
-static ADDRESS_MAP_START( main_readmem, ADDRESS_SPACE_PROGRAM, 8 )
-	AM_RANGE(0x0000, 0x7fff) AM_READ(MRA8_ROM)
-	AM_RANGE(0x8000, 0x97ff) AM_READ(MRA8_RAM)
-	AM_RANGE(0x9800, 0x9fff) AM_READ(kyugo_spriteram_2_r)
-	AM_RANGE(0xa000, 0xa7ff) AM_READ(MRA8_RAM)
-	AM_RANGE(0xf000, 0xf7ff) AM_READ(kyugo_sharedram_r)
-ADDRESS_MAP_END
-
-static ADDRESS_MAP_START( main_writemem, ADDRESS_SPACE_PROGRAM, 8 )
-	AM_RANGE(0x0000, 0x7fff) AM_WRITE(MWA8_ROM)
-	AM_RANGE(0x8000, 0x87ff) AM_WRITE(kyugo_bgvideoram_w) AM_BASE(&kyugo_bgvideoram)
-	AM_RANGE(0x8800, 0x8fff) AM_WRITE(kyugo_bgattribram_w) AM_BASE(&kyugo_bgattribram)
-	AM_RANGE(0x9000, 0x97ff) AM_WRITE(kyugo_fgvideoram_w) AM_BASE(&kyugo_fgvideoram)
-	AM_RANGE(0x9800, 0x9fff) AM_WRITE(MWA8_RAM) AM_BASE(&kyugo_spriteram_2)
-	AM_RANGE(0xa000, 0xa7ff) AM_WRITE(MWA8_RAM) AM_BASE(&kyugo_spriteram_1)
+static ADDRESS_MAP_START( main_map, ADDRESS_SPACE_PROGRAM, 8 )
+	AM_RANGE(0x0000, 0x7fff) AM_ROM
+	AM_RANGE(0x8000, 0x87ff) AM_READWRITE(MRA8_RAM, kyugo_bgvideoram_w) AM_BASE(&kyugo_bgvideoram)
+	AM_RANGE(0x8800, 0x8fff) AM_READWRITE(MRA8_RAM, kyugo_bgattribram_w) AM_BASE(&kyugo_bgattribram)
+	AM_RANGE(0x9000, 0x97ff) AM_READWRITE(MRA8_RAM, kyugo_fgvideoram_w) AM_BASE(&kyugo_fgvideoram)
+	AM_RANGE(0x9800, 0x9fff) AM_READWRITE(kyugo_spriteram_2_r, MWA8_RAM) AM_BASE(&kyugo_spriteram_2)
+	AM_RANGE(0xa000, 0xa7ff) AM_RAM AM_BASE(&kyugo_spriteram_1)
 	AM_RANGE(0xa800, 0xa800) AM_WRITE(kyugo_scroll_x_lo_w)
 	AM_RANGE(0xb000, 0xb000) AM_WRITE(kyugo_gfxctrl_w)
 	AM_RANGE(0xb800, 0xb800) AM_WRITE(kyugo_scroll_y_w)
-	AM_RANGE(0xf000, 0xf7ff) AM_WRITE(kyugo_sharedram_w) AM_BASE(&kyugo_sharedram)
+	AM_RANGE(0xf000, 0xf7ff) AM_RAM AM_SHARE(1) AM_BASE(&shared_ram)
 ADDRESS_MAP_END
 
 
+
 /*************************************
  *
  *  Main CPU port handlers
  *
  *************************************/
 
-#define Main_PortMap( name, base )							\
-static ADDRESS_MAP_START( name##_writeport, ADDRESS_SPACE_IO, 8 )					\
-	ADDRESS_MAP_FLAGS( AMEF_ABITS(8) )										\
-	AM_RANGE(base+0, base+0) AM_WRITE(interrupt_enable_w)					\
-	AM_RANGE(base+1, base+1) AM_WRITE(kyugo_flipscreen_w)					\
+#define Main_PortMap( name, base )										\
+static ADDRESS_MAP_START( name##_portmap, ADDRESS_SPACE_IO, 8 )			\
+	ADDRESS_MAP_FLAGS( AMEF_ABITS(8) )									\
+	AM_RANGE(base+0, base+0) AM_WRITE(interrupt_enable_w)				\
+	AM_RANGE(base+1, base+1) AM_WRITE(kyugo_flipscreen_w)				\
 	AM_RANGE(base+2, base+2) AM_WRITE(kyugo_sub_cpu_control_w)			\
 ADDRESS_MAP_END
 
@@ -74,24 +90,20 @@ Main_PortMap( flashgla, 0xc0 )
 Main_PortMap( srdmissn, 0x08 )
 
 
+
 /*************************************
  *
  *  Sub CPU memory handlers
  *
  *************************************/
 
-#define Sub_MemMap( name, rom_end, shared, in0, in1, in2 )	\
-static ADDRESS_MAP_START( name##_sub_readmem, ADDRESS_SPACE_PROGRAM, 8 )				\
-	AM_RANGE(0x0000, rom_end) AM_READ(MRA8_ROM)							\
-	AM_RANGE(shared, shared+0x7ff) AM_READ(kyugo_sharedram_r)			\
-	AM_RANGE(in0, in0) AM_READ(input_port_2_r)							\
-	AM_RANGE(in1, in1) AM_READ(input_port_3_r)							\
-	AM_RANGE(in2, in2) AM_READ(input_port_4_r)							\
-ADDRESS_MAP_END													\
-															\
-static ADDRESS_MAP_START( name##_sub_writemem, ADDRESS_SPACE_PROGRAM, 8 )			\
-	AM_RANGE(0x0000, rom_end) AM_WRITE(MWA8_ROM)							\
-	AM_RANGE(shared, shared+0x7ff) AM_WRITE(kyugo_sharedram_w)			\
+#define Sub_MemMap( name, rom_end, shared, in0, in1, in2 )					\
+static ADDRESS_MAP_START( name##_sub_map, ADDRESS_SPACE_PROGRAM, 8 )		\
+	AM_RANGE(0x0000, rom_end) AM_ROM										\
+	AM_RANGE(shared, shared+0x7ff) AM_RAM AM_SHARE(1)						\
+	AM_RANGE(in0, in0) AM_READ(input_port_2_r)								\
+	AM_RANGE(in1, in1) AM_READ(input_port_3_r)								\
+	AM_RANGE(in2, in2) AM_READ(input_port_4_r)								\
 ADDRESS_MAP_END
 
 Sub_MemMap( gyrodine, 0x1fff, 0x4000, 0x8080, 0x8040, 0x8000 )
@@ -101,25 +113,22 @@ Sub_MemMap( legend,   0x7fff, 0xc000, 0xf800, 0xf801, 0xf802 )
 Sub_MemMap( flashgla, 0x7fff, 0xe000, 0xc040, 0xc080, 0xc0c0 )
 
 
+
 /*************************************
  *
  *  Sub CPU port handlers
  *
  *************************************/
 
-#define Sub_PortMap( name, ay0_base, ay1_base )				\
-static ADDRESS_MAP_START( name##_sub_readport, ADDRESS_SPACE_IO, 8 )				\
-	ADDRESS_MAP_FLAGS( AMEF_ABITS(8) )									\
-	AM_RANGE(ay0_base+2, ay0_base+2) AM_READ(AY8910_read_port_0_r)		\
-ADDRESS_MAP_END													\
-															\
-static ADDRESS_MAP_START( name##_sub_writeport, ADDRESS_SPACE_IO, 8 )				\
-	ADDRESS_MAP_FLAGS( AMEF_ABITS(8) )									\
-	AM_RANGE(ay0_base+0, ay0_base+0) AM_WRITE(AY8910_control_port_0_w)	\
+#define Sub_PortMap( name, ay0_base, ay1_base )								\
+static ADDRESS_MAP_START( name##_sub_portmap, ADDRESS_SPACE_IO, 8 )			\
+	ADDRESS_MAP_FLAGS( AMEF_ABITS(8) )										\
+	AM_RANGE(ay0_base+0, ay0_base+0) AM_WRITE(AY8910_control_port_0_w)		\
 	AM_RANGE(ay0_base+1, ay0_base+1) AM_WRITE(AY8910_write_port_0_w)		\
-	AM_RANGE(ay1_base+0, ay1_base+0) AM_WRITE(AY8910_control_port_1_w)	\
+	AM_RANGE(ay0_base+2, ay0_base+2) AM_READ(AY8910_read_port_0_r)			\
+	AM_RANGE(ay1_base+0, ay1_base+0) AM_WRITE(AY8910_control_port_1_w)		\
 	AM_RANGE(ay1_base+1, ay1_base+1) AM_WRITE(AY8910_write_port_1_w)		\
-ADDRESS_MAP_END
+ADDRESS_MAP_END																\
 
 Sub_PortMap( gyrodine, 0x00, 0xc0 )
 Sub_PortMap( sonofphx, 0x00, 0x40 )
@@ -427,7 +436,7 @@ INPUT_PORTS_END
  *
  *************************************/
 
-static gfx_layout fg_tilelayout =
+static const gfx_layout fg_tilelayout =
 {
 	8,8,
 	RGN_FRAC(1,1),
@@ -438,7 +447,7 @@ static gfx_layout fg_tilelayout =
 	8*8*2
 };
 
-static gfx_layout bg_tilelayout =
+static const gfx_layout bg_tilelayout =
 {
 	8,8,
 	RGN_FRAC(1,3),
@@ -449,7 +458,7 @@ static gfx_layout bg_tilelayout =
 	8*8
 };
 
-static gfx_layout spritelayout =
+static const gfx_layout spritelayout =
 {
 	16,16,
 	RGN_FRAC(1,3),
@@ -462,7 +471,7 @@ static gfx_layout spritelayout =
 	16*16
 };
 
-static gfx_decode gfxdecodeinfo[] =
+static const gfx_decode gfxdecodeinfo[] =
 {
 	{ REGION_GFX1, 0, &fg_tilelayout, 0, 64 },
 	{ REGION_GFX2, 0, &bg_tilelayout, 0, 32 },
@@ -494,20 +503,20 @@ static MACHINE_DRIVER_START( gyrodine )
 
 	/* basic machine hardware */
 	MDRV_CPU_ADD_TAG("main", Z80, 18432000 / 4)	/* 18.432 MHz crystal */
-	MDRV_CPU_PROGRAM_MAP(main_readmem,main_writemem)
-	MDRV_CPU_IO_MAP(0,gyrodine_writeport)
+	MDRV_CPU_PROGRAM_MAP(main_map,0)
+	MDRV_CPU_IO_MAP(0,gyrodine_portmap)
 	MDRV_CPU_VBLANK_INT(nmi_line_pulse,1)
 
 	MDRV_CPU_ADD_TAG("sub", Z80, 18432000 / 4)	/* 18.432 MHz crystal */
-	MDRV_CPU_PROGRAM_MAP(gyrodine_sub_readmem,gyrodine_sub_writemem)
-	MDRV_CPU_IO_MAP(gyrodine_sub_readport,gyrodine_sub_writeport)
+	MDRV_CPU_PROGRAM_MAP(gyrodine_sub_map,0)
+	MDRV_CPU_IO_MAP(gyrodine_sub_portmap,0)
 	MDRV_CPU_VBLANK_INT(irq0_line_hold,4)
 
 	MDRV_FRAMES_PER_SECOND(60)
 	MDRV_VBLANK_DURATION(DEFAULT_REAL_60HZ_VBLANK_DURATION)
 	MDRV_INTERLEAVE(100)
 
-	MDRV_MACHINE_INIT(kyugo)
+	MDRV_MACHINE_RESET(kyugo)
 
 	/* video hardware */
 	MDRV_VIDEO_ATTRIBUTES(VIDEO_TYPE_RASTER)
@@ -536,8 +545,8 @@ static MACHINE_DRIVER_START( sonofphx )
 	/* basic machine hardware */
 	MDRV_IMPORT_FROM(gyrodine)
 	MDRV_CPU_MODIFY("sub")
-	MDRV_CPU_PROGRAM_MAP(sonofphx_sub_readmem,sonofphx_sub_writemem)
-	MDRV_CPU_IO_MAP(sonofphx_sub_readport,sonofphx_sub_writeport)
+	MDRV_CPU_PROGRAM_MAP(sonofphx_sub_map,0)
+	MDRV_CPU_IO_MAP(sonofphx_sub_portmap,0)
 MACHINE_DRIVER_END
 
 static MACHINE_DRIVER_START( srdmissn )
@@ -545,11 +554,11 @@ static MACHINE_DRIVER_START( srdmissn )
 	/* basic machine hardware */
 	MDRV_IMPORT_FROM(gyrodine)
 	MDRV_CPU_MODIFY("main")
-	MDRV_CPU_IO_MAP(0,srdmissn_writeport)
+	MDRV_CPU_IO_MAP(0,srdmissn_portmap)
 
 	MDRV_CPU_MODIFY("sub")
-	MDRV_CPU_PROGRAM_MAP(srdmissn_sub_readmem,srdmissn_sub_writemem)
-	MDRV_CPU_IO_MAP(srdmissn_sub_readport,srdmissn_sub_writeport)
+	MDRV_CPU_PROGRAM_MAP(srdmissn_sub_map,0)
+	MDRV_CPU_IO_MAP(srdmissn_sub_portmap,0)
 MACHINE_DRIVER_END
 
 static MACHINE_DRIVER_START( flashgal )
@@ -557,7 +566,7 @@ static MACHINE_DRIVER_START( flashgal )
 	/* basic machine hardware */
 	MDRV_IMPORT_FROM(sonofphx)
 	MDRV_CPU_MODIFY("main")
-	MDRV_CPU_IO_MAP(0,flashgal_writeport)
+	MDRV_CPU_IO_MAP(0,flashgal_portmap)
 MACHINE_DRIVER_END
 
 static MACHINE_DRIVER_START( flashgla )
@@ -565,11 +574,11 @@ static MACHINE_DRIVER_START( flashgla )
 	/* basic machine hardware */
 	MDRV_IMPORT_FROM(gyrodine)
 	MDRV_CPU_MODIFY("main")
-	MDRV_CPU_IO_MAP(0,flashgla_writeport)
+	MDRV_CPU_IO_MAP(0,flashgla_portmap)
 
 	MDRV_CPU_MODIFY("sub")
-	MDRV_CPU_PROGRAM_MAP(flashgla_sub_readmem,flashgla_sub_writemem)
-	MDRV_CPU_IO_MAP(flashgla_sub_readport,flashgla_sub_writeport)
+	MDRV_CPU_PROGRAM_MAP(flashgla_sub_map,0)
+	MDRV_CPU_IO_MAP(flashgla_sub_portmap,0)
 MACHINE_DRIVER_END
 
 static MACHINE_DRIVER_START( legend )
@@ -577,8 +586,8 @@ static MACHINE_DRIVER_START( legend )
 	/* basic machine hardware */
 	MDRV_IMPORT_FROM(gyrodine)
 	MDRV_CPU_MODIFY("sub")
-	MDRV_CPU_PROGRAM_MAP(legend_sub_readmem,legend_sub_writemem)
-	MDRV_CPU_IO_MAP(srdmissn_sub_readport,srdmissn_sub_writeport)
+	MDRV_CPU_PROGRAM_MAP(legend_sub_map,0)
+	MDRV_CPU_IO_MAP(srdmissn_sub_portmap,0)
 MACHINE_DRIVER_END
 
 
@@ -854,47 +863,47 @@ ROM_END
 
 ROM_START( flashgal )
 	ROM_REGION( 0x10000, REGION_CPU1, 0 ) /* 64k for code */
-	ROM_LOAD( "15.4f",        0x0000, 0x2000, CRC(cf5ad733) SHA1(24561db9a3d72c7a69a7ce5a85aaa78254788675) )
-	ROM_LOAD( "16.4h",        0x2000, 0x2000, CRC(00c4851f) SHA1(f29ef123702bb3506ac3740b2779ae2757d884c2) )
-	ROM_LOAD( "17.4j",        0x4000, 0x2000, CRC(1ef0b8f7) SHA1(9c3ded1f985f4fb6b38843e0ca90ec458633d145) )
-	ROM_LOAD( "18.4k",        0x6000, 0x2000, CRC(885d53de) SHA1(14c8d4d07574e2dc3fba9fc92483a810649e100a) )
+	ROM_LOAD( "epr-7167.4f",  0x0000, 0x2000, CRC(cf5ad733) SHA1(24561db9a3d72c7a69a7ce5a85aaa78254788675) )
+	ROM_LOAD( "epr-7168.4h",  0x2000, 0x2000, CRC(00c4851f) SHA1(f29ef123702bb3506ac3740b2779ae2757d884c2) )
+	ROM_LOAD( "epr-7169.4j",  0x4000, 0x2000, CRC(1ef0b8f7) SHA1(9c3ded1f985f4fb6b38843e0ca90ec458633d145) )
+	ROM_LOAD( "epr-7170.4k",  0x6000, 0x2000, CRC(885d53de) SHA1(14c8d4d07574e2dc3fba9fc92483a810649e100a) )
 
 	ROM_REGION( 0x10000, REGION_CPU2, 0 ) /* 64k for code */
-	ROM_LOAD( "11.2f",        0x0000, 0x2000, CRC(eee2134d) SHA1(4d67a969ff033576988de73942717c84068a291d) )
-	ROM_LOAD( "12.2h",        0x2000, 0x2000, CRC(e5e0cd22) SHA1(ad17f5a207a6d74cf0bd1cfebb061c8f65309563) )
-	ROM_LOAD( "13.2j",        0x4000, 0x2000, CRC(4cd3fe5e) SHA1(a69e02acbcad825101f96dcabfada667ae25799c) )
-	ROM_LOAD( "14.2k",        0x6000, 0x2000, CRC(552ca339) SHA1(2313c6aaec47957bce00d0d04f89012eafc014fd) )
+	ROM_LOAD( "epr-7163.2f",  0x0000, 0x2000, CRC(eee2134d) SHA1(4d67a969ff033576988de73942717c84068a291d) )
+	ROM_LOAD( "epr-7164.2h",  0x2000, 0x2000, CRC(e5e0cd22) SHA1(ad17f5a207a6d74cf0bd1cfebb061c8f65309563) )
+	ROM_LOAD( "epr-7165.2j",  0x4000, 0x2000, CRC(4cd3fe5e) SHA1(a69e02acbcad825101f96dcabfada667ae25799c) )
+	ROM_LOAD( "epr-7166.2k",  0x6000, 0x2000, CRC(552ca339) SHA1(2313c6aaec47957bce00d0d04f89012eafc014fd) )
 
 	ROM_REGION( 0x01000, REGION_GFX1, ROMREGION_DISPOSE )
-	ROM_LOAD( "19.4b",        0x00000, 0x1000, CRC(dca9052f) SHA1(cbeb997db01b875a73a67e08c0b94ab74de77b7b) ) /* chars */
+	ROM_LOAD( "epr-7177.4a",  0x00000, 0x1000, CRC(dca9052f) SHA1(cbeb997db01b875a73a67e08c0b94ab74de77b7b) ) /* chars */
 
 	ROM_REGION( 0x06000, REGION_GFX2, ROMREGION_DISPOSE )
-	ROM_LOAD( "26.9h",        0x00000, 0x2000, CRC(2f5b62c0) SHA1(8be09e4ef1c3e2b1494431d4f07570a109e93dfd) ) /* tiles - plane 0 */
-	ROM_LOAD( "27.10h",       0x02000, 0x2000, CRC(8fbb49b5) SHA1(111f0c42cee6ab2766a5322dd90e1516ffbbc35c) ) /* tiles - plane 1 */
-	ROM_LOAD( "28.11h",       0x04000, 0x2000, CRC(26a8e5c3) SHA1(9a2bc4de87e16bbb777b39564c08d99fd3ccd4ff) ) /* tiles - plane 2 */
+	ROM_LOAD( "epr-7178.9h",  0x00000, 0x2000, CRC(2f5b62c0) SHA1(8be09e4ef1c3e2b1494431d4f07570a109e93dfd) ) /* tiles - plane 0 */
+	ROM_LOAD( "epr-7179.10h", 0x02000, 0x2000, CRC(8fbb49b5) SHA1(111f0c42cee6ab2766a5322dd90e1516ffbbc35c) ) /* tiles - plane 1 */
+	ROM_LOAD( "epr-7180.11h", 0x04000, 0x2000, CRC(26a8e5c3) SHA1(9a2bc4de87e16bbb777b39564c08d99fd3ccd4ff) ) /* tiles - plane 2 */
 
 	ROM_REGION( 0x18000, REGION_GFX3, ROMREGION_DISPOSE )
-	ROM_LOAD( "20.6b",        0x00000, 0x4000, CRC(62caf2a1) SHA1(6fb2c1882630b32af27638d2e9b306d4fc028d62) ) /* sprites - plane 0 */
-	ROM_LOAD( "21.7b",        0x04000, 0x4000, CRC(10f78a10) SHA1(8745da857bdb873d5ffebf753dd66321e1fabc59) ) /* sprites - plane 0 */
-	ROM_LOAD( "22.8b",        0x08000, 0x4000, CRC(36ea1d59) SHA1(cba9117de745049c06c703dc1782b83376523ce3) ) /* sprites - plane 1 */
-	ROM_LOAD( "23.9b",        0x0c000, 0x4000, CRC(f527d837) SHA1(a674e1e71c98d263670962d60a9ac6e205df1204) ) /* sprites - plane 1 */
-	ROM_LOAD( "24.10b",       0x10000, 0x4000, CRC(ba76e4c1) SHA1(e521fbf6a6a8f0e9866c143a576b9dbbc19c4ffd) ) /* sprites - plane 2 */
-	ROM_LOAD( "25.11b",       0x14000, 0x4000, CRC(f095d619) SHA1(7f278c124141ae03f1d8a03b4ea06c81391f16eb) ) /* sprites - plane 2 */
+	ROM_LOAD( "epr-7171.6a",  0x00000, 0x4000, CRC(62caf2a1) SHA1(6fb2c1882630b32af27638d2e9b306d4fc028d62) ) /* sprites - plane 0 */
+	ROM_LOAD( "epr-7172.7a",  0x04000, 0x4000, CRC(10f78a10) SHA1(8745da857bdb873d5ffebf753dd66321e1fabc59) ) /* sprites - plane 0 */
+	ROM_LOAD( "epr-7173.8a",  0x08000, 0x4000, CRC(36ea1d59) SHA1(cba9117de745049c06c703dc1782b83376523ce3) ) /* sprites - plane 1 */
+	ROM_LOAD( "epr-7174.9a",  0x0c000, 0x4000, CRC(f527d837) SHA1(a674e1e71c98d263670962d60a9ac6e205df1204) ) /* sprites - plane 1 */
+	ROM_LOAD( "epr-7175.10a", 0x10000, 0x4000, CRC(ba76e4c1) SHA1(e521fbf6a6a8f0e9866c143a576b9dbbc19c4ffd) ) /* sprites - plane 2 */
+	ROM_LOAD( "epr-7176.11a", 0x14000, 0x4000, CRC(f095d619) SHA1(7f278c124141ae03f1d8a03b4ea06c81391f16eb) ) /* sprites - plane 2 */
 
 	ROM_REGION( 0x0340, REGION_PROMS, 0 )
-	ROM_LOAD( "flashgal.prr", 0x0000, 0x0100, CRC(02c4043f) SHA1(bc2af8e054d71a3d0835c795b0f2263c32f2bc42) ) /* red */
-	ROM_LOAD( "flashgal.prg", 0x0100, 0x0100, CRC(225938d1) SHA1(22bf02832b9f08e4811f9d74a6007bf0ff030eef) ) /* green */
-	ROM_LOAD( "flashgal.prb", 0x0200, 0x0100, CRC(1e0a1cd3) SHA1(cc120d8fba3e4fb5e18d789981ece77e589ee5a2) ) /* blue */
-	ROM_LOAD( "flashgal.pr2", 0x0300, 0x0020, CRC(cce2e29f) SHA1(787c65b7d69bcd224b45138fdbbf3fdae296dda6) ) /* char lookup table */
-	ROM_LOAD( "m1.2c",        0x0320, 0x0020, CRC(83a39201) SHA1(4fdc722c9e20ee152c890342ef0dce18e35e2ef8) ) /* timing? (not used) */
+	ROM_LOAD( "7161.1j",      0x0000, 0x0100, CRC(02c4043f) SHA1(bc2af8e054d71a3d0835c795b0f2263c32f2bc42) ) /* red */
+	ROM_LOAD( "7160.1h",      0x0100, 0x0100, CRC(225938d1) SHA1(22bf02832b9f08e4811f9d74a6007bf0ff030eef) ) /* green */
+	ROM_LOAD( "7159.1f",      0x0200, 0x0100, CRC(1e0a1cd3) SHA1(cc120d8fba3e4fb5e18d789981ece77e589ee5a2) ) /* blue */
+	ROM_LOAD( "7162.5j",      0x0300, 0x0020, CRC(cce2e29f) SHA1(787c65b7d69bcd224b45138fdbbf3fdae296dda6) ) /* char lookup table */
+	ROM_LOAD( "bpr.2c",       0x0320, 0x0020, CRC(83a39201) SHA1(4fdc722c9e20ee152c890342ef0dce18e35e2ef8) ) /* timing? (not used) */
 ROM_END
 
 ROM_START( flashgla )
 	ROM_REGION( 0x10000, REGION_CPU1, 0 ) /* 64k for code */
 	ROM_LOAD( "flashgal.5",   0x0000, 0x2000, CRC(aa889ace) SHA1(7CAAC8FAE723485ADB6990367BDB8A94BD273322) )
-	ROM_LOAD( "16.4h",        0x2000, 0x2000, CRC(00c4851f) SHA1(f29ef123702bb3506ac3740b2779ae2757d884c2) )
-	ROM_LOAD( "17.4j",        0x4000, 0x2000, CRC(1ef0b8f7) SHA1(9c3ded1f985f4fb6b38843e0ca90ec458633d145) )
-	ROM_LOAD( "18.4k",        0x6000, 0x2000, CRC(885d53de) SHA1(14c8d4d07574e2dc3fba9fc92483a810649e100a) )
+	ROM_LOAD( "epr-7168.4h",  0x2000, 0x2000, CRC(00c4851f) SHA1(f29ef123702bb3506ac3740b2779ae2757d884c2) )
+	ROM_LOAD( "epr-7169.4j",  0x4000, 0x2000, CRC(1ef0b8f7) SHA1(9c3ded1f985f4fb6b38843e0ca90ec458633d145) )
+	ROM_LOAD( "epr-7170.4k",  0x6000, 0x2000, CRC(885d53de) SHA1(14c8d4d07574e2dc3fba9fc92483a810649e100a) )
 
 	ROM_REGION( 0x10000, REGION_CPU2, 0 ) /* 64k for code */
 	ROM_LOAD( "flashgal.1",   0x0000, 0x2000, CRC(55171cc1) SHA1(6780BE187288BD7354769FA29A4250E065A91E28) )
@@ -903,27 +912,27 @@ ROM_START( flashgla )
 	ROM_LOAD( "flashgal.4",   0x6000, 0x2000, CRC(04D2A05F) SHA1(009B8EAFC850A100D3A2CDE8F6FBBA9C98828DDD) )
 
 	ROM_REGION( 0x01000, REGION_GFX1, ROMREGION_DISPOSE )
-	ROM_LOAD( "19.4b",        0x00000, 0x1000, CRC(dca9052f) SHA1(cbeb997db01b875a73a67e08c0b94ab74de77b7b) ) /* chars */
+	ROM_LOAD( "epr-7177.4a",  0x00000, 0x1000, CRC(dca9052f) SHA1(cbeb997db01b875a73a67e08c0b94ab74de77b7b) ) /* chars */
 
 	ROM_REGION( 0x06000, REGION_GFX2, ROMREGION_DISPOSE )
-	ROM_LOAD( "26.9h",        0x00000, 0x2000, CRC(2f5b62c0) SHA1(8be09e4ef1c3e2b1494431d4f07570a109e93dfd) ) /* tiles - plane 0 */
-	ROM_LOAD( "27.10h",       0x02000, 0x2000, CRC(8fbb49b5) SHA1(111f0c42cee6ab2766a5322dd90e1516ffbbc35c) ) /* tiles - plane 1 */
-	ROM_LOAD( "28.11h",       0x04000, 0x2000, CRC(26a8e5c3) SHA1(9a2bc4de87e16bbb777b39564c08d99fd3ccd4ff) ) /* tiles - plane 2 */
+	ROM_LOAD( "epr-7178.9h",  0x00000, 0x2000, CRC(2f5b62c0) SHA1(8be09e4ef1c3e2b1494431d4f07570a109e93dfd) ) /* tiles - plane 0 */
+	ROM_LOAD( "epr-7179.10h", 0x02000, 0x2000, CRC(8fbb49b5) SHA1(111f0c42cee6ab2766a5322dd90e1516ffbbc35c) ) /* tiles - plane 1 */
+	ROM_LOAD( "epr-7180.11h", 0x04000, 0x2000, CRC(26a8e5c3) SHA1(9a2bc4de87e16bbb777b39564c08d99fd3ccd4ff) ) /* tiles - plane 2 */
 
 	ROM_REGION( 0x18000, REGION_GFX3, ROMREGION_DISPOSE )
-	ROM_LOAD( "20.6b",        0x00000, 0x4000, CRC(62caf2a1) SHA1(6fb2c1882630b32af27638d2e9b306d4fc028d62) ) /* sprites - plane 0 */
-	ROM_LOAD( "21.7b",        0x04000, 0x4000, CRC(10f78a10) SHA1(8745da857bdb873d5ffebf753dd66321e1fabc59) ) /* sprites - plane 0 */
-	ROM_LOAD( "22.8b",        0x08000, 0x4000, CRC(36ea1d59) SHA1(cba9117de745049c06c703dc1782b83376523ce3) ) /* sprites - plane 1 */
-	ROM_LOAD( "23.9b",        0x0c000, 0x4000, CRC(f527d837) SHA1(a674e1e71c98d263670962d60a9ac6e205df1204) ) /* sprites - plane 1 */
-	ROM_LOAD( "24.10b",       0x10000, 0x4000, CRC(ba76e4c1) SHA1(e521fbf6a6a8f0e9866c143a576b9dbbc19c4ffd) ) /* sprites - plane 2 */
-	ROM_LOAD( "25.11b",       0x14000, 0x4000, CRC(f095d619) SHA1(7f278c124141ae03f1d8a03b4ea06c81391f16eb) ) /* sprites - plane 2 */
+	ROM_LOAD( "epr-7171.6a",  0x00000, 0x4000, CRC(62caf2a1) SHA1(6fb2c1882630b32af27638d2e9b306d4fc028d62) ) /* sprites - plane 0 */
+	ROM_LOAD( "epr-7172.7a",  0x04000, 0x4000, CRC(10f78a10) SHA1(8745da857bdb873d5ffebf753dd66321e1fabc59) ) /* sprites - plane 0 */
+	ROM_LOAD( "epr-7173.8a",  0x08000, 0x4000, CRC(36ea1d59) SHA1(cba9117de745049c06c703dc1782b83376523ce3) ) /* sprites - plane 1 */
+	ROM_LOAD( "epr-7174.9a",  0x0c000, 0x4000, CRC(f527d837) SHA1(a674e1e71c98d263670962d60a9ac6e205df1204) ) /* sprites - plane 1 */
+	ROM_LOAD( "epr-7175.10a", 0x10000, 0x4000, CRC(ba76e4c1) SHA1(e521fbf6a6a8f0e9866c143a576b9dbbc19c4ffd) ) /* sprites - plane 2 */
+	ROM_LOAD( "epr-7176.11a", 0x14000, 0x4000, CRC(f095d619) SHA1(7f278c124141ae03f1d8a03b4ea06c81391f16eb) ) /* sprites - plane 2 */
 
 	ROM_REGION( 0x0340, REGION_PROMS, 0 )
-	ROM_LOAD( "flashgal.prr", 0x0000, 0x0100, CRC(02c4043f) SHA1(bc2af8e054d71a3d0835c795b0f2263c32f2bc42) ) /* red */
-	ROM_LOAD( "flashgal.prg", 0x0100, 0x0100, CRC(225938d1) SHA1(22bf02832b9f08e4811f9d74a6007bf0ff030eef) ) /* green */
-	ROM_LOAD( "flashgal.prb", 0x0200, 0x0100, CRC(1e0a1cd3) SHA1(cc120d8fba3e4fb5e18d789981ece77e589ee5a2) ) /* blue */
-	ROM_LOAD( "flashgal.pr2", 0x0300, 0x0020, CRC(cce2e29f) SHA1(787c65b7d69bcd224b45138fdbbf3fdae296dda6) ) /* char lookup table */
-	ROM_LOAD( "m1.2c",        0x0320, 0x0020, CRC(83a39201) SHA1(4fdc722c9e20ee152c890342ef0dce18e35e2ef8) ) /* timing? (not used) */
+	ROM_LOAD( "7161.1j",      0x0000, 0x0100, CRC(02c4043f) SHA1(bc2af8e054d71a3d0835c795b0f2263c32f2bc42) ) /* red */
+	ROM_LOAD( "7160.1h",      0x0100, 0x0100, CRC(225938d1) SHA1(22bf02832b9f08e4811f9d74a6007bf0ff030eef) ) /* green */
+	ROM_LOAD( "7159.1f",      0x0200, 0x0100, CRC(1e0a1cd3) SHA1(cc120d8fba3e4fb5e18d789981ece77e589ee5a2) ) /* blue */
+	ROM_LOAD( "7162.5j",      0x0300, 0x0020, CRC(cce2e29f) SHA1(787c65b7d69bcd224b45138fdbbf3fdae296dda6) ) /* char lookup table */
+	ROM_LOAD( "bpr.2c",       0x0320, 0x0020, CRC(83a39201) SHA1(4fdc722c9e20ee152c890342ef0dce18e35e2ef8) ) /* timing? (not used) */
 ROM_END
 
 ROM_START( srdmissn )
@@ -1143,18 +1152,22 @@ static DRIVER_INIT( gyrodine )
 	memory_install_write8_handler(0, ADDRESS_SPACE_PROGRAM, 0xe000, 0xe000, 0, 0, watchdog_reset_w);
 }
 
+
 static DRIVER_INIT( srdmissn )
 {
 	/* shared RAM is mapped at 0xe000 as well  */
-	memory_install_read8_handler(0, ADDRESS_SPACE_PROGRAM, 0xe000, 0xe7ff, 0, 0, kyugo_sharedram_r);
-	memory_install_write8_handler(0, ADDRESS_SPACE_PROGRAM, 0xe000, 0xe7ff, 0, 0, kyugo_sharedram_w);
+	memory_install_read8_handler(0, ADDRESS_SPACE_PROGRAM, 0xe000, 0xe7ff, 0, 0, MRA8_BANK1);
+	memory_install_write8_handler(0, ADDRESS_SPACE_PROGRAM, 0xe000, 0xe7ff, 0, 0, MWA8_BANK1);
+	memory_set_bankptr(1, shared_ram);
 
 	/* extra RAM on sub CPU  */
-	memory_install_read8_handler(1, ADDRESS_SPACE_PROGRAM, 0x8800, 0x8fff, 0, 0, MRA8_RAM);
-	memory_install_write8_handler(1, ADDRESS_SPACE_PROGRAM, 0x8800, 0x8fff, 0, 0, MWA8_RAM);
+	memory_install_read8_handler(1, ADDRESS_SPACE_PROGRAM, 0x8800, 0x8fff, 0, 0, MRA8_BANK2);
+	memory_install_write8_handler(1, ADDRESS_SPACE_PROGRAM, 0x8800, 0x8fff, 0, 0, MWA8_BANK2);
+	memory_set_bankptr(2, auto_malloc(0x800));
 }
 
 
+
 /*************************************
  *
  *  Game drivers
@@ -1171,7 +1184,7 @@ GAME( 1985, 99lstwrk, sonofphx, sonofphx, sonofphx, 0,        ROT90, "Kyugo", "'
 GAME( 1985, flashgal, 0,        flashgal, flashgal, 0,        ROT0,  "Sega", "Flashgal (set 1)", 0 )
 GAME( 1985, flashgla, flashgal, flashgla, flashgal, 0,        ROT0,  "Sega", "Flashgal (set 2)", 0 )
 GAME( 1986, srdmissn, 0,        srdmissn, srdmissn, srdmissn, ROT90, "Taito Corporation", "S.R.D. Mission", 0 )
-GAME( 1986, fx,		  srdmissn, srdmissn, srdmissn, srdmissn, ROT90, "bootleg", "F-X", 0 )
+GAME( 1986, fx,       srdmissn, srdmissn, srdmissn, srdmissn, ROT90, "bootleg", "F-X", 0 )
 GAME( 1986?,legend,   0,        legend,   legend,   srdmissn, ROT0,  "Sega / Coreland ?", "Legend", 0 )
 GAME( 1987, airwolf,  0,        srdmissn, airwolf,  srdmissn, ROT0,  "Kyugo", "Airwolf", 0 )
 GAME( 1987, skywolf,  airwolf,  srdmissn, skywolf,  srdmissn, ROT0,  "bootleg", "Sky Wolf (set 1)", 0 )
