@@ -61,7 +61,6 @@ Preliminary COP MCU memory map
 ***************************************************************************/
 
 #include "driver.h"
-#include "vidhrdw/generic.h"
 #include "cpu/z80/z80.h"
 #include "sndhrdw/seibu.h"
 #include "sound/3812intf.h"
@@ -1351,7 +1350,7 @@ INPUT_PORTS_END
 /*****************************************************************************/
 
 
-static gfx_layout legionna_charlayout =
+static const gfx_layout legionna_charlayout =
 {
 	8,8,
 	RGN_FRAC(1,4),	/* other half is BK3, decoded in char2layout */
@@ -1362,7 +1361,7 @@ static gfx_layout legionna_charlayout =
 	16*8
 };
 
-static gfx_layout heatbrl_charlayout =
+static const gfx_layout heatbrl_charlayout =
 {
 	8,8,
 	RGN_FRAC(1,2),	/* second half is junk, like legionna we may need a different decode */
@@ -1374,7 +1373,7 @@ static gfx_layout heatbrl_charlayout =
 };
 
 
-static gfx_layout legionna_char2layout =
+static const gfx_layout legionna_char2layout =
 {
 	16,16,
 	256,	/* Can't use RGN_FRAC as (1,16) not supported */
@@ -1389,7 +1388,7 @@ static gfx_layout legionna_char2layout =
 	16*8
 };
 
-static gfx_layout legionna_tilelayout =
+static const gfx_layout legionna_tilelayout =
 {
 	16,16,
 	RGN_FRAC(1,1),
@@ -1402,7 +1401,7 @@ static gfx_layout legionna_tilelayout =
 	128*8
 };
 
-static gfx_layout legionna_spritelayout =
+static const gfx_layout legionna_spritelayout =
 {
 	16,16,
 	RGN_FRAC(1,1),
@@ -1415,7 +1414,7 @@ static gfx_layout legionna_spritelayout =
 	128*8
 };
 
-static gfx_decode legionna_gfxdecodeinfo[] =
+static const gfx_decode legionna_gfxdecodeinfo[] =
 {
 	{ REGION_GFX1, 0, &legionna_charlayout,   48*16, 16 },
 	{ REGION_GFX3, 0, &legionna_tilelayout,    0*16, 16 },
@@ -1426,7 +1425,7 @@ static gfx_decode legionna_gfxdecodeinfo[] =
 	{ -1 } /* end of array */
 };
 
-static gfx_decode heatbrl_gfxdecodeinfo[] =
+static const gfx_decode heatbrl_gfxdecodeinfo[] =
 {
 	{ REGION_GFX1, 0, &heatbrl_charlayout,    48*16, 16 },
 	{ REGION_GFX3, 0, &legionna_tilelayout,    0*16, 16 },
@@ -1458,7 +1457,7 @@ static MACHINE_DRIVER_START( legionna )
 	MDRV_FRAMES_PER_SECOND(60)
 	MDRV_VBLANK_DURATION(DEFAULT_60HZ_VBLANK_DURATION)
 
-	MDRV_MACHINE_INIT(seibu_sound_1)
+	MDRV_MACHINE_RESET(seibu_sound_1)
 
 	/* video hardware */
 	MDRV_VIDEO_ATTRIBUTES(VIDEO_TYPE_RASTER | VIDEO_BUFFERS_SPRITERAM)
@@ -1487,7 +1486,7 @@ static MACHINE_DRIVER_START( heatbrl )
 	MDRV_FRAMES_PER_SECOND(60)
 	MDRV_VBLANK_DURATION(DEFAULT_60HZ_VBLANK_DURATION)
 
-	MDRV_MACHINE_INIT(seibu_sound_1)
+	MDRV_MACHINE_RESET(seibu_sound_1)
 
 	/* video hardware */
 	MDRV_VIDEO_ATTRIBUTES(VIDEO_TYPE_RASTER | VIDEO_BUFFERS_SPRITERAM)
@@ -1515,7 +1514,7 @@ static MACHINE_DRIVER_START( godzilla )
 	MDRV_FRAMES_PER_SECOND(61)
 	MDRV_VBLANK_DURATION(DEFAULT_60HZ_VBLANK_DURATION)
 
-	MDRV_MACHINE_INIT(seibu_sound_1)
+	MDRV_MACHINE_RESET(seibu_sound_1)
 
 	/* video hardware */
 	MDRV_VIDEO_ATTRIBUTES(VIDEO_TYPE_RASTER | VIDEO_BUFFERS_SPRITERAM)
@@ -1543,7 +1542,7 @@ static MACHINE_DRIVER_START( sdgndmrb )
 	MDRV_FRAMES_PER_SECOND(60)
 	MDRV_VBLANK_DURATION(DEFAULT_60HZ_VBLANK_DURATION)
 
-	MDRV_MACHINE_INIT(seibu_sound_1)
+	MDRV_MACHINE_RESET(seibu_sound_1)
 
 	/* video hardware */
 	MDRV_VIDEO_ATTRIBUTES(VIDEO_TYPE_RASTER | VIDEO_BUFFERS_SPRITERAM)
@@ -1571,7 +1570,7 @@ static MACHINE_DRIVER_START( cupsoc )
 	MDRV_FRAMES_PER_SECOND(60)
 	MDRV_VBLANK_DURATION(DEFAULT_60HZ_VBLANK_DURATION)
 
-	MDRV_MACHINE_INIT(seibu_sound_1)
+	MDRV_MACHINE_RESET(seibu_sound_1)
 
 	/* video hardware */
 	MDRV_VIDEO_ATTRIBUTES(VIDEO_TYPE_RASTER | VIDEO_BUFFERS_SPRITERAM)
@@ -1819,7 +1818,7 @@ Notes:
 */
 
 ROM_START( godzilla )
-	ROM_REGION( 0x80000, REGION_CPU1, 0 )	/* 68000 code */
+	ROM_REGION( 0x100000, REGION_CPU1, 0 )	/* 68000 code */
 	ROM_LOAD32_BYTE( "2.025",        0x000000, 0x020000, CRC(be9c6e5a) SHA1(9a7e49ac9cdbcc02b13b3448544cee5fe398ec16) )
 	ROM_LOAD32_BYTE( "1.024",        0x000001, 0x020000, CRC(0d6b663d) SHA1(01e02999cffd2642f7a37e492fe7f83770cddd67) )
 	ROM_LOAD32_BYTE( "4.026",        0x000002, 0x020000, CRC(bb8c0132) SHA1(fa8b049f590be710b3cf82f27deade63656db730) )
