@@ -59,7 +59,6 @@ L056-6    9A          "      "      VLI-8-4 7A         "
 */
 
 #include "driver.h"
-#include "vidhrdw/generic.h"
 #include "sound/ay8910.h"
 #include "sound/dac.h"
 #include "sound/5220intf.h"
@@ -299,7 +298,7 @@ static ADDRESS_MAP_START( looping_io_writeport, ADDRESS_SPACE_IO, 8 )
 	AM_RANGE(0x001, 0x007) AM_WRITE(looping_sound_sw)
 ADDRESS_MAP_END
 
-static gfx_layout tile_layout =
+static const gfx_layout tile_layout =
 {
 	8,8,		/* 8*8 characters */
 	0x100,		/* number of characters */
@@ -310,7 +309,7 @@ static gfx_layout tile_layout =
 	8*8
 };
 
-static gfx_layout sprite_layout =
+static const gfx_layout sprite_layout =
 {
 	16,16,		/* 8*8 characters */
 	0x40,		/* number of characters */
@@ -327,7 +326,7 @@ static gfx_layout sprite_layout =
 	8*8*4
 };
 
-static gfx_decode looping_gfxdecodeinfo[] =
+static const gfx_decode looping_gfxdecodeinfo[] =
 {
 	{ REGION_GFX1, 0, &tile_layout,		0, 8 },
 	{ REGION_GFX1, 0, &sprite_layout,	0, 8 },
