@@ -25,7 +25,6 @@ TODO:
 ***************************************************************************/
 
 #include "driver.h"
-#include "vidhrdw/generic.h"
 #include "sound/ay8910.h"
 #include "sound/2203intf.h"
 
@@ -61,7 +60,7 @@ WRITE8_HANDLER( lsasquad_bankswitch_w )
 	unsigned char *ROM = memory_region(REGION_CPU1);
 
 	/* bits 0-2 select ROM bank */
-	cpu_setbank(1,&ROM[0x10000 + 0x2000 * (data & 7)]);
+	memory_set_bankptr(1,&ROM[0x10000 + 0x2000 * (data & 7)]);
 
 	/* bit 3 is zeroed on startup, maybe reset sound CPU */
 
@@ -270,7 +269,7 @@ INPUT_PORTS_END
 
 
 
-static struct GfxLayout charlayout =
+static const gfx_layout charlayout =
 {
 	8,8,
 	RGN_FRAC(1,2),
@@ -281,7 +280,7 @@ static struct GfxLayout charlayout =
 	16*8
 };
 
-static struct GfxLayout spritelayout =
+static const gfx_layout spritelayout =
 {
 	16,16,
 	RGN_FRAC(1,2),
@@ -294,7 +293,7 @@ static struct GfxLayout spritelayout =
 	64*8
 };
 
-static struct GfxDecodeInfo gfxdecodeinfo[] =
+static const gfx_decode gfxdecodeinfo[] =
 {
 	{ REGION_GFX1, 0, &charlayout,     0, 16 },
 	{ REGION_GFX2, 0, &spritelayout, 256, 16 },
@@ -456,5 +455,5 @@ static DRIVER_INIT( lsasquad ) { lsasquad_invertcoin = 0x00; init_common(); }
 static DRIVER_INIT( storming ) { lsasquad_invertcoin = 0x0c; init_common(); }
 
 
-GAMEX( 1986, lsasquad, 0,        lsasquad, lsasquad, lsasquad, ROT270, "Taito", "Land Sea Air Squad / Riku Kai Kuu Saizensen", GAME_IMPERFECT_GRAPHICS )
-GAMEX( 1986, storming, lsasquad, lsasquad, lsasquad, storming, ROT270, "Taito", "Storming Party / Riku Kai Kuu Saizensen", GAME_IMPERFECT_GRAPHICS )
+GAME( 1986, lsasquad, 0,        lsasquad, lsasquad, lsasquad, ROT270, "Taito", "Land Sea Air Squad / Riku Kai Kuu Saizensen", GAME_IMPERFECT_GRAPHICS )
+GAME( 1986, storming, lsasquad, lsasquad, lsasquad, storming, ROT270, "Taito", "Storming Party / Riku Kai Kuu Saizensen", GAME_IMPERFECT_GRAPHICS )
