@@ -46,7 +46,6 @@ Notes:
 ***************************************************************************/
 
 #include "driver.h"
-#include "vidhrdw/generic.h"
 #include "lwings.h"
 #include "sound/2203intf.h"
 #include "sound/msm5205.h"
@@ -136,7 +135,7 @@ static WRITE8_HANDLER( avengers_prot_bank_w )
 
 static int avengers_fetch_paldata( void )
 {
-	const char pal_data[] =
+	static const char pal_data[] =
 	/* page 1: 0x03,0x02,0x01,0x00 */
 	"0000000000000000" "A65486A6364676D6" "C764C777676778A7" "A574E5E5C5756AE5"
 	"0000000000000000" "F51785D505159405" "A637B6A636269636" "F45744E424348824"
@@ -218,8 +217,8 @@ static int avengers_fetch_paldata( void )
 
 static READ8_HANDLER( avengers_protection_r )
 {
-	const int xpos[8] = { 10, 7,  0, -7, -10, -7,   0,  7 };
-	const int ypos[8] = {  0, 7, 10,  7,   0, -7, -10, -7 };
+	static const int xpos[8] = { 10, 7,  0, -7, -10, -7,   0,  7 };
+	static const int ypos[8] = {  0, 7, 10,  7,   0, -7, -10, -7 };
 	int best_dist = 0;
 	int best_dir = 0;
 	int x,y;
@@ -781,7 +780,7 @@ INPUT_PORTS_START( avengers )
 	PORT_DIPSETTING(    0xc0, DEF_STR( 1C_6C ) )
 INPUT_PORTS_END
 
-static gfx_layout charlayout =
+static const gfx_layout charlayout =
 {
 	8,8,
 	RGN_FRAC(1,1),
@@ -792,7 +791,7 @@ static gfx_layout charlayout =
 	16*8
 };
 
-static gfx_layout spritelayout =
+static const gfx_layout spritelayout =
 {
 	16,16,
 	RGN_FRAC(1,2),
@@ -805,7 +804,7 @@ static gfx_layout spritelayout =
 	64*8
 };
 
-static gfx_layout bg1_tilelayout =
+static const gfx_layout bg1_tilelayout =
 {
 	16,16,
 	RGN_FRAC(1,4),
@@ -818,7 +817,7 @@ static gfx_layout bg1_tilelayout =
 	32*8
 };
 
-static gfx_layout bg2_tilelayout =
+static const gfx_layout bg2_tilelayout =
 {
 	16,16,
 	RGN_FRAC(1,2),
@@ -832,7 +831,7 @@ static gfx_layout bg2_tilelayout =
 };
 
 
-static gfx_decode gfxdecodeinfo[] =
+static const gfx_decode gfxdecodeinfo[] =
 {
 	{ REGION_GFX1, 0, &charlayout,     512, 16 }, /* colors 512-575 */
 	{ REGION_GFX2, 0, &bg1_tilelayout,   0,  8 }, /* colors   0-127 */
@@ -840,7 +839,7 @@ static gfx_decode gfxdecodeinfo[] =
 	{ -1 } /* end of array */
 };
 
-static gfx_decode gfxdecodeinfo_trojan[] =
+static const gfx_decode gfxdecodeinfo_trojan[] =
 {
 	{ REGION_GFX1, 0, &charlayout,     768, 16 }, /* colors 768-831 */
 	{ REGION_GFX2, 0, &bg1_tilelayout, 256,  8 }, /* colors 256-383 */
