@@ -9,7 +9,6 @@ TODO:
   (background scrolls faster than sprites)
 - should use VIDEO_RGB_DIRECT for alpha blending to work, but tilemap_draw_roz()
   doesn't support it.
-- lines of garbage tiles in a couple of places in macrossp (e.g. level 2). Bad ROM?
 - Sprite Zoom on quizmoon title screen isn't right
 - Tilemap zoom effect on macrossp title screen and probably other places
 - Priorities (Sprites & Backgrounds) - see quizmoon attract mode
@@ -38,7 +37,6 @@ TODO:
 ******************************************************************************/
 
 #include "driver.h"
-#include "vidhrdw/generic.h"
 #include "sound/es5506.h"
 
 /*** README INFO **************************************************************
@@ -271,8 +269,6 @@ static READ32_HANDLER ( macrossp_soundstatus_r )
 
 	toggle ^= 1;
 
-	if (Machine->sample_rate == 0) return (rand()&2) | toggle;
-
 	return (sndpending << 1) | toggle;
 }
 
@@ -709,7 +705,7 @@ INPUT_PORTS_END
 
 /*** GFX DECODE **************************************************************/
 
-static gfx_layout macrossp_char16x16x4layout =
+static const gfx_layout macrossp_char16x16x4layout =
 {
 	16,16,
 	RGN_FRAC(1,1),
@@ -721,7 +717,7 @@ static gfx_layout macrossp_char16x16x4layout =
 	16*64
 };
 
-static gfx_layout macrossp_char16x16x8layout =
+static const gfx_layout macrossp_char16x16x8layout =
 {
 	16,16,
 	RGN_FRAC(1,1),
@@ -733,7 +729,7 @@ static gfx_layout macrossp_char16x16x8layout =
 	16*128
 };
 
-static gfx_decode gfxdecodeinfo[] =
+static const gfx_decode gfxdecodeinfo[] =
 {
 	{ REGION_GFX1, 0, &macrossp_char16x16x8layout,   0x000, 0x20 },	/* 8bpp but 6bpp granularity */
 	{ REGION_GFX2, 0, &macrossp_char16x16x8layout,   0x800, 0x20 },	/* 8bpp but 6bpp granularity */
@@ -809,8 +805,8 @@ MACHINE_DRIVER_END
 /*** ROM LOADING *************************************************************/
 
 ROM_START( macrossp )
-	ROM_REGION( 0x200000, REGION_CPU1, 0 )
-	ROM_LOAD32_BYTE( "bp964a-c.u1", 0x000003, 0x080000, CRC(e37904e4) SHA1(e51e446f3699632c53c40e4c16d0ffb76ed1123f) )
+	ROM_REGION( 0x400000, REGION_CPU1, 0 )
+	ROM_LOAD32_BYTE( "bp964a-c.u1", 0x000003, 0x080000, CRC(39da35e7) SHA1(022c902b0adf21090c650ce68e4b8b42498e1be6) )
 	ROM_LOAD32_BYTE( "bp964a-c.u2", 0x000002, 0x080000, CRC(86d0ca6a) SHA1(8cc1b4a83cbba8b07e1343c5c20e2590d3ce471a) )
 	ROM_LOAD32_BYTE( "bp964a-c.u3", 0x000001, 0x080000, CRC(fb895a7b) SHA1(547e5d3d43e503a15573748ab49a44e5569db1d7) )
 	ROM_LOAD32_BYTE( "bp964a-c.u4", 0x000000, 0x080000, CRC(8c8b966c) SHA1(881fa2b7aefc3ea916924b715d2cd0ceaffe2d92) )
@@ -847,7 +843,7 @@ ROM_START( macrossp )
 	ROM_LOAD16_BYTE( "bp964a.u24", 0x000000, 0x400000, CRC(93f90336) SHA1(75daa2f8cedc732cf5ef98254f61748c94b94aea) )
 
 	ROM_REGION16_BE( 0x400000, REGION_SOUND2, 0 )
-	/* Filled in below in init routine */
+	ROM_COPY( REGION_SOUND1, 0x400000, 0x000000, 0x400000 )
 ROM_END
 
 ROM_START( quizmoon )
@@ -883,7 +879,7 @@ ROM_START( quizmoon )
 	ROM_REGION( 0x0200000, REGION_GFX4, 0 )
 	ROM_LOAD( "u17.bin", 0x0000000, 0x0200000, CRC(ff93c949) SHA1(13917d73a6cb70d03d0335bd816bf6b094758d0b) )
 
-	ROM_REGION( 0x400000, REGION_GFX5, 0 )
+	ROM_REGION( 0x400000, REGION_GFX5, ROMREGION_ERASE00 )
 	/* nothing on this game? */
 
 	ROM_REGION16_BE( 0x800000, REGION_SOUND1, 0 )
@@ -891,14 +887,14 @@ ROM_START( quizmoon )
 	ROM_LOAD16_BYTE( "u24.bin", 0x0000001, 0x0400000, CRC(5b12d0b1) SHA1(c5ddff2053148a1da0710a10f48689bf5c736ae4) )
 
 	ROM_REGION16_BE( 0x400000, REGION_SOUND2, 0 )
-	/* Filled in below in init routine */
+	ROM_COPY( REGION_SOUND1, 0x400000, 0x000000, 0x400000 )
 
 	ROM_REGION16_BE( 0x800000, REGION_SOUND3, 0 )
 	ROM_LOAD16_BYTE( "u27.bin", 0x0000000, 0x0400000, CRC(bd75d165) SHA1(2da770d15c812cbfdb4e3048d320071edffccfa1) )
 	ROM_LOAD16_BYTE( "u25.bin", 0x0000001, 0x0400000, CRC(3b9689bc) SHA1(0857c3d3e9810f9468f7c17f8b795825c55a9f08) )
 
 	ROM_REGION16_BE( 0x400000, REGION_SOUND4, 0 )
-	/* Filled in below in init routine */
+	ROM_COPY( REGION_SOUND3, 0x400000, 0x000000, 0x400000 )
 ROM_END
 
 
@@ -916,26 +912,11 @@ PC :00018110 018110: beq     18104
 
 static DRIVER_INIT( macrossp )
 {
-	/* Expand top half of sound ROM into second banked sound area */
-	const UINT8* src=memory_region(REGION_SOUND1);
-	UINT8* dst=memory_region(REGION_SOUND2);
-
-	memcpy(dst,src+0x400000,0x400000);
-
 	memory_install_write32_handler(0, ADDRESS_SPACE_PROGRAM, 0xf10158, 0xf1015b, 0, 0, macrossp_speedup_w );
 }
 
 static DRIVER_INIT( quizmoon )
 {
-	/* Expand top half of sound ROM into second banked sound area */
-	const UINT8* src=memory_region(REGION_SOUND1);
-	UINT8* dst=memory_region(REGION_SOUND2);
-
-	memcpy(dst,src+0x400000,0x400000);
-
-	src=memory_region(REGION_SOUND3);
-	dst=memory_region(REGION_SOUND4);
-	memcpy(dst,src+0x400000,0x400000);
 }
 
 GAME( 1996, macrossp, 0, macrossp, macrossp, macrossp, ROT270, "Banpresto", "Macross Plus", GAME_IMPERFECT_GRAPHICS )
