@@ -18,7 +18,6 @@ Magic's 10 instruction for the 1st boot:
 */
 
 #include "driver.h"
-#include "vidhrdw/generic.h"
 #include "sound/okim6295.h"
 
 static tilemap *layer0_tilemap, *layer1_tilemap, *layer2_tilemap;
@@ -322,7 +321,7 @@ VIDEO_UPDATE( magic10 )
 	tilemap_draw(bitmap,cliprect,layer2_tilemap,0,0);
 }
 
-static gfx_layout tiles8x8_layout =
+static const gfx_layout tiles8x8_layout =
 {
 	8,8,
 	RGN_FRAC(1,4),
@@ -333,7 +332,7 @@ static gfx_layout tiles8x8_layout =
 	8*8
 };
 
-static gfx_layout tiles16x16_layout =
+static const gfx_layout tiles16x16_layout =
 {
 	16,16,
 	RGN_FRAC(1,4),
@@ -346,7 +345,7 @@ static gfx_layout tiles16x16_layout =
 	32*8
 };
 
-static gfx_decode gfxdecodeinfo[] =
+static const gfx_decode gfxdecodeinfo[] =
 {
 	{ REGION_GFX1, 0, &tiles8x8_layout,   0, 16 },
 	{ REGION_GFX1, 0, &tiles16x16_layout, 0, 16 },
