@@ -9,7 +9,6 @@ Additional tweaking by Jarek Burczynski
 ***************************************************************************/
 
 #include "driver.h"
-#include "vidhrdw/generic.h"
 #include "cpu/m68000/m68000.h"
 #include "sound/ay8910.h"
 
@@ -18,8 +17,8 @@ VIDEO_UPDATE( magmax );
 VIDEO_START( magmax );
 
 extern unsigned short magmax_vreg;
-extern data16_t *magmax_scroll_x;
-extern data16_t *magmax_scroll_y;
+extern UINT16 *magmax_scroll_x;
+extern UINT16 *magmax_scroll_y;
 
 
 static unsigned char sound_latch = 0;
@@ -67,7 +66,7 @@ static void scanline_callback(int scanline)
 	timer_set( cpu_getscanlinetime( scanline ), scanline, scanline_callback );
 }
 
-static MACHINE_INIT( magmax )
+static MACHINE_RESET( magmax )
 {
 	timer_set(cpu_getscanlinetime( 64 ), 64, scanline_callback );
 #if 0
@@ -135,7 +134,7 @@ bit3 - SOUND Chan#8 name=AY-3-8910 #2 Ch C
 
 	gain_control = data & 0x0f;
 
-	/*usrintf_showmessage("gain_ctrl = %2x",data&0x0f);*/
+	/*ui_popup("gain_ctrl = %2x",data&0x0f);*/
 
 	percent = (gain_control & 1) ? 1.0 : 0.50;
 	sndti_set_output_gain(SOUND_AY8910, 0, 0, percent);
@@ -304,7 +303,7 @@ INPUT_PORTS_START( magmax )
 INPUT_PORTS_END
 
 
-static struct GfxLayout charlayout =
+static const gfx_layout charlayout =
 {
 	8, 8,	/* 8*8 characters */
 	256,	/* 256 characters */
@@ -315,7 +314,7 @@ static struct GfxLayout charlayout =
 	32*8
 };
 
-static struct GfxLayout spritelayout =
+static const gfx_layout spritelayout =
 {
 	16, 16,	/* 16*16 characters */
 	512,	/* 512 characters */
@@ -328,7 +327,7 @@ static struct GfxLayout spritelayout =
 	64*8
 };
 
-static struct GfxDecodeInfo gfxdecodeinfo[] =
+static const gfx_decode gfxdecodeinfo[] =
 {
 	{ REGION_GFX1, 0, &charlayout,           0,  1 }, /*no color codes*/
 	{ REGION_GFX2, 0, &spritelayout,      1*16, 16 }, /*16 color codes*/
@@ -361,7 +360,7 @@ static MACHINE_DRIVER_START( magmax )
 	MDRV_VBLANK_DURATION(DEFAULT_60HZ_VBLANK_DURATION)
 	MDRV_INTERLEAVE(10)
 
-	MDRV_MACHINE_INIT(magmax)
+	MDRV_MACHINE_RESET(magmax)
 
 	/* video hardware */
 	MDRV_VIDEO_ATTRIBUTES(VIDEO_TYPE_RASTER)
@@ -439,4 +438,4 @@ ROM_START( magmax )
 ROM_END
 
 
-GAME( 1985, magmax, 0, magmax, magmax, 0, ROT0, "Nichibutsu", "Mag Max" )
+GAME( 1985, magmax, 0, magmax, magmax, 0, ROT0, "Nichibutsu", "Mag Max", 0 )
