@@ -37,23 +37,18 @@
 */
 
 #include "driver.h"
-#include "vidhrdw/generic.h"
 #include "vidhrdw/s2636.h"
 #include "cpu/s2650/s2650.h"
 #include "sound/sn76477.h"
 
 #define SAA5050_VBLANK 2500
 
-int malzak_bank1;
-int malzak_bank2;
+static int malzak_bank1;
 
-extern int temp_x,temp_y;
+extern int malzak_x;
+extern int malzak_y;
 
 extern unsigned char* saa5050_vidram;  /* Video RAM for SAA 5050 */
-extern unsigned char* s2636_1_ram;  /* Video RAM for S2636 #1 */
-extern unsigned char* s2636_2_ram;  /* Video RAM for S2636 #2 */
-extern unsigned char s2636_1_dirty[4];
-extern unsigned char s2636_2_dirty[4];
 
 /* in vidhrdw/malzak.c */
 VIDEO_START( malzak );
@@ -240,7 +235,7 @@ static WRITE8_HANDLER( port40_w )
 /*  Bits 1-3 are all set high upon death, until the game continues */
 /*  Bit 6 is used only in Malzak II, and is set high after checking */
 /*        the selected version */
-/*  logerror("S2650 [0x%04x]: port 0x40 write: 0x%02x\n",cpunum_get_pc_byte(0),data); */
+/*  logerror("S2650 [0x%04x]: port 0x40 write: 0x%02x\n",cpunum_get_physical_pc_byte(0),data); */
 	if(data & 0x40)
 		malzak_bank1 = 1;
 	else
@@ -249,13 +244,13 @@ static WRITE8_HANDLER( port40_w )
 
 static WRITE8_HANDLER( port60_w )
 {
-	temp_x = data;
+	malzak_x = data;
 /*  logerror("I/O: port 0x60 write 0x%02x\n",data); */
 }
 
 static WRITE8_HANDLER( portc0_w )
 {
-	temp_y = data;
+	malzak_y = data;
 /*  logerror("I/O: port 0xc0 write 0x%02x\n",data); */
 }
 
@@ -335,7 +330,7 @@ INPUT_PORTS_START( malzak2 )
 INPUT_PORTS_END
 
 
-static gfx_layout charlayout =
+static const gfx_layout charlayout =
 {
 	16,16,
 	RGN_FRAC(1,1),
@@ -349,7 +344,7 @@ static gfx_layout charlayout =
 /*  8*8 */
 };
 
-static gfx_layout s2636_character10 =
+static const gfx_layout s2636_character10 =
 {
 	8,10,
 	5,
@@ -360,7 +355,7 @@ static gfx_layout s2636_character10 =
 	8*16
 };
 
-static gfx_layout saa5050_charlayout =
+static const gfx_layout saa5050_charlayout =
 {
 	6, 10,
 	256,
@@ -372,7 +367,7 @@ static gfx_layout saa5050_charlayout =
 	8 * 10
 };
 
-static gfx_layout saa5050_hilayout =
+static const gfx_layout saa5050_hilayout =
 {
 	6, 10,
 	256,
@@ -384,7 +379,7 @@ static gfx_layout saa5050_hilayout =
 	8 * 10
 };
 
-static gfx_layout saa5050_lolayout =
+static const gfx_layout saa5050_lolayout =
 {
 	6, 10,
 	256,
@@ -422,7 +417,7 @@ static	unsigned	short	saa5050_colortable[64 * 2] =
 };
 
 /*add s2636 decodes here (i.e. from zac2650) and maybe re-arrange them */
-static gfx_decode malzak_gfxdecodeinfo[] =
+static const gfx_decode malzak_gfxdecodeinfo[] =
 {
 	{ REGION_GFX1, 0, &charlayout,  0, 16 },
   	{ REGION_CPU1, 0x0000, &s2636_character10, 0, 8 },	/* s2636 #1  */
@@ -443,7 +438,7 @@ static PALETTE_INIT( malzak )
 }
 
 
-MACHINE_INIT(malzak)
+MACHINE_RESET(malzak)
 {
 /*  val++; */
 /*  printf("val = %X\n",val); */
@@ -489,7 +484,7 @@ static MACHINE_DRIVER_START( malzak )
 	MDRV_PALETTE_INIT(malzak)
 	MDRV_COLORTABLE_LENGTH(128)
 
-/*  MDRV_MACHINE_INIT(malzak) */
+/*  MDRV_MACHINE_RESET(malzak) */
 
 	MDRV_VIDEO_START(malzak)
 	MDRV_VIDEO_UPDATE(malzak)
