@@ -36,14 +36,13 @@ write
 ***************************************************************************/
 
 #include "driver.h"
-#include "vidhrdw/generic.h"
 #include "sound/ay8910.h"
 
 
 extern unsigned char *marineb_column_scroll;
 extern int marineb_active_low_flipscreen;
 
-MACHINE_INIT( espial );
+MACHINE_RESET( espial );
 PALETTE_INIT( espial );
 
 WRITE8_HANDLER( marineb_palbank0_w );
@@ -59,16 +58,16 @@ VIDEO_UPDATE( hoccer );
 VIDEO_UPDATE( hopprobo );
 
 
-static MACHINE_INIT( marineb )
+static MACHINE_RESET( marineb )
 {
 	marineb_active_low_flipscreen = 0;
-	machine_init_espial();
+	machine_reset_espial();
 }
 
-static MACHINE_INIT( springer )
+static MACHINE_RESET( springer )
 {
 	marineb_active_low_flipscreen = 1;
-	machine_init_espial();
+	machine_reset_espial();
 }
 
 static ADDRESS_MAP_START( readmem, ADDRESS_SPACE_PROGRAM, 8 )
@@ -408,7 +407,7 @@ INPUT_PORTS_START( bcruzm12 )
 	PORT_DIPSETTING(    0x00, DEF_STR( Free_Play ) )
 INPUT_PORTS_END
 
-static gfx_layout marineb_charlayout =
+static const gfx_layout marineb_charlayout =
 {
 	8,8,	/* 8*8 characters */
 	512,	/* 512 characters */
@@ -419,7 +418,7 @@ static gfx_layout marineb_charlayout =
 	16*8	/* every char takes 16 bytes */
 };
 
-static gfx_layout wanted_charlayout =
+static const gfx_layout wanted_charlayout =
 {
 	8,8,	/* 8*8 characters */
 	1024,	/* 1024 characters */
@@ -430,7 +429,7 @@ static gfx_layout wanted_charlayout =
 	16*8	/* every char takes 16 bytes */
 };
 
-static gfx_layout hopprobo_charlayout =
+static const gfx_layout hopprobo_charlayout =
 {
 	8,8,	/* 8*8 characters */
 	1024,	/* 1024 characters */
@@ -441,7 +440,7 @@ static gfx_layout hopprobo_charlayout =
 	16*8	/* every char takes 16 bytes */
 };
 
-static gfx_layout marineb_small_spritelayout =
+static const gfx_layout marineb_small_spritelayout =
 {
 	16,16,	/* 16*16 sprites */
 	64,	    /* 64 sprites */
@@ -454,7 +453,7 @@ static gfx_layout marineb_small_spritelayout =
 	32*8	/* every sprite takes 32 consecutive bytes */
 };
 
-static gfx_layout marineb_big_spritelayout =
+static const gfx_layout marineb_big_spritelayout =
 {
 	32,32,	/* 32*32 sprites */
 	64,	    /* 64 sprites */
@@ -471,7 +470,7 @@ static gfx_layout marineb_big_spritelayout =
 	4*32*8	/* every sprite takes 128 consecutive bytes */
 };
 
-static gfx_layout changes_small_spritelayout =
+static const gfx_layout changes_small_spritelayout =
 {
 	16,16,	/* 16*16 sprites */
 	64,	    /* 64 sprites */
@@ -484,7 +483,7 @@ static gfx_layout changes_small_spritelayout =
 	64*8	/* every sprite takes 64 consecutive bytes */
 };
 
-static gfx_layout changes_big_spritelayout =
+static const gfx_layout changes_big_spritelayout =
 {
 	32,32,	/* 32*3 sprites */
 	16,	    /* 32 sprites */
@@ -502,7 +501,7 @@ static gfx_layout changes_big_spritelayout =
 };
 
 
-static gfx_decode marineb_gfxdecodeinfo[] =
+static const gfx_decode marineb_gfxdecodeinfo[] =
 {
 	{ REGION_GFX1, 0x0000, &marineb_charlayout,          0, 64 },
 	{ REGION_GFX2, 0x0000, &marineb_small_spritelayout,  0, 64 },
@@ -510,7 +509,7 @@ static gfx_decode marineb_gfxdecodeinfo[] =
 	{ -1 } /* end of array */
 };
 
-static gfx_decode wanted_gfxdecodeinfo[] =
+static const gfx_decode wanted_gfxdecodeinfo[] =
 {
 	{ REGION_GFX1, 0x0000, &wanted_charlayout,           0, 64 },
 	{ REGION_GFX2, 0x0000, &marineb_small_spritelayout,  0, 64 },
@@ -518,7 +517,7 @@ static gfx_decode wanted_gfxdecodeinfo[] =
 	{ -1 } /* end of array */
 };
 
-static gfx_decode changes_gfxdecodeinfo[] =
+static const gfx_decode changes_gfxdecodeinfo[] =
 {
 	{ REGION_GFX1, 0x0000, &marineb_charlayout,          0, 64 },
 	{ REGION_GFX2, 0x0000, &changes_small_spritelayout,  0, 64 },
@@ -526,14 +525,14 @@ static gfx_decode changes_gfxdecodeinfo[] =
 	{ -1 } /* end of array */
 };
 
-static gfx_decode hoccer_gfxdecodeinfo[] =
+static const gfx_decode hoccer_gfxdecodeinfo[] =
 {
 	{ REGION_GFX1, 0x0000, &marineb_charlayout,          0, 16 },	/* no palette banks */
 	{ REGION_GFX2, 0x0000, &changes_small_spritelayout,  0, 16 },	/* no palette banks */
 	{ -1 } /* end of array */
 };
 
-static gfx_decode hopprobo_gfxdecodeinfo[] =
+static const gfx_decode hopprobo_gfxdecodeinfo[] =
 {
 	{ REGION_GFX1, 0x0000, &hopprobo_charlayout,         0, 64 },
 	{ REGION_GFX2, 0x0000, &marineb_small_spritelayout,  0, 64 },
@@ -553,7 +552,7 @@ static MACHINE_DRIVER_START( marineb )
 	MDRV_FRAMES_PER_SECOND(60)
 	MDRV_VBLANK_DURATION(5000)	/* frames per second, vblank duration */
 
-	MDRV_MACHINE_INIT(marineb)
+	MDRV_MACHINE_RESET(marineb)
 
 	/* video hardware */
 	MDRV_VIDEO_ATTRIBUTES(VIDEO_TYPE_RASTER)
@@ -588,7 +587,7 @@ static MACHINE_DRIVER_START( springer )
 
 	/* basic machine hardware */
 	MDRV_IMPORT_FROM(marineb)
-	MDRV_MACHINE_INIT(springer)
+	MDRV_MACHINE_RESET(springer)
 
 	/* video hardware */
 	MDRV_VIDEO_UPDATE(springer)
@@ -642,7 +641,7 @@ static MACHINE_DRIVER_START( bcruzm12 )
 
 	/* basic machine hardware */
 	MDRV_IMPORT_FROM(wanted)
-	MDRV_MACHINE_INIT(springer)
+	MDRV_MACHINE_RESET(springer)
 MACHINE_DRIVER_END
 
 /***************************************************************************
