@@ -21,7 +21,6 @@ MAIN BOARD:
 ***************************************************************************/
 
 #include "driver.h"
-#include "vidhrdw/generic.h"
 #include "cpu/m6502/m6502.h"
 #include "cpu/m6809/m6809.h"
 #include "sound/ay8910.h"
@@ -218,22 +217,21 @@ INPUT_PORTS_START( matmania )
 	PORT_DIPSETTING(   0x02, DEF_STR( Medium ) )
 	PORT_DIPSETTING(   0x01, DEF_STR( Hard ) )
 	PORT_DIPSETTING(   0x00, DEF_STR( Hardest ) )
-	PORT_DIPNAME(0x04, 0x04, DEF_STR( Unknown ) )
-	PORT_DIPSETTING(   0x04, DEF_STR( Off ) )
-	PORT_DIPSETTING(   0x00, DEF_STR( On ) )
-	PORT_DIPNAME(0x08, 0x08, DEF_STR( Unknown ) )
-	PORT_DIPSETTING(   0x08, DEF_STR( Off ) )
-	PORT_DIPSETTING(   0x00, DEF_STR( On ) )
-	PORT_DIPNAME(0x10, 0x10, DEF_STR( Unknown ) )
+	PORT_DIPNAME(0x0c, 0x0c, "Tournament Time" )    /* Tournament time is always 3:00, but time per 1 second is shorter. */
+	PORT_DIPSETTING(   0x00, "2:12" )
+	PORT_DIPSETTING(   0x04, "2:24" )
+	PORT_DIPSETTING(   0x08, "2:30" )
+	PORT_DIPSETTING(   0x0c, "2:36" )
+	PORT_DIPNAME(0x10, 0x10, DEF_STR( Unused ) )
 	PORT_DIPSETTING(   0x10, DEF_STR( Off ) )
 	PORT_DIPSETTING(   0x00, DEF_STR( On ) )
-	PORT_DIPNAME(0x20, 0x20, DEF_STR( Unknown ) )
+	PORT_DIPNAME(0x20, 0x20, DEF_STR( Unused ) )
 	PORT_DIPSETTING(   0x20, DEF_STR( Off ) )
 	PORT_DIPSETTING(   0x00, DEF_STR( On ) )
-	PORT_DIPNAME(0x40, 0x40, DEF_STR( Unknown ) )
+	PORT_DIPNAME(0x40, 0x40, DEF_STR( Unused ) )
 	PORT_DIPSETTING(   0x40, DEF_STR( Off ) )
 	PORT_DIPSETTING(   0x00, DEF_STR( On ) )
-	PORT_DIPNAME(0x80, 0x80, DEF_STR( Unknown ) )
+	PORT_DIPNAME(0x80, 0x80, DEF_STR( Unused ) )
 	PORT_DIPSETTING(   0x80, DEF_STR( Off ) )
 	PORT_DIPSETTING(   0x00, DEF_STR( On ) )
 
@@ -251,14 +249,14 @@ INPUT_PORTS_START( matmania )
 	PORT_DIPNAME(0x10, 0x10, DEF_STR( Demo_Sounds ) )
 	PORT_DIPSETTING(   0x00, DEF_STR( Off ) )
 	PORT_DIPSETTING(   0x10, DEF_STR( On ) )
-	PORT_DIPNAME(0x20, 0x00, DEF_STR( Cabinet ) )
+	PORT_DIPNAME(0x20, 0x00, DEF_STR( Cabinet ) )    /* The default setting should be cocktail. */
 	PORT_DIPSETTING(   0x00, DEF_STR( Upright ) )
 	PORT_DIPSETTING(   0x20, DEF_STR( Cocktail ) )
 	PORT_SERVICE( 0x40, IP_ACTIVE_LOW )
 	PORT_BIT( 0x80, IP_ACTIVE_HIGH, IPT_VBLANK )
 INPUT_PORTS_END
 
-static gfx_layout charlayout =
+static const gfx_layout charlayout =
 {
 	8,8,	/* 8*8 characters */
 	1024,	/* 1024 characters */
@@ -269,7 +267,7 @@ static gfx_layout charlayout =
 	8*8	/* every char takes 8 consecutive bytes */
 };
 
-static gfx_layout tilelayout =
+static const gfx_layout tilelayout =
 {
 	16,16,  /* 16*16 tiles */
 	512,    /* 512 tiles */
@@ -282,7 +280,7 @@ static gfx_layout tilelayout =
 	32*8	/* every tile takes 16 consecutive bytes */
 };
 
-static gfx_layout matmania_spritelayout =
+static const gfx_layout matmania_spritelayout =
 {
 	16,16,  /* 16*16 sprites */
 	3584,    /* 3584 sprites */
@@ -295,7 +293,7 @@ static gfx_layout matmania_spritelayout =
 	32*8	/* every sprite takes 16 consecutive bytes */
 };
 
-static gfx_layout maniach_spritelayout =
+static const gfx_layout maniach_spritelayout =
 {
 	16,16,  /* 16*16 sprites */
 	3584,    /* 3584 sprites */
@@ -308,7 +306,7 @@ static gfx_layout maniach_spritelayout =
 	32*8	/* every sprite takes 16 consecutive bytes */
 };
 
-static gfx_layout maniach_tilelayout =
+static const gfx_layout maniach_tilelayout =
 {
 	16,16,  /* 16*16 tiles */
 	1024,    /* 1024 tiles */
@@ -321,7 +319,7 @@ static gfx_layout maniach_tilelayout =
 	32*8	/* every tile takes 16 consecutive bytes */
 };
 
-static gfx_decode matmania_gfxdecodeinfo[] =
+static const gfx_decode matmania_gfxdecodeinfo[] =
 {
 	{ REGION_GFX1, 0, &charlayout,              0, 4 },
 	{ REGION_GFX2, 0, &tilelayout,            4*8, 4 },
@@ -329,7 +327,7 @@ static gfx_decode matmania_gfxdecodeinfo[] =
 	{ -1 } /* end of array */
 };
 
-static gfx_decode maniach_gfxdecodeinfo[] =
+static const gfx_decode maniach_gfxdecodeinfo[] =
 {
 	{ REGION_GFX1, 0, &charlayout,             0, 4 },
 	{ REGION_GFX2, 0, &maniach_tilelayout,   4*8, 4 },
