@@ -23,13 +23,13 @@
 
 /* Supervisor board emulation */
 
-static unsigned char portA_in,portA_out,ddrA;
-static unsigned char portB_in,portB_out,ddrB;
-static unsigned char portC_in,portC_out,ddrC;
-static unsigned char tdr,tcr;
+static UINT8 portA_in,portA_out,ddrA;
+static UINT8 portB_in,portB_out,ddrB;
+static UINT8 portC_in,portC_out,ddrC;
+static UINT8 tdr,tcr;
 static mame_timer *mcu_timer;
-static signed char digitA, digitB, digitC;
-static unsigned char lamps;
+static INT8 digitA, digitB, digitC;
+static UINT8 lamps;
 
 /* Port A:
     0   (in)  DSW
@@ -197,7 +197,7 @@ WRITE8_HANDLER( mcu_tcr_w )
 	}
 }
 
-static MACHINE_INIT(supervisor_board)
+static MACHINE_RESET(supervisor_board)
 {
 	portA_in = portA_out = ddrA	= 0;
 	portB_in = portB_out = ddrB	= 0;
@@ -216,10 +216,10 @@ void supervisor_board_check_coin_input(void)
 	}
 }
 
-static MACHINE_INIT(maxaflex)
+static MACHINE_RESET(maxaflex)
 {
-	machine_init_supervisor_board();
-	machine_init_a600xl();
+	machine_reset_supervisor_board();
+	machine_reset_a600xl();
 }
 
 VIDEO_UPDATE(maxaflex)
@@ -269,7 +269,7 @@ int atari_readinputport(int port)
 
 static ADDRESS_MAP_START(a600xl_mem, ADDRESS_SPACE_PROGRAM, 8)
 	AM_RANGE(0x0000, 0x3fff) AM_RAM
-	AM_RANGE(0x5000, 0x57ff) AM_READWRITE(MRA8_BANK1, MWA8_BANK1)	/* self test */
+	AM_RANGE(0x5000, 0x57ff) AM_ROM AM_REGION(REGION_CPU1, 0x5000)	/* self test */
 	AM_RANGE(0x8000, 0xbfff) AM_ROM	/* game cartridge */
 	AM_RANGE(0xc000, 0xcfff) AM_ROM /* OS */
 	AM_RANGE(0xd000, 0xd0ff) AM_READWRITE(atari_gtia_r, atari_gtia_w)
@@ -512,7 +512,7 @@ static MACHINE_DRIVER_START( a600xl )
 	MDRV_SOUND_ADD(DAC, 0)
 	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.50)
 
-	MDRV_MACHINE_INIT( maxaflex )
+	MDRV_MACHINE_RESET( maxaflex )
 MACHINE_DRIVER_END
 
 ROM_START(maxaflex)
