@@ -36,7 +36,6 @@ TO DO:
 ****************************************************************************/
 
 #include "driver.h"
-#include "vidhrdw/generic.h"
 #include "sound/ay8910.h"
 
 static UINT8 *cfb_ram;
@@ -86,8 +85,8 @@ static double weights_r[2], weights_g[3], weights_b[3];
 static PALETTE_INIT( mazerbla )
 {
 
-	const int resistances_r[2]  = { 4700, 2200 };
-	const int resistances_gb[3] = { 10000, 4700, 2200 };
+	static const int resistances_r[2]  = { 4700, 2200 };
+	static const int resistances_gb[3] = { 10000, 4700, 2200 };
 
 
 /* just to calculate coefficients for later use */
@@ -741,7 +740,7 @@ unsigned char * rom = memory_region(REGION_CPU3) + (gfx_rom_bank * 0x2000) + 0x1
 		{
 			for (x = 0; x <= pix_xsize; x++)
 			{
-				UINT8 pixeldata = rom[offs + (bits>>3)];
+				UINT8 pixeldata = rom[(offs + (bits>>3)) % 0x2000];
 				UINT8 data = (pixeldata>>(6-(bits&7))) & 3;
 				UINT8 col = 0;
 
@@ -791,7 +790,7 @@ unsigned char * rom = memory_region(REGION_CPU3) + (gfx_rom_bank * 0x2000) + 0x1
 		{
 			for (x = 0; x <= pix_xsize; x++)
 			{
-				UINT8 pixeldata = rom[offs + (bits>>3)];
+				UINT8 pixeldata = rom[(offs + (bits>>3)) % 0x2000];
 				UINT8 data = (pixeldata>>(7-(bits&7))) & 1;
 
 				/* color = 4 MSB = front PEN, 4 LSB = background PEN */
@@ -826,7 +825,7 @@ unsigned char * rom = memory_region(REGION_CPU3) + (gfx_rom_bank * 0x2000) + 0x1
 		{
 			for (x = 0; x <= pix_xsize; x++)
 			{
-				UINT8 pixeldata = rom[offs + (bits>>3)];
+				UINT8 pixeldata = rom[(offs + (bits>>3)) % 0x2000];
 				UINT8 data = (pixeldata>>(4-(bits&7))) & 15;
 				UINT8 col = 0;
 
@@ -913,7 +912,7 @@ unsigned char * rom = memory_region(REGION_CPU3) + (gfx_rom_bank * 0x2000) + 0x1
 		{
 			for (x = 0; x <= pix_xsize; x++)
 			{
-				UINT8 pixeldata = rom[offs + (bits>>3)];
+				UINT8 pixeldata = rom[(offs + (bits>>3)) % 0x2000];
 				UINT8 data = (pixeldata>>(6-(bits&7))) & 3;
 				UINT8 col = 0;
 
@@ -1448,19 +1447,19 @@ INPUT_PORTS_END
 
 
 
-static MACHINE_INIT( mazerbla )
+static MACHINE_RESET( mazerbla )
 {
 	game_id = MAZERBLA;
 	zpu_int_vector = 0xff;
-	cpu_set_irq_callback(0, irq_callback);
+	cpunum_set_irq_callback(0, irq_callback);
 }
 
 
-static MACHINE_INIT( greatgun )
+static MACHINE_RESET( greatgun )
 {
 	game_id = GREATGUN;
 	zpu_int_vector = 0xff;
-	cpu_set_irq_callback(0, irq_callback);
+	cpunum_set_irq_callback(0, irq_callback);
 
 
 /*patch VCU test */
@@ -1514,7 +1513,7 @@ but handled differently for now
 
 	/* synchronization forced on the fly */
 
-	MDRV_MACHINE_INIT(mazerbla)
+	MDRV_MACHINE_RESET(mazerbla)
 
 	/* video hardware */
 	MDRV_VIDEO_ATTRIBUTES(VIDEO_TYPE_RASTER)
@@ -1555,7 +1554,7 @@ but handled differently for now
 	MDRV_FRAMES_PER_SECOND(60)
 	MDRV_VBLANK_DURATION(DEFAULT_REAL_60HZ_VBLANK_DURATION)
 
-	MDRV_MACHINE_INIT(greatgun)
+	MDRV_MACHINE_RESET(greatgun)
 
 	/* video hardware */
 	MDRV_VIDEO_ATTRIBUTES(VIDEO_TYPE_RASTER)
