@@ -136,7 +136,6 @@ Stephh's notes (based on the games M68000 code and some tests) :
 ******************************************************************************/
 
 #include "driver.h"
-#include "vidhrdw/generic.h"
 #include "sound/2610intf.h"
 
 VIDEO_UPDATE( mcatadv );
@@ -460,7 +459,7 @@ INPUT_PORTS_END
 
 /*** GFX Decode ***/
 
-static gfx_layout mcatadv_tiles16x16x4_layout =
+static const gfx_layout mcatadv_tiles16x16x4_layout =
 {
 	16,16,
 	RGN_FRAC(1,1),
@@ -471,7 +470,7 @@ static gfx_layout mcatadv_tiles16x16x4_layout =
 	128*8
 };
 
-static gfx_decode mcatadv_gfxdecodeinfo[] =
+static const gfx_decode mcatadv_gfxdecodeinfo[] =
 {
 	{ REGION_GFX2, 0, &mcatadv_tiles16x16x4_layout, 0, 0x200 },
 	{ REGION_GFX3, 0, &mcatadv_tiles16x16x4_layout, 0, 0x200 },
@@ -491,11 +490,6 @@ struct YM2610interface mcatadv_ym2610_interface =
 	REGION_SOUND1	/* adpcm */
 };
 
-static MACHINE_INIT( mcatadv )
-{
-	watchdog_reset_r(0);
-}
-
 
 static MACHINE_DRIVER_START( mcatadv )
 
@@ -518,7 +512,7 @@ static MACHINE_DRIVER_START( mcatadv )
 	MDRV_GFXDECODE(mcatadv_gfxdecodeinfo)
 	MDRV_PALETTE_LENGTH(0x2000/2)
 
-	MDRV_MACHINE_INIT(mcatadv)
+	MDRV_WATCHDOG_VBLANK_INIT(DEFAULT_60HZ_3S_VBLANK_WATCHDOG)
 
 	MDRV_VIDEO_START(mcatadv)
 	MDRV_VIDEO_EOF(mcatadv) /* Buffer Spriteram */
