@@ -117,7 +117,6 @@
 
 #include "driver.h"
 #include "artwork.h"
-#include "vidhrdw/generic.h"
 #include "cpu/s2650/s2650.h"
 #include "meadows.h"
 #include "sound/dac.h"
@@ -131,7 +130,7 @@
  *
  *************************************/
 
-static int cycles_at_vsync;
+static UINT32 cycles_at_vsync;
 static UINT8 main_sense_state;
 static UINT8 sound_sense_state;
 static UINT8 coin1_state;
@@ -148,7 +147,7 @@ static UINT8 minferno_sense;
 static READ8_HANDLER( hsync_chain_r )
 {
 	/* horizontal sync divider chain */
-	UINT8 val = (cycles_currently_ran() - cycles_at_vsync) & 0xff;
+	UINT8 val = (activecpu_gettotalcycles() - cycles_at_vsync) & 0xff;
 	return BITSWAP8(val,0,1,2,3,4,5,6,7);
 }
 
@@ -212,7 +211,7 @@ static WRITE8_HANDLER( meadows_sound_w )
 static INTERRUPT_GEN( meadows_interrupt )
 {
 	/* preserve the actual cycle count */
-    cycles_at_vsync = cycles_currently_ran();
+    cycles_at_vsync = cpunum_gettotalcycles(0);
 
     /* fake something toggling the sense input line of the S2650 */
 	main_sense_state ^= 1;
@@ -242,7 +241,7 @@ static INTERRUPT_GEN( meadows_interrupt )
 static INTERRUPT_GEN( minferno_interrupt )
 {
 	/* preserve the actual cycle count */
-	cycles_at_vsync = cycles_currently_ran();
+	cycles_at_vsync = cpunum_gettotalcycles(0);
 	minferno_sense++;
 	cpunum_set_input_line(0, 1, (minferno_sense & 0x40) ? ASSERT_LINE : CLEAR_LINE );
 }
@@ -563,7 +562,7 @@ INPUT_PORTS_END
  *
  *************************************/
 
-static gfx_layout charlayout =
+static const gfx_layout charlayout =
 {
 	8,8,							/* 8*8 characters */
 	128,							/* 128 characters ? */
@@ -575,7 +574,7 @@ static gfx_layout charlayout =
 };
 
 
-static gfx_layout spritelayout =
+static const gfx_layout spritelayout =
 {
 	16,16,							/* 16*16 sprites ?  */
 	32, 							/* 32 sprites  */
@@ -589,7 +588,7 @@ static gfx_layout spritelayout =
 };
 
 
-static gfx_decode gfxdecodeinfo[] =
+static const gfx_decode gfxdecodeinfo[] =
 {
 	{ REGION_GFX1, 0, &charlayout,	 0, 1 },		/* character generator */
 	{ REGION_GFX2, 0, &spritelayout, 0, 1 },		/* sprite prom 1 */
@@ -600,7 +599,7 @@ static gfx_decode gfxdecodeinfo[] =
 };
 
 
-static gfx_decode minferno_gfxdecodeinfo[] =
+static const gfx_decode minferno_gfxdecodeinfo[] =
 {
 	{ REGION_GFX1, 0, &charlayout,   0, 4 },
 	{ -1 } /* end of array */
