@@ -52,14 +52,13 @@
 #define DRMATH_MONITOR_DISPLAY 0
 #endif
 
-data16_t *micro3d_sprite_vram;
-data16_t *m68681_base;
-data16_t *m68901_base;
-data16_t dpyadr;
+UINT16 *micro3d_sprite_vram;
+static UINT16 *m68681_base;
+static UINT16 *m68901_base;
+UINT16 dpyadr;
 int dpyadrscan;
 
-    struct {
-
+static struct {
     UINT16 MR1A;
     UINT16 MR2A;
     UINT16 SRA;
@@ -89,13 +88,11 @@ int dpyadrscan;
 
     int MRA_ptr;
     int MRB_ptr;
+} M68681;
 
-    }M68681;
-
-UINT8 ti_uart[8];
-int ti_uart_mode_cycle=0;
-int ti_uart_sync_cycle=0;
-UINT8 tmra_cnt,tmrb_cnt,tmrc_cnt,tmrd_cnt;
+static UINT8 ti_uart[8];
+static int ti_uart_mode_cycle=0;
+static int ti_uart_sync_cycle=0;
 
 void m68901_int_gen(int source);
 
@@ -159,7 +156,7 @@ INTERRUPT_GEN( micro3d_tms_vblank )
 }
 
 
-static MACHINE_INIT( micro3d )
+static MACHINE_RESET( micro3d )
 {
         i8051_set_serial_tx_callback(data_from_i8031);
         i8051_set_serial_rx_callback(data_to_i8031);
@@ -170,7 +167,7 @@ static MACHINE_INIT( micro3d )
 
 static DRIVER_INIT( stankatk )
 {
-       data16_t *rom = (data16_t *)memory_region(REGION_CPU1);
+       UINT16 *rom = (UINT16 *)memory_region(REGION_CPU1);
        rom[0x1F543]=0x4E71;                                       /* 3ea86 - nop */
        rom[0x1F546]=0x4E71;                                       /* 3ea8c - nop */
        rom[0x1F596]=0x4E71;
@@ -185,7 +182,7 @@ static DRIVER_INIT( stankatk )
 
 static DRIVER_INIT( botss )
 {
-       data16_t *rom = (data16_t *)memory_region(REGION_CPU1);
+       UINT16 *rom = (UINT16 *)memory_region(REGION_CPU1);
        rom[0x1FCC0]=0x4E71;         /* Eliminate startup Am29000 timeout */
        rom[0x1FBF0]=0x4E71;         /* Skip AM29k code version detect */
        rom[0x1FC88]=0x4E71;
@@ -197,7 +194,7 @@ static DRIVER_INIT( botss )
 
 static DRIVER_INIT( f15se )
 {
-       data16_t *rom = (data16_t *)memory_region(REGION_CPU1);
+       UINT16 *rom = (UINT16 *)memory_region(REGION_CPU1);
        rom[0x2A8B3]=0x6006;                          /*055166: 6606                     bne     5516e -> bra */
        rom[0x2A8BF]=0x4E71;                          /*05517E: 6704                     beq     55184 -> nop */
        rom[0x28AD1]=0x4E71;                          /*0515A2: 67F8                     beq     5159c -> nop */
@@ -678,17 +675,17 @@ static READ32_HANDLER( am_uart_r )
 
 static WRITE16_HANDLER( mystery_w )
 {
-       usrintf_showmessage("Write to 900000: %x",data);
+       ui_popup("Write to 900000: %x",data);
 }
 
 static WRITE16_HANDLER( mystery2_w )
 {
-       usrintf_showmessage("TMS Write to e00000: %x",data);
+       ui_popup("TMS Write to e00000: %x",data);
 }
 
 static WRITE16_HANDLER( mystery3_w )
 {
-       usrintf_showmessage("TMS Write to 2600000: %x",data);
+       ui_popup("TMS Write to 2600000: %x",data);
 }
 
 
@@ -856,7 +853,7 @@ static MACHINE_DRIVER_START( micro3d )
 
 	MDRV_FRAMES_PER_SECOND(57)
 	MDRV_VBLANK_DURATION(DEFAULT_60HZ_VBLANK_DURATION)
-	MDRV_MACHINE_INIT(micro3d)
+	MDRV_MACHINE_RESET(micro3d)
 	MDRV_INTERLEAVE(50)
 
 	MDRV_VIDEO_ATTRIBUTES(VIDEO_TYPE_RASTER)
@@ -1050,6 +1047,6 @@ ROM_START( f15se )
 	ROM_LOAD( "3-001.snd", 0x000000, 0x40000, CRC(af84b635) SHA1(844e5987a66e9e3ab2d2fe05b93a4da3512776bb) )
 ROM_END
 
-GAMEX( 1991, f15se,    0, micro3d, f15se, f15se, ROT0, "Microprose", "F-15 Strike Eagle (rev. 2.1)", GAME_NOT_WORKING )
-GAMEX( 1992, botss,    0, micro3d, botss, botss, ROT0, "Microprose", "Battle of the Solar System (rev. 1.1)", GAME_NOT_WORKING )
-GAMEX( 1992, stankatk, 0, micro3d, stankatk, stankatk, ROT0, "Microprose", "Super Tank Attack (prototype rev. 4/21/92 )", GAME_NOT_WORKING )
+GAME( 1991, f15se,    0, micro3d, f15se, f15se, ROT0, "Microprose", "F-15 Strike Eagle (rev. 2.1)", GAME_NOT_WORKING )
+GAME( 1992, botss,    0, micro3d, botss, botss, ROT0, "Microprose", "Battle of the Solar System (rev. 1.1)", GAME_NOT_WORKING )
+GAME( 1992, stankatk, 0, micro3d, stankatk, stankatk, ROT0, "Microprose", "Super Tank Attack (prototype rev. 4/21/92 )", GAME_NOT_WORKING )
