@@ -54,7 +54,7 @@ static UINT32 *midvplus_misc;
  *
  *************************************/
 
-static MACHINE_INIT( midvunit )
+static MACHINE_RESET( midvunit )
 {
 	dcs_reset_w(1);
 	dcs_reset_w(0);
@@ -66,7 +66,7 @@ static MACHINE_INIT( midvunit )
 }
 
 
-static MACHINE_INIT( midvplus )
+static MACHINE_RESET( midvplus )
 {
 	dcs_reset_w(1);
 	dcs_reset_w(0);
@@ -995,7 +995,7 @@ MACHINE_DRIVER_START( midvcommon )
 	MDRV_FRAMES_PER_SECOND(57)
 	MDRV_VBLANK_DURATION(DEFAULT_60HZ_VBLANK_DURATION)
 
-	MDRV_MACHINE_INIT(midvunit)
+	MDRV_MACHINE_RESET(midvunit)
 	MDRV_NVRAM_HANDLER(generic_1fill)
 
 	/* video hardware */
@@ -1013,7 +1013,7 @@ MACHINE_DRIVER_START( midvunit )
 	MDRV_IMPORT_FROM(midvcommon)
 
 	/* sound hardware */
-	MDRV_IMPORT_FROM(dcs_audio)
+	MDRV_IMPORT_FROM(dcs_audio_2k)
 MACHINE_DRIVER_END
 
 
@@ -1025,11 +1025,11 @@ MACHINE_DRIVER_START( midvplus )
 	MDRV_CPU_CONFIG(midvplus_config)
 	MDRV_CPU_PROGRAM_MAP(midvplus_map,0)
 
-	MDRV_MACHINE_INIT(midvplus)
+	MDRV_MACHINE_RESET(midvplus)
 	MDRV_NVRAM_HANDLER(midway_serial_pic2)
 
 	/* sound hardware */
-	MDRV_IMPORT_FROM(dcs2_audio)
+	MDRV_IMPORT_FROM(dcs2_audio_2115)
 MACHINE_DRIVER_END
 
 
@@ -1051,7 +1051,7 @@ ROM_START( crusnusa )
 	ROM_LOAD16_BYTE( "cusa.u8",  0xc00000, 0x80000, CRC(03c28199) SHA1(393b009acd3eceb346b8fff45ae2bdf4f53d041f) )
 	ROM_LOAD16_BYTE( "cusa.u9",  0xe00000, 0x80000, CRC(24ba6371) SHA1(f60a9ff73b3645e2c8bad67e2f6debc61b5e0653) )
 
-	ROM_REGION32_LE( 0xa00000, REGION_USER1, 0 )
+	ROM_REGION32_LE( 0x1000000, REGION_USER1, 0 )
 	ROM_LOAD32_BYTE( "cusa-l41.u10", 0x000000, 0x80000, CRC(eb9372d1) SHA1(ab1e489b23b4540c4e0d1d9a6c9a2c9317f5c099) )
 	ROM_LOAD32_BYTE( "cusa-l41.u11", 0x000001, 0x80000, CRC(76f3cd40) SHA1(52276841944ada54d56ecd2da95998aabd699465) )
 	ROM_LOAD32_BYTE( "cusa-l41.u12", 0x000002, 0x80000, CRC(9021a376) SHA1(6a838d49bec4201e8ead7491e3b6d4a3a52dcb12) )
@@ -1086,7 +1086,7 @@ ROM_START( crusnu40 )
 	ROM_LOAD16_BYTE( "cusa.u8",  0xc00000, 0x80000, CRC(03c28199) SHA1(393b009acd3eceb346b8fff45ae2bdf4f53d041f) )
 	ROM_LOAD16_BYTE( "cusa.u9",  0xe00000, 0x80000, CRC(24ba6371) SHA1(f60a9ff73b3645e2c8bad67e2f6debc61b5e0653) )
 
-	ROM_REGION32_LE( 0xa00000, REGION_USER1, 0 )
+	ROM_REGION32_LE( 0x1000000, REGION_USER1, 0 )
 	ROM_LOAD32_BYTE( "cusa-l4.u10",  0x000000, 0x80000, CRC(7526d8bf) SHA1(ef00ea3b6e1923d3e4d10bf3601b080a009fb711) )
 	ROM_LOAD32_BYTE( "cusa-l4.u11",  0x000001, 0x80000, CRC(bfc691b9) SHA1(41d1503c4290e396a49043fea7778851cdf11310) )
 	ROM_LOAD32_BYTE( "cusa-l4.u12",  0x000002, 0x80000, CRC(059c2234) SHA1(145ec1ab3a46c3316f39bd731730dcb57b55b4ec) )
@@ -1121,7 +1121,7 @@ ROM_START( crusnu21 )
 	ROM_LOAD16_BYTE( "cusa.u8",  0xc00000, 0x80000, CRC(03c28199) SHA1(393b009acd3eceb346b8fff45ae2bdf4f53d041f) )
 	ROM_LOAD16_BYTE( "cusa.u9",  0xe00000, 0x80000, CRC(24ba6371) SHA1(f60a9ff73b3645e2c8bad67e2f6debc61b5e0653) )
 
-	ROM_REGION32_LE( 0xa00000, REGION_USER1, 0 )
+	ROM_REGION32_LE( 0x1000000, REGION_USER1, 0 )
 	ROM_LOAD32_BYTE( "cusa-l21.u10", 0x000000, 0x80000, CRC(bb759945) SHA1(dbf5270503cb58adb0abd34a8aece5933063ec66) )
 	ROM_LOAD32_BYTE( "cusa-l21.u11", 0x000001, 0x80000, CRC(4d2da096) SHA1(6ccb9fee095580089f8d43a2e86e0f8a4407dda5) )
 	ROM_LOAD32_BYTE( "cusa-l21.u12", 0x000002, 0x80000, CRC(4b66fe5e) SHA1(885d31c06b11209a1154789bc84e75d0ac9e1e8a) )
@@ -1219,7 +1219,7 @@ ROM_START( crusnw13 )
 	ROM_LOAD16_BYTE( "cwld.u9",  0xe00000, 0x80000, CRC(84cdc781) SHA1(62287aa72903698d1890908adde53c39f8bd200c) )
 
 	ROM_REGION32_LE( 0x1000000, REGION_USER1, 0 )
-	ROM_LOAD32_BYTE( "cwld_l13.u10", 0x0000000, 0x100000, BAD_DUMP CRC(956bac74) SHA1(bf0b121670df23f2cc64302d9f215e7c81187bbb)  )
+	ROM_LOAD32_BYTE( "cwld_l13.u10", 0x0000000, 0x100000, CRC(d361d17d) SHA1(7f42baec5492c4040e030e6233e500eb54bd9cba) )
 	ROM_LOAD32_BYTE( "cwld_l13.u11", 0x0000001, 0x100000, CRC(b0c0a462) SHA1(22ae081c3eb9f298aea73e99a0124becd540f0df) )
 	ROM_LOAD32_BYTE( "cwld_l13.u12", 0x0000002, 0x100000, CRC(5e7c566b) SHA1(81e6f21309bd3ba8589bc591a9ba5729f301539e) )
 	ROM_LOAD32_BYTE( "cwld_l13.u13", 0x0000003, 0x100000, CRC(46886e9c) SHA1(a2400f42fef9838fd8a347e8a249ba977d9fbcfe) )
@@ -1270,7 +1270,7 @@ ROM_END
 
 
 ROM_START( wargods )
-	ROM_REGION16_LE( 0x210000, REGION_SOUND1, 0 )	/* sound data */
+	ROM_REGION16_LE( 0x10000, REGION_SOUND1, 0 )	/* sound data */
 	ROM_LOAD16_BYTE( "u2.rom",   0x000000, 0x8000, CRC(bec7d3ae) SHA1(db80aa4a645804a4574b07b9f34dec6b6b64190d) )
 
 	ROM_REGION32_LE( 0x1000000, REGION_USER1, 0 )
@@ -1366,7 +1366,7 @@ static DRIVER_INIT( wargods )
 	UINT8 default_nvram[256];
 
 	/* initialize the subsystems */
-	dcs2_init(0x3839);
+	dcs2_init(2, 0x3839);
 	ide_controller_init(0, &ide_intf);
 	midway_ioasic_init(0, 452/* no alternates */, 94, NULL);
 	adc_shift = 16;
