@@ -200,7 +200,7 @@ static MACHINE_DRIVER_START( midxunit )
 
 	MDRV_FRAMES_PER_SECOND(MKLA5_FPS)
 	MDRV_VBLANK_DURATION((1000000 * (288 - 254)) / (MKLA5_FPS * 288))
-	MDRV_MACHINE_INIT(midxunit)
+	MDRV_MACHINE_RESET(midxunit)
 	MDRV_NVRAM_HANDLER(generic_0fill)
 
 	/* video hardware */
@@ -213,7 +213,7 @@ static MACHINE_DRIVER_START( midxunit )
 	MDRV_VIDEO_UPDATE(midtunit)
 
 	/* sound hardware */
-	MDRV_IMPORT_FROM(dcs_audio_uart)
+	MDRV_IMPORT_FROM(dcs_audio_2k_uart)
 MACHINE_DRIVER_END
 
 
