@@ -17,7 +17,6 @@ MAIN BOARD:
 ***************************************************************************/
 
 #include "driver.h"
-#include "vidhrdw/generic.h"
 #include "cpu/m6809/m6809.h"
 #include "sound/sn76496.h"
 
@@ -203,7 +202,7 @@ INPUT_PORTS_END
 
 /* Graphics Layouts */
 
-static gfx_layout charlayout =
+static const gfx_layout charlayout =
 {
 	8,8,    /* 8*8 characters */
 	512,    /* 512 characters */
@@ -214,7 +213,7 @@ static gfx_layout charlayout =
 	8*4*8     /* every char takes 32 consecutive bytes */
 };
 
-static gfx_layout spritelayout =
+static const gfx_layout spritelayout =
 {
 	16,16,	     /* 16*16 sprites */
 	256,	        /* 256 sprites */
@@ -229,7 +228,7 @@ static gfx_layout spritelayout =
 
 /* Graphics Decode Information */
 
-static gfx_decode gfxdecodeinfo[] =
+static const gfx_decode gfxdecodeinfo[] =
 {
 	{ REGION_GFX1, 0x0000, &charlayout,         0, 16*8 },
 	{ REGION_GFX2, 0x0000, &spritelayout, 16*8*16, 16*8 },
