@@ -78,7 +78,6 @@ mw-9.rom = ST M27C1001 / GFX
 
 
 #include "driver.h"
-#include "vidhrdw/generic.h"
 #include "machine/eeprom.h"
 #include "sound/okim6295.h"
 #include "sound/3812intf.h"
@@ -126,12 +125,7 @@ extern size_t pang_videoram_size;
 
 static WRITE8_HANDLER( pang_bankswitch_w )
 {
-	int bankaddress;
-	unsigned char *RAM = memory_region(REGION_CPU1);
-
-	bankaddress = 0x10000 + (data & 0x0f) * 0x4000;
-
-	memory_set_bankptr(1,&RAM[bankaddress]);
+	memory_set_bank(1, data & 0x0f);
 }
 
 
@@ -182,7 +176,6 @@ static NVRAM_HANDLER( mitchell )
 static READ8_HANDLER( pang_port5_r )
 {
 	int bit;
-	extern const game_driver driver_mgakuen2;
 
 	bit = EEPROM_read_bit() << 7;
 
@@ -193,8 +186,23 @@ static READ8_HANDLER( pang_port5_r )
 	/* otherwise music doesn't work. */
 	if (cpu_getiloops() & 1) bit |= 0x01;
 	else bit |= 0x08;
-if (Machine->gamedrv == &driver_mgakuen2)	/* hack... music doesn't work otherwise */
-	bit ^= 0x08;
+
+	{
+		static const game_driver *mitchell_driver = NULL;
+		static int pang_port5_kludge = 0;
+
+		/* Only compute pang_port5_kludge when confronted with a new gamedrv */
+		if (mitchell_driver != Machine->gamedrv)
+		{
+			mitchell_driver = Machine->gamedrv;
+			if (strcmp(mitchell_driver->name, "mgakuen2") == 0)
+				pang_port5_kludge = 0;
+			else
+				pang_port5_kludge = 1;
+		}
+		if (pang_port5_kludge)	/* hack... music doesn't work otherwise */
+			bit ^= 0x08;
+	}
 
 	return (input_port_0_r(0) & 0x76) | bit;
 }
@@ -369,7 +377,7 @@ static ADDRESS_MAP_START( mgakuen_writemem, ADDRESS_SPACE_PROGRAM, 8 )
 	AM_RANGE(0xc000, 0xc7ff) AM_WRITE(mgakuen_paletteram_w)
 	AM_RANGE(0xc800, 0xcfff) AM_WRITE(pang_colorram_w) AM_BASE(&pang_colorram)
 	AM_RANGE(0xd000, 0xdfff) AM_WRITE(mgakuen_videoram_w) AM_BASE(&pang_videoram) AM_SIZE(&pang_videoram_size)
-	AM_RANGE(0xe000, 0xefff) AM_WRITE(MWA8_RAMROM)
+	AM_RANGE(0xe000, 0xefff) AM_WRITE(MWA8_RAM)
 	AM_RANGE(0xf000, 0xffff) AM_WRITE(mgakuen_objram_w)	/* OBJ RAM */
 ADDRESS_MAP_END
 
@@ -387,7 +395,7 @@ static ADDRESS_MAP_START( writemem, ADDRESS_SPACE_PROGRAM, 8 )
 	AM_RANGE(0xc000, 0xc7ff) AM_WRITE(pang_paletteram_w)
 	AM_RANGE(0xc800, 0xcfff) AM_WRITE(pang_colorram_w) AM_BASE(&pang_colorram)
 	AM_RANGE(0xd000, 0xdfff) AM_WRITE(pang_videoram_w) AM_BASE(&pang_videoram) AM_SIZE(&pang_videoram_size)
-	AM_RANGE(0xe000, 0xffff) AM_WRITE(MWA8_RAMROM)
+	AM_RANGE(0xe000, 0xffff) AM_WRITE(MWA8_RAM)
 ADDRESS_MAP_END
 
 static ADDRESS_MAP_START( readport, ADDRESS_SPACE_IO, 8 )
@@ -959,30 +967,28 @@ INPUT_PORTS_START( mstworld )
 	PORT_BIT( 0x80, IP_ACTIVE_LOW, IPT_JOYSTICK_UP ) PORT_8WAY PORT_PLAYER(2)
 
 	PORT_START	/* IN3 */  /* coinage seems to be in here.. */
-	PORT_DIPNAME( 0x01, 0x00, "ds1" )
-	PORT_DIPSETTING(    0x01, DEF_STR( Off ) )
-	PORT_DIPSETTING(    0x00, DEF_STR( On ) )
-	PORT_DIPNAME( 0x02, 0x00, DEF_STR( Unknown ) )
-	PORT_DIPSETTING(    0x02, DEF_STR( Off ) )
-	PORT_DIPSETTING(    0x00, DEF_STR( On ) )
-	PORT_DIPNAME( 0x04, 0x00, DEF_STR( Unknown ) )
-	PORT_DIPSETTING(    0x04, DEF_STR( Off ) )
-	PORT_DIPSETTING(    0x00, DEF_STR( On ) )
-	PORT_DIPNAME( 0x08, 0x00, DEF_STR( Unknown ) )
-	PORT_DIPSETTING(    0x08, DEF_STR( Off ) )
-	PORT_DIPSETTING(    0x00, DEF_STR( On ) )
-	PORT_DIPNAME( 0x10, 0x10, DEF_STR( Unknown ) )
-	PORT_DIPSETTING(    0x10, DEF_STR( Off ) )
-	PORT_DIPSETTING(    0x00, DEF_STR( On ) )
-	PORT_DIPNAME( 0x20, 0x20, DEF_STR( Unknown ) )
-	PORT_DIPSETTING(    0x20, DEF_STR( Off ) )
-	PORT_DIPSETTING(    0x00, DEF_STR( On ) )
-	PORT_DIPNAME( 0x40, 0x40, DEF_STR( Unknown ) )
-	PORT_DIPSETTING(    0x40, DEF_STR( Off ) )
-	PORT_DIPSETTING(    0x00, DEF_STR( On ) )
-	PORT_DIPNAME( 0x80, 0x80, DEF_STR( Unknown ) )
-	PORT_DIPSETTING(    0x80, DEF_STR( Off ) )
-	PORT_DIPSETTING(    0x00, DEF_STR( On ) )
+	PORT_DIPNAME( 0x07, 0x00, DEF_STR( Coinage ) )
+	PORT_DIPSETTING(    0x03, "A 1Coin 4Credits / B 1Coin 4Credits" )
+	PORT_DIPSETTING(    0x02, "A 1Coin 3Credits / B 1Coin 3Credits" )
+	PORT_DIPSETTING(    0x01, "A 1Coin 2Credits / B 1Coin 2Credits" )
+	PORT_DIPSETTING(    0x00, "A 1Coin 1Credit / B 1Coin 4Credists" )
+	PORT_DIPSETTING(    0x04, "A 2Coins 1Credit / B 1Coin 2Credits" )
+	PORT_DIPSETTING(    0x05, "A 2Coins 1Credit / B 1Coin 3Credits" )
+	PORT_DIPSETTING(    0x06, "A 3Coins 1Credit / B 1Coin 2Credits" )
+	PORT_DIPSETTING(    0x07, "A 4Coins 1Credit / B 1Coin 1Credit" )
+	PORT_DIPNAME( 0x18, 0x00, DEF_STR( Lives ) )
+	PORT_DIPSETTING(    0x00, "1" )
+	PORT_DIPSETTING(    0x08, "2" )
+	PORT_DIPSETTING(    0x10, "3" )
+	PORT_DIPSETTING(    0x18, "4" )
+	PORT_DIPNAME( 0x60, 0x20, DEF_STR( Difficulty ) )
+	PORT_DIPSETTING(    0x00, DEF_STR( Easy ) )
+	PORT_DIPSETTING(    0x20, DEF_STR( Normal ) )
+	PORT_DIPSETTING(    0x40, DEF_STR( Hard ) )
+	PORT_DIPSETTING(    0x60, DEF_STR( Hardest ) )
+	PORT_DIPNAME( 0x80, 0x80, DEF_STR( Demo_Sounds ) )
+	PORT_DIPSETTING(    0x00, DEF_STR( Off ) )
+	PORT_DIPSETTING(    0x80, DEF_STR( On ) )
 
 	PORT_START	/* IN3 */
 	PORT_DIPNAME( 0x01, 0x00, "ds2" )
@@ -1011,7 +1017,7 @@ INPUT_PORTS_START( mstworld )
 	PORT_DIPSETTING(    0x00, DEF_STR( On ) )
 
 	PORT_START	/* IN3 */
-	PORT_DIPNAME( 0x01, 0x00, "ds2" )
+	PORT_DIPNAME( 0x01, 0x00, "ds3" )
 	PORT_DIPSETTING(    0x01, DEF_STR( Off ) )
 	PORT_DIPSETTING(    0x00, DEF_STR( On ) )
 	PORT_DIPNAME( 0x02, 0x00, DEF_STR( Unknown ) )
@@ -1119,7 +1125,7 @@ INPUT_PORTS_START( block )
 	PORT_BIT( 0xff, 0x00, IPT_DIAL ) PORT_SENSITIVITY(50) PORT_KEYDELTA(20) PORT_PLAYER(2)
 INPUT_PORTS_END
 
-INPUT_PORTS_START( blockj )
+INPUT_PORTS_START( blockjoy )
 	PORT_START      /* DSW */
 	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_UNKNOWN )	/* USED - handled in port5_r */
 	PORT_BIT(0x02, 0x02, IPT_SERVICE ) PORT_NAME( DEF_STR( Service_Mode )) PORT_CODE(KEYCODE_F2)
@@ -1161,7 +1167,7 @@ INPUT_PORTS_END
 
 
 
-static gfx_layout charlayout =
+static const gfx_layout charlayout =
 {
 	8,8,	/* 8*8 characters */
 	32768,	/* 32768 characters */
@@ -1172,7 +1178,7 @@ static gfx_layout charlayout =
 	16*8    /* every char takes 16 consecutive bytes */
 };
 
-static gfx_layout marukin_charlayout =
+static const gfx_layout marukin_charlayout =
 {
 	8,8,	/* 8*8 characters */
 	65536,	/* 65536 characters */
@@ -1183,7 +1189,7 @@ static gfx_layout marukin_charlayout =
 	32*8    /* every char takes 32 consecutive bytes */
 };
 
-static gfx_layout spritelayout =
+static const gfx_layout spritelayout =
 {
 	16,16,  /* 16*16 sprites */
 	2048,   /* 2048 sprites */
@@ -1196,28 +1202,28 @@ static gfx_layout spritelayout =
 	64*8    /* every sprite takes 64 consecutive bytes */
 };
 
-static gfx_decode mgakuen_gfxdecodeinfo[] =
+static const gfx_decode mgakuen_gfxdecodeinfo[] =
 {
 	{ REGION_GFX1, 0, &marukin_charlayout, 0,  64 }, /* colors 0-1023 */
 	{ REGION_GFX2, 0, &spritelayout,       0,  16 }, /* colors 0- 255 */
 	{ -1 } /* end of array */
 };
 
-static gfx_decode marukin_gfxdecodeinfo[] =
+static const gfx_decode marukin_gfxdecodeinfo[] =
 {
 	{ REGION_GFX1, 0, &marukin_charlayout, 0, 128 }, /* colors 0-2047 */
 	{ REGION_GFX2, 0, &spritelayout,       0,  16 }, /* colors 0- 255 */
 	{ -1 } /* end of array */
 };
 
-static gfx_decode gfxdecodeinfo[] =
+static const gfx_decode gfxdecodeinfo[] =
 {
 	{ REGION_GFX1, 0, &charlayout,     0, 128 }, /* colors 0-2047 */
 	{ REGION_GFX2, 0, &spritelayout,   0,  16 }, /* colors 0- 255 */
 	{ -1 } /* end of array */
 };
 
-static gfx_layout mstworld_charlayout =
+static const gfx_layout mstworld_charlayout =
 {
 	8,8,
 	RGN_FRAC(1,4),
@@ -1228,7 +1234,7 @@ static gfx_layout mstworld_charlayout =
 	8*8
 };
 
-static gfx_layout mstworld_spritelayout =
+static const gfx_layout mstworld_spritelayout =
 {
 	16,16,
 	RGN_FRAC(1,2),
@@ -1243,7 +1249,7 @@ static gfx_layout mstworld_spritelayout =
 };
 
 
-static gfx_decode mstworld_gfxdecodeinfo[] =
+static const gfx_decode mstworld_gfxdecodeinfo[] =
 {
 	{ REGION_GFX1, 0, &mstworld_charlayout,   0x000, 0x40 },
 	{ REGION_GFX2, 0, &mstworld_spritelayout, 0x000, 0x40 },
@@ -1395,7 +1401,7 @@ MACHINE_DRIVER_END
 
 
 ROM_START( mgakuen )
-	ROM_REGION( 0x30000, REGION_CPU1, 0 )	/* 192k for code */
+	ROM_REGION( 0x50000, REGION_CPU1, 0 )	/* 320k for code */
 	ROM_LOAD( "mg-1.1j",      0x00000, 0x08000, CRC(bf02ea6b) SHA1(bb1f5fbb211a5ed181f1afbba6b39737639d3ee7) )
 	ROM_LOAD( "mg-2.1l",      0x10000, 0x20000, CRC(64141b0c) SHA1(2de6bcd5cf2c042e5bf5c294dd7625393e99682b) )
 
@@ -1414,7 +1420,7 @@ ROM_START( mgakuen )
 ROM_END
 
 ROM_START( 7toitsu )
-	ROM_REGION( 0x30000, REGION_CPU1, 0 )	/* 192k for code */
+	ROM_REGION( 0x50000, REGION_CPU1, 0 )	/* 320k for code */
 	ROM_LOAD( "mc01.1j",      0x00000, 0x08000, CRC(0bebe45f) SHA1(24fadffd0033565441a75f36e2cb085a37e0f0e5) )
 	ROM_LOAD( "mc02.1l",      0x10000, 0x20000, CRC(375378b0) SHA1(cbb5db5fda1d87902b22130243d579cb28803707) )
 
@@ -1433,7 +1439,7 @@ ROM_START( 7toitsu )
 ROM_END
 
 ROM_START( mgakuen2 )
-	ROM_REGION( 2*0x50000, REGION_CPU1, 0 )	/* 320k for code + 320k for decrypted opcodes */
+	ROM_REGION( 0x50000, REGION_CPU1, 0 )	/* 320k for code */
 	ROM_LOAD( "mg2-xf.1j",    0x00000, 0x08000, CRC(c8165d2d) SHA1(95146e293b2e005c4015590811119a4070dda65b) )
 	ROM_LOAD( "mg2-y.1l",     0x10000, 0x20000, CRC(75bbcc14) SHA1(52ec279fda131c8de06d8c940df12d61ec6881cc) )
 	ROM_LOAD( "mg2-z.3l",     0x30000, 0x20000, CRC(bfdba961) SHA1(75045562edbdef1eb599d6a6bfc4247c33c11258) )
@@ -1453,7 +1459,7 @@ ROM_START( mgakuen2 )
 ROM_END
 
 ROM_START( pkladies )
-	ROM_REGION( 2*0x20000, REGION_CPU1, 0 )	/* 128k for code + 128k for decrypted opcodes */
+	ROM_REGION( 0x50000, REGION_CPU1, 0 )	/* 320k for code */
 	ROM_LOAD( "pko-prg1.14f", 0x00000, 0x08000, CRC(86585a94) SHA1(067791da20556e6c47de26fbf85389d92f9709db) )
 	ROM_LOAD( "pko-prg2.15f", 0x10000, 0x10000, CRC(86cbe82d) SHA1(3997a642004d1226cfce0f590123d4e407edf094) )
 
@@ -1473,7 +1479,7 @@ ROM_START( pkladies )
 ROM_END
 
 ROM_START( pkladiel )
-	ROM_REGION( 2*0x30000, REGION_CPU1, 0 )	/* 128k for code + 128k for decrypted opcodes */
+	ROM_REGION( 0x50000, REGION_CPU1, 0 )	/* 320k for code */
 	ROM_LOAD( "pk05.14f",     0x00000, 0x08000, CRC(ea1740a6) SHA1(eafd3fb0056a648dfc67b5d0a1dc93c4262e2a8b) )
 	ROM_LOAD( "pk06.15f",     0x10000, 0x20000, CRC(3078ff5e) SHA1(5d91d68a07a968ee59f693841da165833a9fcf08) )	/* larger than pkladies - 2nd half unused? */
 
@@ -1493,7 +1499,7 @@ ROM_START( pkladiel )
 ROM_END
 
 ROM_START( pkladila )
-	ROM_REGION( 2*0x20000, REGION_CPU1, 0 )	/* 128k for code + 128k for decrypted opcodes */
+	ROM_REGION( 0x50000, REGION_CPU1, 0 )	/* 320k for code */
 	ROM_LOAD( "05.14f",       0x00000, 0x08000, CRC(fa18e16a) SHA1(05fff3335a55b9ebf13a0bc89216f00fba6b6b6d) )
 	ROM_LOAD( "06.15f",       0x10000, 0x10000, CRC(a2fb7646) SHA1(778d3c1348efe6e46aed4ce968826ce73e320187) )
 
@@ -1513,12 +1519,12 @@ ROM_START( pkladila )
 ROM_END
 
 ROM_START( dokaben )
-	ROM_REGION( 2*0x50000, REGION_CPU1, 0 )	/* 320k for code + 320k for decrypted opcodes */
+	ROM_REGION( 0x50000, REGION_CPU1, 0 )	/* 320k for code */
 	ROM_LOAD( "db06.11h",     0x00000, 0x08000, CRC(413e0886) SHA1(e9e6117fbbd980bc0f5448ada6c1856919bf92b5) )
 	ROM_LOAD( "db07.13h",     0x10000, 0x20000, CRC(8bdcf49e) SHA1(7d845ae2e640ec7d8d642e3aeef741d9f7b0a57c) )
 	ROM_LOAD( "db08.14h",     0x30000, 0x20000, CRC(1643bdd9) SHA1(5805e749713dbffacbb1238b1b4d42e8473d3656) )
 
-	ROM_REGION( 0x100000, REGION_GFX1, ROMREGION_DISPOSE )
+	ROM_REGION( 0x100000, REGION_GFX1, ROMREGION_DISPOSE | ROMREGION_ERASEFF )
 	ROM_LOAD( "db02.1e",      0x000000, 0x20000, CRC(9aa8470c) SHA1(8acbed381d6140e70045da232dee9b4b165953f9) )	/* chars */
 	ROM_LOAD( "db03.2e",      0x020000, 0x20000, CRC(3324e43d) SHA1(ed273d4de56e382e24ab0f0a8bcd5e30a05a1c6d) )
 	/* 40000-7ffff empty */
@@ -1535,11 +1541,11 @@ ROM_START( dokaben )
 ROM_END
 
 ROM_START( pang )
-	ROM_REGION( 2*0x30000, REGION_CPU1, 0 )	/* 192k for code + 192k for decrypted opcodes */
+	ROM_REGION( 0x50000, REGION_CPU1, 0 )	/* 320k for code */
 	ROM_LOAD( "pang6.bin",    0x00000, 0x08000, CRC(68be52cd) SHA1(67b9ac15f4cbd3959c417f979beae36ae17334c1) )
 	ROM_LOAD( "pang7.bin",    0x10000, 0x20000, CRC(4a2e70f6) SHA1(039db1b51374e5637b5c2ba8e18ccd08816613a7) )
 
-	ROM_REGION( 0x100000, REGION_GFX1, ROMREGION_DISPOSE )
+	ROM_REGION( 0x100000, REGION_GFX1, ROMREGION_DISPOSE | ROMREGION_ERASEFF )
 	ROM_LOAD( "pang_09.bin",  0x000000, 0x20000, CRC(3a5883f5) SHA1(a8a33071e10f5992e80afdb782c334829f9ae27f) )	/* chars */
 	ROM_LOAD( "bb3.bin",      0x020000, 0x20000, CRC(79a8ed08) SHA1(c1e43889e29b80c7fe2c09b11eecde24450a1ff5) )
 	/* 40000-7ffff empty */
@@ -1556,13 +1562,13 @@ ROM_START( pang )
 ROM_END
 
 ROM_START( pangb )
-	ROM_REGION( 2*0x30000, REGION_CPU1, 0 )	/* 192k for code + 192k for decrypted opcodes */
-	ROM_LOAD( "pang_04.bin",  0x30000, 0x08000, CRC(f68f88a5) SHA1(6f57891d399a46d8d5a531771129552ed420d10a) )   /* Decrypted opcode + data */
+	ROM_REGION( 2*0x50000, REGION_CPU1, 0 )	/* 320k for code */
+	ROM_LOAD( "pang_04.bin",  0x50000, 0x08000, CRC(f68f88a5) SHA1(6f57891d399a46d8d5a531771129552ed420d10a) )   /* Decrypted opcode + data */
 	ROM_CONTINUE(             0x00000, 0x08000 )
-	ROM_LOAD( "pang_02.bin",  0x40000, 0x20000, CRC(3f15bb61) SHA1(4f74ee25f32a201482840158b4d4c7aca1cda684) )   /* Decrypted op codes */
+	ROM_LOAD( "pang_02.bin",  0x60000, 0x20000, CRC(3f15bb61) SHA1(4f74ee25f32a201482840158b4d4c7aca1cda684) )   /* Decrypted op codes */
 	ROM_LOAD( "pang_03.bin",  0x10000, 0x20000, CRC(0c8477ae) SHA1(a31a8c00407dfc3017d56e29fac6114b73248030) )   /* Decrypted data */
 
-	ROM_REGION( 0x100000, REGION_GFX1, ROMREGION_DISPOSE )
+	ROM_REGION( 0x100000, REGION_GFX1, ROMREGION_DISPOSE | ROMREGION_ERASEFF )
 	ROM_LOAD( "pang_09.bin",  0x000000, 0x20000, CRC(3a5883f5) SHA1(a8a33071e10f5992e80afdb782c334829f9ae27f) )	/* chars */
 	ROM_LOAD( "bb3.bin",      0x020000, 0x20000, CRC(79a8ed08) SHA1(c1e43889e29b80c7fe2c09b11eecde24450a1ff5) )
 	/* 40000-7ffff empty */
@@ -1579,11 +1585,11 @@ ROM_START( pangb )
 ROM_END
 
 ROM_START( bbros )
-	ROM_REGION( 2*0x30000, REGION_CPU1, 0 )	/* 192k for code + 192k for decrypted opcodes */
+	ROM_REGION( 0x50000, REGION_CPU1, 0 )	/* 320k for code */
 	ROM_LOAD( "bb6.bin",      0x00000, 0x08000, CRC(a3041ca4) SHA1(2accb2151f621e4802211efe986969ebd3acb6d4) )
 	ROM_LOAD( "bb7.bin",      0x10000, 0x20000, CRC(09231c68) SHA1(9e735487a99a5eb89a6abb81d5d9a20414ad75bf) )
 
-	ROM_REGION( 0x100000, REGION_GFX1, ROMREGION_DISPOSE )
+	ROM_REGION( 0x100000, REGION_GFX1, ROMREGION_DISPOSE | ROMREGION_ERASEFF )
 	ROM_LOAD( "bb2.bin",      0x000000, 0x20000, CRC(62f29992) SHA1(af4d43f76228e9908fbfbf83af2f577b84cc5e1d) )	/* chars */
 	ROM_LOAD( "bb3.bin",      0x020000, 0x20000, CRC(79a8ed08) SHA1(c1e43889e29b80c7fe2c09b11eecde24450a1ff5) )
 	/* 40000-7ffff empty */
@@ -1600,11 +1606,11 @@ ROM_START( bbros )
 ROM_END
 
 ROM_START( pompingw )
-	ROM_REGION( 2*0x30000, REGION_CPU1, 0 )	/* 192k for code + 192k for decrypted opcodes */
+	ROM_REGION( 0x50000, REGION_CPU1, 0 )	/* 320k for code */
 	ROM_LOAD( "pwj_06.11h",   0x00000, 0x08000, CRC(4a0a6426) SHA1(c61346c5f80507bdf543e9ea32ee3f814be8e27f) )
 	ROM_LOAD( "pwj_07.13h",   0x10000, 0x20000, CRC(a9402420) SHA1(2ca3aa59d561826477e3509fcaeeec753d64d419) )
 
-	ROM_REGION( 0x100000, REGION_GFX1, ROMREGION_DISPOSE )
+	ROM_REGION( 0x100000, REGION_GFX1, ROMREGION_DISPOSE | ROMREGION_ERASEFF )
 	ROM_LOAD( "pw_02.1e",     0x000000, 0x20000, CRC(4b5992e4) SHA1(2071a1fcfc739d7ca837c03133909101b462d5a6) )	/* chars */
 	ROM_LOAD( "bb3.bin",      0x020000, 0x20000, CRC(79a8ed08) SHA1(c1e43889e29b80c7fe2c09b11eecde24450a1ff5) )
 	/* 40000-7ffff empty */
@@ -1621,12 +1627,12 @@ ROM_START( pompingw )
 ROM_END
 
 ROM_START( cworld )
-	ROM_REGION( 2*0x50000, REGION_CPU1, 0 )	/* 320k for code + 320k for decrypted opcodes */
+	ROM_REGION( 0x50000, REGION_CPU1, 0 )	/* 320k for code */
 	ROM_LOAD( "cw05.bin",     0x00000, 0x08000, CRC(d3c1723d) SHA1(b67f63e39f4301909c967555222820b54e98a205) )
 	ROM_LOAD( "cw06.bin",     0x10000, 0x20000, CRC(d71ed4a3) SHA1(5b6d498810e6fc8041f4326087f3be56863e91d9) )
 	ROM_LOAD( "cw07.bin",     0x30000, 0x20000, CRC(d419ce08) SHA1(f0a8265e839f6bdab2926f48aba88b6f9aaa3b29) )
 
-	ROM_REGION( 0x100000, REGION_GFX1, ROMREGION_DISPOSE )
+	ROM_REGION( 0x100000, REGION_GFX1, ROMREGION_DISPOSE | ROMREGION_ERASEFF )
 	ROM_LOAD( "cw08.bin",     0x000000, 0x20000, CRC(6c80da3c) SHA1(3ed8bc025703d6eccc88af0caeeb8e75a88ba5db) )	/* chars */
 	ROM_LOAD( "cw09.bin",     0x020000, 0x20000, CRC(7607da71) SHA1(4486550aa96bf5be0294763a9585fafda3216b27) )
 	ROM_LOAD( "cw10.bin",     0x040000, 0x20000, CRC(6f0e639f) SHA1(473804068479516694a864982e2a734f63cb1cce) )
@@ -1645,12 +1651,12 @@ ROM_START( cworld )
 ROM_END
 
 ROM_START( hatena )
-	ROM_REGION( 2*0x50000, REGION_CPU1, 0 )	/* 320k for code + 320k for decrypted opcodes */
+	ROM_REGION( 0x50000, REGION_CPU1, 0 )	/* 320k for code */
 	ROM_LOAD( "q2-05.rom",    0x00000, 0x08000, CRC(66c9e1da) SHA1(7ddbc4acf9d9d5b69f0bb60af65a171f3ba185b1) )
 	ROM_LOAD( "q2-06.rom",    0x10000, 0x20000, CRC(5fc39916) SHA1(84ead43d8bad3f9c88fcb02171500298613646dc) )
 	ROM_LOAD( "q2-07.rom",    0x30000, 0x20000, CRC(ec6d5e5e) SHA1(6269f5a5a3af91193afe85d34a764499877c2a24) )
 
-	ROM_REGION( 0x100000, REGION_GFX1, ROMREGION_DISPOSE )
+	ROM_REGION( 0x100000, REGION_GFX1, ROMREGION_DISPOSE | ROMREGION_ERASEFF )
 	ROM_LOAD( "q2-08.rom",    0x000000, 0x20000, CRC(6c80da3c) SHA1(3ed8bc025703d6eccc88af0caeeb8e75a88ba5db) )	/* chars */
 	ROM_LOAD( "q2-09.rom",    0x020000, 0x20000, CRC(abe3e15c) SHA1(5af589e58b317758d1162913f6c104c8459546c0) )
 	ROM_LOAD( "q2-10.rom",    0x040000, 0x20000, CRC(6963450d) SHA1(8fff6e9653b10194940b7a7a10f57995aafdd37c) )
@@ -1672,10 +1678,7 @@ ROM_END
 
 /* seems to be the same basic hardware, but the memory map and io map are different at least.. */
 ROM_START( mstworld )
-	ROM_REGION( 0x80000*2, REGION_CPU1, 0 )	/* CPU1 code */
-	/* we descramble code to here */
-
-	ROM_REGION( 0x80000, REGION_USER1, 0 )	/* CPU1 code - scrambled */
+	ROM_REGION( 0x50000*2, REGION_CPU1, 0 )	/* CPU1 code */
 	ROM_LOAD( "mw-1.rom", 0x00000, 0x080000, CRC(c4e51fb4) SHA1(60ad4ff2cec3a4d13b4aa0319dfcdab941404b1a) ) /* fixed code */
 
 	ROM_REGION( 0x10000, REGION_CPU2, 0 )	/* CPU2 code */
@@ -1710,12 +1713,12 @@ ROM_END
 
 
 ROM_START( spang )
-	ROM_REGION( 2*0x50000, REGION_CPU1, 0 )	/* 320k for code + 320k for decrypted opcodes */
+	ROM_REGION( 0x50000, REGION_CPU1, 0 )	/* 320k for code */
 	ROM_LOAD( "spe_06.rom",   0x00000, 0x08000, CRC(1af106fb) SHA1(476ba5c95e090663a47d3f98451bf3b79bac7748) )
 	ROM_LOAD( "spe_07.rom",   0x10000, 0x20000, CRC(208b5f54) SHA1(9d44f7240b56756dcb69d110036b1cb13b1bbc02) )
 	ROM_LOAD( "spe_08.rom",   0x30000, 0x20000, CRC(2bc03ade) SHA1(3a8ee342b0556a8f6d5a417c98e5c3c43422713d) )
 
-	ROM_REGION( 0x100000, REGION_GFX1, ROMREGION_DISPOSE )
+	ROM_REGION( 0x100000, REGION_GFX1, ROMREGION_DISPOSE | ROMREGION_ERASEFF )
 	ROM_LOAD( "spe_02.rom",   0x000000, 0x20000, CRC(63c9dfd2) SHA1(ddc8ddee336855e857fb3124c8b64af33c2d0080) )	/* chars */
 	ROM_LOAD( "03.f2",        0x020000, 0x20000, CRC(3ae28bc1) SHA1(4f6d9a86f624598ebc0825b50941adfb7436e98a) )
 	/* 40000-7ffff empty */
@@ -1732,12 +1735,12 @@ ROM_START( spang )
 ROM_END
 
 ROM_START( spangj )
-	ROM_REGION( 2*0x50000, REGION_CPU1, 0 )	/* 320k for code + 320k for decrypted opcodes */
+	ROM_REGION( 0x50000, REGION_CPU1, 0 )	/* 320k for code */
 	ROM_LOAD( "spj_11h.bin",    0x00000, 0x08000, CRC(1a548b0b) SHA1(3aa65028876ab6e176f5b227366e65212c944888) )
 	ROM_LOAD( "spj7_13h.bin",   0x10000, 0x20000, CRC(14c2b765) SHA1(af0f965dd13d878bae7850cf8419b26511090579) )
 	ROM_LOAD( "spj8_14h.bin",   0x30000, 0x20000, CRC(4be4e5b7) SHA1(6273e8bf5d9f5b100ecda20001808dcf86411d83) )
 
-	ROM_REGION( 0x100000, REGION_GFX1, ROMREGION_DISPOSE )
+	ROM_REGION( 0x100000, REGION_GFX1, ROMREGION_DISPOSE | ROMREGION_ERASEFF )
 	ROM_LOAD( "spj02_1e.bin",   0x000000, 0x20000,  CRC(419f69d7) SHA1(e3431b5ce3e687ba9a45cb6e0e0a2dfa3a9e5b29) )	/* chars */
 	ROM_LOAD( "03.f2",          0x020000, 0x20000, CRC(3ae28bc1) SHA1(4f6d9a86f624598ebc0825b50941adfb7436e98a) )	/* spj03_3e.bin */
 	/* 40000-7ffff empty */
@@ -1754,12 +1757,12 @@ ROM_START( spangj )
 ROM_END
 
 ROM_START( sbbros )
-	ROM_REGION( 2*0x50000, REGION_CPU1, 0 )	/* 320k for code + 320k for decrypted opcodes */
+	ROM_REGION( 0x50000, REGION_CPU1, 0 )	/* 320k for code */
 	ROM_LOAD( "06.j12",       0x00000, 0x08000, CRC(292eee6a) SHA1(d33368d2373a1ee9e24ada6aa045e0675c8e8160) )
 	ROM_LOAD( "07.j13",       0x10000, 0x20000, CRC(f46b698d) SHA1(6a1867f591aa0fb9e02dd472699df93f9d018793) )
 	ROM_LOAD( "08.j14",       0x30000, 0x20000, CRC(a75e7fbe) SHA1(0331d1a3e888678909f3e6d21f97896a5350e585) )
 
-	ROM_REGION( 0x100000, REGION_GFX1, ROMREGION_DISPOSE )
+	ROM_REGION( 0x100000, REGION_GFX1, ROMREGION_DISPOSE | ROMREGION_ERASEFF )
 	ROM_LOAD( "02.f1",        0x000000, 0x20000, CRC(0c22ffc6) SHA1(f95b50617ef5cd8cffffacab0b96b4bfe8dd3a1e) )	/* chars */
 	ROM_LOAD( "03.f2",        0x020000, 0x20000, CRC(3ae28bc1) SHA1(4f6d9a86f624598ebc0825b50941adfb7436e98a) )
 	/* 40000-7ffff empty */
@@ -1776,7 +1779,7 @@ ROM_START( sbbros )
 ROM_END
 
 ROM_START( marukin )
-	ROM_REGION( 2*0x30000, REGION_CPU1, 0 )	/* 192k for code + 192k for decrypted opcodes */
+	ROM_REGION( 0x50000, REGION_CPU1, 0 )	/* 320k for code */
 	ROM_LOAD( "mg3-01.9d",    0x00000, 0x08000, CRC(04357973) SHA1(61b0b347479126213c90ef6833c09537fab03093) )
 	ROM_LOAD( "mg3-02.10d",   0x10000, 0x20000, CRC(50d08da0) SHA1(5d115eb646f34827d02219be3d5346f05c0c27b6) )
 
@@ -1795,12 +1798,12 @@ ROM_START( marukin )
 ROM_END
 
 ROM_START( qtono1 )
-	ROM_REGION( 2*0x50000, REGION_CPU1, 0 )	/* 320k for code + 320k for decrypted opcodes */
+	ROM_REGION( 0x50000, REGION_CPU1, 0 )	/* 320k for code */
 	ROM_LOAD( "q3-05.rom",    0x00000, 0x08000, CRC(1dd0a344) SHA1(814049bf957b78ff2d1c8da316dfe5303abee4df) )
 	ROM_LOAD( "q3-06.rom",    0x10000, 0x20000, CRC(bd6a2110) SHA1(8c4d7a10dfaee0fcd18be21c80fc3d2ff9615eae) )
 	ROM_LOAD( "q3-07.rom",    0x30000, 0x20000, CRC(61e53c4f) SHA1(bcde0029a217994561ae0a6fb0482bf1e3517913) )
 
-	ROM_REGION( 0x100000, REGION_GFX1, ROMREGION_DISPOSE )
+	ROM_REGION( 0x100000, REGION_GFX1, ROMREGION_DISPOSE | ROMREGION_ERASEFF )
 	ROM_LOAD( "q3-08.rom",    0x000000, 0x20000, CRC(1533b978) SHA1(586d3b93152cc78a3ae42987e66d984645cd2849) )	/* chars */
 	ROM_LOAD( "q3-09.rom",    0x020000, 0x20000, CRC(a32db2f2) SHA1(df2243bff5fd44ebdfe02c5e0bbcccaff5c32628) )
 	ROM_LOAD( "q3-10.rom",    0x040000, 0x20000, CRC(ed681aa8) SHA1(9f8dcebc384ca1582d509de94c194df9e3f81441) )
@@ -1819,12 +1822,12 @@ ROM_START( qtono1 )
 ROM_END
 
 ROM_START( qsangoku )
-	ROM_REGION( 2*0x50000, REGION_CPU1, 0 )	/* 320k for code + 320k for decrypted opcodes */
+	ROM_REGION( 0x50000, REGION_CPU1, 0 )	/* 320k for code */
 	ROM_LOAD( "q4-05c.rom",   0x00000, 0x08000, CRC(e1d010b4) SHA1(7fca1ee45054331320abb6a99f10fa98dd4be994) )
 	ROM_LOAD( "q4-06.rom",    0x10000, 0x20000, CRC(a0301849) SHA1(60910d84f869fd5735cd5500a93b761d8b8dbacb) )
 	ROM_LOAD( "q4-07.rom",    0x30000, 0x20000, CRC(2941ef5b) SHA1(a86f5365edd315fcbb2a50489d63b4be9587ae29) )
 
-	ROM_REGION( 0x100000, REGION_GFX1, ROMREGION_DISPOSE )
+	ROM_REGION( 0x100000, REGION_GFX1, ROMREGION_DISPOSE | ROMREGION_ERASEFF )
 	ROM_LOAD( "q4-08.rom",    0x000000, 0x20000, CRC(dc84c6cb) SHA1(0fb5737bb2adeddde888d24974806d4c2ac5b2ee) )	/* chars */
 	ROM_LOAD( "q4-09.rom",    0x020000, 0x20000, CRC(cbb6234c) SHA1(76b749cc39d3af1d9e4959ea513ed054723ffefd) )
 	ROM_LOAD( "q4-10.rom",    0x040000, 0x20000, CRC(c20a27a8) SHA1(f462babb7090b2838326bb65e2cafab0fea12f99) )
@@ -1842,45 +1845,20 @@ ROM_START( qsangoku )
 	ROM_LOAD( "q4-01.rom",    0x00000, 0x20000, CRC(5d0d07d8) SHA1(d36e42852dd1ec0955d19b16e7dfe157b3d48522) )
 ROM_END
 
+
 ROM_START( block )
-	ROM_REGION( 2*0x50000, REGION_CPU1, 0 )	/* 320k for code + 320k for decrypted opcodes */
-	ROM_LOAD( "ble_05.bin",   0x00000, 0x08000, CRC(fa2a4536) SHA1(8f584745116bd0ced4d66719cd80c0372b797134) )
-	ROM_LOAD( "ble_06.bin",   0x10000, 0x20000, CRC(58a77402) SHA1(cb24b1edd53a0965c3a9a34fe764b5c1f8dd9733) )
-	ROM_LOAD( "ble_07.rom",   0x30000, 0x20000, CRC(1d114f13) SHA1(ee3588e1752b3432fd611e2d7d4fb43f942de580) )
-
-	ROM_REGION( 0x100000, REGION_GFX1, ROMREGION_DISPOSE )
-	ROM_LOAD( "bl_08.rom",    0x000000, 0x20000, CRC(aa0f4ff1) SHA1(58f3c468f89d834caaf66d3c084ab87addbb75c0) )	/* chars */
-	ROM_RELOAD(               0x040000, 0x20000 )
-	ROM_LOAD( "bl_09.rom",    0x020000, 0x20000, CRC(6fa8c186) SHA1(d4dd26d666f2accce871f70e7882e140d924dd07) )
-	ROM_RELOAD(               0x060000, 0x20000 )
-	ROM_LOAD( "bl_18.rom",    0x080000, 0x20000, CRC(c0acafaf) SHA1(7c44b2605da6a324d0c145202cb8bac7af7a9c68) )
-	ROM_RELOAD(               0x0c0000, 0x20000 )
-	ROM_LOAD( "bl_19.rom",    0x0a0000, 0x20000, CRC(1ae942f5) SHA1(e9322790db0bf2a9e862b14e166ee3f36f9ea5ad) )
-	ROM_RELOAD(               0x0e0000, 0x20000 )
-
-	ROM_REGION( 0x040000, REGION_GFX2, ROMREGION_DISPOSE )
-	ROM_LOAD( "bl_16.rom",    0x000000, 0x20000, CRC(fadcaff7) SHA1(f4bd8e375fe6b1e6a07b4ec4e58f5807dbd738f8) )	/* sprites */
-	ROM_LOAD( "bl_17.rom",    0x020000, 0x20000, CRC(5f8cab42) SHA1(3a4c682a7938479e0be80c0494c2c8fc7303b663) )
-
-	ROM_REGION( 0x80000, REGION_SOUND1, 0 )	/* OKIM */
-	ROM_LOAD( "bl_01.rom",    0x00000, 0x20000, CRC(c2ec2abb) SHA1(89981f2a887ace4c4580e2828cbdc962f89c215e) )
-ROM_END
-
-ROM_START( blocka )
-	ROM_REGION( 2*0x50000, REGION_CPU1, 0 )	/* 320k for code + 320k for decrypted opcodes */
+	ROM_REGION( 0x50000, REGION_CPU1, 0 )	/* 320k for code */
 	ROM_LOAD( "ble_05.rom",   0x00000, 0x08000, CRC(c12e7f4c) SHA1(335f4eab2323b942d5feeb3bab6f7286fabfffb4) )
 	ROM_LOAD( "ble_06.rom",   0x10000, 0x20000, CRC(cdb13d55) SHA1(2e4489d12a603b4c7dfb90d246ebff9176e88a0b) )
 	ROM_LOAD( "ble_07.rom",   0x30000, 0x20000, CRC(1d114f13) SHA1(ee3588e1752b3432fd611e2d7d4fb43f942de580) )
 
-	ROM_REGION( 0x100000, REGION_GFX1, ROMREGION_DISPOSE )
+	ROM_REGION( 0x100000, REGION_GFX1, ROMREGION_DISPOSE | ROMREGION_ERASEFF )
 	ROM_LOAD( "bl_08.rom",    0x000000, 0x20000, CRC(aa0f4ff1) SHA1(58f3c468f89d834caaf66d3c084ab87addbb75c0) )	/* chars */
-	ROM_RELOAD(               0x040000, 0x20000 )
 	ROM_LOAD( "bl_09.rom",    0x020000, 0x20000, CRC(6fa8c186) SHA1(d4dd26d666f2accce871f70e7882e140d924dd07) )
-	ROM_RELOAD(               0x060000, 0x20000 )
+	/* 40000-7ffff empty */
 	ROM_LOAD( "bl_18.rom",    0x080000, 0x20000, CRC(c0acafaf) SHA1(7c44b2605da6a324d0c145202cb8bac7af7a9c68) )
-	ROM_RELOAD(               0x0c0000, 0x20000 )
 	ROM_LOAD( "bl_19.rom",    0x0a0000, 0x20000, CRC(1ae942f5) SHA1(e9322790db0bf2a9e862b14e166ee3f36f9ea5ad) )
-	ROM_RELOAD(               0x0e0000, 0x20000 )
+	/* c0000-fffff empty */
 
 	ROM_REGION( 0x040000, REGION_GFX2, ROMREGION_DISPOSE )
 	ROM_LOAD( "bl_16.rom",    0x000000, 0x20000, CRC(fadcaff7) SHA1(f4bd8e375fe6b1e6a07b4ec4e58f5807dbd738f8) )	/* sprites */
@@ -1891,20 +1869,45 @@ ROM_START( blocka )
 ROM_END
 
 ROM_START( blockj )
-	ROM_REGION( 2*0x50000, REGION_CPU1, 0 )	/* 320k for code + 320k for decrypted opcodes */
+	ROM_REGION( 0x50000, REGION_CPU1, 0 )	/* 320k for code */
 	ROM_LOAD( "blj_05.rom",   0x00000, 0x08000, CRC(3b55969a) SHA1(86de2f1f5878de380a8b1e3935cffa146863f07f) )
 	ROM_LOAD( "ble_06.rom",   0x10000, 0x20000, CRC(cdb13d55) SHA1(2e4489d12a603b4c7dfb90d246ebff9176e88a0b) )
 	ROM_LOAD( "blj_07.rom",   0x30000, 0x20000, CRC(1723883c) SHA1(e6b7575a55c045b90fb41290a60306713121acfb) )
 
-	ROM_REGION( 0x100000, REGION_GFX1, ROMREGION_DISPOSE )
+	ROM_REGION( 0x100000, REGION_GFX1, ROMREGION_DISPOSE | ROMREGION_ERASEFF )
 	ROM_LOAD( "bl_08.rom",    0x000000, 0x20000, CRC(aa0f4ff1) SHA1(58f3c468f89d834caaf66d3c084ab87addbb75c0) )	/* chars */
-	ROM_RELOAD(               0x040000, 0x20000 )
 	ROM_LOAD( "bl_09.rom",    0x020000, 0x20000, CRC(6fa8c186) SHA1(d4dd26d666f2accce871f70e7882e140d924dd07) )
-	ROM_RELOAD(               0x060000, 0x20000 )
+	/* 40000-7ffff empty */
 	ROM_LOAD( "bl_18.rom",    0x080000, 0x20000, CRC(c0acafaf) SHA1(7c44b2605da6a324d0c145202cb8bac7af7a9c68) )
-	ROM_RELOAD(               0x0c0000, 0x20000 )
 	ROM_LOAD( "bl_19.rom",    0x0a0000, 0x20000, CRC(1ae942f5) SHA1(e9322790db0bf2a9e862b14e166ee3f36f9ea5ad) )
-	ROM_RELOAD(               0x0e0000, 0x20000 )
+	/* c0000-fffff empty */
+
+	ROM_REGION( 0x040000, REGION_GFX2, ROMREGION_DISPOSE )
+	ROM_LOAD( "bl_16.rom",    0x000000, 0x20000, CRC(fadcaff7) SHA1(f4bd8e375fe6b1e6a07b4ec4e58f5807dbd738f8) )	/* sprites */
+	ROM_LOAD( "bl_17.rom",    0x020000, 0x20000, CRC(5f8cab42) SHA1(3a4c682a7938479e0be80c0494c2c8fc7303b663) )
+
+	ROM_REGION( 0x80000, REGION_SOUND1, 0 )	/* OKIM */
+	ROM_LOAD( "bl_01.rom",    0x00000, 0x20000, CRC(c2ec2abb) SHA1(89981f2a887ace4c4580e2828cbdc962f89c215e) )
+ROM_END
+
+ROM_START( blockjoy )
+	ROM_REGION( 0x50000, REGION_CPU1, 0 )	/* 320k for code */
+	ROM_LOAD( "ble_05.bin",   0x00000, 0x08000, CRC(fa2a4536) SHA1(8f584745116bd0ced4d66719cd80c0372b797134) )
+	ROM_LOAD( "blf_06.bin",   0x10000, 0x20000, CRC(e114ebde) SHA1(12362e809443644b43fbc72e7eead5f376fe11d3) )
+/* this seems to be a bad version of the above rom, although the rom code is different it is 99% the same, and level 6 */
+/* is impossible to finish due to a missing block.  Probably bitrot */
+/*  ROM_LOAD( "ble_06.bin",   0x10000, 0x20000, BAD_DUMP CRC(58a77402) SHA1(cb24b1edd53a0965c3a9a34fe764b5c1f8dd9733) ) */
+
+	ROM_LOAD( "ble_07.rom",   0x30000, 0x20000, CRC(1d114f13) SHA1(ee3588e1752b3432fd611e2d7d4fb43f942de580) )
+
+	/* the highscore table specifies an unused tile number, so we need ROMREGION_ERASEFF to ensure it is blank */
+	ROM_REGION( 0x100000, REGION_GFX1, ROMREGION_DISPOSE | ROMREGION_ERASEFF )
+	ROM_LOAD( "bl_08.rom",    0x000000, 0x20000, CRC(aa0f4ff1) SHA1(58f3c468f89d834caaf66d3c084ab87addbb75c0) )	/* chars */
+	ROM_LOAD( "bl_09.rom",    0x020000, 0x20000, CRC(6fa8c186) SHA1(d4dd26d666f2accce871f70e7882e140d924dd07) )
+	/* 40000-7ffff empty */
+	ROM_LOAD( "bl_18.rom",    0x080000, 0x20000, CRC(c0acafaf) SHA1(7c44b2605da6a324d0c145202cb8bac7af7a9c68) )
+	ROM_LOAD( "bl_19.rom",    0x0a0000, 0x20000, CRC(1ae942f5) SHA1(e9322790db0bf2a9e862b14e166ee3f36f9ea5ad) )
+	/* c0000-fffff empty */
 
 	ROM_REGION( 0x040000, REGION_GFX2, ROMREGION_DISPOSE )
 	ROM_LOAD( "bl_16.rom",    0x000000, 0x20000, CRC(fadcaff7) SHA1(f4bd8e375fe6b1e6a07b4ec4e58f5807dbd738f8) )	/* sprites */
@@ -1915,22 +1918,20 @@ ROM_START( blockj )
 ROM_END
 
 ROM_START( blockbl )
-	ROM_REGION( 2*0x50000, REGION_CPU1, 0 )	/* 320k for code + 320k for decrypted opcodes */
+	ROM_REGION( 0x50000*2, REGION_CPU1, 0 )	/* 320k for code */
 	ROM_LOAD( "m7.l6",        0x50000, 0x08000, CRC(3b576fd9) SHA1(99cf14eba089ed9c7d9f287277dab4a8a997a9a4) )   /* Decrypted opcode + data */
 	ROM_CONTINUE(             0x00000, 0x08000 )
 	ROM_LOAD( "m5.l3",        0x60000, 0x20000, CRC(7c988bb7) SHA1(138ffe62ef9186849c3db73b048132ad0349ccf7) )   /* Decrypted opcode + data */
 	ROM_CONTINUE(             0x10000, 0x20000 )
 	ROM_LOAD( "m6.l5",        0x30000, 0x20000, CRC(5768d8eb) SHA1(6aa9bc4e778c6a06444bba0f4022710cd2abf35c) )   /* Decrypted data */
 
-	ROM_REGION( 0x100000, REGION_GFX1, ROMREGION_DISPOSE )
+	ROM_REGION( 0x100000, REGION_GFX1, ROMREGION_DISPOSE | ROMREGION_ERASEFF )
 	ROM_LOAD( "m12.o10",      0x000000, 0x20000, CRC(963154d9) SHA1(ef2d5bb4de3b17a2507f9656d924593edce0f3ed) )	/* chars */
-	ROM_RELOAD(               0x040000, 0x20000 )
 	ROM_LOAD( "m13.o14",      0x020000, 0x20000, CRC(069480bb) SHA1(f33793822848c1c3589fd2f17bbb95254ab64736) )
-	ROM_RELOAD(               0x060000, 0x20000 )
+	/* 40000-7ffff empty */
 	ROM_LOAD( "m4.j17",       0x080000, 0x20000, CRC(9e3b6f4f) SHA1(d129ffd1689eaa21b354dcf60b471542ff434588) )
-	ROM_RELOAD(               0x0c0000, 0x20000 )
 	ROM_LOAD( "m3.j20",       0x0a0000, 0x20000, CRC(629d58fe) SHA1(936ebc993f382a2cd138b6933d1bd1acd153bc01) )
-	ROM_RELOAD(               0x0e0000, 0x20000 )
+	/* c0000-fffff empty */
 
 	ROM_REGION( 0x040000, REGION_GFX2, ROMREGION_DISPOSE )
 	ROM_LOAD( "m11.o7",       0x000000, 0x10000, CRC(255180a5) SHA1(8fde20c6c14b84d768ebe3634584f7d4e0702548) )	/* sprites */
@@ -1945,43 +1946,51 @@ ROM_END
 
 static void bootleg_decode(void)
 {
-	unsigned char *rom = memory_region(REGION_CPU1);
-	int diff = memory_region_length(REGION_CPU1) / 2;
-
-	memory_set_opcode_base(0,rom+diff);
+	memory_set_decrypted_region(0, 0x0000, 0x7fff, memory_region(REGION_CPU1) + 0x50000);
+	memory_configure_bank_decrypted(1, 0, 16, memory_region(REGION_CPU1) + 0x60000, 0x4000);
 }
 
 
+static void configure_banks(void)
+{
+	memory_configure_bank(1, 0, 16, memory_region(REGION_CPU1) + 0x10000, 0x4000);
+}
+
 
 static DRIVER_INIT( dokaben )
 {
 	input_type = 0;
 	nvram_size = 0;
 	mgakuen2_decode();
+	configure_banks();
 }
 static DRIVER_INIT( pang )
 {
 	input_type = 0;
 	nvram_size = 0;
 	pang_decode();
+	configure_banks();
 }
 static DRIVER_INIT( pangb )
 {
 	input_type = 0;
 	nvram_size = 0;
 	bootleg_decode();
+	configure_banks();
 }
 static DRIVER_INIT( cworld )
 {
 	input_type = 0;
 	nvram_size = 0;
 	cworld_decode();
+	configure_banks();
 }
 static DRIVER_INIT( hatena )
 {
 	input_type = 0;
 	nvram_size = 0;
 	hatena_decode();
+	configure_banks();
 }
 static DRIVER_INIT( spang )
 {
@@ -1989,6 +1998,7 @@ static DRIVER_INIT( spang )
 	nvram_size = 0x80;
 	nvram = &memory_region(REGION_CPU1)[0xe000];	/* NVRAM */
 	spang_decode();
+	configure_banks();
 }
 static DRIVER_INIT( spangj )
 {
@@ -1996,6 +2006,7 @@ static DRIVER_INIT( spangj )
 	nvram_size = 0x80;
 	nvram = &memory_region(REGION_CPU1)[0xe000];	/* NVRAM */
 	spangj_decode();
+	configure_banks();
 
 	/* fix data that will be written to nvram */
 	{
@@ -2011,34 +2022,40 @@ static DRIVER_INIT( sbbros )
 	nvram_size = 0x80;
 	nvram = &memory_region(REGION_CPU1)[0xe000];	/* NVRAM */
 	sbbros_decode();
+	configure_banks();
 }
 static DRIVER_INIT( qtono1 )
 {
 	input_type = 0;
 	nvram_size = 0;
 	qtono1_decode();
+	configure_banks();
 }
 static DRIVER_INIT( qsangoku )
 {
 	input_type = 0;
 	nvram_size = 0;
 	qsangoku_decode();
+	configure_banks();
 }
 static DRIVER_INIT( mgakuen )
 {
 	input_type = 1;
+	configure_banks();
 }
 static DRIVER_INIT( mgakuen2 )
 {
 	input_type = 1;
 	nvram_size = 0;
 	mgakuen2_decode();
+	configure_banks();
 }
 static DRIVER_INIT( marukin )
 {
 	input_type = 1;
 	nvram_size = 0;
 	marukin_decode();
+	configure_banks();
 }
 static DRIVER_INIT( block )
 {
@@ -2046,6 +2063,7 @@ static DRIVER_INIT( block )
 	nvram_size = 0x80;
 	nvram = &memory_region(REGION_CPU1)[0xff80];	/* NVRAM */
 	block_decode();
+	configure_banks();
 }
 static DRIVER_INIT( blockbl )
 {
@@ -2053,16 +2071,17 @@ static DRIVER_INIT( blockbl )
 	nvram_size = 0x80;
 	nvram = &memory_region(REGION_CPU1)[0xff80];	/* NVRAM */
 	bootleg_decode();
+	configure_banks();
 }
 
 static DRIVER_INIT( mstworld )
 {
 	/* descramble the program rom .. */
-	UINT8* source = memory_region(REGION_USER1) ;
+	UINT8* source = malloc_or_die(memory_region_length(REGION_CPU1));
 	UINT8* dst    = memory_region(REGION_CPU1) ;
 	int x;
 
-	int tablebank[]=
+	static const int tablebank[]=
 	{
 		/* fixed code */ 0,  0,
 		/* fixed code */ 1,  1,
@@ -2086,16 +2105,19 @@ static DRIVER_INIT( mstworld )
 		/* bank f     */12, 12,
 	};
 
+	memcpy(source, dst, memory_region_length(REGION_CPU1));
 	for (x=0;x<40;x+=2)
 	{
 		if (tablebank[x]!=-1)
 		{
 			memcpy(&dst[(x/2)*0x4000],&source[tablebank[x]*0x4000],0x4000);
-			memcpy(&dst[((x/2)*0x4000)+0x80000],&source[tablebank[x+1]*0x4000],0x4000);
+			memcpy(&dst[((x/2)*0x4000)+0x50000],&source[tablebank[x+1]*0x4000],0x4000);
 		}
 	}
+	free(source);
 
-	memory_set_opcode_base(0,memory_region(REGION_CPU1)+0x80000);
+	bootleg_decode();
+	configure_banks();
 }
 
 
@@ -2119,7 +2141,7 @@ GAME( 1990, sbbros,   spang,    pang,    pang,     sbbros,   ROT0,   "Mitchell +
 GAME( 1990, marukin,  0,        marukin, marukin,  marukin,  ROT0,   "Yuga", "Super Marukin-Ban (Japan 901017)", 0 )
 GAME( 1991, qtono1,   0,        pang,    qtono1,   qtono1,   ROT0,   "Capcom", "Quiz Tonosama no Yabou (Japan)", 0 )
 GAME( 1991, qsangoku, 0,        pang,    qtono1,   qsangoku, ROT0,   "Capcom", "Quiz Sangokushi (Japan)", 0 )
-GAME( 1991, block,    0,        pang,    blockj,   block,    ROT270, "Capcom", "Block Block (World 911106 Joystick)", 0 )
-GAME( 1991, blocka,   block,    pang,    block,    block,    ROT270, "Capcom", "Block Block (World 910910)", 0 )
+GAME( 1991, block,    0,        pang,    block,    block,    ROT270, "Capcom", "Block Block (World 910910)", 0 )
 GAME( 1991, blockj,   block,    pang,    block,    block,    ROT270, "Capcom", "Block Block (Japan 910910)", 0 )
+GAME( 1991, blockjoy, block,    pang,    blockjoy, block,    ROT270, "Capcom", "Block Block (World 911106 Joystick)", 0 )
 GAME( 1991, blockbl,  block,    pang,    block,    blockbl,  ROT270, "bootleg", "Block Block (bootleg)", 0 )
