@@ -16,8 +16,8 @@ extern int mjsister_flip_screen;
 extern int mjsister_video_enable;
 extern int mjsister_screen_redraw;
 
-extern int vrambank;
-extern int colorbank;
+extern int mjsister_vrambank;
+extern int mjsister_colorbank;
 
 VIDEO_START( mjsister );
 VIDEO_UPDATE( mjsister );
@@ -34,7 +34,7 @@ static unsigned int dac_adr,dac_bank,dac_adr_s,dac_adr_e,dac_busy;
 
 static void dac_callback(int param)
 {
-	data8_t *DACROM = memory_region(REGION_SOUND1);
+	UINT8 *DACROM = memory_region(REGION_SOUND1);
 
 	DAC_data_w(0,DACROM[(dac_bank * 0x10000 + dac_adr++) & 0x1ffff]);
 
@@ -60,15 +60,15 @@ static WRITE8_HANDLER( mjsister_dac_adr_e_w )
 	dac_busy = 1;
 }
 
-static MACHINE_INIT( mjsister )
+static MACHINE_RESET( mjsister )
 {
 	dac_busy = 0;
 }
 
 static WRITE8_HANDLER( mjsister_banksel1_w )
 {
-	data8_t *BANKROM = memory_region(REGION_CPU1);
-	int tmp = colorbank;
+	UINT8 *BANKROM = memory_region(REGION_CPU1);
+	int tmp = mjsister_colorbank;
 
 	switch (data)
 	{
@@ -78,32 +78,32 @@ static WRITE8_HANDLER( mjsister_banksel1_w )
 		case 0x2: mjsister_flip_screen = 0 ; break;
 		case 0x3: mjsister_flip_screen = 1 ; break;
 
-		case 0x4: colorbank &=0xfe; break;
-		case 0x5: colorbank |=0x01; break;
-		case 0x6: colorbank &=0xfd; break;
-		case 0x7: colorbank |=0x02; break;
-		case 0x8: colorbank &=0xfb; break;
-		case 0x9: colorbank |=0x04; break;
+		case 0x4: mjsister_colorbank &=0xfe; break;
+		case 0x5: mjsister_colorbank |=0x01; break;
+		case 0x6: mjsister_colorbank &=0xfd; break;
+		case 0x7: mjsister_colorbank |=0x02; break;
+		case 0x8: mjsister_colorbank &=0xfb; break;
+		case 0x9: mjsister_colorbank |=0x04; break;
 
 		case 0xa: mjsister_video_enable = 0 ; break;
 		case 0xb: mjsister_video_enable = 1 ; break;
 
-		case 0xe: vrambank = 0 ; break;
-		case 0xf: vrambank = 1 ; break;
+		case 0xe: mjsister_vrambank = 0 ; break;
+		case 0xf: mjsister_vrambank = 1 ; break;
 
 		default:
 			logerror("%04x p30_w:%02x\n",activecpu_get_pc(),data);
 	}
 
-	if (tmp != colorbank)
+	if (tmp != mjsister_colorbank)
 		mjsister_screen_redraw = 1;
 
-	cpu_setbank(1,&BANKROM[rombank0*0x10000+rombank1*0x8000]+0x10000);
+	memory_set_bankptr(1,&BANKROM[rombank0*0x10000+rombank1*0x8000]+0x10000);
 }
 
 static WRITE8_HANDLER( mjsister_banksel2_w )
 {
-	data8_t *BANKROM = memory_region(REGION_CPU1);
+	UINT8 *BANKROM = memory_region(REGION_CPU1);
 
 	switch (data)
 	{
@@ -117,7 +117,7 @@ static WRITE8_HANDLER( mjsister_banksel2_w )
 			logerror("%04x p31_w:%02x\n",activecpu_get_pc(),data);
 	}
 
-	cpu_setbank(1,&BANKROM[rombank0*0x10000+rombank1*0x8000]+0x10000);
+	memory_set_bankptr(1,&BANKROM[rombank0*0x10000+rombank1*0x8000]+0x10000);
 }
 
 static WRITE8_HANDLER( mjsister_input_sel1_w )
@@ -312,7 +312,7 @@ static MACHINE_DRIVER_START( mjsister )
 
 	MDRV_FRAMES_PER_SECOND(60)
 	MDRV_VBLANK_DURATION(DEFAULT_REAL_60HZ_VBLANK_DURATION)
-	MDRV_MACHINE_INIT(mjsister)
+	MDRV_MACHINE_RESET(mjsister)
 
 	/* video hardware */
 	MDRV_VIDEO_ATTRIBUTES(VIDEO_TYPE_RASTER)
@@ -358,4 +358,4 @@ ROM_START( mjsister )
 	ROM_LOAD( "ms08.bpr", 0x0300,  0x0100, CRC(da2b3b38) SHA1(4de99c17b227653bc1b904f1309f447f5a0ab516) ) /* ? */
 ROM_END
 
-GAME( 1986, mjsister, 0, mjsister, mjsister, 0, ROT0, "Toaplan", "Mahjong Sisters (Japan)" )
+GAME( 1986, mjsister, 0, mjsister, mjsister, 0, ROT0, "Toaplan", "Mahjong Sisters (Japan)", 0 )
