@@ -3,7 +3,6 @@
 */
 
 #include "driver.h"
-#include "vidhrdw/generic.h"
 #include "machine/eeprom.h"
 #include "system16.h"
 #include "vidhrdw/segaic24.h"
@@ -29,6 +28,9 @@ WRITE16_HANDLER( model1_tgp_copro_ram_w );
 
 static int model1_sound_irq;
 
+#define FIFO_SIZE	(8)
+static int to_68k[FIFO_SIZE], fifo_wptr, fifo_rptr;
+
 void model1_tgp_reset(int swa);
 
 static READ16_HANDLER( io_r )
@@ -56,7 +58,7 @@ static WRITE16_HANDLER( bank_w )
 	if(ACCESSING_LSB) {
 		switch(data & 0xf) {
 		case 0x1: /* 100000-1fffff data roms banking */
-			cpu_setbank(1, memory_region(REGION_CPU1) + 0x1000000 + 0x100000*((data >> 4) & 0xf));
+			memory_set_bankptr(1, memory_region(REGION_CPU1) + 0x1000000 + 0x100000*((data >> 4) & 0xf));
 			logerror("BANK %x\n", 0x1000000 + 0x100000*((data >> 4) & 0xf));
 			break;
 		case 0x2: /* 200000-2fffff data roms banking (unused, all known games have only one bank) */
@@ -99,7 +101,7 @@ static int irq_callback(int irqline)
 static void irq_init(void)
 {
 	cpunum_set_input_line(0, 0, CLEAR_LINE);
-	cpu_set_irq_callback(0, irq_callback);
+	cpunum_set_irq_callback(0, irq_callback);
 }
 
 extern void tgp_tick(void);
@@ -113,12 +115,18 @@ static INTERRUPT_GEN(model1_interrupt)
 	else
 	{
 		irq_raise(model1_sound_irq);
+
+		/* if the FIFO has something in it, signal the 68k too */
+		if (fifo_rptr != fifo_wptr)
+		{
+			cpunum_set_input_line(1, 2, HOLD_LINE);
+		}
 	}
 }
 
-static MACHINE_INIT(model1)
+static MACHINE_RESET(model1)
 {
-	cpu_setbank(1, memory_region(REGION_CPU1) + 0x1000000);
+	memory_set_bankptr(1, memory_region(REGION_CPU1) + 0x1000000);
 	irq_init();
 	model1_tgp_reset(!strcmp(Machine->gamedrv->name, "swa") || !strcmp(Machine->gamedrv->name, "wingwar") || !strcmp(Machine->gamedrv->name, "wingwara"));
 	if (!strcmp(Machine->gamedrv->name, "swa"))
@@ -129,6 +137,10 @@ static MACHINE_INIT(model1)
 	{
 		model1_sound_irq = 3;
 	}
+
+	/* init the sound FIFO */
+	fifo_rptr = fifo_wptr = 0;
+	memset(to_68k, 0, sizeof(to_68k));
 }
 
 static READ16_HANDLER( network_ctl_r )
@@ -204,8 +216,6 @@ static WRITE16_HANDLER(mr2_w)
 		logerror("MW 10[r10], %f (%x)\n", *(float *)(mr2+0x1f10/2), activecpu_get_pc());
 }
 
-static int to_68k;
-
 static READ16_HANDLER( snd_68k_ready_r )
 {
 	int sr = cpunum_get_reg(1, M68K_REG_SR);
@@ -221,13 +231,11 @@ static READ16_HANDLER( snd_68k_ready_r )
 
 static WRITE16_HANDLER( snd_latch_to_68k_w )
 {
-	while (!snd_68k_ready_r(0, 0))
-	{
-		cpu_spinuntil_time(TIME_IN_USEC(40));
-	}
-
-	to_68k = data;
+	to_68k[fifo_wptr] = data;
+	fifo_wptr++;
+	if (fifo_wptr >= FIFO_SIZE) fifo_wptr = 0;
 
+	/* signal the 68000 that there's data waiting */
 	cpunum_set_input_line(1, 2, HOLD_LINE);
 	/* give the 68k time to reply */
 	cpu_spinuntil_time(TIME_IN_USEC(40));
@@ -283,7 +291,14 @@ ADDRESS_MAP_END
 
 static READ16_HANDLER( m1_snd_68k_latch_r )
 {
-	return to_68k;
+	UINT16 retval;
+
+	retval = to_68k[fifo_rptr];
+
+	fifo_rptr++;
+	if (fifo_rptr >= FIFO_SIZE) fifo_rptr = 0;
+
+	return retval;
 }
 
 static READ16_HANDLER( m1_snd_v60_ready_r )
@@ -303,7 +318,7 @@ static WRITE16_HANDLER( m1_snd_mpcm0_w )
 
 static WRITE16_HANDLER( m1_snd_mpcm0_bnk_w )
 {
-	MultiPCM_bank_0_w(0, data);
+	multipcm_set_bank(0, 0x100000 * (data & 3), 0x100000 * (data & 3));
 }
 
 static READ16_HANDLER( m1_snd_mpcm1_r )
@@ -318,7 +333,7 @@ static WRITE16_HANDLER( m1_snd_mpcm1_w )
 
 static WRITE16_HANDLER( m1_snd_mpcm1_bnk_w )
 {
-	MultiPCM_bank_1_w(0, data);
+	multipcm_set_bank(1, 0x100000 * (data & 3), 0x100000 * (data & 3));
 }
 
 static READ16_HANDLER( m1_snd_ym_r )
@@ -371,15 +386,11 @@ ADDRESS_MAP_END
 
 static struct MultiPCM_interface m1_multipcm_interface_1 =
 {
-	MULTIPCM_MODE_MODEL1,
-	(1024*1024),
 	REGION_SOUND1
 };
 
 static struct MultiPCM_interface m1_multipcm_interface_2 =
 {
-	MULTIPCM_MODE_MODEL1,
-	(1024*1024),
 	REGION_SOUND2
 };
 
@@ -818,18 +829,18 @@ ROM_START( wingwara )
 ROM_END
 
 static MACHINE_DRIVER_START( model1 )
-	MDRV_CPU_ADD(V60, 16000000/12) /* Reality is 16Mhz */
+	MDRV_CPU_ADD(V60, 16000000)
 	MDRV_CPU_PROGRAM_MAP(model1_mem, 0)
 	MDRV_CPU_IO_MAP(model1_io, 0)
 	MDRV_CPU_VBLANK_INT(model1_interrupt, 2)
 
-	MDRV_CPU_ADD(M68000, 12000000)	/* Confirmed 10 MHz on real PCB, run slightly faster here to prevent sync trouble */
+	MDRV_CPU_ADD(M68000, 10000000)	/* verified on real h/w */
 	MDRV_CPU_PROGRAM_MAP(model1_snd, 0)
 
 	MDRV_FRAMES_PER_SECOND(60)
 	MDRV_VBLANK_DURATION(DEFAULT_60HZ_VBLANK_DURATION)
 
-	MDRV_MACHINE_INIT(model1)
+	MDRV_MACHINE_RESET(model1)
 	MDRV_NVRAM_HANDLER(generic_0fill)
 
 	MDRV_VIDEO_ATTRIBUTES(VIDEO_TYPE_RASTER | VIDEO_UPDATE_AFTER_VBLANK | VIDEO_RGB_DIRECT)
@@ -858,9 +869,9 @@ static MACHINE_DRIVER_START( model1 )
 	MDRV_SOUND_ROUTE(1, "right", 1.0)
 MACHINE_DRIVER_END
 
-GAMEX( 1993, vf,      0, model1, vf,      0, ROT0, "Sega", "Virtua Fighter", GAME_IMPERFECT_GRAPHICS )
-GAMEX( 1992, vr,       0, model1, vr,       0, ROT0, "Sega", "Virtua Racing", GAME_NOT_WORKING )
-GAMEX( 1993, vformula, vr, model1, vr,       0, ROT0, "Sega", "Virtua Formula", GAME_NOT_WORKING )
-GAMEX( 1993, swa,      0, model1, swa,      0, ROT0, "Sega", "Star Wars Arcade", GAME_NOT_WORKING|GAME_NO_SOUND )
-GAMEX( 1994, wingwar,  0, model1, wingwar,  0, ROT0, "Sega", "Wing War (US)", GAME_NOT_WORKING )
-GAMEX( 1994, wingwara, wingwar, model1, wingwar,  0, ROT0, "Sega", "Wing War", GAME_NOT_WORKING )
+GAME( 1993, vf,      0, model1, vf,      0, ROT0, "Sega", "Virtua Fighter", GAME_IMPERFECT_GRAPHICS )
+GAME( 1992, vr,       0, model1, vr,       0, ROT0, "Sega", "Virtua Racing", GAME_NOT_WORKING )
+GAME( 1993, vformula, vr, model1, vr,       0, ROT0, "Sega", "Virtua Formula", GAME_NOT_WORKING )
+GAME( 1993, swa,      0, model1, swa,      0, ROT0, "Sega", "Star Wars Arcade", GAME_NOT_WORKING | GAME_IMPERFECT_SOUND )
+GAME( 1994, wingwar,  0, model1, wingwar,  0, ROT0, "Sega", "Wing War (US)", GAME_NOT_WORKING )
+GAME( 1994, wingwara, wingwar, model1, wingwar,  0, ROT0, "Sega", "Wing War", GAME_NOT_WORKING )
