@@ -3,9 +3,9 @@
 #include "driver.h"
 #include "sound/dac.h"
 
-data8_t *mogura_tileram;
-data8_t* mogura_gfxram;
-static struct tilemap *mogura_tilemap;
+UINT8 *mogura_tileram;
+UINT8* mogura_gfxram;
+static tilemap *mogura_tilemap;
 
 PALETTE_INIT( mogura )
 {
@@ -62,7 +62,7 @@ VIDEO_START( mogura )
 VIDEO_UPDATE( mogura )
 {
 	/* tilemap layout is a bit strange ... */
-	struct rectangle clip;
+	rectangle clip;
 	clip.min_x = Machine->visible_area.min_x;
 	clip.max_x = 256-1;
 	clip.min_y = Machine->visible_area.min_y;
@@ -194,7 +194,7 @@ INPUT_PORTS_END
 
 
 
-static struct GfxLayout tiles8x8_layout =
+static const gfx_layout tiles8x8_layout =
 {
 	8,8,
 	RGN_FRAC(1,1),
@@ -205,9 +205,9 @@ static struct GfxLayout tiles8x8_layout =
 	16*8
 };
 
-static struct GfxDecodeInfo gfxdecodeinfo[] =
+static const gfx_decode gfxdecodeinfo[] =
 {
-	{ REGION_GFX1, 0, &tiles8x8_layout, 0, 8 },
+	{ 0, 0, &tiles8x8_layout, 0, 8 },
 	{ -1 }
 };
 
@@ -247,11 +247,8 @@ ROM_START( mogura )
 	ROM_REGION( 0x10000, REGION_CPU1, 0 )
 	ROM_LOAD( "gx141.5n", 0x00000, 0x08000, CRC(98e6120d) SHA1(45cdb2d78224a7c44fff8cd3487f33c57669a06c)  )
 
-	ROM_REGION( 0x1000, REGION_GFX1, 0 )
-	/* allocate ram here for ram based characters */
-
 	ROM_REGION( 0x20, REGION_PROMS, 0 )
 	ROM_LOAD( "gx141.7j", 0x00, 0x20,  CRC(b21c5d5f) SHA1(6913c840dd69a7d4687f4c4cbe3ff12300f62bc2) )
 ROM_END
 
-GAME( 1991, mogura, 0, mogura, mogura, 0, ROT0, "Konami", "Mogura Desse" )
+GAME( 1991, mogura, 0, mogura, mogura, 0, ROT0, "Konami", "Mogura Desse", 0 )
