@@ -75,7 +75,6 @@ Known issues:
 ***************************************************************************/
 
 #include "driver.h"
-#include "vidhrdw/generic.h"
 #include "cpu/z80/z80.h"
 #include "machine/8255ppi.h"
 #include "sound/ay8910.h"
@@ -94,7 +93,7 @@ VIDEO_UPDATE( monzagp )
 	{
 		UINT16 *dest = bitmap->line[sy];
 		int sx;
-		for( sx=0; sx<512; sx++ );
+		for( sx=0; sx<512; sx++ )
 		{
 			dest[sx] = *source++;
 		}
@@ -142,7 +141,7 @@ ADDRESS_MAP_END
 
 /***************************************************************************/
 
-static gfx_layout tile_layout =
+static const gfx_layout tile_layout =
 {
 	/* game doesn't appear to use character-based graphics, but this allows us to view contents of the data */
 	/* ROMs that do contain bitmaps */
@@ -159,7 +158,7 @@ static gfx_layout tile_layout =
 	0x200
 };
 
-static gfx_layout tile_layout2 =
+static const gfx_layout tile_layout2 =
 {
 	16,16,
 	RGN_FRAC(1,1),
@@ -174,7 +173,7 @@ static gfx_layout tile_layout2 =
 	0x200
 };
 
-static gfx_decode gfxdecodeinfo[] =
+static const gfx_decode gfxdecodeinfo[] =
 {
 	{ REGION_GFX1, 0x0000, &tile_layout,  0, 4 },
 	{ REGION_GFX1, 0x0000, &tile_layout2,  0, 4 },
