@@ -38,7 +38,6 @@ are supported. What should really be filled in for each mode?
 
 #include "driver.h"
 #include "sndhrdw/irem.h"
-#include "vidhrdw/generic.h"
 #include "cpu/z80/z80.h"
 
 
@@ -246,7 +245,7 @@ INPUT_PORTS_END
 
 
 
-static gfx_layout charlayout =
+static const gfx_layout charlayout =
 {
 	8,8,    /* 8*8 characters */
 	512,    /* 512 characters */
@@ -256,7 +255,7 @@ static gfx_layout charlayout =
 	{ 0*8, 1*8, 2*8, 3*8, 4*8, 5*8, 6*8, 7*8 },
 	8*8     /* every char takes 8 consecutive bytes */
 };
-static gfx_layout spritelayout =
+static const gfx_layout spritelayout =
 {
 	16,16,  /* 16*16 sprites */
 	128,    /* 128 sprites */
@@ -268,13 +267,9 @@ static gfx_layout spritelayout =
 			8*8, 9*8, 10*8, 11*8, 12*8, 13*8, 14*8, 15*8 },
 	32*8    /* every sprite takes 32 consecutive bytes */
 };
-static gfx_layout bgcharlayout =
+
+static const UINT32 bgcharlayout_xoffset[256] =
 {
-	256, 64, /* 256x64 image format */
-	1,       /* 1 image */
-	2,       /* 2 bits per pixel */
-	{ 4, 0 },       /* the two bitplanes for 4 pixels are packed into one byte */
-	{
 		0x000, 0x001, 0x002, 0x003, 0x008, 0x009, 0x00a, 0x00b,
 		0x010, 0x011, 0x012, 0x013, 0x018, 0x019, 0x01a, 0x01b,
 		0x020, 0x021, 0x022, 0x023, 0x028, 0x029, 0x02a, 0x02b,
@@ -307,8 +302,10 @@ static gfx_layout bgcharlayout =
 		0x1d0, 0x1d1, 0x1d2, 0x1d3, 0x1d8, 0x1d9, 0x1da, 0x1db,
 		0x1e0, 0x1e1, 0x1e2, 0x1e3, 0x1e8, 0x1e9, 0x1ea, 0x1eb,
 		0x1f0, 0x1f1, 0x1f2, 0x1f3, 0x1f8, 0x1f9, 0x1fa, 0x1fb,
-	},
-	{
+};
+
+static const UINT32 bgcharlayout_yoffset[64] =
+{
 		0x0000, 0x0200, 0x0400, 0x0600, 0x0800, 0x0a00, 0x0c00, 0x0e00,
 		0x1000, 0x1200, 0x1400, 0x1600, 0x1800, 0x1a00, 0x1c00, 0x1e00,
 		0x2000, 0x2200, 0x2400, 0x2600, 0x2800, 0x2a00, 0x2c00, 0x2e00,
@@ -317,13 +314,24 @@ static gfx_layout bgcharlayout =
 		0x5000, 0x5200, 0x5400, 0x5600, 0x5800, 0x5a00, 0x5c00, 0x5e00,
 		0x6000, 0x6200, 0x6400, 0x6600, 0x6800, 0x6a00, 0x6c00, 0x6e00,
 		0x7000, 0x7200, 0x7400, 0x7600, 0x7800, 0x7a00, 0x7c00, 0x7e00,
-	},
-	0x8000
+};
+
+static const gfx_layout bgcharlayout =
+{
+	256, 64, /* 256x64 image format */
+	1,       /* 1 image */
+	2,       /* 2 bits per pixel */
+	{ 4, 0 },       /* the two bitplanes for 4 pixels are packed into one byte */
+	EXTENDED_XOFFS,
+	EXTENDED_YOFFS,
+	0x8000,
+	bgcharlayout_xoffset,
+	bgcharlayout_yoffset
 };
 
 
 
-static gfx_decode gfxdecodeinfo[] =
+static const gfx_decode gfxdecodeinfo[] =
 {
 	{ REGION_GFX1, 0x0000, &charlayout,                0, 128 },
 	{ REGION_GFX2, 0x0000, &spritelayout,          128*4,  16 },
