@@ -14,7 +14,6 @@ Notes:
 ***************************************************************************/
 
 #include "driver.h"
-#include "vidhrdw/generic.h"
 #include "sound/ay8910.h"
 
 
@@ -94,8 +93,8 @@ static ADDRESS_MAP_START( writemem, ADDRESS_SPACE_PROGRAM, 8 )
 	AM_RANGE(0x0780, 0x07df) AM_WRITE(MWA8_RAM) AM_BASE(&spriteram) AM_SIZE(&spriteram_size)
 	AM_RANGE(0x07e0, 0x07ff) AM_WRITE(MWA8_RAM)
 	AM_RANGE(0x0800, 0x0fff) AM_WRITE(MWA8_RAM)	/* work RAM? */
-	AM_RANGE(0x1000, 0x17ff) AM_WRITE(&mystston_videoram_w) AM_BASE(&videoram)
-	AM_RANGE(0x1800, 0x1bff) AM_WRITE(&mystston_videoram2_w) AM_BASE(&mystston_videoram2)
+	AM_RANGE(0x1000, 0x17ff) AM_WRITE(mystston_videoram_w) AM_BASE(&videoram)
+	AM_RANGE(0x1800, 0x1bff) AM_WRITE(mystston_videoram2_w) AM_BASE(&mystston_videoram2)
 	AM_RANGE(0x1c00, 0x1fff) AM_WRITE(MWA8_RAM)	/* work RAM? This gets copied to videoram */
 	AM_RANGE(0x2000, 0x2000) AM_WRITE(mystston_control_w)	/* text color, flip screen & coin counters */
 	AM_RANGE(0x2010, 0x2010) AM_WRITE(mystston_irq_reset_w)
@@ -138,7 +137,21 @@ INPUT_PORTS_START( mystston )
 	PORT_DIPNAME(0x04, 0x00, DEF_STR( Demo_Sounds ) )
 	PORT_DIPSETTING(   0x04, DEF_STR( Off ) )
 	PORT_DIPSETTING(   0x00, DEF_STR( On ) )
-	PORT_BIT( 0xf8, IP_ACTIVE_LOW, IPT_UNUSED )
+	PORT_DIPNAME(0x08, 0x08, DEF_STR( Unused ) )
+	PORT_DIPSETTING(   0x08, DEF_STR( Off ) )
+	PORT_DIPSETTING(   0x00, DEF_STR( On ) )
+	PORT_DIPNAME(0x10, 0x10, DEF_STR( Unused ) )
+	PORT_DIPSETTING(   0x10, DEF_STR( Off ) )
+	PORT_DIPSETTING(   0x00, DEF_STR( On ) )
+	PORT_DIPNAME(0x20, 0x20, DEF_STR( Unused ) )
+	PORT_DIPSETTING(   0x20, DEF_STR( Off ) )
+	PORT_DIPSETTING(   0x00, DEF_STR( On ) )
+	PORT_DIPNAME(0x40, 0x40, DEF_STR( Unused ) )
+	PORT_DIPSETTING(   0x40, DEF_STR( Off ) )
+	PORT_DIPSETTING(   0x00, DEF_STR( On ) )
+	PORT_DIPNAME(0x80, 0x80, DEF_STR( Unused ) )
+	PORT_DIPSETTING(   0x80, DEF_STR( Off ) )
+	PORT_DIPSETTING(   0x00, DEF_STR( On ) )
 
 	PORT_START	/* DSW2 */
 	PORT_DIPNAME(0x03, 0x03, DEF_STR( Coin_A ) )
@@ -151,7 +164,9 @@ INPUT_PORTS_START( mystston )
 	PORT_DIPSETTING(   0x0c, DEF_STR( 1C_1C ) )
 	PORT_DIPSETTING(   0x08, DEF_STR( 1C_2C ) )
 	PORT_DIPSETTING(   0x04, DEF_STR( 1C_3C ) )
-	PORT_BIT( 0x10, IP_ACTIVE_LOW, IPT_UNUSED )
+	PORT_DIPNAME(0x10, 0x10, DEF_STR( Unused ) )
+	PORT_DIPSETTING(   0x10, DEF_STR( Off ) )
+	PORT_DIPSETTING(   0x00, DEF_STR( On ) )
 	PORT_DIPNAME(0x20, 0x00, DEF_STR( Flip_Screen ) )
 	PORT_DIPSETTING(   0x00, DEF_STR( Off ) )
 	PORT_DIPSETTING(   0x20, DEF_STR( On ) )
@@ -162,7 +177,7 @@ INPUT_PORTS_START( mystston )
 INPUT_PORTS_END
 
 
-static gfx_layout charlayout =
+static const gfx_layout charlayout =
 {
 	8,8,
 	RGN_FRAC(1,3),
@@ -173,7 +188,7 @@ static gfx_layout charlayout =
 	8*8
 };
 
-static gfx_layout spritelayout =
+static const gfx_layout spritelayout =
 {
 	16,16,
 	RGN_FRAC(1,3),
@@ -186,7 +201,7 @@ static gfx_layout spritelayout =
 	32*8
 };
 
-static gfx_decode gfxdecodeinfo[] =
+static const gfx_decode gfxdecodeinfo[] =
 {
 	{ REGION_GFX1, 0, &charlayout,   3*8, 4 },
 	{ REGION_GFX2, 0, &spritelayout, 2*8, 1 },
@@ -223,7 +238,7 @@ static INTERRUPT_GEN( mystston_interrupt )
 	/* IMS is triggered every time VLOC line 3 is raised,
        as VLOC counter starts at 16, effectively every 16 scanlines */
 	if ((scanline % 16) == 0)
-		cpunum_set_input_line(0, 0, HOLD_LINE);
+		cpunum_set_input_line(0, 0, ASSERT_LINE);
 }
 
 
