@@ -22,9 +22,7 @@
  */
 
 #include "driver.h"
-#include "state.h"
 
-#include "vidhrdw/generic.h"
 #include "vidhrdw/konamiic.h"
 #include "machine/konamigx.h"
 #include "cpu/m68000/m68000.h"
@@ -53,8 +51,8 @@ READ16_HANDLER(ddd_053936_tilerom_2_r);
 
 static UINT16 *gx_workram;
 
-static int init_eeprom_count;
-static int mw_irq_control;
+static INT32 init_eeprom_count;
+static UINT8 mw_irq_control;
 
 static struct EEPROM_interface eeprom_interface =
 {
@@ -434,7 +432,7 @@ static ADDRESS_MAP_START( writemem, ADDRESS_SPACE_PROGRAM, 16 )
 	AM_RANGE(0x49e000, 0x49e007) AM_WRITE(irq_ack_w)	/* VSCCS (custom) */
 	AM_RANGE(0x600000, 0x601fff) AM_WRITE(K056832_ram_word_w)
 	AM_RANGE(0x602000, 0x603fff) AM_WRITE(K056832_ram_word_w)	/* tilemap RAM mirror write(essential) */
-	AM_RANGE(0x700000, 0x701fff) AM_WRITE(paletteram16_xrgb_word_w) AM_BASE(&paletteram16)
+	AM_RANGE(0x700000, 0x701fff) AM_WRITE(paletteram16_xrgb_word_be_w) AM_BASE(&paletteram16)
 ADDRESS_MAP_END
 
 /* Metamorphic Force */
@@ -489,7 +487,7 @@ static ADDRESS_MAP_START( mmwritemem, ADDRESS_SPACE_PROGRAM, 16 )
 	AM_RANGE(0x27C000, 0x27C001) AM_WRITE(mmeeprom_w)
 	AM_RANGE(0x300000, 0x301fff) AM_WRITE(K056832_ram_word_w)
 	AM_RANGE(0x302000, 0x303fff) AM_WRITE(K056832_ram_word_w)	/* tilemap RAM mirror write(essential) */
-	AM_RANGE(0x330000, 0x331fff) AM_WRITE(paletteram16_xrgb_word_w) AM_BASE(&paletteram16)
+	AM_RANGE(0x330000, 0x331fff) AM_WRITE(paletteram16_xrgb_word_be_w) AM_BASE(&paletteram16)
 ADDRESS_MAP_END
 
 /* Violent Storm */
@@ -547,7 +545,7 @@ static ADDRESS_MAP_START( vswritemem, ADDRESS_SPACE_PROGRAM, 16 )
 	AM_RANGE(0x300000, 0x301fff) AM_WRITE(K056832_ram_word_w)
 	AM_RANGE(0x302000, 0x303fff) AM_WRITE(K056832_ram_word_w) /* tilemap RAM mirror write(essential) */
 	AM_RANGE(0x304000, 0x3041ff) AM_WRITE(MWA16_RAM)
-	AM_RANGE(0x330000, 0x331fff) AM_WRITE(paletteram16_xrgb_word_w) AM_BASE(&paletteram16)
+	AM_RANGE(0x330000, 0x331fff) AM_WRITE(paletteram16_xrgb_word_be_w) AM_BASE(&paletteram16)
 ADDRESS_MAP_END
 
 /* Martial Champion specific interfaces */
@@ -646,7 +644,7 @@ static ADDRESS_MAP_START( mcwritemem, ADDRESS_SPACE_PROGRAM, 16 )
 	AM_RANGE(0x418000, 0x41801f) AM_WRITE(MWA16_RAM)			/* sound regs fall through */
 	AM_RANGE(0x41a000, 0x41a001) AM_WRITE(sound_irq_w)
 	AM_RANGE(0x480000, 0x483fff) AM_WRITE(K053247_martchmp_word_w) AM_BASE(&spriteram16)
-	AM_RANGE(0x600000, 0x601fff) AM_WRITE(paletteram16_xrgb_word_w) AM_BASE(&paletteram16)
+	AM_RANGE(0x600000, 0x601fff) AM_WRITE(paletteram16_xrgb_word_be_w) AM_BASE(&paletteram16)
 	AM_RANGE(0x680000, 0x681fff) AM_WRITE(K056832_ram_word_w)
 	AM_RANGE(0x682000, 0x683fff) AM_WRITE(K056832_ram_word_w)	/* tilemap RAM mirror write(essential) */
 ADDRESS_MAP_END
@@ -685,7 +683,7 @@ static ADDRESS_MAP_START( dddwritemem, ADDRESS_SPACE_PROGRAM, 16 )
 	AM_RANGE(0x400000, 0x40ffff) AM_WRITE(K053247_scattered_word_w) AM_BASE(&spriteram16)
 	AM_RANGE(0x410000, 0x411fff) AM_WRITE(K056832_ram_word_w)
 	AM_RANGE(0x412000, 0x413fff) AM_WRITE(K056832_ram_word_w)	/* tile RAM mirror write(essential) */
-	AM_RANGE(0x420000, 0x421fff) AM_WRITE(paletteram16_xrgb_word_w) AM_BASE(&paletteram16)
+	AM_RANGE(0x420000, 0x421fff) AM_WRITE(paletteram16_xrgb_word_be_w) AM_BASE(&paletteram16)
 	AM_RANGE(0x430000, 0x430007) AM_WRITE(K053246_word_w)
 	AM_RANGE(0x450010, 0x45001f) AM_WRITE(K053247_reg_word_w)
 	AM_RANGE(0x460000, 0x46001f) AM_WRITE(MWA16_RAM) AM_BASE(&K053936_0_ctrl)
@@ -745,7 +743,7 @@ static ADDRESS_MAP_START( gaiawritemem, ADDRESS_SPACE_PROGRAM, 16 )
 	AM_RANGE(0x410000, 0x411fff) AM_WRITE(K056832_ram_word_w)
 	AM_RANGE(0x412000, 0x413fff) AM_WRITE(K056832_ram_word_w)	/* tilemap RAM mirror write(essential) */
 	AM_RANGE(0x412000, 0x4120ff) AM_WRITE(MWA16_RAM)
-	AM_RANGE(0x420000, 0x421fff) AM_WRITE(paletteram16_xrgb_word_w) AM_BASE(&paletteram16)
+	AM_RANGE(0x420000, 0x421fff) AM_WRITE(paletteram16_xrgb_word_be_w) AM_BASE(&paletteram16)
 	AM_RANGE(0x430000, 0x430007) AM_WRITE(K053246_word_w)
 	AM_RANGE(0x450010, 0x45001f) AM_WRITE(K053247_reg_word_w)
 	AM_RANGE(0x460000, 0x46001f) AM_WRITE(MWA16_RAM) AM_BASE(&K053936_0_ctrl)
@@ -821,7 +819,7 @@ static struct K054539interface k054539_interface =
 
 /**********************************************************************************/
 
-static gfx_layout bglayout_4bpp =
+static const gfx_layout bglayout_4bpp =
 {
 	16,16,
 	RGN_FRAC(1,1),
@@ -832,7 +830,7 @@ static gfx_layout bglayout_4bpp =
 	16*64
 };
 
-static gfx_layout bglayout_8bpp =
+static const gfx_layout bglayout_8bpp =
 {
 	16,16,
 	RGN_FRAC(1,1),
@@ -843,19 +841,34 @@ static gfx_layout bglayout_8bpp =
 	16*128
 };
 
-static gfx_decode gfxdecodeinfo_gaiapols[] =
+static const gfx_decode gfxdecodeinfo_gaiapols[] =
 {
 	{ REGION_GFX3, 0, &bglayout_4bpp, 0x0000, 128 },
 	{ -1 } /* end of array */
 };
 
-static gfx_decode gfxdecodeinfo_dadandrn[] =
+static const gfx_decode gfxdecodeinfo_dadandrn[] =
 {
 	{ REGION_GFX3, 0, &bglayout_8bpp, 0x0000, 8 },
 	{ -1 } /* end of array */
 };
 
-static MACHINE_INIT(mystwarr)
+static MACHINE_START( mystwarr )
+{
+	/* set default bankswitch */
+	cur_sound_region = 2;
+	reset_sound_region();
+
+	mw_irq_control = 0;
+
+	state_save_register_global(mw_irq_control);
+	state_save_register_global(cur_sound_region);
+	state_save_register_func_postload(reset_sound_region);
+
+	return 0;
+}
+
+static MACHINE_RESET(mystwarr)
 {
 	int i;
 
@@ -870,7 +883,7 @@ static MACHINE_INIT(mystwarr)
 	for (i=0; i<=7; i++) K054539_set_gain(1, i, 0.5);
 }
 
-static MACHINE_INIT(dadandrn)
+static MACHINE_RESET(dadandrn)
 {
 	int i;
 
@@ -878,7 +891,7 @@ static MACHINE_INIT(dadandrn)
 	for (i=4; i<=7; i++) K054539_set_gain(0, i, 2.0);
 }
 
-static MACHINE_INIT(viostorm)
+static MACHINE_RESET(viostorm)
 {
 	int i;
 
@@ -886,7 +899,7 @@ static MACHINE_INIT(viostorm)
 	for (i=4; i<=7; i++) K054539_set_gain(0, i, 2.0);
 }
 
-static MACHINE_INIT(metamrph)
+static MACHINE_RESET(metamrph)
 {
 	int i;
 
@@ -900,7 +913,7 @@ static MACHINE_INIT(metamrph)
 	}
 }
 
-static MACHINE_INIT(martchmp)
+static MACHINE_RESET(martchmp)
 {
 	int i;
 
@@ -910,7 +923,7 @@ static MACHINE_INIT(martchmp)
 	for (i=4; i<=7; i++) K054539_set_gain(0, i, 1.4);
 }
 
-static MACHINE_INIT(gaiapols)
+static MACHINE_RESET(gaiapols)
 {
 	int i;
 
@@ -935,7 +948,8 @@ static MACHINE_DRIVER_START( mystwarr )
 	MDRV_VBLANK_DURATION(600)
 
 	MDRV_NVRAM_HANDLER(mystwarr)
-	MDRV_MACHINE_INIT(mystwarr)
+	MDRV_MACHINE_START(mystwarr)
+	MDRV_MACHINE_RESET(mystwarr)
 
 	/* video hardware */
 	MDRV_VIDEO_ATTRIBUTES(VIDEO_TYPE_RASTER | VIDEO_NEEDS_6BITS_PER_GUN | VIDEO_HAS_SHADOWS | VIDEO_HAS_HIGHLIGHTS | VIDEO_RGB_DIRECT | VIDEO_UPDATE_AFTER_VBLANK)
@@ -963,7 +977,7 @@ MACHINE_DRIVER_END
 static MACHINE_DRIVER_START( viostorm )
 	MDRV_IMPORT_FROM(mystwarr)
 
-	MDRV_MACHINE_INIT(viostorm)
+	MDRV_MACHINE_RESET(viostorm)
 
 	/* basic machine hardware */
 	MDRV_CPU_MODIFY("main")
@@ -981,7 +995,7 @@ MACHINE_DRIVER_END
 static MACHINE_DRIVER_START( metamrph )
 	MDRV_IMPORT_FROM(mystwarr)
 
-	MDRV_MACHINE_INIT(metamrph)
+	MDRV_MACHINE_RESET(metamrph)
 
 	/* basic machine hardware */
 	MDRV_CPU_MODIFY("main")
@@ -999,7 +1013,7 @@ MACHINE_DRIVER_END
 static MACHINE_DRIVER_START( dadandrn )
 	MDRV_IMPORT_FROM(mystwarr)
 
-	MDRV_MACHINE_INIT(dadandrn)
+	MDRV_MACHINE_RESET(dadandrn)
 
 	/* basic machine hardware */
 	MDRV_CPU_MODIFY("main")
@@ -1019,7 +1033,7 @@ MACHINE_DRIVER_END
 static MACHINE_DRIVER_START( gaiapols )
 	MDRV_IMPORT_FROM(mystwarr)
 
-	MDRV_MACHINE_INIT(gaiapols)
+	MDRV_MACHINE_RESET(gaiapols)
 
 	/* basic machine hardware */
 	MDRV_CPU_MODIFY("main")
@@ -1041,7 +1055,7 @@ MACHINE_DRIVER_END
 static MACHINE_DRIVER_START( martchmp )
 	MDRV_IMPORT_FROM(mystwarr)
 
-	MDRV_MACHINE_INIT(martchmp)
+	MDRV_MACHINE_RESET(martchmp)
 
 	/* basic machine hardware */
 	MDRV_CPU_MODIFY("main")
@@ -1411,8 +1425,8 @@ ROM_START( mystwarr )
 	ROM_REGION( 0x200000, REGION_CPU1, 0 )
 	ROM_LOAD16_BYTE( "128eaa01.20f", 0x000000, 0x40000, CRC(508f249c) SHA1(d27a272ec63e4a39379c4a23fe15c4fb45674cb4) )
 	ROM_LOAD16_BYTE( "128eaa02.20g", 0x000001, 0x40000, CRC(f8ffa352) SHA1(678c59d5fbb85d808e842947621b7f13669d35b5) )
-	ROM_LOAD16_BYTE( "128a03.19f", 0x100000, 0x80000, CRC(e98094f3) SHA1(a3f9b804ff487f792a00ce85a383868ab0b1b5d8) )
-	ROM_LOAD16_BYTE( "128a04.19g", 0x100001, 0x80000, CRC(88c6a3e4) SHA1(7c2361f716a2320730a3dd6723a271e349ad61c3) )
+	ROM_LOAD16_BYTE( "128a03.19f",   0x100000, 0x80000, CRC(e98094f3) SHA1(a3f9b804ff487f792a00ce85a383868ab0b1b5d8) )
+	ROM_LOAD16_BYTE( "128a04.19g",   0x100001, 0x80000, CRC(88c6a3e4) SHA1(7c2361f716a2320730a3dd6723a271e349ad61c3) )
 
 	/* sound program */
 	ROM_REGION( 0x030000, REGION_CPU2, 0 )
@@ -1435,7 +1449,7 @@ ROM_START( mystwarr )
 	ROM_LOAD16_BYTE( "128a11.10k", 0x400001, 512*1024, CRC(4eac941a) SHA1(c0a33f4b975ebee217fd335001839992f4c0bdc8) )
 
 	/* road generator */
-	ROM_REGION( 0x40000, REGION_GFX3, 0 )
+	ROM_REGION( 0x40000, REGION_GFX3, ROMREGION_ERASE00 )
 
 	/* sound data */
 	ROM_REGION( 0x400000, REGION_SOUND1, 0 )
@@ -1448,8 +1462,8 @@ ROM_START( mystwaru )
 	ROM_REGION( 0x200000, REGION_CPU1, 0 )
 	ROM_LOAD16_BYTE( "128uaa01.20f", 0x000000, 0x40000, CRC(3a89aafd) SHA1(6d2ebb7e04d262545276c8dbe1c63405e5de4901) )
 	ROM_LOAD16_BYTE( "128uaa02.20g", 0x000001, 0x40000, CRC(de07410f) SHA1(4583cb4402b3b046f185fa6d5a1cfaa8fe0d858c) )
-	ROM_LOAD16_BYTE( "128a03.19f", 0x100000, 0x80000, CRC(e98094f3) SHA1(a3f9b804ff487f792a00ce85a383868ab0b1b5d8) )
-	ROM_LOAD16_BYTE( "128a04.19g", 0x100001, 0x80000, CRC(88c6a3e4) SHA1(7c2361f716a2320730a3dd6723a271e349ad61c3) )
+	ROM_LOAD16_BYTE( "128a03.19f",   0x100000, 0x80000, CRC(e98094f3) SHA1(a3f9b804ff487f792a00ce85a383868ab0b1b5d8) )
+	ROM_LOAD16_BYTE( "128a04.19g",   0x100001, 0x80000, CRC(88c6a3e4) SHA1(7c2361f716a2320730a3dd6723a271e349ad61c3) )
 
 	/* sound program */
 	ROM_REGION( 0x030000, REGION_CPU2, 0 )
@@ -1472,7 +1486,7 @@ ROM_START( mystwaru )
 	ROM_LOAD16_BYTE( "128a11.10k", 0x400001, 512*1024, CRC(4eac941a) SHA1(c0a33f4b975ebee217fd335001839992f4c0bdc8) )
 
 	/* road generator */
-	ROM_REGION( 0x40000, REGION_GFX3, 0 )
+	ROM_REGION( 0x40000, REGION_GFX3, ROMREGION_ERASE00 )
 
 	/* sound data */
 	ROM_REGION( 0x400000, REGION_SOUND1, 0 )
@@ -1504,7 +1518,7 @@ ROM_START( viostorm )
 	ROM_LOAD64_WORD( "168a13.17k", 0x000006, 2*1024*1024, CRC(cdec3650) SHA1(949bc06bb38a2d5315ee4f6db19e043655b90e6e) )
 
 	/* road generator */
-	ROM_REGION( 0x40000, REGION_GFX3, 0)
+	ROM_REGION( 0x40000, REGION_GFX3, ROMREGION_ERASE00)
 
 	/* sound data */
 	ROM_REGION( 0x400000, REGION_SOUND1, 0)
@@ -1536,7 +1550,7 @@ ROM_START( viostrmu )
 	ROM_LOAD64_WORD( "168a13.17k", 0x000006, 2*1024*1024, CRC(cdec3650) SHA1(949bc06bb38a2d5315ee4f6db19e043655b90e6e) )
 
 	/* road generator */
-	ROM_REGION( 0x40000, REGION_GFX3, 0)
+	ROM_REGION( 0x40000, REGION_GFX3, ROMREGION_ERASE00)
 
 	/* sound data */
 	ROM_REGION( 0x400000, REGION_SOUND1, 0)
@@ -1568,7 +1582,7 @@ ROM_START( viostrma )
 	ROM_LOAD64_WORD( "168a13.17k", 0x000006, 2*1024*1024, CRC(cdec3650) SHA1(949bc06bb38a2d5315ee4f6db19e043655b90e6e) )
 
 	/* road generator */
-	ROM_REGION( 0x40000, REGION_GFX3, 0 )
+	ROM_REGION( 0x40000, REGION_GFX3, ROMREGION_ERASE00 )
 
 	/* sound data */
 	ROM_REGION( 0x400000, REGION_SOUND1, 0 )
@@ -1600,7 +1614,7 @@ ROM_START( viostrmj )
 	ROM_LOAD64_WORD( "168a13.17k", 0x000006, 2*1024*1024, CRC(cdec3650) SHA1(949bc06bb38a2d5315ee4f6db19e043655b90e6e) )
 
 	/* road generator */
-	ROM_REGION( 0x40000, REGION_GFX3, 0 )
+	ROM_REGION( 0x40000, REGION_GFX3, ROMREGION_ERASE00 )
 
 	/* sound data */
 	ROM_REGION( 0x400000, REGION_SOUND1, 0 )
@@ -1611,10 +1625,45 @@ ROM_END
 ROM_START( metamrph )
 	/* main program */
 	ROM_REGION( 0x200000, REGION_CPU1, 0 )
-	ROM_LOAD16_BYTE( "224a01", 0x000001, 0x40000, CRC(e1d9b516) SHA1(387ed5ce87af376c0568e39187330a4585dc499a) )
-	ROM_LOAD16_BYTE( "224a02", 0x000000, 0x40000, CRC(289c926b) SHA1(5a5129fd85afc4fee97155e28bff89d3bb497b59) )
-	ROM_LOAD16_BYTE( "224a03", 0x100001, 0x80000, CRC(a5bedb01) SHA1(5e7a0b93af654ba6a87be8d449c7080a0f0e2a43) )
-	ROM_LOAD16_BYTE( "224a04", 0x100000, 0x80000, CRC(ada53ba4) SHA1(f77bf854dff1f8f718579fe6d3730066708396e2) )
+	ROM_LOAD16_BYTE( "224eaa01.15h", 0x000001, 0x40000, CRC(30962c2b) SHA1(ae1b2f92881bb0f386b6a413c1da507e73c29382) )
+	ROM_LOAD16_BYTE( "224eaa02.15f", 0x000000, 0x40000, CRC(e314330a) SHA1(728a18d604eca58409551e52b7dc18e2d807700a) )
+	ROM_LOAD16_BYTE( "224a03",       0x100001, 0x80000, CRC(a5bedb01) SHA1(5e7a0b93af654ba6a87be8d449c7080a0f0e2a43) )
+	ROM_LOAD16_BYTE( "224a04",       0x100000, 0x80000, CRC(ada53ba4) SHA1(f77bf854dff1f8f718579fe6d3730066708396e2) )
+
+	/* sound program */
+	ROM_REGION( 0x050000, REGION_CPU2, 0 )
+	ROM_LOAD("224a05", 0x000000, 0x040000, CRC(4b4c985c) SHA1(c83cce05355023be9cd55b4aa595c61f8236269c) )
+	ROM_RELOAD(           0x010000, 0x040000 )
+
+	/* tiles */
+	ROM_REGION( 0x500000, REGION_GFX1, ROMREGION_ERASE00 )
+	ROM_LOADTILE_WORD( "224a09", 0x000000, 1*1024*1024, CRC(1931afce) SHA1(78838c0fd2a9c80f130db1fcf6c88b14f7363639) )
+	ROM_LOADTILE_WORD( "224a08", 0x000002, 1*1024*1024, CRC(dc94d53a) SHA1(91e16371a335f078a81c06a1045759653080aba0) )
+
+	/* sprites */
+	ROM_REGION( 0x800000, REGION_GFX2, ROMREGION_ERASE00 )
+	ROM_LOAD64_WORD( "224a10", 0x000000, 2*1024*1024, CRC(161287f0) SHA1(a13b197a98fa1cebb11fb87b54e277c72852c4ee) )
+	ROM_LOAD64_WORD( "224a11", 0x000002, 2*1024*1024, CRC(df5960e1) SHA1(ee7794dd119f5f2c52e7ba589d78067a89ff3cab) )
+	ROM_LOAD64_WORD( "224a12", 0x000004, 2*1024*1024, CRC(ca72a4b3) SHA1(a09deb6d7cb8be4edaeb78e0e676ea2d6055e9e0) )
+	ROM_LOAD64_WORD( "224a13", 0x000006, 2*1024*1024, CRC(86b58feb) SHA1(5a43746e2cd3c7aca21496c092aef83e64b3ab2c) )
+
+	/* K053250 linescroll/zoom thingy */
+	ROM_REGION( 0x80000, REGION_GFX3, ROMREGION_ERASE00 ) /* NOTE: region must be 2xROM size for unpacking */
+	ROM_LOAD( "224a14", 0x000000, 0x40000, CRC(3c79b404) SHA1(7c6bb4cbf050f314ea0cd3e8bc6e1947d0573084) )
+
+	/* sound data */
+	ROM_REGION( 0x400000, REGION_SOUND1, 0 )
+	ROM_LOAD( "224a06", 0x000000, 2*1024*1024, CRC(972f6abe) SHA1(30907495fc49fe3424c092b074c1dc137aa14306) )
+	ROM_LOAD( "224a07", 0x200000, 1*1024*1024, CRC(61b2f97a) SHA1(34bf835d6361c7809d40fa20fd238c9e2a84b101) )
+ROM_END
+
+ROM_START( metamrpu )
+	/* main program */
+	ROM_REGION( 0x200000, REGION_CPU1, 0 )
+	ROM_LOAD16_BYTE( "224uaa01.15h", 0x000001, 0x40000, CRC(e1d9b516) SHA1(387ed5ce87af376c0568e39187330a4585dc499a) )
+	ROM_LOAD16_BYTE( "224uaa02.15f", 0x000000, 0x40000, CRC(289c926b) SHA1(5a5129fd85afc4fee97155e28bff89d3bb497b59) )
+	ROM_LOAD16_BYTE( "224a03",       0x100001, 0x80000, CRC(a5bedb01) SHA1(5e7a0b93af654ba6a87be8d449c7080a0f0e2a43) )
+	ROM_LOAD16_BYTE( "224a04",       0x100000, 0x80000, CRC(ada53ba4) SHA1(f77bf854dff1f8f718579fe6d3730066708396e2) )
 
 	/* sound program */
 	ROM_REGION( 0x050000, REGION_CPU2, 0 )
@@ -1646,10 +1695,10 @@ ROM_END
 ROM_START( metamrpj )
 	/* main program */
 	ROM_REGION( 0x200000, REGION_CPU1, 0 )
-	ROM_LOAD16_BYTE( "224jaa01", 0x000001, 0x40000, CRC(558d2602) SHA1(2dbc16fcc07436ca7eff8d070196348f272b8723) )
-	ROM_LOAD16_BYTE( "224jaa02", 0x000000, 0x40000, CRC(9b252ace) SHA1(efe8cd942f3d4e2366d9af0fb9647d2a4aeac2c9) )
-	ROM_LOAD16_BYTE( "224a03", 0x100001, 0x80000, CRC(a5bedb01) SHA1(5e7a0b93af654ba6a87be8d449c7080a0f0e2a43) )
-	ROM_LOAD16_BYTE( "224a04", 0x100000, 0x80000, CRC(ada53ba4) SHA1(f77bf854dff1f8f718579fe6d3730066708396e2) )
+	ROM_LOAD16_BYTE( "224jaa01.15h", 0x000001, 0x40000, CRC(558d2602) SHA1(2dbc16fcc07436ca7eff8d070196348f272b8723) )
+	ROM_LOAD16_BYTE( "224jaa02.15f", 0x000000, 0x40000, CRC(9b252ace) SHA1(efe8cd942f3d4e2366d9af0fb9647d2a4aeac2c9) )
+	ROM_LOAD16_BYTE( "224a03",       0x100001, 0x80000, CRC(a5bedb01) SHA1(5e7a0b93af654ba6a87be8d449c7080a0f0e2a43) )
+	ROM_LOAD16_BYTE( "224a04",       0x100000, 0x80000, CRC(ada53ba4) SHA1(f77bf854dff1f8f718579fe6d3730066708396e2) )
 
 	/* sound program */
 	ROM_REGION( 0x050000, REGION_CPU2, 0 )
@@ -1681,10 +1730,44 @@ ROM_END
 ROM_START( mtlchamp )
 	/* main program */
 	ROM_REGION( 0x400000, REGION_CPU1, 0 )
-        ROM_LOAD16_BYTE( "234eaa01.20f", 0x000000, 0x040000, CRC(8fa731db) SHA1(e2ed81762070a764f51aae36ce03859b5d86520d) )
-        ROM_LOAD16_BYTE( "234eaa02.20g", 0x000001, 0x040000, CRC(e7b50b54) SHA1(594391a37479e6973aadd1fc866671c306a75497) )
-	ROM_LOAD16_BYTE( "234_d03.19f", 0x300000, 0x80000, CRC(abb577c6) SHA1(493f11a10a4d5b62d755ff8274e77d898544944f) )
-	ROM_LOAD16_BYTE( "234_d04.19g", 0x300001, 0x80000, CRC(030a1925) SHA1(03783488950c9f27af5948e7b9f6a609c2df6e0b) )
+        ROM_LOAD16_BYTE( "234eab01.20f", 0x000000, 0x40000, CRC(7c4d1e50) SHA1(f943b955aa66f0892c20df7a94fc8bf070bf4624) )
+        ROM_LOAD16_BYTE( "234eab02.20g", 0x000001, 0x40000, CRC(d8bc85c9) SHA1(40a13b4139dd24c06378c6bd982ef3f5fd646dcc) )
+	ROM_LOAD16_BYTE( "234_d03.19f",  0x300000, 0x80000, CRC(abb577c6) SHA1(493f11a10a4d5b62d755ff8274e77d898544944f) )
+	ROM_LOAD16_BYTE( "234_d04.19g",  0x300001, 0x80000, CRC(030a1925) SHA1(03783488950c9f27af5948e7b9f6a609c2df6e0b) )
+
+	/* sound program */
+	ROM_REGION( 0x040000, REGION_CPU2, 0 )
+	ROM_LOAD("234_d05.6b", 0x000000, 0x020000, CRC(efb6bcaa) SHA1(4fb24b89a50b341871945547859278a6e2f5e002) )
+	ROM_RELOAD(           0x010000, 0x020000 )
+
+	/* tiles */
+	ROM_REGION( 0x600000, REGION_GFX1, ROMREGION_ERASE00 )
+	ROM_LOADTILE_WORD( "234a08.1h", 0x000000, 1*1024*1024, CRC(27e94288) SHA1(a92b03adf7beea6a1ceb74f659c87c628a7ab8e4) )
+	ROM_LOADTILE_WORD( "234a09.1k", 0x000002, 1*1024*1024, CRC(03aad28f) SHA1(e7d9d788822ac9666e089b58288e3fcdba1b89da) )
+	ROM_LOADTILE_BYTE( "234a10.3h", 0x000004, 512*1024, CRC(51f50fe2) SHA1(164fc975feff442d93f1917727c159051dcd3a55) )
+
+	/* sprites */
+	ROM_REGION( 0xa00000, REGION_GFX2, ROMREGION_ERASE00 )
+	ROM_LOAD64_WORD( "234a16.22k", 0x000000, 2*1024*1024, CRC(14d909a5) SHA1(15da356852fc0c63ecd924ac37ebe24bf3ba0760) )
+	ROM_LOAD64_WORD( "234a15.20k", 0x000002, 2*1024*1024, CRC(a5028418) SHA1(ec6fc7b38fb1d27490a5a9310ecac2d1049e197c) )
+	ROM_LOAD64_WORD( "234a14.19k", 0x000004, 2*1024*1024, CRC(d7921f47) SHA1(3fc97b308ad2ca25a376373ddfe08c8a375c424e) )
+	ROM_LOAD64_WORD( "234a13.17k", 0x000006, 2*1024*1024, CRC(5974392e) SHA1(7c380419244439804797a9510846d273ebe99d02) )
+	ROM_LOAD16_BYTE( "234a12.12k", 0x800000, 1024*1024, CRC(c7f2b099) SHA1(b72b80feb52560a5a42a1db39b059ac8bca27c10) )
+	ROM_LOAD16_BYTE( "234a11.10k", 0x800001, 1024*1024, CRC(82923713) SHA1(a36cd3b2c9d36e93a3c25ba1d4e162f3d92e06ae) )
+
+	/* sound data */
+	ROM_REGION( 0x400000, REGION_SOUND1, 0 )
+	ROM_LOAD( "234a06.2d", 0x000000, 2*1024*1024, CRC(12d32384) SHA1(ecd6cd752b0e20339e17a7652ed843fbb43f7595) )
+	ROM_LOAD( "234a07.1d", 0x200000, 2*1024*1024, CRC(05ee239f) SHA1(f4e6e7568dc73666a2b5e0c3fe743432e0436464) )
+ROM_END
+
+ROM_START( mtlchmp1 )
+	/* main program */
+	ROM_REGION( 0x400000, REGION_CPU1, 0 )
+        ROM_LOAD16_BYTE( "234eaa01.20f", 0x000000, 0x40000, CRC(8fa731db) SHA1(e2ed81762070a764f51aae36ce03859b5d86520d) )
+        ROM_LOAD16_BYTE( "234eaa02.20g", 0x000001, 0x40000, CRC(e7b50b54) SHA1(594391a37479e6973aadd1fc866671c306a75497) )
+	ROM_LOAD16_BYTE( "234_d03.19f",  0x300000, 0x80000, CRC(abb577c6) SHA1(493f11a10a4d5b62d755ff8274e77d898544944f) )
+	ROM_LOAD16_BYTE( "234_d04.19g",  0x300001, 0x80000, CRC(030a1925) SHA1(03783488950c9f27af5948e7b9f6a609c2df6e0b) )
 
 	/* sound program */
 	ROM_REGION( 0x040000, REGION_CPU2, 0 )
@@ -1717,8 +1800,8 @@ ROM_START( mtlchmpa )
 	ROM_REGION( 0x400000, REGION_CPU1, 0 )
 	ROM_LOAD16_BYTE( "234aaa01.20f", 0x000000, 0x40000, CRC(32c70e65) SHA1(10103ba403656d962bafe970a4ad0b2a9bed0ffe) )
 	ROM_LOAD16_BYTE( "234aaa02.20g", 0x000001, 0x40000, CRC(2f666d52) SHA1(97765ef89e9b9ed36e7039f31f4d57187c6bb6e5) )
-	ROM_LOAD16_BYTE( "234_d03.19f", 0x300000, 0x80000, CRC(abb577c6) SHA1(493f11a10a4d5b62d755ff8274e77d898544944f) )
-	ROM_LOAD16_BYTE( "234_d04.19g", 0x300001, 0x80000, CRC(030a1925) SHA1(03783488950c9f27af5948e7b9f6a609c2df6e0b) )
+	ROM_LOAD16_BYTE( "234_d03.19f",  0x300000, 0x80000, CRC(abb577c6) SHA1(493f11a10a4d5b62d755ff8274e77d898544944f) )
+	ROM_LOAD16_BYTE( "234_d04.19g",  0x300001, 0x80000, CRC(030a1925) SHA1(03783488950c9f27af5948e7b9f6a609c2df6e0b) )
 
 	/* sound program */
 	ROM_REGION( 0x040000, REGION_CPU2, 0 )
@@ -1751,8 +1834,8 @@ ROM_START( mtlchmpj )
 	ROM_REGION( 0x400000, REGION_CPU1, 0 )
 	ROM_LOAD16_BYTE( "234jaa01.20f", 0x000000, 0x40000, CRC(76c3c568) SHA1(14c0009804fcedd8a3e5a105cc871dd6cd4cf7b3) )
 	ROM_LOAD16_BYTE( "234jaa02.20g", 0x000001, 0x40000, CRC(95eec0aa) SHA1(11f1986d792951d6d5b3740b435dab2a2f4e6cbd) )
-	ROM_LOAD16_BYTE( "234_d03.19f", 0x300000, 0x80000, CRC(abb577c6) SHA1(493f11a10a4d5b62d755ff8274e77d898544944f) )
-	ROM_LOAD16_BYTE( "234_d04.19g", 0x300001, 0x80000, CRC(030a1925) SHA1(03783488950c9f27af5948e7b9f6a609c2df6e0b) )
+	ROM_LOAD16_BYTE( "234_d03.19f",  0x300000, 0x80000, CRC(abb577c6) SHA1(493f11a10a4d5b62d755ff8274e77d898544944f) )
+	ROM_LOAD16_BYTE( "234_d04.19g",  0x300001, 0x80000, CRC(030a1925) SHA1(03783488950c9f27af5948e7b9f6a609c2df6e0b) )
 
 	/* sound program */
 	ROM_REGION( 0x040000, REGION_CPU2, 0 )
@@ -1785,8 +1868,8 @@ ROM_START( mtlchmpu )
 	ROM_REGION( 0x400000, REGION_CPU1, 0 )
 	ROM_LOAD16_BYTE( "234uad01.20f", 0x000000, 0x40000, CRC(5f6c8d09) SHA1(5850398cb9582973b400eaa82d84b7d07c87f779) )
 	ROM_LOAD16_BYTE( "234uad02.20g", 0x000001, 0x40000, CRC(15ca4fb2) SHA1(f3025f0d54ce20717207ce219fd9e07b808eda34) )
-	ROM_LOAD16_BYTE( "234_d03.19f", 0x300000, 0x80000, CRC(abb577c6) SHA1(493f11a10a4d5b62d755ff8274e77d898544944f) )
-	ROM_LOAD16_BYTE( "234_d04.19g", 0x300001, 0x80000, CRC(030a1925) SHA1(03783488950c9f27af5948e7b9f6a609c2df6e0b) )
+	ROM_LOAD16_BYTE( "234_d03.19f",  0x300000, 0x80000, CRC(abb577c6) SHA1(493f11a10a4d5b62d755ff8274e77d898544944f) )
+	ROM_LOAD16_BYTE( "234_d04.19g",  0x300001, 0x80000, CRC(030a1925) SHA1(03783488950c9f27af5948e7b9f6a609c2df6e0b) )
 
 	/* sound program */
 	ROM_REGION( 0x040000, REGION_CPU2, 0 )
@@ -1952,10 +2035,10 @@ ROM_END
 ROM_START( mmaulers )
 	/* main program */
 	ROM_REGION( 0x400000, REGION_CPU1, 0 )
-        ROM_LOAD16_BYTE( "170eaa07.24m", 0x000000, 0x080000, CRC(5458bd93) SHA1(d27a29076be3c745e3efdb1c528b07bd5d8aff1c) )
-        ROM_LOAD16_BYTE( "170eaa09.19l", 0x000001, 0x080000, CRC(99c95c7b) SHA1(7f22930c2fe21205ccd01b80566d6bc31fea34d2) )
-	ROM_LOAD16_BYTE( "170a08.21m", 0x100000, 0x40000, CRC(03c59ba2) SHA1(041473fe5f9004bfb7ca767c2004154c27f726ff) )
-	ROM_LOAD16_BYTE( "170a10.17l", 0x100001, 0x40000, CRC(8a340909) SHA1(3e2ef2642e792cdc38b3442df67377ed9e70d3ab) )
+        ROM_LOAD16_BYTE( "170eaa07.24m", 0x000000, 0x80000, CRC(5458bd93) SHA1(d27a29076be3c745e3efdb1c528b07bd5d8aff1c) )
+        ROM_LOAD16_BYTE( "170eaa09.19l", 0x000001, 0x80000, CRC(99c95c7b) SHA1(7f22930c2fe21205ccd01b80566d6bc31fea34d2) )
+	ROM_LOAD16_BYTE( "170a08.21m",   0x100000, 0x40000, CRC(03c59ba2) SHA1(041473fe5f9004bfb7ca767c2004154c27f726ff) )
+	ROM_LOAD16_BYTE( "170a10.17l",   0x100001, 0x40000, CRC(8a340909) SHA1(3e2ef2642e792cdc38b3442df67377ed9e70d3ab) )
 
 	/* sound program */
 	ROM_REGION( 0x080000, REGION_CPU2, 0 )
@@ -1997,10 +2080,10 @@ ROM_END
 ROM_START( dadandrn )
 	/* main program */
 	ROM_REGION( 0x400000, REGION_CPU1, 0 )
-	ROM_LOAD16_BYTE( "170a07.24m", 0x000000, 0x80000, CRC(6a55e828) SHA1(06be9a45fdddcc826a33ff8d6eb595e11b98a31f) )
-	ROM_LOAD16_BYTE( "170a09.19l", 0x000001, 0x80000, CRC(9e821cd8) SHA1(51e9c3b0a187db62cfcdff23ecaf3205f368f4e0) )
-	ROM_LOAD16_BYTE( "170a08.21m", 0x100000, 0x40000, CRC(03c59ba2) SHA1(041473fe5f9004bfb7ca767c2004154c27f726ff) )
-	ROM_LOAD16_BYTE( "170a10.17l", 0x100001, 0x40000, CRC(8a340909) SHA1(3e2ef2642e792cdc38b3442df67377ed9e70d3ab) )
+	ROM_LOAD16_BYTE( "170jaa07.24m", 0x000000, 0x80000, CRC(6a55e828) SHA1(06be9a45fdddcc826a33ff8d6eb595e11b98a31f) )
+	ROM_LOAD16_BYTE( "170jaa09.19l", 0x000001, 0x80000, CRC(9e821cd8) SHA1(51e9c3b0a187db62cfcdff23ecaf3205f368f4e0) )
+	ROM_LOAD16_BYTE( "170a08.21m",   0x100000, 0x40000, CRC(03c59ba2) SHA1(041473fe5f9004bfb7ca767c2004154c27f726ff) )
+	ROM_LOAD16_BYTE( "170a10.17l",   0x100001, 0x40000, CRC(8a340909) SHA1(3e2ef2642e792cdc38b3442df67377ed9e70d3ab) )
 
 	/* sound program */
 	ROM_REGION( 0x080000, REGION_CPU2, 0 )
@@ -2039,48 +2122,30 @@ ROM_START( dadandrn )
 	ROM_LOAD("170a15.2m", 0x200000, 2*1024*1024, CRC(d4113ae9) SHA1(e234d06f462e3db64455c384c2f42174f9ef9c6a) )
 ROM_END
 
-static void init_common(void)
-{
-	/* set default bankswitch */
-	cur_sound_region = 2;
-	reset_sound_region();
-
-	mw_irq_control = 0;
-
-	state_save_register_int("Mystwarr", 0, "IRQ control", &mw_irq_control);
-	state_save_register_int("Mystwarr", 0, "sound region", &cur_sound_region);
-	state_save_register_func_postload(reset_sound_region);
-}
-
 static DRIVER_INIT(metamrph)
 {
-	init_common();
-
 	K053250_unpack_pixels(REGION_GFX3);
 }
 
-static DRIVER_INIT(mwcommon)
-{
-	init_common();
-}
-
 
 /*           ROM       parent    machine   inp       init */
-GAME( 1993, mystwarr, 0,        mystwarr, mystwarr, mwcommon, ROT0,  "Konami", "Mystic Warriors (ver EAA)", GAME_IMPERFECT_GRAPHICS )
-GAME( 1993, mystwaru, mystwarr, mystwarr, mystwarr, mwcommon, ROT0,  "Konami", "Mystic Warriors (ver UAA)", GAME_IMPERFECT_GRAPHICS )
-GAME( 1993, mmaulers, 0,        dadandrn, dadandrn, mwcommon, ROT0,  "Konami", "Monster Maulers (ver EAA)", GAME_IMPERFECT_GRAPHICS )
-GAME( 1993, dadandrn, mmaulers, dadandrn, dadandrn, mwcommon, ROT0,  "Konami", "Kyukyoku Sentai Dadandarn (ver JAA)", GAME_IMPERFECT_GRAPHICS )
-GAME( 1993, viostorm, 0,        viostorm, viostorm, mwcommon, ROT0,  "Konami", "Violent Storm (ver EAB)", GAME_IMPERFECT_GRAPHICS )
-GAME( 1993, viostrmu, viostorm, viostorm, viostorm, mwcommon, ROT0,  "Konami", "Violent Storm (ver UAB)", GAME_IMPERFECT_GRAPHICS )
-GAME( 1993, viostrmj, viostorm, viostorm, viostorm, mwcommon, ROT0,  "Konami", "Violent Storm (ver JAC)", GAME_IMPERFECT_GRAPHICS )
-GAME( 1993, viostrma, viostorm, viostorm, viostorm, mwcommon, ROT0,  "Konami", "Violent Storm (ver AAC)", GAME_IMPERFECT_GRAPHICS )
-GAME( 1993, metamrph, 0,        metamrph, metamrph, metamrph, ROT0,  "Konami", "Metamorphic Force (ver UAA)", GAME_IMPERFECT_GRAPHICS )
+GAME( 1993, mystwarr, 0,        mystwarr, mystwarr, 0,        ROT0,  "Konami", "Mystic Warriors (ver EAA)", GAME_IMPERFECT_GRAPHICS )
+GAME( 1993, mystwaru, mystwarr, mystwarr, mystwarr, 0,        ROT0,  "Konami", "Mystic Warriors (ver UAA)", GAME_IMPERFECT_GRAPHICS )
+GAME( 1993, mmaulers, 0,        dadandrn, dadandrn, 0,        ROT0,  "Konami", "Monster Maulers (ver EAA)", GAME_IMPERFECT_GRAPHICS )
+GAME( 1993, dadandrn, mmaulers, dadandrn, dadandrn, 0,        ROT0,  "Konami", "Kyukyoku Sentai Dadandarn (ver JAA)", GAME_IMPERFECT_GRAPHICS )
+GAME( 1993, viostorm, 0,        viostorm, viostorm, 0,        ROT0,  "Konami", "Violent Storm (ver EAB)", GAME_IMPERFECT_GRAPHICS )
+GAME( 1993, viostrmu, viostorm, viostorm, viostorm, 0,        ROT0,  "Konami", "Violent Storm (ver UAB)", GAME_IMPERFECT_GRAPHICS )
+GAME( 1993, viostrmj, viostorm, viostorm, viostorm, 0,        ROT0,  "Konami", "Violent Storm (ver JAC)", GAME_IMPERFECT_GRAPHICS )
+GAME( 1993, viostrma, viostorm, viostorm, viostorm, 0,        ROT0,  "Konami", "Violent Storm (ver AAC)", GAME_IMPERFECT_GRAPHICS )
+GAME( 1993, metamrph, 0,        metamrph, metamrph, metamrph, ROT0,  "Konami", "Metamorphic Force (ver EAA)", GAME_IMPERFECT_GRAPHICS )
+GAME( 1993, metamrpu, metamrph, metamrph, metamrph, metamrph, ROT0,  "Konami", "Metamorphic Force (ver UAA)", GAME_IMPERFECT_GRAPHICS )
 GAME( 1993, metamrpj, metamrph, metamrph, metamrph, metamrph, ROT0,  "Konami", "Metamorphic Force (ver JAA)", GAME_IMPERFECT_GRAPHICS )
-GAME( 1993, mtlchamp, 0,        martchmp, martchmp, mwcommon, ROT0,  "Konami", "Martial Champion (ver EAA)", GAME_IMPERFECT_GRAPHICS )
-GAME( 1993, mtlchmpu, mtlchamp, martchmp, martchmp, mwcommon, ROT0,  "Konami", "Martial Champion (ver UAD)", GAME_IMPERFECT_GRAPHICS )
-GAME( 1993, mtlchmpj, mtlchamp, martchmp, martchmp, mwcommon, ROT0,  "Konami", "Martial Champion (ver JAA)", GAME_IMPERFECT_GRAPHICS )
-GAME( 1993, mtlchmpa, mtlchamp, martchmp, martchmp, mwcommon, ROT0,  "Konami", "Martial Champion (ver AAA)", GAME_IMPERFECT_GRAPHICS )
-GAME( 1993, gaiapols, 0,        gaiapols, dadandrn, mwcommon, ROT90, "Konami", "Gaiapolis (ver EAF)", GAME_IMPERFECT_GRAPHICS )
-GAME( 1993, gaiapolu, gaiapols, gaiapols, dadandrn, mwcommon, ROT90, "Konami", "Gaiapolis (ver UAF)", GAME_IMPERFECT_GRAPHICS )
-GAME( 1993, gaiapolj, gaiapols, gaiapols, dadandrn, mwcommon, ROT90, "Konami", "Gaiapolis (ver JAF)", GAME_IMPERFECT_GRAPHICS )
+GAME( 1993, mtlchamp, 0,        martchmp, martchmp, 0,        ROT0,  "Konami", "Martial Champion (ver EAB)", GAME_IMPERFECT_GRAPHICS )
+GAME( 1993, mtlchmp1, mtlchamp, martchmp, martchmp, 0,        ROT0,  "Konami", "Martial Champion (ver EAA)", GAME_IMPERFECT_GRAPHICS )
+GAME( 1993, mtlchmpu, mtlchamp, martchmp, martchmp, 0,        ROT0,  "Konami", "Martial Champion (ver UAD)", GAME_IMPERFECT_GRAPHICS )
+GAME( 1993, mtlchmpj, mtlchamp, martchmp, martchmp, 0,        ROT0,  "Konami", "Martial Champion (ver JAA)", GAME_IMPERFECT_GRAPHICS )
+GAME( 1993, mtlchmpa, mtlchamp, martchmp, martchmp, 0,        ROT0,  "Konami", "Martial Champion (ver AAA)", GAME_IMPERFECT_GRAPHICS )
+GAME( 1993, gaiapols, 0,        gaiapols, dadandrn, 0,        ROT90, "Konami", "Gaiapolis (ver EAF)", GAME_IMPERFECT_GRAPHICS )
+GAME( 1993, gaiapolu, gaiapols, gaiapols, dadandrn, 0,        ROT90, "Konami", "Gaiapolis (ver UAF)", GAME_IMPERFECT_GRAPHICS )
+GAME( 1993, gaiapolj, gaiapols, gaiapols, dadandrn, 0,        ROT90, "Konami", "Gaiapolis (ver JAF)", GAME_IMPERFECT_GRAPHICS )
 
