@@ -66,7 +66,6 @@ Notes:
  *************************************************************/
 
 #include "driver.h"
-#include "vidhrdw/generic.h"
 #include "vidhrdw/ygv608.h"
 #include "cpu/h83002/h83002.h"
 #include "namcond1.h"
@@ -124,75 +123,94 @@ INPUT_PORTS_END
 
 /* text-layer characters */
 
-static gfx_layout pts_8x8_4bits_layout =
+static const UINT32 pts_4bits_layout_xoffset[64] =
+{
+	STEP8( 0*256, 4 ), STEP8( 1*256, 4 ), STEP8( 4*256, 4 ), STEP8( 5*256, 4 ),
+	STEP8( 16*256, 4 ), STEP8( 17*256, 4 ), STEP8( 20*256, 4 ), STEP8( 21*256, 4 )
+};
+
+static const UINT32 pts_4bits_layout_yoffset[64] =
+{
+	STEP8( 0*256, 8*4 ), STEP8( 2*256, 8*4 ), STEP8( 8*256, 8*4 ), STEP8( 10*256, 8*4 ),
+	STEP8( 32*256, 8*4 ), STEP8( 34*256, 8*4 ), STEP8( 40*256, 8*4 ), STEP8( 42*256, 8*4 )
+};
+
+static const gfx_layout pts_8x8_4bits_layout =
 {
 	8,8,	      /* 8*8 pixels */
 	RGN_FRAC(1,1),        /* 65536 patterns */
 	4,	          /* 4 bits per pixel */
 	{ 0, 1, 2, 3 },
-    { STEP8( 0*256, 4 ) },
-    { STEP8( 0*256, 8*4 ) },
-	8*8*4
+	EXTENDED_XOFFS,
+	EXTENDED_YOFFS,
+	8*8*4,
+	pts_4bits_layout_xoffset,
+	pts_4bits_layout_yoffset
 };
 
-static gfx_layout pts_16x16_4bits_layout =
+static const gfx_layout pts_16x16_4bits_layout =
 {
 	16,16,        /* 16*16 pixels */
 	RGN_FRAC(1,1),        /* 16384 patterns */
 	4,	          /* 4 bits per pixel */
 	{ 0, 1, 2, 3 },
-    { STEP8( 0*256, 4 ), STEP8( 1*256, 4 ) },
-    { STEP8( 0*256, 8*4 ), STEP8( 2*256, 8*4 ) },
-	16*16*4
+	EXTENDED_XOFFS,
+	EXTENDED_YOFFS,
+	16*16*4,
+	pts_4bits_layout_xoffset,
+	pts_4bits_layout_yoffset
 };
 
-static gfx_layout pts_32x32_4bits_layout =
+static const gfx_layout pts_32x32_4bits_layout =
 {
 	32,32,        /* 32*32 pixels */
 	RGN_FRAC(1,1),         /* 4096 patterns */
 	4,	          /* 4 bits per pixel */
 	{ 0, 1, 2, 3 },
-    { STEP8( 0*256, 4 ), STEP8( 1*256, 4 ), STEP8( 4*256, 4 ), STEP8( 5*256, 4 ) },
-    { STEP8( 0*256, 8*4 ), STEP8( 2*256, 8*4 ), STEP8( 8*256, 8*4 ), STEP8( 10*256, 8*4 ) },
-	32*32*4
+	EXTENDED_XOFFS,
+	EXTENDED_YOFFS,
+	32*32*4,
+	pts_4bits_layout_xoffset,
+	pts_4bits_layout_yoffset
 };
 
-static gfx_layout pts_64x64_4bits_layout =
+static const gfx_layout pts_64x64_4bits_layout =
 {
 	64,64,        /* 32*32 pixels */
 	RGN_FRAC(1,1),         /* 1024 patterns */
 	4,	          /* 4 bits per pixel */
 	{ 0, 1, 2, 3 },
-    { STEP8( 0*256, 4 ), STEP8( 1*256, 4 ), STEP8( 4*256, 4 ), STEP8( 5*256, 4 ),
-      STEP8( 16*256, 4 ), STEP8( 17*256, 4 ), STEP8( 20*256, 4 ), STEP8( 21*256, 4 ) },
-    { STEP8( 0*256, 8*4 ), STEP8( 2*256, 8*4 ), STEP8( 8*256, 8*4 ), STEP8( 10*256, 8*4 ),
-      STEP8( 32*256, 8*4 ), STEP8( 34*256, 8*4 ), STEP8( 40*256, 8*4 ), STEP8( 42*256, 8*4 ) },
-	64*64*4
+	EXTENDED_XOFFS,
+	EXTENDED_YOFFS,
+	64*64*4,
+	pts_4bits_layout_xoffset,
+	pts_4bits_layout_yoffset
 };
 
-static gfx_layout pts_8x8_8bits_layout =
+
+static const gfx_layout pts_8x8_8bits_layout =
 {
 	8,8,	      /* 8*8 pixels */
 	RGN_FRAC(1,1),        /* 32768 patterns */
 	8,	          /* 8 bits per pixel */
 	{ 0, 1, 2, 3, 4, 5, 6, 7 },
-    { STEP8( 0*512, 8 ) },
-    { STEP8( 0*512, 8*8 ) },
+	{ STEP8( 0*512, 8 ) },
+	{ STEP8( 0*512, 8*8 ) },
 	8*8*8
 };
 
-static gfx_layout pts_16x16_8bits_layout =
+static const gfx_layout pts_16x16_8bits_layout =
 {
 	16,16,        /* 16*16 pixels */
 	RGN_FRAC(1,1),         /* 8192 patterns */
 	8,	          /* 8 bits per pixel */
 	{ 0, 1, 2, 3, 4, 5, 6, 7 },
-    { STEP8( 0*512, 8 ), STEP8( 1*512, 8 ) },
-    { STEP8( 0*512, 8*8 ), STEP8( 2*512, 8*8 ) },
+	{ STEP8( 0*512, 8 ), STEP8( 1*512, 8 ) },
+	{ STEP8( 0*512, 8*8 ), STEP8( 2*512, 8*8 ) },
 	16*16*8
 };
 
-static gfx_decode gfxdecodeinfo[] =
+static const gfx_decode gfxdecodeinfo[] =
 {
 	{ REGION_GFX1, 0x00000000, &pts_8x8_4bits_layout,    0,  16 },
 	{ REGION_GFX1, 0x00000000, &pts_16x16_4bits_layout,  0,  16 },
@@ -286,7 +304,8 @@ static MACHINE_DRIVER_START( namcond1 )
 	MDRV_VBLANK_DURATION(DEFAULT_REAL_60HZ_VBLANK_DURATION)
 	MDRV_INTERLEAVE(100)
 
-	MDRV_MACHINE_INIT(namcond1)
+	MDRV_MACHINE_START(namcond1)
+	MDRV_MACHINE_RESET(namcond1)
 	MDRV_NVRAM_HANDLER(at28c16_0)
 
 	/* video hardware */
@@ -298,7 +317,6 @@ static MACHINE_DRIVER_START( namcond1 )
 
 	MDRV_VIDEO_START(ygv608)
 	MDRV_VIDEO_UPDATE(ygv608)
-	MDRV_VIDEO_STOP(ygv608)
 
 	/* sound hardware */
 	MDRV_SPEAKER_STANDARD_STEREO("left", "right")
@@ -388,8 +406,8 @@ ROM_START( ncv2j )
     ROM_LOAD( "ncs1voic.7c",     0x000000, 0x200000, CRC(ed05fd88) SHA1(ad88632c89a9946708fc6b4c9247e1bae9b2944b) )
 ROM_END
 
-GAME( 1995, ncv1,      0, namcond1, namcond1, 0, ROT90, "Namco", "Namco Classics Collection Vol.1", GAME_IMPERFECT_SOUND | GAME_IMPERFECT_GRAPHICS )
-GAME( 1995, ncv1j,  ncv1, namcond1, namcond1, 0, ROT90, "Namco", "Namco Classics Collection Vol.1 (Japan, v1.00)", GAME_IMPERFECT_SOUND | GAME_IMPERFECT_GRAPHICS )
-GAME( 1995, ncv1j2, ncv1, namcond1, namcond1, 0, ROT90, "Namco", "Namco Classics Collection Vol.1 (Japan, v1.03)", GAME_IMPERFECT_SOUND | GAME_IMPERFECT_GRAPHICS )
-GAME( 1996, ncv2,      0, namcond1, namcond1, 0, ROT90, "Namco", "Namco Classics Collection Vol.2", GAME_IMPERFECT_SOUND | GAME_IMPERFECT_GRAPHICS )
-GAME( 1996, ncv2j,  ncv2, namcond1, namcond1, 0, ROT90, "Namco", "Namco Classics Collection Vol.2 (Japan)", GAME_IMPERFECT_SOUND | GAME_IMPERFECT_GRAPHICS )
+GAME( 1995, ncv1,      0, namcond1, namcond1, 0, ROT90, "Namco", "Namco Classics Collection Vol.1", GAME_IMPERFECT_SOUND | GAME_IMPERFECT_GRAPHICS | GAME_SUPPORTS_SAVE )
+GAME( 1995, ncv1j,  ncv1, namcond1, namcond1, 0, ROT90, "Namco", "Namco Classics Collection Vol.1 (Japan, v1.00)", GAME_IMPERFECT_SOUND | GAME_IMPERFECT_GRAPHICS | GAME_SUPPORTS_SAVE )
+GAME( 1995, ncv1j2, ncv1, namcond1, namcond1, 0, ROT90, "Namco", "Namco Classics Collection Vol.1 (Japan, v1.03)", GAME_IMPERFECT_SOUND | GAME_IMPERFECT_GRAPHICS | GAME_SUPPORTS_SAVE )
+GAME( 1996, ncv2,      0, namcond1, namcond1, 0, ROT90, "Namco", "Namco Classics Collection Vol.2", GAME_IMPERFECT_SOUND | GAME_IMPERFECT_GRAPHICS | GAME_UNEMULATED_PROTECTION | GAME_SUPPORTS_SAVE )
+GAME( 1996, ncv2j,  ncv2, namcond1, namcond1, 0, ROT90, "Namco", "Namco Classics Collection Vol.2 (Japan)", GAME_IMPERFECT_SOUND | GAME_IMPERFECT_GRAPHICS | GAME_UNEMULATED_PROTECTION | GAME_SUPPORTS_SAVE )
