@@ -34,11 +34,11 @@ Memo:
 
 #include "driver.h"
 #include "machine/m68kfmly.h"
-#include "machine/z80fmly.h"
-#include "vidhrdw/generic.h"
+#include "machine/z80ctc.h"
 #include "nb1413m3.h"
 #include "sound/dac.h"
 #include "sound/3812intf.h"
+#include "cpu/z80/z80daisy.h"
 
 
 #define SIGNED_DAC	0		/* 0:unsigned DAC, 1:signed DAC */
@@ -80,7 +80,7 @@ static void niyanpai_soundbank_w(int data)
 {
 	unsigned char *SNDROM = memory_region(REGION_CPU2);
 
-	cpu_setbank(1, &SNDROM[0x08000 + (0x8000 * (data & 0x03))]);
+	memory_set_bankptr(1, &SNDROM[0x08000 + (0x8000 * (data & 0x03))]);
 }
 
 static int niyanpai_sound_r(int offset)
@@ -186,28 +186,27 @@ static WRITE8_HANDLER( tmpz84c011_0_dir_pe_w )	{ pio_dir[4] = data; }
 
 static void ctc0_interrupt(int state)
 {
-	cpunum_set_input_line_and_vector(1, 0, HOLD_LINE, Z80_VECTOR(0, state));
+	cpunum_set_input_line(1, 0, state);
 }
 
 static z80ctc_interface ctc_intf =
 {
-	1,						/* 1 chip */
-	{ 1 },					/* clock */
-	{ 0 },					/* timer disables */
-	{ ctc0_interrupt },		/* interrupt handler */
-	{ z80ctc_0_trg3_w },	/* ZC/TO0 callback ctc1.zc0 -> ctc1.trg3 */
-	{ 0 },					/* ZC/TO1 callback */
-	{ 0 },					/* ZC/TO2 callback */
+	1,					/* clock */
+	0,					/* timer disables */
+	ctc0_interrupt,		/* interrupt handler */
+	z80ctc_0_trg3_w,	/* ZC/TO0 callback ctc1.zc0 -> ctc1.trg3 */
+	0,					/* ZC/TO1 callback */
+	0,					/* ZC/TO2 callback */
 };
 
 static void tmpz84c011_init(void)
 {
 	/* initialize the CTC */
-	ctc_intf.baseclock[0] = Machine->drv->cpu[1].cpu_clock;
-	z80ctc_init(&ctc_intf);
+	ctc_intf.baseclock = Machine->drv->cpu[1].cpu_clock;
+	z80ctc_init(0, &ctc_intf);
 }
 
-static MACHINE_INIT( niyanpai )
+static MACHINE_RESET( niyanpai )
 {
 	int i;
 
@@ -288,7 +287,7 @@ static READ16_HANDLER( musobana_inputport_0_r )
 		case 0x04:	portdata = ((readinputport(5) << 8) | (readinputport(10))); break;
 		case 0x08:	portdata = ((readinputport(6) << 8) | (readinputport(11))); break;
 		case 0x10:	portdata = ((readinputport(7) << 8) | (readinputport(12))); break;
-		default:	portdata = 0xffff; break;
+		default:	portdata = (((readinputport(3) << 8) | (readinputport(8)))) & (((readinputport(4) << 8) | (readinputport(9)))) & (((readinputport(5) << 8) | (readinputport(10)))) & (((readinputport(6) << 8) | (readinputport(11)))) & (((readinputport(7) << 8) | (readinputport(12)))); break;
 	}
 
 	return (portdata);
@@ -846,10 +845,10 @@ static INTERRUPT_GEN( niyanpai_interrupt )
 	cpunum_set_input_line(0, 1, HOLD_LINE);
 }
 
-static Z80_DaisyChain daisy_chain_sound[] =
+static struct z80_irq_daisy_chain daisy_chain_sound[] =
 {
-	{ z80ctc_reset, z80ctc_interrupt, z80ctc_reti, 0 },	/* device 0 = CTC_1 */
-	{ 0, 0, 0, -1 }		/* end mark */
+	{ z80ctc_reset, z80ctc_irq_state, z80ctc_irq_ack, z80ctc_irq_reti, 0 },	/* device 0 = CTC_1 */
+	{ 0, 0, 0, 0, -1 }		/* end mark */
 };
 
 
@@ -869,7 +868,7 @@ static MACHINE_DRIVER_START( niyanpai )
 	MDRV_FRAMES_PER_SECOND(60)
 	MDRV_VBLANK_DURATION(DEFAULT_60HZ_VBLANK_DURATION)
 
-	MDRV_MACHINE_INIT(niyanpai)
+	MDRV_MACHINE_RESET(niyanpai)
 	MDRV_NVRAM_HANDLER(generic_0fill)
 
 	/* video hardware */
@@ -988,7 +987,7 @@ ROM_START( mhhonban )
 ROM_END
 
 
-GAME( 1996, niyanpai, 0, niyanpai, niyanpai, niyanpai, ROT0, "Nichibutsu", "Niyanpai (Japan)" )
-GAME( 1995, musobana, 0, musobana, musobana, musobana, ROT0, "Nichibutsu/Yubis", "Musoubana (Japan)" )
-GAME( 1994, 4psimasy, 0, musobana, 4psimasy, 4psimasy, ROT0, "SPHINX/AV JAPAN", "Mahjong 4P Simasyo (Japan)" )
-GAME( 199?, mhhonban, 0, mhhonban, mhhonban, mhhonban, ROT0, "Nichibutsu?", "Mahjong Housoukyoku Honbanchuu (Japan)" )
+GAME( 1996, niyanpai, 0, niyanpai, niyanpai, niyanpai, ROT0, "Nichibutsu", "Niyanpai (Japan)", 0 )
+GAME( 1995, musobana, 0, musobana, musobana, musobana, ROT0, "Nichibutsu/Yubis", "Musoubana (Japan)", 0 )
+GAME( 1994, 4psimasy, 0, musobana, 4psimasy, 4psimasy, ROT0, "SPHINX/AV JAPAN", "Mahjong 4P Simasyo (Japan)", 0 )
+GAME( 199?, mhhonban, 0, mhhonban, mhhonban, mhhonban, ROT0, "Nichibutsu?", "Mahjong Housoukyoku Honbanchuu (Japan)", 0 )
