@@ -32,7 +32,6 @@
 *******************************************************************************/
 
 #include "driver.h"
-#include "vidhrdw/generic.h"
 #include "sound/ay8910.h"
 
 /* From vidhrdw/nova2001.c */
@@ -141,7 +140,7 @@ INPUT_PORTS_END
 
 
 
-static gfx_layout charlayout =
+static const gfx_layout charlayout =
 {
 	8,8,    /* 8*8 characters */
 	256,    /* 256 characters */
@@ -152,7 +151,7 @@ static gfx_layout charlayout =
 	8*16
 };
 
-static gfx_layout spritelayout =
+static const gfx_layout spritelayout =
 {
 	16,16,    /* 16*16 characters */
 	128,      /* 128 sprites */
@@ -165,7 +164,7 @@ static gfx_layout spritelayout =
 	8*64
 };
 
-static gfx_decode gfxdecodeinfo[] =
+static const gfx_decode gfxdecodeinfo[] =
 {
 	{ REGION_GFX1, 0x0000, &charlayout,       0, 16 },
 	{ REGION_GFX2, 0x0000, &charlayout,   16*16, 16 },
