@@ -148,7 +148,6 @@ Stephh's additional notes (based on the game Z80 code and some tests) :
 
 #include <math.h>
 #include "driver.h"
-#include "vidhrdw/generic.h"
 #include "cpu/z80/z80.h"
 #include "sound/ay8910.h"
 #include "sound/msm5232.h"
@@ -245,7 +244,7 @@ static WRITE8_HANDLER( sound_cpu_reset_w )
 
 static int vol_ctrl[16];
 
-static MACHINE_INIT( ta7630 )
+static MACHINE_RESET( ta7630 )
 {
 	int i;
 
@@ -764,7 +763,7 @@ INPUT_PORTS_START( nycaptor )
 	PORT_BIT( 0xff, 0x80, IPT_LIGHTGUN_Y ) PORT_MINMAX(0x00,0xff) PORT_SENSITIVITY(25) PORT_KEYDELTA(15) PORT_PLAYER(1)
 INPUT_PORTS_END
 
-static gfx_layout charlayout =
+static const gfx_layout charlayout =
 {
 	8,8,
 	RGN_FRAC(1,2),
@@ -775,7 +774,7 @@ static gfx_layout charlayout =
 	16*8
 };
 
-static gfx_layout spritelayout =
+static const gfx_layout spritelayout =
 {
 	16,16,
 	RGN_FRAC(1,2),
@@ -788,7 +787,7 @@ static gfx_layout spritelayout =
 	64*8
 };
 
-static gfx_decode gfxdecodeinfo[] =
+static const gfx_decode gfxdecodeinfo[] =
 {
 	{ REGION_GFX1, 0, &charlayout,     0, 16 },/*16 kolorow */
 	{ REGION_GFX1, 0, &spritelayout, 256, 16 },/*paleta 2, 16 kolorow */
@@ -821,7 +820,7 @@ static MACHINE_DRIVER_START( nycaptor )
 	MDRV_INTERLEAVE(100)	/* 100 CPU slices per frame - an high value to ensure proper */
 
 	/* synchronization of the CPUs */
-	MDRV_MACHINE_INIT(ta7630)
+	MDRV_MACHINE_RESET(ta7630)
 
 	/* video hardware */
 	MDRV_VIDEO_ATTRIBUTES(VIDEO_TYPE_RASTER)
@@ -872,7 +871,7 @@ static MACHINE_DRIVER_START( cyclshtg )
 	MDRV_FRAMES_PER_SECOND(60)
 	MDRV_VBLANK_DURATION(DEFAULT_60HZ_VBLANK_DURATION)
 	MDRV_INTERLEAVE(1)
-	MDRV_MACHINE_INIT(ta7630)
+	MDRV_MACHINE_RESET(ta7630)
 	MDRV_VIDEO_ATTRIBUTES(VIDEO_TYPE_RASTER)
 	MDRV_SCREEN_SIZE(32*8, 32*8)
 	MDRV_VISIBLE_AREA(0*8, 32*8-1, 2*8, 30*8-1)
@@ -918,7 +917,7 @@ static MACHINE_DRIVER_START( bronx )
 	MDRV_FRAMES_PER_SECOND(60)
 	MDRV_VBLANK_DURATION(DEFAULT_60HZ_VBLANK_DURATION)
 	MDRV_INTERLEAVE(2)
-	MDRV_MACHINE_INIT(ta7630)
+	MDRV_MACHINE_RESET(ta7630)
 	MDRV_VIDEO_ATTRIBUTES(VIDEO_TYPE_RASTER)
 	MDRV_SCREEN_SIZE(32*8, 32*8)
 	MDRV_VISIBLE_AREA(0*8, 32*8-1, 2*8, 30*8-1)
@@ -1258,7 +1257,7 @@ ROM_START( colt )
 	ROM_LOAD( "05.bin",   0x0000, 0x4000, CRC(2b6e017a) SHA1(60715e1c6fbcdd2c0e114035c342ba587dfc1b4b) )
 	ROM_LOAD( "a50_06",   0x4000, 0x4000, CRC(450d6783) SHA1(e652bf83fb6bdd8152dbafb05bb695259c2619cc) )
 
-	ROM_REGION( 0x08000, REGION_USER1, 0 ) /*empty */
+	ROM_REGION( 0x08000, REGION_USER1, ROMREGION_ERASE00 ) /*empty */
 
 	ROM_REGION( 0x10000, REGION_CPU3, 0 )
 	ROM_LOAD( "a50_15",   0x0000, 0x4000, CRC(f8a604e5) SHA1(8fae920fd09584b5e5ccd0db8b8934b393a23d50) )
