@@ -34,7 +34,6 @@ fedcba98
 ****/
 
 #include "driver.h"
-#include "vidhrdw/generic.h"
 #include "machine/6821pia.h"
 #include "vidhrdw/crtc6845.h"
 #include "cpu/m6800/m6800.h"
@@ -84,7 +83,7 @@ INTERRUPT_GEN( nyny_interrupt )
     6821 PIA handlers
 ***************************************************************************/
 
-void cpu0_irq(int state)
+static void cpu0_irq(int state)
 {
 	cpunum_set_input_line(0,M6809_IRQ_LINE,state ? ASSERT_LINE : CLEAR_LINE);
 }
@@ -111,25 +110,29 @@ static WRITE8_HANDLER( pia1_portb_w )
 	cpunum_set_input_line(2,M6802_IRQ_LINE,(data & 0x80) ? CLEAR_LINE : ASSERT_LINE);
 }
 
-static struct pia6821_interface pia0_intf =
+static const pia6821_interface pia0_intf =
 {
 	/*inputs : A/B,CA/B1,CA/B2 */ input_port_0_r, input_port_1_r, input_port_5_r, 0, input_port_6_r, 0,
 	/*outputs: A/B,CA/B2       */ 0, 0, 0, 0,
 	/*irqs   : A/B             */ cpu0_irq, 0
 };
 
-static struct pia6821_interface pia1_intf =
+static const pia6821_interface pia1_intf =
 {
 	/*inputs : A/B,CA/B1,CA/B2 */ 0, 0, pia1_ca1_r, 0, 0, 0,
 	/*outputs: A/B,CA/B2       */ pia1_porta_w, pia1_portb_w, nyny_flipscreen_w, 0,
 	/*irqs   : A/B             */ 0, 0
 };
 
-MACHINE_INIT( nyny )
+MACHINE_START( nyny )
 {
-	pia_unconfig();
 	pia_config(0, PIA_STANDARD_ORDERING, &pia0_intf);
 	pia_config(1, PIA_ALTERNATE_ORDERING, &pia1_intf);
+	return 0;
+}
+
+MACHINE_RESET( nyny )
+{
 	pia_reset();
 }
 
@@ -151,7 +154,7 @@ WRITE8_HANDLER( ay8910_portb_w )
 	DAC_1_data_w( 0, dac_enable * dac_volume ) ;
 }
 
-WRITE8_HANDLER( shared_w_irq )
+static WRITE8_HANDLER( shared_w_irq )
 {
 	soundlatch_w(0,data);
 	cpunum_set_input_line(1,M6802_IRQ_LINE,HOLD_LINE);
@@ -160,12 +163,12 @@ WRITE8_HANDLER( shared_w_irq )
 
 static unsigned char snd_w = 0;
 
-READ8_HANDLER( snd_answer_r )
+static READ8_HANDLER( snd_answer_r )
 {
 	return snd_w;
 }
 
-WRITE8_HANDLER( snd_answer_w )
+static WRITE8_HANDLER( snd_answer_w )
 {
 	snd_w = data;
 }
@@ -353,7 +356,8 @@ static MACHINE_DRIVER_START( nyny )
 	MDRV_FRAMES_PER_SECOND(50)
 	MDRV_VBLANK_DURATION(DEFAULT_60HZ_VBLANK_DURATION)
 
-	MDRV_MACHINE_INIT(nyny)
+	MDRV_MACHINE_START(nyny)
+	MDRV_MACHINE_RESET(nyny)
 	MDRV_NVRAM_HANDLER(generic_0fill)
 
 	/* video hardware */
