@@ -330,7 +330,7 @@ INPUT_PORTS_START( maddonna )
 INPUT_PORTS_END
 
 
-static gfx_layout oneshot16x16_layout =
+static const gfx_layout oneshot16x16_layout =
 {
 	16,16,
 	RGN_FRAC(1,8),
@@ -343,7 +343,7 @@ static gfx_layout oneshot16x16_layout =
 	16*16
 };
 
-static gfx_layout oneshot8x8_layout =
+static const gfx_layout oneshot8x8_layout =
 {
 	8,8,
 	RGN_FRAC(1,8),
@@ -355,7 +355,7 @@ static gfx_layout oneshot8x8_layout =
 };
 
 
-static gfx_decode gfxdecodeinfo[] =
+static const gfx_decode gfxdecodeinfo[] =
 {
 	{ REGION_GFX1, 0, &oneshot16x16_layout,   0x00, 4  }, /* sprites */
 	{ REGION_GFX1, 0, &oneshot8x8_layout,     0x00, 4  }, /* sprites */
@@ -461,7 +461,7 @@ ROM_START( maddonna )
 	ROM_LOAD( "maddonna.b10",  0x300000, 0x080000, CRC(87936423) SHA1(dda42f3685427edad7686d9712ff07d2fd9bf57e) )
 	ROM_LOAD( "maddonna.b12",  0x380000, 0x080000, CRC(879ab23c) SHA1(5288016542a10e60ccb28a930d8dfe4db41c6fc6) )
 
-	ROM_REGION( 0x100000, REGION_SOUND1, 0 ) /* Samples */
+	ROM_REGION( 0x100000, REGION_SOUND1, ROMREGION_ERASE00 ) /* Samples */
 	/* no samples for this game */
 
 	ROM_REGION( 0x10000, REGION_USER1, 0 )
@@ -487,7 +487,7 @@ ROM_START( maddonnb )
 	ROM_LOAD( "x10.11",  0x300000, 0x080000, CRC(479d718c) SHA1(4fbc2568744cf78b15c6e0f3caba4d7109743cdd) )
 	ROM_LOAD( "x12.08",  0x380000, 0x080000, CRC(d56ca9f8) SHA1(49bca5dbc048e7b7efa34e1c08ee1b76767ffe38) )
 
-	ROM_REGION( 0x100000, REGION_SOUND1, 0 ) /* Samples */
+	ROM_REGION( 0x100000, REGION_SOUND1, ROMREGION_ERASE00 ) /* Samples */
 	/* no samples for this game */
 
 	ROM_REGION( 0x10000, REGION_USER1, 0 )
