@@ -196,10 +196,8 @@ TODO:
 ***************************************************************************/
 
 #include "driver.h"
-#include "state.h"
 #include "cpu/m68000/m68000.h"
 #include "machine/eeprom.h"
-#include "vidhrdw/generic.h"
 #include "vidhrdw/taitoic.h"
 #include "sndhrdw/taitosnd.h"
 #include "sound/2610intf.h"
@@ -217,7 +215,7 @@ extern UINT16 *othunder_ram;
 
 static int vblank_irq, ad_irq, last_irq_level;
 
-static MACHINE_INIT( othunder )
+static MACHINE_RESET( othunder )
 {
 	vblank_irq = 0;
 	ad_irq = 0;
@@ -411,13 +409,21 @@ static WRITE16_HANDLER( othunder_lightgun_w )
             SOUND
 *****************************************/
 
-static int banknum = -1;
+static INT32 banknum = -1;
 
 static void reset_sound_region(void)
 {
 	memory_set_bankptr( 10, memory_region(REGION_CPU2) + (banknum * 0x4000) + 0x10000 );
 }
 
+static MACHINE_START( othunder )
+{
+	state_save_register_global(banknum);
+	state_save_register_func_postload(reset_sound_region);
+	return 0;
+}
+
+
 static WRITE8_HANDLER( sound_bankswitch_w )
 {
 	banknum = (data - 1) & 7;
@@ -638,7 +644,7 @@ INPUT_PORTS_END
                 GFX DECODING
 ***********************************************************/
 
-static gfx_layout tile16x8_layout =
+static const gfx_layout tile16x8_layout =
 {
 	16,8,
 	RGN_FRAC(1,1),
@@ -649,7 +655,7 @@ static gfx_layout tile16x8_layout =
 	64*8
 };
 
-static gfx_layout charlayout =
+static const gfx_layout charlayout =
 {
 	8,8,
 	RGN_FRAC(1,1),
@@ -660,7 +666,7 @@ static gfx_layout charlayout =
 	32*8
 };
 
-static gfx_decode othunder_gfxdecodeinfo[] =
+static const gfx_decode othunder_gfxdecodeinfo[] =
 {
 	{ REGION_GFX2, 0, &tile16x8_layout, 0, 256 },	/* sprite parts */
 	{ REGION_GFX1, 0, &charlayout,      0, 256 },	/* sprites & playfield */
@@ -708,7 +714,8 @@ static MACHINE_DRIVER_START( othunder )
 	MDRV_VBLANK_DURATION(DEFAULT_60HZ_VBLANK_DURATION)
 
 	MDRV_NVRAM_HANDLER(othunder)
-	MDRV_MACHINE_INIT(othunder)
+	MDRV_MACHINE_START(othunder)
+	MDRV_MACHINE_RESET(othunder)
 
 	/* video hardware */
 	MDRV_VIDEO_ATTRIBUTES(VIDEO_TYPE_RASTER)
@@ -781,7 +788,7 @@ ROM_START( othunder )
 	ROM_REGION( 0x80000, REGION_SOUND2, 0 )	/* Delta-T samples */
 	ROM_LOAD( "b67-07", 0x00000, 0x80000, CRC(4f834357) SHA1(f34705ce64870a8b24ec2639505079cc031fb719) )
 
-	ROM_REGION( 0x10000, REGION_USER2, 0 )	/* PALs */
+/*  ROM_REGION( 0x10000, REGION_USER2, 0 )     PALs    */
 /*  ROM_LOAD( "b67-09", 0x00000, 0xd56, CRC(130fd2ab) )     // PAL read as PLHS18P8A/B but I don't see that in the schematics */
 /*  ROM_LOAD( "b67-10.33", 0x00000, 0xcd5, CRC(312f9e2a) )  // address decoding (PAL 20L8B) */
 /*  ROM_LOAD( "b67-11.36", 0x00000, 0xada, CRC(f863b864) )  // interrupt control (PAL 16L8B) */
@@ -880,14 +887,7 @@ ROM_END
 
 
 
-static DRIVER_INIT( othunder )
-{
-	state_save_register_int("sound1", 0, "sound region", &banknum);
-	state_save_register_func_postload(reset_sound_region);
-}
-
-
-GAME( 1988, othunder, 0,        othunder, othunder, othunder, ORIENTATION_FLIP_X, "Taito Corporation Japan", "Operation Thunderbolt (World)", 0 )
-GAME( 1988, othundu,  othunder, othunder, othundu,  othunder, ORIENTATION_FLIP_X, "Taito America Corporation", "Operation Thunderbolt (US)", 0 )
-GAME( 1988, othunduo, othunder, othunder, othundrj, othunder, ORIENTATION_FLIP_X, "Taito America Corporation", "Operation Thunderbolt (US, older)", 0 )
-GAME( 1988, othundrj, othunder, othunder, othundrj, othunder, ORIENTATION_FLIP_X, "Taito Corporation", "Operation Thunderbolt (Japan)", 0 )
+GAME( 1988, othunder, 0,        othunder, othunder, 0, ORIENTATION_FLIP_X, "Taito Corporation Japan", "Operation Thunderbolt (World)", 0 )
+GAME( 1988, othundu,  othunder, othunder, othundu,  0, ORIENTATION_FLIP_X, "Taito America Corporation", "Operation Thunderbolt (US)", 0 )
+GAME( 1988, othunduo, othunder, othunder, othundrj, 0, ORIENTATION_FLIP_X, "Taito America Corporation", "Operation Thunderbolt (US, older)", 0 )
+GAME( 1988, othundrj, othunder, othunder, othundrj, 0, ORIENTATION_FLIP_X, "Taito Corporation", "Operation Thunderbolt (Japan)", 0 )
