@@ -7,14 +7,13 @@ driver by Nicola Salmoria
 ***************************************************************************/
 
 #include "driver.h"
-#include "vidhrdw/generic.h"
 #include "cpu/konami/konami.h" /* for the callback and the firq irq definition */
 #include "vidhrdw/konamiic.h"
 #include "sound/2151intf.h"
 #include "sound/k053260.h"
 
 /* prototypes */
-static MACHINE_INIT( parodius );
+static MACHINE_RESET( parodius );
 static void parodius_banking( int lines );
 VIDEO_START( parodius );
 VIDEO_UPDATE( parodius );
@@ -45,9 +44,9 @@ static WRITE8_HANDLER( bankedram_w )
 	if (videobank & 0x01)
 	{
 		if (videobank & 0x04)
-			paletteram_xBBBBBGGGGGRRRRR_swap_w(offset + 0x0800,data);
+			paletteram_xBBBBBGGGGGRRRRR_be_w(offset + 0x0800,data);
 		else
-			paletteram_xBBBBBGGGGGRRRRR_swap_w(offset,data);
+			paletteram_xBBBBBGGGGGRRRRR_be_w(offset,data);
 	}
 	else
 		ram[offset] = data;
@@ -95,10 +94,7 @@ static WRITE8_HANDLER( parodius_3fc0_w )
 
 static READ8_HANDLER( parodius_sound_r )
 {
-	/* If the sound CPU is running, read the status, otherwise
-       just make it pass the test */
-	if (Machine->sample_rate != 0) 	return K053260_0_r(2 + offset);
-	else return offset ? 0x00 : 0x80;
+	return K053260_0_r(2 + offset);
 }
 
 static WRITE8_HANDLER( parodius_sh_irqtrigger_w )
@@ -129,21 +125,10 @@ static WRITE8_HANDLER( sound_arm_nmi_w )
 	timer_set(TIME_IN_USEC(50),0,nmi_callback);	/* kludge until the K053260 is emulated correctly */
 }
 
-static READ8_HANDLER( speedup_r )
-{
-	int data = memory_region(REGION_CPU1)[0x1837];
-
-	if ( activecpu_get_pc() == 0xa400 && data == 0 )
-		cpu_spinuntil_int();
-
-	return data;
-}
-
 /********************************************/
 
 static ADDRESS_MAP_START( parodius_readmem, ADDRESS_SPACE_PROGRAM, 8 )
 	AM_RANGE(0x0000, 0x07ff) AM_READ(bankedram_r)
-	AM_RANGE(0x1837, 0x1837) AM_READ(speedup_r)
 	AM_RANGE(0x0800, 0x1fff) AM_READ(MRA8_RAM)
 	AM_RANGE(0x3f8c, 0x3f8c) AM_READ(input_port_0_r)
 	AM_RANGE(0x3f8d, 0x3f8d) AM_READ(input_port_1_r)
@@ -203,9 +188,9 @@ INPUT_PORTS_START( parodius )
 	PORT_BIT( 0x04, IP_ACTIVE_LOW, IPT_JOYSTICK_DOWN ) PORT_8WAY PORT_PLAYER(1)
 	PORT_BIT( 0x08, IP_ACTIVE_LOW, IPT_JOYSTICK_LEFT ) PORT_8WAY PORT_PLAYER(1)
 	PORT_BIT( 0x10, IP_ACTIVE_LOW, IPT_JOYSTICK_RIGHT ) PORT_8WAY PORT_PLAYER(1)
-	PORT_BIT( 0x20, IP_ACTIVE_LOW, IPT_BUTTON3 ) PORT_PLAYER(1)
-	PORT_BIT( 0x40, IP_ACTIVE_LOW, IPT_BUTTON1 ) PORT_PLAYER(1)
-	PORT_BIT( 0x80, IP_ACTIVE_LOW, IPT_BUTTON2 ) PORT_PLAYER(1)
+	PORT_BIT( 0x20, IP_ACTIVE_LOW, IPT_BUTTON1 ) PORT_PLAYER(1)		/* power-up */
+	PORT_BIT( 0x40, IP_ACTIVE_LOW, IPT_BUTTON2 ) PORT_PLAYER(1)		/* shoot */
+	PORT_BIT( 0x80, IP_ACTIVE_LOW, IPT_BUTTON3 ) PORT_PLAYER(1)		/* missile */
 
 	PORT_START	/* PLAYER 2 INPUTS */
 	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_START2 )
@@ -213,9 +198,9 @@ INPUT_PORTS_START( parodius )
 	PORT_BIT( 0x04, IP_ACTIVE_LOW, IPT_JOYSTICK_DOWN ) PORT_8WAY PORT_PLAYER(2)
 	PORT_BIT( 0x08, IP_ACTIVE_LOW, IPT_JOYSTICK_LEFT ) PORT_8WAY PORT_PLAYER(2)
 	PORT_BIT( 0x10, IP_ACTIVE_LOW, IPT_JOYSTICK_RIGHT ) PORT_8WAY PORT_PLAYER(2)
-	PORT_BIT( 0x20, IP_ACTIVE_LOW, IPT_BUTTON3 ) PORT_PLAYER(2)
-	PORT_BIT( 0x40, IP_ACTIVE_LOW, IPT_BUTTON1 ) PORT_PLAYER(2)
-	PORT_BIT( 0x80, IP_ACTIVE_LOW, IPT_BUTTON2 ) PORT_PLAYER(2)
+	PORT_BIT( 0x20, IP_ACTIVE_LOW, IPT_BUTTON1 ) PORT_PLAYER(2)
+	PORT_BIT( 0x40, IP_ACTIVE_LOW, IPT_BUTTON2 ) PORT_PLAYER(2)
+	PORT_BIT( 0x80, IP_ACTIVE_LOW, IPT_BUTTON3 ) PORT_PLAYER(2)
 
 	PORT_START	/* DSW #1 */
 	PORT_DIPNAME( 0x0f, 0x0f, DEF_STR( Coin_A ) )
@@ -322,7 +307,7 @@ static MACHINE_DRIVER_START( parodius )
 	MDRV_FRAMES_PER_SECOND(60)
 	MDRV_VBLANK_DURATION(DEFAULT_60HZ_VBLANK_DURATION)
 
-	MDRV_MACHINE_INIT(parodius)
+	MDRV_MACHINE_RESET(parodius)
 
 	/* video hardware */
 	MDRV_VIDEO_ATTRIBUTES(VIDEO_TYPE_RASTER | VIDEO_HAS_SHADOWS)
@@ -409,10 +394,10 @@ static void parodius_banking(int lines)
 
 	offs = 0x10000 + (((lines & 0x0f)^0x0f) * 0x4000);
 	if (offs >= 0x48000) offs -= 0x40000;
-	cpu_setbank( 1, &RAM[offs] );
+	memory_set_bankptr( 1, &RAM[offs] );
 }
 
-static MACHINE_INIT( parodius )
+static MACHINE_RESET( parodius )
 {
 	unsigned char *RAM = memory_region(REGION_CPU1);
 
@@ -423,7 +408,7 @@ static MACHINE_INIT( parodius )
 	videobank = 0;
 
 	/* init the default bank */
-	cpu_setbank(1,&RAM[0x10000]);
+	memory_set_bankptr(1,&RAM[0x10000]);
 }
 
 
@@ -435,5 +420,5 @@ static DRIVER_INIT( parodius )
 
 
 
-GAME( 1990, parodius, 0,        parodius, parodius, parodius, ROT0, "Konami", "Parodius DA! (World)" )
-GAME( 1990, parodisj, parodius, parodius, parodius, parodius, ROT0, "Konami", "Parodius DA! (Japan)" )
+GAME( 1990, parodius, 0,        parodius, parodius, parodius, ROT0, "Konami", "Parodius DA! (World)", 0 )
+GAME( 1990, parodisj, parodius, parodius, parodius, parodius, ROT0, "Konami", "Parodius DA! (Japan)", 0 )
