@@ -279,7 +279,6 @@ O to A-F AND, at the same time, O to P ... Any help is appreciated ...
 Notes & Todo:
 -------------
 
-- Fix Mike Tyson's Punchout background when playing.
 - Look at Ninja Gaiden 3. It has some slight timming issues on the
   second level. Probably related to the mapper's irq timming.
 - Fix some remaining bad gfx in Rad Racer II.
@@ -292,7 +291,6 @@ Notes & Todo:
 ***************************************************************************/
 
 #include "driver.h"
-#include "vidhrdw/generic.h"
 #include "vidhrdw/ppu2c03b.h"
 #include "cpu/z80/z80.h"
 #include "machine/rp5h01.h"
@@ -309,7 +307,7 @@ extern VIDEO_START( playch10 );
 extern VIDEO_UPDATE( playch10 );
 
 /* from machine */
-extern MACHINE_INIT( pc10 );
+extern MACHINE_RESET( pc10 );
 extern DRIVER_INIT( playch10 );	/* standard games */
 extern DRIVER_INIT( pc_gun );	/* gun games */
 extern DRIVER_INIT( pc_hrz );	/* horizontal games */
@@ -378,9 +376,8 @@ static WRITE8_HANDLER( ram_8w_w )
 
 static WRITE8_HANDLER( sprite_dma_w )
 {
-	int source = ( data & 7 ) * 0x100;
-
-	ppu2c03b_spriteram_dma( 0, &work_ram[source] );
+	int source = ( data & 7 );
+	ppu2c03b_spriteram_dma(source );
 }
 
 static NVRAM_HANDLER( playch10 )
@@ -408,6 +405,21 @@ static WRITE8_HANDLER( time_w )
 	ui_popup("Time: %d%d%d%d",timedata[3],timedata[2],timedata[1],timedata[0]);
 }
 
+static READ8_HANDLER( psg_4015_r )
+{
+	return NESPSG_0_r(0x15);
+}
+
+static WRITE8_HANDLER( psg_4015_w )
+{
+	NESPSG_0_w(0x15, data);
+}
+
+static WRITE8_HANDLER( psg_4017_w )
+{
+	NESPSG_0_w(0x17, data);
+}
+
 /******************************************************************************/
 
 /* BIOS */
@@ -441,10 +453,11 @@ static ADDRESS_MAP_START( cart_map, ADDRESS_SPACE_PROGRAM, 8 )
 	AM_RANGE(0x0000, 0x07ff) AM_RAM AM_MIRROR(0x1800) AM_BASE(&work_ram)
 	AM_RANGE(0x2000, 0x3fff) AM_READWRITE(ppu2c03b_0_r, ppu2c03b_0_w)
 	AM_RANGE(0x4011, 0x4011) AM_WRITE(DAC_0_data_w)
+	AM_RANGE(0x4000, 0x4013) AM_READWRITE(NESPSG_0_r, NESPSG_0_w)
 	AM_RANGE(0x4014, 0x4014) AM_WRITE(sprite_dma_w)
-	AM_RANGE(0x4000, 0x4015) AM_READWRITE(NESPSG_0_r, NESPSG_0_w)
+	AM_RANGE(0x4015, 0x4015) AM_READWRITE(psg_4015_r, psg_4015_w)  /* PSG status / first control register */
 	AM_RANGE(0x4016, 0x4016) AM_READWRITE(pc10_in0_r, pc10_in0_w)
-	AM_RANGE(0x4017, 0x4017) AM_READ(pc10_in1_r) AM_WRITENOP /* in1 writes ignored */
+	AM_RANGE(0x4017, 0x4017) AM_READWRITE(pc10_in1_r, psg_4017_w) /* IN1 - input port 2 / PSG second control register */
 	AM_RANGE(0x8000, 0xffff) AM_ROM
 ADDRESS_MAP_END
 
@@ -683,7 +696,7 @@ INPUT_PORTS_START( playc10g )
 INPUT_PORTS_END
 
 
-static gfx_layout bios_charlayout =
+static const gfx_layout bios_charlayout =
 {
     8,8,    /* 8*8 characters */
     1024,   /* 1024 characters */
@@ -694,7 +707,7 @@ static gfx_layout bios_charlayout =
     8*8     /* every char takes 8 consecutive bytes */
 };
 
-static gfx_decode gfxdecodeinfo[] =
+static const gfx_decode gfxdecodeinfo[] =
 {
 	{ REGION_GFX1, 0, &bios_charlayout,   0,  32 },
 	{ -1 }
@@ -730,10 +743,10 @@ static MACHINE_DRIVER_START( playch10 )
 	MDRV_FRAMES_PER_SECOND(60)
 	MDRV_VBLANK_DURATION(( ( ( 1.0 / 60.0 ) * 1000000.0 ) / 262 ) * ( 262 - 239 ))
 
-	MDRV_MACHINE_INIT(pc10)
+	MDRV_MACHINE_RESET(pc10)
 
 	/* video hardware */
-	MDRV_VIDEO_ATTRIBUTES(VIDEO_TYPE_RASTER | VIDEO_DUAL_MONITOR)
+	MDRV_VIDEO_ATTRIBUTES(VIDEO_TYPE_RASTER)
 	MDRV_ASPECT_RATIO(4,6)
 	MDRV_SCREEN_SIZE(32*8, 30*8*2)
 	MDRV_VISIBLE_AREA(0*8, 32*8-1, 0*8, 30*8*2-1)
