@@ -121,7 +121,6 @@ CN1 standard DB15 VGA connector (15KHz)
 */
 
 #include "driver.h"
-#include "machine/random.h"
 #include "machine/eeprom.h"
 
 
@@ -157,7 +156,7 @@ static NVRAM_HANDLER( pntnpuzl )
 	}
 }
 
-static data16_t pntnpuzl_eeprom;
+static UINT16 pntnpuzl_eeprom;
 
 READ16_HANDLER( pntnpuzl_eeprom_r )
 {
@@ -181,8 +180,8 @@ WRITE16_HANDLER( pntnpuzl_eeprom_w )
 
 
 
-data16_t* pntnpuzl_3a0000ram;
-data16_t* pntnpuzl_bank;
+UINT16* pntnpuzl_3a0000ram;
+UINT16* pntnpuzl_bank;
 /* vid */
 VIDEO_START( pntnpuzl )
 {
@@ -255,7 +254,7 @@ VIDEO_UPDATE( pntnpuzl )
 		sx = readinputport(1) * 400 / 128;
 		sy = (0x7f - readinputport(2)) * 240 / 128;
 
-		draw_crosshair(bitmap,sx,sy,cliprect);
+		draw_crosshair(bitmap,sx,sy,cliprect,0);
 	}
 }
 
@@ -327,7 +326,7 @@ write                                     read
 01 53 45 32 0d                       ---> 80 0c
 01 03 46 31 38 0d                    ---> 80 0c
 */
-static data16_t pntpzl_200000, serial, serial_out,read_count;
+static UINT16 pntpzl_200000, serial, serial_out,read_count;
 
 WRITE16_HANDLER( pntnpuzl_200000_w )
 {
@@ -493,4 +492,4 @@ static DRIVER_INIT(pip)
 /*  rom[0x26a0/2] = 0x4e71; */
 }
 
-GAMEX( 199?, pntnpuzl,    0, pntnpuzl,    pntnpuzl,    pip, ROT90,  "Century?", "Paint & Puzzle",GAME_NO_SOUND|GAME_NOT_WORKING )
+GAME( 199?, pntnpuzl,    0, pntnpuzl,    pntnpuzl,    pip, ROT90,  "Century?", "Paint & Puzzle",GAME_NO_SOUND|GAME_NOT_WORKING )
