@@ -217,7 +217,7 @@ Notes:
 #include "sound/namco54.h"
 #include "sound/custom.h"
 #include "sound/samples.h"
-#include "rc.h"
+#include "rescap.h"
 
 
 #define POLEPOS_TOGGLE	PORT_TOGGLE
@@ -230,10 +230,10 @@ WRITE8_HANDLER( polepos_engine_sound_lsb_w );
 WRITE8_HANDLER( polepos_engine_sound_msb_w );
 
 /* from vidhrdw */
-extern data16_t *polepos_view16_memory;
-extern data16_t *polepos_road16_memory;
-extern data16_t *polepos_alpha16_memory;
-extern data16_t *polepos_sprite16_memory;
+extern UINT16 *polepos_view16_memory;
+extern UINT16 *polepos_road16_memory;
+extern UINT16 *polepos_alpha16_memory;
+extern UINT16 *polepos_sprite16_memory;
 extern int polepos_gear_bit;
 
 VIDEO_START( polepos );
@@ -404,13 +404,13 @@ static struct namcoio_interface intf0 =
 };
 static struct namcoio_interface intf1 =
 {
-	{ in1_l, in1_h, dipA_l, dipA_h, },	/* port read handlers */
+	{ in1_l, in1_h, dipA_l, dipA_h },	/* port read handlers */
 	{ NULL, NULL }						/* port write handlers */
 };
 
 
 #include "cpu/z8000/z8000.h"
-static MACHINE_INIT( polepos )
+static MACHINE_RESET( polepos )
 {
 	int i;
 
@@ -771,7 +771,7 @@ INPUT_PORTS_END
  * Graphics layouts
  *********************************************************************/
 
-static struct GfxLayout charlayout_2bpp =
+static const gfx_layout charlayout_2bpp =
 {
 	8,8,
 	RGN_FRAC(1,1),
@@ -782,7 +782,7 @@ static struct GfxLayout charlayout_2bpp =
 	8*8*2
 };
 
-static struct GfxLayout bigspritelayout =
+static const gfx_layout bigspritelayout =
 {
 	32,32,
 	RGN_FRAC(1,2),
@@ -799,7 +799,7 @@ static struct GfxLayout bigspritelayout =
 	32*64
 };
 
-static struct GfxLayout smallspritelayout =
+static const gfx_layout smallspritelayout =
 {
 	16,16,
 	RGN_FRAC(1,2),
@@ -813,7 +813,7 @@ static struct GfxLayout smallspritelayout =
 	16*32
 };
 
-static struct GfxDecodeInfo gfxdecodeinfo[] =
+static const gfx_decode gfxdecodeinfo[] =
 {
 	{ REGION_GFX1, 0, &charlayout_2bpp,   0x0000, 128 },
 	{ REGION_GFX2, 0, &charlayout_2bpp,   0x0200,  64 },
@@ -922,7 +922,7 @@ static MACHINE_DRIVER_START( polepos )
 	MDRV_VBLANK_DURATION(DEFAULT_REAL_60HZ_VBLANK_DURATION)
 	MDRV_INTERLEAVE(100)	/* some interleaving */
 
-	MDRV_MACHINE_INIT(polepos)
+	MDRV_MACHINE_RESET(polepos)
 	MDRV_NVRAM_HANDLER(generic_1fill)
 
 	/* video hardware */
@@ -1699,13 +1699,13 @@ static DRIVER_INIT( polepos2 )
  * Game drivers
  *********************************************************************/
 
-GAME( 1982, polepos,  0,		polepos, polepos,  polepos,	 ROT0, "Namco", "Pole Position" )
-GAME( 1982, poleposa, polepos,	polepos, poleposa, polepos,	 ROT0, "Namco (Atari license)", "Pole Position (Atari version 2)" )
-GAME( 1982, polepos1, polepos,	polepos, poleposa, polepos,	 ROT0, "[Namco] (Atari license)", "Pole Position (Atari version 1)" )
-GAME( 1982, topracer, polepos,	polepos, polepos,  polepos,	 ROT0, "bootleg", "Top Racer (set 1)" )
-GAME( 1982, topracra, polepos,	polepos, topracra, topracra, ROT0, "bootleg", "Top Racer (set 2)" )
-GAME( 1983, topracrb, polepos,	polepos, polepos,  polepos,	 ROT0, "bootleg", "Top Racer (set 3)" )
-GAME( 1983, polepos2, 0,		polepos, polepos2, polepos2, ROT0, "Namco", "Pole Position II" )
-GAME( 1983, poleps2a, polepos2, polepos, polepos2, polepos2, ROT0, "Namco (Atari license)", "Pole Position II (Atari)" )
-GAME( 1983, poleps2b, polepos2, polepos, polepos2, polepos,	 ROT0, "bootleg", "Pole Position II (bootleg)" )
+GAME( 1982, polepos,  0,		polepos, polepos,  polepos,	 ROT0, "Namco", "Pole Position", 0 )
+GAME( 1982, poleposa, polepos,	polepos, poleposa, polepos,	 ROT0, "Namco (Atari license)", "Pole Position (Atari version 2)", 0 )
+GAME( 1982, polepos1, polepos,	polepos, poleposa, polepos,	 ROT0, "[Namco] (Atari license)", "Pole Position (Atari version 1)", 0 )
+GAME( 1982, topracer, polepos,	polepos, polepos,  polepos,	 ROT0, "bootleg", "Top Racer (set 1)", 0 )
+GAME( 1982, topracra, polepos,	polepos, topracra, topracra, ROT0, "bootleg", "Top Racer (set 2)", 0 )
+GAME( 1983, topracrb, polepos,	polepos, polepos,  polepos,	 ROT0, "bootleg", "Top Racer (set 3)", 0 )
+GAME( 1983, polepos2, 0,		polepos, polepos2, polepos2, ROT0, "Namco", "Pole Position II", 0 )
+GAME( 1983, poleps2a, polepos2, polepos, polepos2, polepos2, ROT0, "Namco (Atari license)", "Pole Position II (Atari)", 0 )
+GAME( 1983, poleps2b, polepos2, polepos, polepos2, polepos,	 ROT0, "bootleg", "Pole Position II (bootleg)", 0 )
 
