@@ -17,7 +17,6 @@ Notes:
 ***************************************************************************/
 
 #include "driver.h"
-#include "vidhrdw/generic.h"
 #include "cpu/z80/z80.h"
 #include "sound/ay8910.h"
 
@@ -416,7 +415,7 @@ INPUT_PORTS_START( popeyef )
 INPUT_PORTS_END
 
 
-static gfx_layout charlayout =
+static const gfx_layout charlayout =
 {
 	16,16,	/* 16*16 characters (8*8 doubled) */
 	RGN_FRAC(1,1),
@@ -427,7 +426,7 @@ static gfx_layout charlayout =
 	8*8
 };
 
-static gfx_layout spritelayout =
+static const gfx_layout spritelayout =
 {
 	16,16,
 	RGN_FRAC(1,4),
@@ -441,7 +440,7 @@ static gfx_layout spritelayout =
 	16*8
 };
 
-static gfx_decode gfxdecodeinfo[] =
+static const gfx_decode gfxdecodeinfo[] =
 {
 	{ REGION_GFX1, 0, &charlayout,      0, 16 },	/* chars */
 	{ REGION_GFX2, 0, &spritelayout, 16*2, 64 },	/* sprites */
