@@ -81,7 +81,7 @@ Notes:
 #include "driver.h"
 #include "sound/ay8910.h"
 
-extern data8_t *popper_videoram, *popper_attribram, *popper_ol_videoram, *popper_ol_attribram, *popper_spriteram;
+extern UINT8 *popper_videoram, *popper_attribram, *popper_ol_videoram, *popper_ol_attribram, *popper_spriteram;
 extern size_t popper_spriteram_size;
 
 WRITE8_HANDLER( popper_videoram_w );
@@ -95,7 +95,7 @@ WRITE8_HANDLER( popper_gfx_bank_w );
 PALETTE_INIT( popper );
 VIDEO_START( popper );
 VIDEO_UPDATE( popper );
-static data8_t *popper_sharedram;
+static UINT8 *popper_sharedram;
 
 static READ8_HANDLER( popper_sharedram_r )
 {
@@ -131,7 +131,7 @@ static READ8_HANDLER( popper_sharedram_r )
 /*                      -------x  sound */
 static READ8_HANDLER( popper_input_ports_r )
 {
-	data8_t data=0;
+	UINT8 data=0;
 	switch (offset)
 	{
 		/*           player inputs        dsw1                           dsw2 */
@@ -279,7 +279,7 @@ INPUT_PORTS_START( popper )
 	PORT_DIPSETTING(    0x80, DEF_STR( On ) )
 INPUT_PORTS_END
 
-static struct GfxLayout popper_charlayout =
+static const gfx_layout popper_charlayout =
 {
 	8,8,
 	RGN_FRAC(2,2),
@@ -290,7 +290,7 @@ static struct GfxLayout popper_charlayout =
 	16*8
 };
 
-static struct GfxLayout popper_spritelayout =
+static const gfx_layout popper_spritelayout =
 {
 	16,16,
 	RGN_FRAC(1,2),
@@ -301,7 +301,7 @@ static struct GfxLayout popper_spritelayout =
 	16*2*8
 };
 
-static struct GfxDecodeInfo popper_gfxdecodeinfo[] =
+static const gfx_decode popper_gfxdecodeinfo[] =
 {
 	{ REGION_GFX1, 0, &popper_charlayout,   0, 16 },
 	{ REGION_GFX2, 0, &popper_spritelayout, 0, 16 },
@@ -368,4 +368,4 @@ ROM_START( popper )
 ROM_END
 
 
-GAMEX(1983, popper, 0, popper, popper, 0, ROT90, "Omori Electric Co., Ltd.", "Popper", GAME_IMPERFECT_COLORS )
+GAME( 1983, popper, 0, popper, popper, 0, ROT90, "Omori Electric Co., Ltd.", "Popper", GAME_IMPERFECT_COLORS )
