@@ -61,7 +61,6 @@ This was pointed out by Bart Puype
 *****/
 
 #include "driver.h"
-#include "vidhrdw/generic.h"
 #include "sound/2610intf.h"
 #include "sound/ymf278b.h"
 
@@ -84,7 +83,13 @@ extern void psikyo_switch_banks( int tilemap, int bank );
 
 /* Variables only used here */
 
-static int ack_latch;
+static UINT8 psikyo_soundlatch;
+static int z80_nmi, mcu_status;
+
+MACHINE_RESET( psikyo )
+{
+	z80_nmi = mcu_status = 0;
+}
 
 
 /***************************************************************************
@@ -95,19 +100,50 @@ static int ack_latch;
 
 ***************************************************************************/
 
+static int psikyo_readcoinport(int has_mcu)
+{
+	int ret = readinputport(1) & ~0x84;
+
+	if (has_mcu)
+	{
+		/* Don't know exactly what this bit is, but s1945 and tengai
+           both spin waiting for it to go low during POST.  Also,
+           the following code in tengai (don't know where or if it is
+           reached) waits for it to pulse:
+
+           01A546:  move.b  (A2), D0    ; A2 = $c00003
+           01A548:  andi.b  #$4, D0
+           01A54C:  beq     $1a546
+           01A54E:  move.b  (A2), D0
+           01A550:  andi.b  #$4, D0
+           01A554:  bne     $1a54e
+
+           Interestingly, s1945jn has the code that spins on this bit,
+           but said code is never reached.  Prototype? */
+		if (mcu_status) ret |= 0x04;
+		mcu_status = !mcu_status;	/* hack */
+	}
+
+	if (z80_nmi)
+	{
+		ret |= 0x80;
+
+		/* main CPU might be waiting for sound CPU to finish NMI,
+           so set a timer to give sound CPU a chance to run */
+		timer_set(TIME_NOW, 0, NULL);
+/*      logerror("PC %06X - Read coin port during Z80 NMI\n", activecpu_get_pc()); */
+	}
+
+	return ret;
+}
+
 READ32_HANDLER( sngkace_input_r )
 {
 	switch(offset)
 	{
 		case 0x0:	return (readinputport(0) << 16) | 0xffff;
 		case 0x1:	return (readinputport(2) << 16) | readinputport(4);
-		case 0x2:
-		{
-					const int bit = 0x80;
-					int ret = ack_latch ? bit : 0;
-					if (Machine->sample_rate == 0)	ret = 0;
-					return (((readinputport(1) & ~bit) | ret) << 16) | readinputport(3);
-		}
+		case 0x2:	return (psikyo_readcoinport(0) << 16) | readinputport(3);
 		default:	logerror("PC %06X - Read input %02X !\n", activecpu_get_pc(), offset*2);
 					return 0;
 	}
@@ -117,14 +153,7 @@ READ32_HANDLER( gunbird_input_r )
 {
 	switch(offset)
 	{
-		case 0x0:
-		{
-					const int bit = 0x80;
-					int ret = ack_latch ? bit : 0;
-
-					if (Machine->sample_rate == 0)	ret = 0;
-					return (readinputport(0) << 16) | (readinputport(1) & ~bit) | ret;
-		}
+		case 0x0:	return (readinputport(0) << 16) | psikyo_readcoinport(0);
 		case 0x1:	return (readinputport(2) << 16) | readinputport(3);
 		default:	logerror("PC %06X - Read input %02X !\n", activecpu_get_pc(), offset*2);
 					return 0;
@@ -132,17 +161,17 @@ READ32_HANDLER( gunbird_input_r )
 }
 
 
+static void psikyo_soundlatch_callback(int data)
+{
+	psikyo_soundlatch = data;
+	cpunum_set_input_line(1, INPUT_LINE_NMI, ASSERT_LINE);
+	z80_nmi = 1;
+}
+
 WRITE32_HANDLER( psikyo_soundlatch_w )
 {
 	if (ACCESSING_LSB32)
-	{
-		if (Machine->sample_rate == 0)		return;
-
-		ack_latch = 1;
-		soundlatch_w(0, data & 0xff);
-		cpunum_set_input_line(1, INPUT_LINE_NMI, PULSE_LINE);
-		cpu_spinuntil_time(TIME_IN_USEC(50));	/* Allow the other cpu to reply */
-	}
+		timer_set(TIME_NOW, data & 0xff, psikyo_soundlatch_callback);
 }
 
 /***************************************************************************
@@ -152,14 +181,7 @@ WRITE32_HANDLER( psikyo_soundlatch_w )
 WRITE32_HANDLER( s1945_soundlatch_w )
 {
 	if (!(mem_mask & 0x00ff0000))
-	{
-		if (Machine->sample_rate == 0)		return;
-
-		ack_latch = 1;
-		soundlatch_w(0, (data >> 16) & 0xff);
-		cpunum_set_input_line(1, INPUT_LINE_NMI, PULSE_LINE);
-		cpu_spinuntil_time(TIME_IN_USEC(50));	/* Allow the other cpu to reply */
-	}
+		timer_set(TIME_NOW, (data >> 16) & 0xff, psikyo_soundlatch_callback);
 }
 
 static UINT8 s1945_table[256] = {
@@ -168,7 +190,6 @@ static UINT8 s1945_table[256] = {
 	0x00, 0x00, 0x32, 0x90, 0x00, 0x00, 0xac, 0x5c, 0x00, 0x00, 0x2b, 0xc0
 };
 
-
 static UINT8 s1945a_table[256] = {
 	0x00, 0x00, 0x64, 0xbe, 0x00, 0x00, 0x26, 0x2c, 0x00, 0x00, 0x2c, 0xda, 0x00, 0x00, 0x2c, 0xbc,
 	0x00, 0x00, 0x2c, 0x9e, 0x00, 0x00, 0x2f, 0x0e, 0x00, 0x00, 0x31, 0x10, 0x00, 0x00, 0xc7, 0x2a,
@@ -288,13 +309,7 @@ READ32_HANDLER( s1945_input_r )
 {
 	switch(offset)
 	{
-		case 0x0:
-		{
-					const int bit = 0x04;
-					int ret = ack_latch ? bit : 0;
-					if (Machine->sample_rate == 0)	ret = 0;
-					return (readinputport(0) << 16) | (readinputport(1) & ~bit) | ret;
-		}
+		case 0x0:	return (readinputport(0) << 16) | psikyo_readcoinport(1);
 		case 0x1:	return (((readinputport(2) << 16) | readinputport(3)) & 0xffff000f) | s1945_mcu_r(offset-1, mem_mask);
 		case 0x2:	return s1945_mcu_r(offset-1, mem_mask);
 		default:	logerror("PC %06X - Read input %02X !\n", activecpu_get_pc(), offset*2);
@@ -358,11 +373,18 @@ static void sound_irq( int irq )
 	cpunum_set_input_line(1,0,irq ? ASSERT_LINE : CLEAR_LINE);
 }
 
-WRITE8_HANDLER( psikyo_ack_latch_w )
+READ8_HANDLER( psikyo_soundlatch_r )
 {
-	ack_latch = 0;
+	return psikyo_soundlatch;
 }
 
+WRITE8_HANDLER( psikyo_clear_nmi_w )
+{
+	cpunum_set_input_line(1, INPUT_LINE_NMI, CLEAR_LINE);
+	z80_nmi = 0;
+}
+
+
 /***************************************************************************
                         Sengoku Ace / Samurai Aces
 ***************************************************************************/
@@ -391,7 +413,7 @@ static ADDRESS_MAP_START( sngkace_sound_readport, ADDRESS_SPACE_IO, 8 )
 	ADDRESS_MAP_FLAGS( AMEF_ABITS(8) )
 	AM_RANGE(0x00, 0x00) AM_READ(YM2610_status_port_0_A_r		)
 	AM_RANGE(0x02, 0x02) AM_READ(YM2610_status_port_0_B_r		)
-	AM_RANGE(0x08, 0x08) AM_READ(soundlatch_r					)
+	AM_RANGE(0x08, 0x08) AM_READ(psikyo_soundlatch_r			)
 ADDRESS_MAP_END
 
 static ADDRESS_MAP_START( sngkace_sound_writeport, ADDRESS_SPACE_IO, 8 )
@@ -401,7 +423,7 @@ static ADDRESS_MAP_START( sngkace_sound_writeport, ADDRESS_SPACE_IO, 8 )
 	AM_RANGE(0x02, 0x02) AM_WRITE(YM2610_control_port_0_B_w		)
 	AM_RANGE(0x03, 0x03) AM_WRITE(YM2610_data_port_0_B_w		)
 	AM_RANGE(0x04, 0x04) AM_WRITE(sngkace_sound_bankswitch_w	)
-	AM_RANGE(0x0c, 0x0c) AM_WRITE(psikyo_ack_latch_w			)
+	AM_RANGE(0x0c, 0x0c) AM_WRITE(psikyo_clear_nmi_w			)
 ADDRESS_MAP_END
 
 
@@ -437,7 +459,7 @@ static ADDRESS_MAP_START( gunbird_sound_readport, ADDRESS_SPACE_IO, 8 )
 	ADDRESS_MAP_FLAGS( AMEF_ABITS(8) )
 	AM_RANGE(0x04, 0x04) AM_READ(YM2610_status_port_0_A_r		)
 	AM_RANGE(0x06, 0x06) AM_READ(YM2610_status_port_0_B_r		)
-	AM_RANGE(0x08, 0x08) AM_READ(soundlatch_r					)
+	AM_RANGE(0x08, 0x08) AM_READ(psikyo_soundlatch_r			)
 ADDRESS_MAP_END
 
 static ADDRESS_MAP_START( gunbird_sound_writeport, ADDRESS_SPACE_IO, 8 )
@@ -447,11 +469,10 @@ static ADDRESS_MAP_START( gunbird_sound_writeport, ADDRESS_SPACE_IO, 8 )
 	AM_RANGE(0x05, 0x05) AM_WRITE(YM2610_data_port_0_A_w		)
 	AM_RANGE(0x06, 0x06) AM_WRITE(YM2610_control_port_0_B_w		)
 	AM_RANGE(0x07, 0x07) AM_WRITE(YM2610_data_port_0_B_w		)
-	AM_RANGE(0x0c, 0x0c) AM_WRITE(psikyo_ack_latch_w			)
+	AM_RANGE(0x0c, 0x0c) AM_WRITE(psikyo_clear_nmi_w			)
 ADDRESS_MAP_END
 
 
-
 /***************************************************************************
                         Strikers 1945 / Tengai
 ***************************************************************************/
@@ -459,7 +480,7 @@ ADDRESS_MAP_END
 static ADDRESS_MAP_START( s1945_sound_readport, ADDRESS_SPACE_IO, 8 )
 	ADDRESS_MAP_FLAGS( AMEF_ABITS(8) )
 	AM_RANGE(0x08, 0x08) AM_READ(YMF278B_status_port_0_r		)
-	AM_RANGE(0x10, 0x10) AM_READ(soundlatch_r					)
+	AM_RANGE(0x10, 0x10) AM_READ(psikyo_soundlatch_r			)
 ADDRESS_MAP_END
 
 static ADDRESS_MAP_START( s1945_sound_writeport, ADDRESS_SPACE_IO, 8 )
@@ -472,7 +493,7 @@ static ADDRESS_MAP_START( s1945_sound_writeport, ADDRESS_SPACE_IO, 8 )
 	AM_RANGE(0x0b, 0x0b) AM_WRITE(YMF278B_data_port_0_B_w		)
 	AM_RANGE(0x0c, 0x0c) AM_WRITE(YMF278B_control_port_0_C_w	)
 	AM_RANGE(0x0d, 0x0d) AM_WRITE(YMF278B_data_port_0_C_w		)
-	AM_RANGE(0x18, 0x18) AM_WRITE(psikyo_ack_latch_w			)
+	AM_RANGE(0x18, 0x18) AM_WRITE(psikyo_clear_nmi_w			)
 ADDRESS_MAP_END
 
 
@@ -507,7 +528,7 @@ ADDRESS_MAP_END
 #define PSIKYO_PORT_COIN \
 	PORT_BIT( 0x0001, IP_ACTIVE_LOW,  IPT_COIN1    ) \
 	PORT_BIT( 0x0002, IP_ACTIVE_LOW,  IPT_COIN2    ) \
-	PORT_BIT( 0x0004, IP_ACTIVE_LOW,  IPT_UNKNOWN  ) \
+	PORT_BIT( 0x0004, IP_ACTIVE_HIGH, IPT_SPECIAL  ) \
 	PORT_BIT( 0x0008, IP_ACTIVE_LOW,  IPT_UNKNOWN  ) \
 	PORT_BIT( 0x0010, IP_ACTIVE_LOW,  IPT_SERVICE1 ) \
 	PORT_BIT(0x0020, IP_ACTIVE_LOW,  IPT_SERVICE ) PORT_NAME( DEF_STR( Service_Mode )) PORT_CODE(KEYCODE_F2) \
@@ -739,7 +760,7 @@ INPUT_PORTS_START( sngkace )
 
     ************************************************/
 
-#if 0 /* See Patch in MACHINE_INIT, only text not logo */
+#if 0 /* See Patch in MACHINE_RESET, only text not logo */
 	PORT_DIPNAME( 0x00ff, 0x00ff, "Country" )
 	PORT_DIPSETTING(      0x00ff, DEF_STR( Japan ) )
 	PORT_DIPSETTING(      0x00ef, "USA & Canada" )
@@ -1498,7 +1519,7 @@ INPUT_PORTS_END
 
 ***************************************************************************/
 
-static gfx_layout layout_16x16x4 =
+static const gfx_layout layout_16x16x4 =
 {
 	16,16,
 	RGN_FRAC(1,1),
@@ -1511,7 +1532,7 @@ static gfx_layout layout_16x16x4 =
 	16*16*4
 };
 
-static gfx_decode psikyo_gfxdecodeinfo[] =
+static const gfx_decode psikyo_gfxdecodeinfo[] =
 {
 	{ REGION_GFX1, 0, &layout_16x16x4, 0x000, 0x20 }, /* [0] Sprites */
 	{ REGION_GFX2, 0, &layout_16x16x4, 0x800, 0x48 }, /* [1] Layer 0 + 1 */
@@ -1555,6 +1576,8 @@ static MACHINE_DRIVER_START( sngkace )
 	MDRV_FRAMES_PER_SECOND(59.3)
 	MDRV_VBLANK_DURATION(DEFAULT_REAL_60HZ_VBLANK_DURATION)	/* we're using IPT_VBLANK */
 
+	MDRV_MACHINE_RESET(psikyo)
+
 	/* video hardware */
 	MDRV_VIDEO_ATTRIBUTES(VIDEO_TYPE_RASTER)
 	MDRV_SCREEN_SIZE(320, 256)
@@ -1606,6 +1629,8 @@ static MACHINE_DRIVER_START( gunbird )
 	MDRV_FRAMES_PER_SECOND(59.3)
 	MDRV_VBLANK_DURATION(DEFAULT_REAL_60HZ_VBLANK_DURATION)	/* we're using IPT_VBLANK */
 
+	MDRV_MACHINE_RESET(psikyo)
+
 	/* video hardware */
 	MDRV_VIDEO_ATTRIBUTES(VIDEO_TYPE_RASTER)
 	MDRV_SCREEN_SIZE(320, 256)
@@ -1667,6 +1692,8 @@ static MACHINE_DRIVER_START( s1945 )
 	MDRV_FRAMES_PER_SECOND(59.3)
 	MDRV_VBLANK_DURATION(DEFAULT_REAL_60HZ_VBLANK_DURATION)	/* we're using IPT_VBLANK */
 
+	MDRV_MACHINE_RESET(psikyo)
+
 	/* video hardware */
 	MDRV_VIDEO_ATTRIBUTES(VIDEO_TYPE_RASTER)
 	MDRV_SCREEN_SIZE(320, 256)
@@ -1732,7 +1759,7 @@ ROM_START( samuraia )
 	ROM_LOAD( "u34.bin",  0x000000, 0x100000, CRC(e6a75bd8) SHA1(1aa84ea54584b6c8b2846194b48bf6d2afa67fee) )
 	ROM_LOAD( "u35.bin",  0x100000, 0x100000, CRC(c4ca0164) SHA1(c75422de2e0127cdc23d8c223b674a5bd85b00fb) )
 
-/*  ROM_REGION( 0x100000, REGION_SOUND1, ROMREGION_SOUNDONLY )     Samples    */
+/*  ROM_REGION( 0x100000, REGION_SOUND1, 0 )     Samples    */
 	ROM_REGION( 0x100000, REGION_SOUND1, 0 )	/* Samples */
 	ROM_LOAD( "u68.bin",  0x000000, 0x100000, CRC(9a7f6c34) SHA1(c549b209bce1d2c6eeb512db198ad20c3f5fb0ea) )
 
@@ -1758,7 +1785,7 @@ ROM_START( sngkace )
 	ROM_LOAD( "u34.bin",  0x000000, 0x100000, CRC(e6a75bd8) SHA1(1aa84ea54584b6c8b2846194b48bf6d2afa67fee) )
 	ROM_LOAD( "u35.bin",  0x100000, 0x100000, CRC(c4ca0164) SHA1(c75422de2e0127cdc23d8c223b674a5bd85b00fb) )
 
-/*  ROM_REGION( 0x100000, REGION_SOUND1, ROMREGION_SOUNDONLY )     Samples    */
+/*  ROM_REGION( 0x100000, REGION_SOUND1, 0 )     Samples    */
 	ROM_REGION( 0x100000, REGION_SOUND1, 0 )	/* Samples */
 	ROM_LOAD( "u68.bin",  0x000000, 0x100000, CRC(9a7f6c34) SHA1(c549b209bce1d2c6eeb512db198ad20c3f5fb0ea) )
 
@@ -1844,10 +1871,10 @@ ROM_START( gunbird )
 	ROM_REGION( 0x200000, REGION_GFX2, ROMREGION_DISPOSE )	/* Layers 0 + 1 */
 	ROM_LOAD( "u33.bin",  0x000000, 0x200000, CRC(54494e6b) SHA1(f5d090d2d34d908b56b53a246def194929eba990) )
 
-	ROM_REGION( 0x080000, REGION_SOUND1, ROMREGION_SOUNDONLY )	/* DELTA-T Samples */
+	ROM_REGION( 0x080000, REGION_SOUND1, 0 )	/* DELTA-T Samples */
 	ROM_LOAD( "u64.bin",  0x000000, 0x080000, CRC(e187ed4f) SHA1(05060723d89b1d05714447a14b5f5888ff3c2306) )
 
-	ROM_REGION( 0x100000, REGION_SOUND2, ROMREGION_SOUNDONLY )	/* ADPCM Samples */
+	ROM_REGION( 0x100000, REGION_SOUND2, 0 )	/* ADPCM Samples */
 	ROM_LOAD( "u56.bin",  0x000000, 0x100000, CRC(9e07104d) SHA1(3bc54cb755bb3194197706965b532d62b48c4d12) )
 
 	ROM_REGION( 0x040000, REGION_USER1, 0 )	/* Sprites LUT */
@@ -1874,10 +1901,10 @@ ROM_START( gunbirdk )
 	ROM_REGION( 0x200000, REGION_GFX2, ROMREGION_DISPOSE )	/* Layers 0 + 1 */
 	ROM_LOAD( "u33.bin",  0x000000, 0x200000, CRC(54494e6b) SHA1(f5d090d2d34d908b56b53a246def194929eba990) )
 
-	ROM_REGION( 0x080000, REGION_SOUND1, ROMREGION_SOUNDONLY )	/* DELTA-T Samples */
+	ROM_REGION( 0x080000, REGION_SOUND1, 0 )	/* DELTA-T Samples */
 	ROM_LOAD( "u64.bin",  0x000000, 0x080000, CRC(e187ed4f) SHA1(05060723d89b1d05714447a14b5f5888ff3c2306) )
 
-	ROM_REGION( 0x100000, REGION_SOUND2, ROMREGION_SOUNDONLY )	/* ADPCM Samples */
+	ROM_REGION( 0x100000, REGION_SOUND2, 0 )	/* ADPCM Samples */
 	ROM_LOAD( "u56.bin",  0x000000, 0x100000, CRC(9e07104d) SHA1(3bc54cb755bb3194197706965b532d62b48c4d12) )
 
 	ROM_REGION( 0x040000, REGION_USER1, 0 )	/* Sprites LUT */
@@ -1904,10 +1931,10 @@ ROM_START( gunbirdj )
 	ROM_REGION( 0x200000, REGION_GFX2, ROMREGION_DISPOSE )	/* Layers 0 + 1 */
 	ROM_LOAD( "u33.bin",  0x000000, 0x200000, CRC(54494e6b) SHA1(f5d090d2d34d908b56b53a246def194929eba990) )
 
-	ROM_REGION( 0x080000, REGION_SOUND1, ROMREGION_SOUNDONLY )	/* DELTA-T Samples */
+	ROM_REGION( 0x080000, REGION_SOUND1, 0 )	/* DELTA-T Samples */
 	ROM_LOAD( "u64.bin",  0x000000, 0x080000, CRC(e187ed4f) SHA1(05060723d89b1d05714447a14b5f5888ff3c2306) )
 
-	ROM_REGION( 0x100000, REGION_SOUND2, ROMREGION_SOUNDONLY )	/* ADPCM Samples */
+	ROM_REGION( 0x100000, REGION_SOUND2, 0 )	/* ADPCM Samples */
 	ROM_LOAD( "u56.bin",  0x000000, 0x100000, CRC(9e07104d) SHA1(3bc54cb755bb3194197706965b532d62b48c4d12) )
 
 	ROM_REGION( 0x040000, REGION_USER1, 0 )	/* Sprites LUT */
@@ -1935,10 +1962,10 @@ ROM_START( btlkroad )
 	ROM_REGION( 0x200000, REGION_GFX2, ROMREGION_DISPOSE )	/* Layers 0 + 1 */
 	ROM_LOAD( "u33.bin",  0x000000, 0x200000, CRC(4c8577f1) SHA1(d27043514632954a06667ac63f4a4e4a31870511) )
 
-	ROM_REGION( 0x080000, REGION_SOUND1, ROMREGION_SOUNDONLY )	/* DELTA-T Samples */
+	ROM_REGION( 0x080000, REGION_SOUND1, 0 )	/* DELTA-T Samples */
 	ROM_LOAD( "u64.bin",  0x000000, 0x080000, CRC(0f33049f) SHA1(ca4fd5f3906685ace1af40b75f5678231d7324e8) )
 
-	ROM_REGION( 0x100000, REGION_SOUND2, ROMREGION_SOUNDONLY )	/* ADPCM Samples */
+	ROM_REGION( 0x100000, REGION_SOUND2, 0 )	/* ADPCM Samples */
 	ROM_LOAD( "u56.bin",  0x000000, 0x100000, CRC(51d73682) SHA1(562038d08e9a4389ffa39f3a659b2a29b94dc156) )
 
 	ROM_REGION( 0x040000, REGION_USER1, 0 )	/* Sprites LUT */
@@ -1995,10 +2022,10 @@ ROM_START( s1945jn )
 	ROM_REGION( 0x200000, REGION_GFX2, ROMREGION_DISPOSE )	/* Layer 0 + 1 */
 	ROM_LOAD( "u34.bin",  0x000000, 0x200000, CRC(aaf83e23) SHA1(1c75d09ff42c0c215f8c66c699ca75688c95a05e) )
 
-	ROM_REGION( 0x080000, REGION_SOUND1, ROMREGION_SOUNDONLY )	/* DELTA-T Samples */
+	ROM_REGION( 0x080000, REGION_SOUND1, 0 )	/* DELTA-T Samples */
 	ROM_LOAD( "u64.bin",  0x000000, 0x080000, CRC(a44a4a9b) SHA1(5378256752d709daed0b5f4199deebbcffe84e10) )
 
-	ROM_REGION( 0x100000, REGION_SOUND2, ROMREGION_SOUNDONLY )	/* ADPCM Samples */
+	ROM_REGION( 0x100000, REGION_SOUND2, 0 )	/* ADPCM Samples */
 	ROM_LOAD( "u56.bin",  0x000000, 0x100000, CRC(fe1312c2) SHA1(8339a96a0885518d6e22cb3bdb9c2f82d011d86d) )
 
 	ROM_REGION( 0x040000, REGION_USER1, 0 )	/* */
@@ -2052,7 +2079,7 @@ ROM_START( s1945 )
 	ROM_RELOAD(            0x10000, 0x20000             )
 
 	ROM_REGION( 0x000100, REGION_CPU3, 0 )		/* MCU? */
-	 /* ROM_LOAD( "4-u59.bin", 0x00000, 0x00100, NO_DUMP ) */
+	ROM_LOAD( "4-u59.bin", 0x00000, 0x00100, NO_DUMP )
 
 	ROM_REGION( 0x800000, REGION_GFX1, ROMREGION_DISPOSE )	/* Sprites */
 	ROM_LOAD( "u20.bin",  0x000000, 0x200000, CRC(28a27fee) SHA1(913f3bc4d0c6fb6b776a020c8099bf96f16fd06f) )
@@ -2063,7 +2090,7 @@ ROM_START( s1945 )
 	ROM_REGION( 0x200000, REGION_GFX2, ROMREGION_DISPOSE )	/* Layer 0 + 1 */
 	ROM_LOAD( "u34.bin",  0x000000, 0x200000, CRC(aaf83e23) SHA1(1c75d09ff42c0c215f8c66c699ca75688c95a05e) )
 
-	ROM_REGION( 0x200000, REGION_SOUND1, ROMREGION_SOUNDONLY )	/* Samples */
+	ROM_REGION( 0x200000, REGION_SOUND1, 0 )	/* Samples */
 	ROM_LOAD( "u61.bin",  0x000000, 0x200000, CRC(a839cf47) SHA1(e179eb505c80d5bb3ccd9e228f2cf428c62b72ee) )	/* 8 bit signed pcm (16KHz) */
 
 	ROM_REGION( 0x040000, REGION_USER1, 0 )	/* */
@@ -2082,7 +2109,7 @@ ROM_START( s1945a )
 	ROM_RELOAD(            0x10000, 0x20000             )
 
 	ROM_REGION( 0x000100, REGION_CPU3, 0 )		/* MCU? */
-	 /* ROM_LOAD( "4-u59.bin", 0x00000, 0x00100, NO_DUMP ) */
+	ROM_LOAD( "4-u59.bin", 0x00000, 0x00100, NO_DUMP )
 
 	ROM_REGION( 0x800000, REGION_GFX1, ROMREGION_DISPOSE )	/* Sprites */
 	ROM_LOAD( "u20.bin",  0x000000, 0x200000, CRC(28a27fee) SHA1(913f3bc4d0c6fb6b776a020c8099bf96f16fd06f) )
@@ -2093,7 +2120,7 @@ ROM_START( s1945a )
 	ROM_REGION( 0x200000, REGION_GFX2, ROMREGION_DISPOSE )	/* Layer 0 + 1 */
 	ROM_LOAD( "u34.bin",  0x000000, 0x200000, CRC(aaf83e23) SHA1(1c75d09ff42c0c215f8c66c699ca75688c95a05e) )
 
-	ROM_REGION( 0x200000, REGION_SOUND1, ROMREGION_SOUNDONLY )	/* Samples */
+	ROM_REGION( 0x200000, REGION_SOUND1, 0 )	/* Samples */
 	ROM_LOAD( "u61.bin",  0x000000, 0x200000, CRC(a839cf47) SHA1(e179eb505c80d5bb3ccd9e228f2cf428c62b72ee) )	/* 8 bit signed pcm (16KHz) */
 
 	ROM_REGION( 0x040000, REGION_USER1, 0 )	/* */
@@ -2112,7 +2139,7 @@ ROM_START( s1945j )
 	ROM_RELOAD(            0x10000, 0x20000             )
 
 	ROM_REGION( 0x000100, REGION_CPU3, 0 )		/* MCU */
-	 /* ROM_LOAD( "4-u59.bin", 0x00000, 0x00100, NO_DUMP ) */
+	ROM_LOAD( "4-u59.bin", 0x00000, 0x00100, NO_DUMP )
 
 	ROM_REGION( 0x800000, REGION_GFX1, ROMREGION_DISPOSE )	/* Sprites */
 	ROM_LOAD( "u20.bin",  0x000000, 0x200000, CRC(28a27fee) SHA1(913f3bc4d0c6fb6b776a020c8099bf96f16fd06f) )
@@ -2123,7 +2150,7 @@ ROM_START( s1945j )
 	ROM_REGION( 0x200000, REGION_GFX2, ROMREGION_DISPOSE )	/* Layer 0 + 1 */
 	ROM_LOAD( "u34.bin",  0x000000, 0x200000, CRC(aaf83e23) SHA1(1c75d09ff42c0c215f8c66c699ca75688c95a05e) )
 
-	ROM_REGION( 0x200000, REGION_SOUND1, ROMREGION_SOUNDONLY )	/* Samples */
+	ROM_REGION( 0x200000, REGION_SOUND1, 0 )	/* Samples */
 	ROM_LOAD( "u61.bin",  0x000000, 0x200000, CRC(a839cf47) SHA1(e179eb505c80d5bb3ccd9e228f2cf428c62b72ee) )	/* 8 bit signed pcm (16KHz) */
 
 	ROM_REGION( 0x040000, REGION_USER1, 0 )	/* */
@@ -2176,6 +2203,7 @@ DRIVER_INIT( s1945j )
 	psikyo_ka302c_banking = 0; /* Banking is controlled by mcu */
 }
 
+
 /***************************************************************************
 
                                 Tengai (World) / Sengoku Blade (Japan)
@@ -2208,7 +2236,7 @@ ROM_START( tengai )
 	ROM_RELOAD(            0x10000, 0x20000             )
 
 	ROM_REGION( 0x000100, REGION_CPU3, 0 )		/* MCU */
-	/*  ROM_LOAD( "4-u59.bin", 0x00000, 0x00100, NO_DUMP ) */
+	ROM_LOAD( "4-u59.bin", 0x00000, 0x00100, NO_DUMP )
 
 	ROM_REGION( 0x600000, REGION_GFX1, ROMREGION_DISPOSE )	/* Sprites */
 	ROM_LOAD16_WORD_SWAP( "u20.bin",  0x000000, 0x200000, CRC(ed42ef73) SHA1(74693fcc83a2654ddb18fd513d528033863d6116) )
@@ -2218,7 +2246,7 @@ ROM_START( tengai )
 	ROM_REGION( 0x400000, REGION_GFX2, ROMREGION_DISPOSE )	/* Layer 0 + 1 */
 	ROM_LOAD16_WORD_SWAP( "u34.bin",  0x000000, 0x400000, CRC(2a2e2eeb) SHA1(f1d99353c0affc5c908985e6f2a5724e5223cccc) ) /* four banks of 0x100000 */
 
-	ROM_REGION( 0x400000, REGION_SOUND1, ROMREGION_SOUNDONLY )	/* Samples */
+	ROM_REGION( 0x400000, REGION_SOUND1, 0 )	/* Samples */
 	ROM_LOAD( "u61.bin",  0x000000, 0x200000, CRC(a63633c5) SHA1(89e75a40518926ebcc7d88dea86c01ba0bb496e5) )	/* 8 bit signed pcm (16KHz) */
 	ROM_LOAD( "u62.bin",  0x200000, 0x200000, CRC(3ad0c357) SHA1(35f78cfa2eafa93ab96b24e336f569ee84af06b6) )
 
