@@ -3,20 +3,21 @@
    driver by David Haywood (+ Paul Priest)
 ------------------------------------------------------------------
 
-Moving on from the 68020 based system used for the first Strikers
-1945 game Psikyo introduced a system using Hitachi's SH-2 CPU
-
-This driver is for the dual-screen PS4 boards
+This driver is for the dual-screen PS4 boards using an SH-2 processor
 
  Board PS4 (Custom Chip PS6807)
  ------------------------------
  Taisen Hot Gimmick (c)1997
  Taisen Hot Gimmick Kairakuten (c)1998
  Taisen Hot Gimmick 3 Digital Surfing (c)1999
- Taisen Hot Gimmick 4 Ever (c)2000 (confirmed by Japump)
  Lode Runner - The Dig Fight (c)2000
  Quiz de Idol! Hot Debut (c)2000
 
+ Incomplete Dumps
+ Taisen Hot Gimmick 4 Ever (c)2000 (confirmed by Japump)
+ Taisen Hot Gimmick Integral (c)2001 (confirmed by Yahoo! Japan auction)
+
+
  The PS4 board appears to be a cheaper board than PS3/5/5v2, with only simple sprites, no bgs,
  smaller palette etc, only 8bpp sprites too.
  Supports dual-screen though.
@@ -48,23 +49,17 @@ Quiz de Idol! Hot Debut:       PL1 Start (passes)
 
 5-0-8-2-0 Maintenance Mode
 
-You can switch the game to English temporarily.
-
-Or use these cheats:
-:loderndf:00000000:0600A533:00000001:FFFFFFFF:Language = English
-:loderdfa:00000000:0600A473:00000001:FFFFFFFF:Language = English
-
 --- Quiz de Idol! Hot Debut ---
 
 9-2-3-0-1 Maintenance Mode
 
+NOTE: The version number (A/B) on Lode Runner: The Dig Fight is ONLY displayed when the game is set
+      to Japanese.  The same is true for Space Bomber in psikyosh.c
+
 ----------------------------------------------------------------*/
 
 #include "driver.h"
-#include "state.h"
-#include "cpuintrf.h"
 
-#include "vidhrdw/generic.h"
 #include "cpu/sh2/sh2.h"
 #include "machine/eeprom.h"
 #include "sound/ymf278b.h"
@@ -72,8 +67,9 @@ Or use these cheats:
 #define DUAL_SCREEN 1 /* Display both screens simultaneously if 1, change in vidhrdw too */
 #define ROMTEST 0 /* Does necessary stuff to perform rom test, uses RAM as it doesn't dispose of GFX after decoding */
 
-data32_t *psikyo4_vidregs, *ps4_ram, *ps4_io_select;
-data32_t *bgpen_1, *bgpen_2, *screen1_brt, *screen2_brt;
+UINT32 *psikyo4_vidregs;
+static UINT32 *ps4_ram, *ps4_io_select;
+static UINT32 *bgpen_1, *bgpen_2;
 
 #define MASTER_CLOCK 57272700	/* main oscillator frequency */
 
@@ -81,7 +77,7 @@ data32_t *bgpen_1, *bgpen_2, *screen1_brt, *screen2_brt;
 VIDEO_START( psikyo4 );
 VIDEO_UPDATE( psikyo4 );
 
-static struct GfxLayout layout_16x16x8 =
+static const gfx_layout layout_16x16x8 =
 {
 	16,16,
 	RGN_FRAC(1,1),
@@ -92,7 +88,7 @@ static struct GfxLayout layout_16x16x8 =
 	16*16*8
 };
 
-static struct GfxDecodeInfo gfxdecodeinfops4[] =
+static const gfx_decode gfxdecodeinfops4[] =
 {
 	{ REGION_GFX1, 0, &layout_16x16x8, 0x000, 0x80 }, /* 8bpp tiles */
 	{ -1 }
@@ -156,9 +152,9 @@ static READ32_HANDLER( ps4_eeprom_r )
 		return ((EEPROM_read_bit() << 20)); /* EEPROM */
 	}
 
-	logerror("Unk EEPROM read mask %x\n", mem_mask);
+/*  logerror("Unk EEPROM read mask %x\n", mem_mask); */
 
-	return 0;
+	return readinputportbytag("JP4")<<16;
 }
 
 static INTERRUPT_GEN(psikyosh_interrupt)
@@ -284,7 +280,7 @@ static WRITE32_HANDLER( ps4_vidregs_w )
 		if (!(mem_mask & 0x000000ff) || !(mem_mask & 0x0000ff00))	/* Bank */
 		{
 			unsigned char *ROM = memory_region(REGION_GFX1);
-			cpu_setbank(2,&ROM[0x2000 * (psikyo4_vidregs[offset]&0xfff)]); /* Bank comes from vidregs */
+			memory_set_bankptr(2,&ROM[0x2000 * (psikyo4_vidregs[offset]&0xfff)]); /* Bank comes from vidregs */
 		}
 	}
 #endif
@@ -349,6 +345,34 @@ static WRITE32_HANDLER( psh_ymf_pcm_w )
 	}
 }
 
+#define PCM_BANK_NO(n)	((ps4_io_select[0] >> (n * 4 + 24)) & 0x07)
+
+static void set_hotgmck_pcm_bank(int n)
+{
+	UINT8 *ymf_pcmbank = memory_region(REGION_SOUND1) + 0x200000;
+	UINT8 *pcm_rom = memory_region(REGION_SOUND2);
+
+	memcpy(ymf_pcmbank + n * 0x100000, pcm_rom + PCM_BANK_NO(n) * 0x100000, 0x100000);
+}
+
+static WRITE32_HANDLER( hotgmck_pcm_bank_w )
+{
+	int old_bank0 = PCM_BANK_NO(0);
+	int old_bank1 = PCM_BANK_NO(1);
+	int new_bank0, new_bank1;
+
+	COMBINE_DATA(&ps4_io_select[0]);
+
+	new_bank0 = PCM_BANK_NO(0);
+	new_bank1 = PCM_BANK_NO(1);
+
+	if (old_bank0 != new_bank0)
+		set_hotgmck_pcm_bank(0);
+
+	if (old_bank1 != new_bank1)
+		set_hotgmck_pcm_bank(1);
+}
+
 static ADDRESS_MAP_START( ps4_readmem, ADDRESS_SPACE_PROGRAM, 32 )
 	AM_RANGE(0x00000000, 0x000fffff) AM_READ(MRA32_ROM)	/* program ROM (1 meg) */
 	AM_RANGE(0x02000000, 0x021fffff) AM_READ(MRA32_BANK1) /* data ROM */
@@ -410,7 +434,7 @@ static MACHINE_DRIVER_START( ps4big )
 	MDRV_NVRAM_HANDLER(93C56)
 
 	/* video hardware */
-	MDRV_VIDEO_ATTRIBUTES(VIDEO_TYPE_RASTER | VIDEO_NEEDS_6BITS_PER_GUN | VIDEO_DUAL_MONITOR)
+	MDRV_VIDEO_ATTRIBUTES(VIDEO_TYPE_RASTER | VIDEO_NEEDS_6BITS_PER_GUN)
 #if DUAL_SCREEN
 	MDRV_ASPECT_RATIO(8,3)
 	MDRV_SCREEN_SIZE(80*8, 32*8)
@@ -563,6 +587,9 @@ INPUT_PORTS_START( hotgmck )
 	PORT_BIT(  0x02, IP_ACTIVE_HIGH, IPT_BUTTON2 ) PORT_NAME("Select PL2 Screen") PORT_CODE(KEYCODE_EQUALS)
 	PORT_BIT(   0xfc, IP_ACTIVE_LOW, IPT_UNUSED )
 #endif
+
+	PORT_START_TAG("JP4")/* jumper pads 'JP4' on the PCB */
+	UNUSED_PORT
 INPUT_PORTS_END
 
 INPUT_PORTS_START( loderndf )
@@ -639,6 +666,13 @@ INPUT_PORTS_START( loderndf )
 	PORT_BIT(  0x02, IP_ACTIVE_HIGH, IPT_BUTTON2 ) PORT_NAME("Select PL3+PL4 Screen") PORT_CODE(KEYCODE_EQUALS)
 	PORT_BIT(   0xfc, IP_ACTIVE_LOW, IPT_UNUSED )
 #endif
+
+	PORT_START_TAG("JP4")/* jumper pads 'JP4' on the PCB */
+/*  1-ON,2-ON,3-ON,4-ON  --> Japanese */
+/*  1-ON,2-ON,3-ON,4-OFF --> English */
+	PORT_DIPNAME( 0x03, 0x01, DEF_STR( Region ) )
+	PORT_DIPSETTING(    0x00, "Japan (Shows Version Number)" )
+	PORT_DIPSETTING(    0x01, "World (Does Not Show Version Number)" )
 INPUT_PORTS_END
 
 /* unused inputs also act as duplicate buttons */
@@ -716,6 +750,9 @@ INPUT_PORTS_START( hotdebut )
 	PORT_BIT(  0x02, IP_ACTIVE_HIGH, IPT_BUTTON2 ) PORT_NAME("Select PL3+PL4 Screen") PORT_CODE(KEYCODE_EQUALS)
 	PORT_BIT(   0xfc, IP_ACTIVE_LOW, IPT_UNUSED )
 #endif
+
+	PORT_START_TAG("JP4")/* jumper pads 'JP4' on the PCB */
+	UNUSED_PORT
 INPUT_PORTS_END
 
 #if ROMTEST
@@ -741,7 +778,9 @@ ROM_START( hotgmck )
 	ROM_LOAD32_WORD( "3l.bin", 0x1800000, 0x400000, CRC(a8a646f7) SHA1(be96626f3a4c8eb81f0bb7d8ac1c4e6619be50c8) )
 	ROM_LOAD32_WORD( "3h.bin", 0x1800002, 0x400000, CRC(8c32becd) SHA1(9a8ddda4c6c007bb5cd4abb11859a4b7f1b1d578) )
 
-	ROM_REGION( 0x800000, REGION_SOUND1, 0 )
+	ROM_REGION( 0x400000, REGION_SOUND1, ROMREGION_ERASE00 )
+
+	ROM_REGION( 0x800000, REGION_SOUND2, 0 )
 	ROM_LOAD( "snd0.bin", 0x000000, 0x400000, CRC(c090d51a) SHA1(d229753b536209fe0da1985ca694fd1a73bc0f39) )
 	ROM_LOAD( "snd1.bin", 0x400000, 0x400000, CRC(c24243b5) SHA1(2100d5d7d2e4b9ed90bde38cb61a5da09f00ce21) )
 ROM_END
@@ -766,7 +805,9 @@ ROM_START( hgkairak )
 	ROM_LOAD32_WORD( "5l.u7",  0x2800000, 0x400000, CRC(4639ef36) SHA1(324ffcfa1b1b9def00c15f628c59cea1d09b031d) )
 	ROM_LOAD32_WORD( "5h.u16", 0x2800002, 0x400000, CRC(549e9e9e) SHA1(90c1695c89c059852f8b4f714b3dfee006839b44) )
 
-	ROM_REGION( 0x800000, REGION_SOUND1, 0 )
+	ROM_REGION( 0x400000, REGION_SOUND1, ROMREGION_ERASE00 )
+
+	ROM_REGION( 0x800000, REGION_SOUND2, 0 )
 	ROM_LOAD( "snd0.u10", 0x000000, 0x400000, CRC(0e8e5fdf) SHA1(041e3118f7a838dcc9fb99a1028fb48a452ba1d9) )
 	ROM_LOAD( "snd1.u19", 0x400000, 0x400000, CRC(d8057d2f) SHA1(51d96cc4e9da81cbd1e815c652707407e6c7c3ae) )
 ROM_END
@@ -796,11 +837,85 @@ ROM_START( hotgmck3 )
 	ROM_LOAD32_WORD( "7l.u9",  0x3800000, 0x400000, CRC(2ec78fb2) SHA1(194e9833ab7057c2f83c581e722b41631d99fccc) )
 	ROM_LOAD32_WORD( "7h.u18", 0x3800002, 0x400000, CRC(c1735612) SHA1(84e32d3249d57cdc8ea91780801eaa196c439895) )
 
-	ROM_REGION( 0x800000, REGION_SOUND1, 0 )
+	ROM_REGION( 0x400000, REGION_SOUND1, ROMREGION_ERASE00 )
+
+	ROM_REGION( 0x800000, REGION_SOUND2, 0 )
 	ROM_LOAD( "snd0.u10", 0x000000, 0x400000, CRC(d62a0dba) SHA1(d81e2e1251b62eca8cd4d8eec2515b2cf7d7ff0a) )
 	ROM_LOAD( "snd1.u19", 0x400000, 0x400000, CRC(1df91fb4) SHA1(f0f2d2d717fbd16a67da9f0e21f288ceedef839f) )
 ROM_END
 
+ROM_START( hotgm4ev )
+	/* main program */
+	ROM_REGION( 0x300000, REGION_CPU1, 0)
+	ROM_LOAD32_WORD_SWAP( "2.u22",   0x000000, 0x080000, CRC(3334c21e) SHA1(8d825448e40bc50d670ab8587a40df6b27ac918e) )
+	ROM_LOAD32_WORD_SWAP( "1.u23",   0x000002, 0x080000, CRC(b1a1c643) SHA1(1912a2d231e97ffbe9b668ca7f25cf406664f3ba) )
+	/* not dumped yet */
+    ROM_LOAD16_WORD_SWAP( "prog.u1", 0x100000, 0x100000, NO_DUMP )
+
+	ROM_REGION( 0x4000000, REGION_GFX1, ROMTEST_GFX )	/* Sprites */
+	/* not dumped yet */
+    ROM_LOAD32_WORD( "0l.u2",  0x0000000, 0x400000, NO_DUMP )
+    ROM_LOAD32_WORD( "0h.u11", 0x0000002, 0x400000, NO_DUMP )
+    ROM_LOAD32_WORD( "1l.u3",  0x0800000, 0x400000, NO_DUMP )
+    ROM_LOAD32_WORD( "1h.u12", 0x0800002, 0x400000, NO_DUMP )
+    ROM_LOAD32_WORD( "2l.u4",  0x1000000, 0x400000, NO_DUMP )
+    ROM_LOAD32_WORD( "2h.u13", 0x1000002, 0x400000, NO_DUMP )
+    ROM_LOAD32_WORD( "3l.u5",  0x1800000, 0x400000, NO_DUMP )
+    ROM_LOAD32_WORD( "3h.u14", 0x1800002, 0x400000, NO_DUMP )
+    ROM_LOAD32_WORD( "4l.u6",  0x2000000, 0x400000, NO_DUMP )
+    ROM_LOAD32_WORD( "4h.u15", 0x2000002, 0x400000, NO_DUMP )
+    ROM_LOAD32_WORD( "5l.u7",  0x2800000, 0x400000, NO_DUMP )
+    ROM_LOAD32_WORD( "5h.u16", 0x2800002, 0x400000, NO_DUMP )
+    ROM_LOAD32_WORD( "6l.u8",  0x3000000, 0x400000, NO_DUMP )
+    ROM_LOAD32_WORD( "6h.u17", 0x3000002, 0x400000, NO_DUMP )
+    ROM_LOAD32_WORD( "7l.u9",  0x3800000, 0x400000, NO_DUMP )
+    ROM_LOAD32_WORD( "7h.u18", 0x3800002, 0x400000, NO_DUMP )
+
+	ROM_REGION( 0x400000, REGION_SOUND1, ROMREGION_ERASE00 )
+
+	ROM_REGION( 0x800000, REGION_SOUND2, 0 )
+	/* not dumped yet */
+    ROM_LOAD( "snd0.u10", 0x000000, 0x400000, NO_DUMP )
+    ROM_LOAD( "snd1.u19", 0x400000, 0x400000, NO_DUMP )
+ROM_END
+
+ROM_START( hotgmcki )
+	/* main program */
+	ROM_REGION( 0x300000, REGION_CPU1, 0)
+	ROM_LOAD32_WORD_SWAP( "2.u22",   0x000000, 0x080000, CRC(abc192dd) SHA1(674c2b8814319605c1b6221bbe18588a98dda093) )
+	ROM_LOAD32_WORD_SWAP( "1.u23",   0x000002, 0x080000, CRC(8be896d0) SHA1(5d677dede4ec18cbfc54acae95fe0f10bfc4d566) )
+	/* not dumped yet */
+    ROM_LOAD16_WORD_SWAP( "prog.u1", 0x100000, 0x100000, NO_DUMP )
+
+	/* exact number & size of gfx / sound roms may be incorrect */
+	ROM_REGION( 0x4000000, REGION_GFX1, ROMTEST_GFX )	/* Sprites */
+	/* not dumped yet */
+    ROM_LOAD32_WORD( "0l.u2",  0x0000000, 0x400000, NO_DUMP )
+    ROM_LOAD32_WORD( "0h.u11", 0x0000002, 0x400000, NO_DUMP )
+    ROM_LOAD32_WORD( "1l.u3",  0x0800000, 0x400000, NO_DUMP )
+    ROM_LOAD32_WORD( "1h.u12", 0x0800002, 0x400000, NO_DUMP )
+    ROM_LOAD32_WORD( "2l.u4",  0x1000000, 0x400000, NO_DUMP )
+    ROM_LOAD32_WORD( "2h.u13", 0x1000002, 0x400000, NO_DUMP )
+    ROM_LOAD32_WORD( "3l.u5",  0x1800000, 0x400000, NO_DUMP )
+    ROM_LOAD32_WORD( "3h.u14", 0x1800002, 0x400000, NO_DUMP )
+    ROM_LOAD32_WORD( "4l.u6",  0x2000000, 0x400000, NO_DUMP )
+    ROM_LOAD32_WORD( "4h.u15", 0x2000002, 0x400000, NO_DUMP )
+    ROM_LOAD32_WORD( "5l.u7",  0x2800000, 0x400000, NO_DUMP )
+    ROM_LOAD32_WORD( "5h.u16", 0x2800002, 0x400000, NO_DUMP )
+    ROM_LOAD32_WORD( "6l.u8",  0x3000000, 0x400000, NO_DUMP )
+    ROM_LOAD32_WORD( "6h.u17", 0x3000002, 0x400000, NO_DUMP )
+    ROM_LOAD32_WORD( "7l.u9",  0x3800000, 0x400000, NO_DUMP )
+    ROM_LOAD32_WORD( "7h.u18", 0x3800002, 0x400000, NO_DUMP )
+
+	ROM_REGION( 0x400000, REGION_SOUND1, ROMREGION_ERASE00 )
+
+	ROM_REGION( 0x800000, REGION_SOUND2, 0 )
+	/* not dumped yet */
+    ROM_LOAD( "snd0.u10", 0x000000, 0x400000, NO_DUMP )
+    ROM_LOAD( "snd1.u19", 0x400000, 0x400000, NO_DUMP )
+ROM_END
+
+
 ROM_START( loderndf )
 	ROM_REGION( 0x100000, REGION_CPU1, 0)
 	ROM_LOAD32_WORD_SWAP( "1b.u23", 0x000002, 0x080000, CRC(fae92286) SHA1(c3d3a50514fb9c0bbd3ffb5c4bfcc853dc1893d2) )
@@ -812,7 +927,7 @@ ROM_START( loderndf )
 	ROM_LOAD32_WORD( "1l.u3",  0x1000000, 0x800000, CRC(7a9cd21e) SHA1(dfb36625c2aae3e774ec2451051b7038e0767b6d) )
 	ROM_LOAD32_WORD( "1h.u12", 0x1000002, 0x800000, CRC(78f40d0d) SHA1(243acb73a183a41a3e35a2c746ad31dd6fcd3ef4) )
 
-	ROM_REGION( 0x800000, REGION_SOUND1, 0 )
+	ROM_REGION( 0x800000, REGION_SOUND1, ROMREGION_ERASE00 )
 	ROM_LOAD( "snd0.u10", 0x000000, 0x800000, CRC(2da3788f) SHA1(199d4d750a107cbdf8c16cd5b097171743769d9c) ) /* Fails hidden rom test */
 ROM_END
 
@@ -827,7 +942,7 @@ ROM_START( loderdfa )
 	ROM_LOAD32_WORD( "1l.u3",  0x1000000, 0x800000, CRC(7a9cd21e) SHA1(dfb36625c2aae3e774ec2451051b7038e0767b6d) )
 	ROM_LOAD32_WORD( "1h.u12", 0x1000002, 0x800000, CRC(78f40d0d) SHA1(243acb73a183a41a3e35a2c746ad31dd6fcd3ef4) )
 
-	ROM_REGION( 0x800000, REGION_SOUND1, 0 )
+	ROM_REGION( 0x800000, REGION_SOUND1, ROMREGION_ERASE00 )
 	ROM_LOAD( "snd0.u10", 0x000000, 0x800000, CRC(2da3788f) SHA1(199d4d750a107cbdf8c16cd5b097171743769d9c) ) /* Fails hidden rom test */
 ROM_END
 
@@ -844,7 +959,7 @@ ROM_START( hotdebut )
 	ROM_LOAD32_WORD( "2l.u4",  0x1000000, 0x400000, CRC(9d2d1bb1) SHA1(33b41aa50be3040871b6dc6faee0bd99c5e46cd3) )
 	ROM_LOAD32_WORD( "2h.u13", 0x1000002, 0x400000, CRC(a7753c4d) SHA1(adb33de478064cc9255d1bb5c63acc5d8bfbb8eb) )
 
-	ROM_REGION( 0x400000, REGION_SOUND1, 0 )
+	ROM_REGION( 0x400000, REGION_SOUND1, ROMREGION_ERASE00 )
 	ROM_LOAD( "snd0.u10", 0x000000, 0x400000, CRC(eef28aa7) SHA1(d10d3f62a2e4c2a8e5fccece9c272f8ead50e5ed) )
 ROM_END
 
@@ -901,11 +1016,28 @@ PC  :000029F8: BT      $000029EC
 	return ps4_ram[0x00001c/4];
 }
 
+static void install_hotgmck_pcm_bank(void)
+{
+	UINT8 *ymf_pcm = memory_region(REGION_SOUND1);
+	UINT8 *pcm_rom = memory_region(REGION_SOUND2);
+
+	memcpy(ymf_pcm, pcm_rom, 0x200000);
+
+	ps4_io_select[0] = (ps4_io_select[0] & 0x00ffffff) | 0x32000000;
+	set_hotgmck_pcm_bank(0);
+	set_hotgmck_pcm_bank(1);
+
+	memory_install_write32_handler(0, ADDRESS_SPACE_PROGRAM, 0x5800008, 0x580000b, 0, 0, hotgmck_pcm_bank_w );
+	state_save_register_func_postload_int(set_hotgmck_pcm_bank, 0);
+	state_save_register_func_postload_int(set_hotgmck_pcm_bank, 1);
+}
+
 static DRIVER_INIT( hotgmck )
 {
 	unsigned char *RAM = memory_region(REGION_CPU1);
-	cpu_setbank(1,&RAM[0x100000]);
+	memory_set_bankptr(1,&RAM[0x100000]);
 	memory_install_read32_handler(0, ADDRESS_SPACE_PROGRAM, 0x5800000, 0x5800007, 0, 0, hotgmck_io32_r ); /* Different Inputs */
+	install_hotgmck_pcm_bank();	/* Banked PCM ROM */
 }
 
 static DRIVER_INIT( loderndf )
@@ -926,9 +1058,11 @@ static DRIVER_INIT( hotdebut )
 
 /*     YEAR  NAME      PARENT    MACHINE    INPUT     INIT      MONITOR COMPANY   FULLNAME FLAGS */
 
-GAMEX( 1997, hotgmck,  0,        ps4big,    hotgmck,  hotgmck,  ROT0,   "Psikyo", "Taisen Hot Gimmick (Japan)", GAME_IMPERFECT_SOUND )
-GAMEX( 1998, hgkairak, 0,        ps4big,    hotgmck,  hotgmck,  ROT0,   "Psikyo", "Taisen Hot Gimmick Kairakuten (Japan)", GAME_IMPERFECT_SOUND )
-GAMEX( 1999, hotgmck3, 0,        ps4big,    hotgmck,  hotgmck,  ROT0,   "Psikyo", "Taisen Hot Gimmick 3 Digital Surfing (Japan)", GAME_IMPERFECT_SOUND )
-GAME ( 2000, loderndf, 0,        ps4small,  loderndf, loderndf, ROT0,   "Psikyo", "Lode Runner - The Dig Fight (ver. B) (Japan)" )
-GAME ( 2000, loderdfa, loderndf, ps4small,  loderndf, loderdfa, ROT0,   "Psikyo", "Lode Runner - The Dig Fight (ver. A) (Japan)" )
-GAME ( 2000, hotdebut, 0,        ps4small,  hotdebut, hotdebut, ROT0,   "Psikyo / Moss", "Quiz de Idol! Hot Debut (Japan)" )
+GAME( 1997, hotgmck,  0,        ps4big,    hotgmck,  hotgmck,  ROT0,   "Psikyo", "Taisen Hot Gimmick (Japan)", 0 )
+GAME( 1998, hgkairak, 0,        ps4big,    hotgmck,  hotgmck,  ROT0,   "Psikyo", "Taisen Hot Gimmick Kairakuten (Japan)", 0 )
+GAME( 1999, hotgmck3, 0,        ps4big,    hotgmck,  hotgmck,  ROT0,   "Psikyo", "Taisen Hot Gimmick 3 Digital Surfing (Japan)", 0 )
+GAME( 2000, hotgm4ev, 0,        ps4big,    hotgmck,  hotgmck,  ROT0,   "Psikyo", "Taisen Hot Gimmick 4 Ever (Japan)", GAME_NOT_WORKING )
+GAME( 2001, hotgmcki, 0,        ps4big,    hotgmck,  hotgmck,  ROT0,   "Psikyo", "Taisen Hot Gimmick Integral (Japan)", GAME_NOT_WORKING )
+GAME( 2000, loderndf, 0,        ps4small,  loderndf, loderndf, ROT0,   "Psikyo", "Lode Runner - The Dig Fight (ver. B)", 0 )
+GAME( 2000, loderdfa, loderndf, ps4small,  loderndf, loderdfa, ROT0,   "Psikyo", "Lode Runner - The Dig Fight (ver. A)", 0 )
+GAME( 2000, hotdebut, 0,        ps4small,  hotdebut, hotdebut, ROT0,   "Psikyo / Moss", "Quiz de Idol! Hot Debut (Japan)", 0 )
