@@ -32,6 +32,7 @@ There appear to be multiple revisions of this board
  Tetris The Grand Master 2 (c)2000
  Tetris The Grand Master 2 Plus (c)2000 (Confirmed by Japump to be a Dragon Blaze upgraded board)
  GunBarich (c)2001 (Appears to be a Dragon Blaze upgraded board, easily replaced chips have been swapped)
+ Mahjong G-Taste (c)2002
 
  The PS5v2 board is only different physically.
 
@@ -60,7 +61,7 @@ Daraku:           PL1 Button 1 (passes, doesn't test sound)
 Space Bomber:     PL1 Start (passes all, only if bit 0x40 is set. But then EEPROM resets?)
 Gunbird 2:        PL1 Start (passes all, only if bit 0x40 is set. But then EEPROM resets)
 Strikers 1945III: PL1 Start (passes all, only if bit 0x40 is set)
-Dragon Blaze:     PL1 Start (fails on undumped sample rom, bit 0x40 has to be set anyway)
+Dragon Blaze:     PL1 Start (passes all, only if bit 0x40 is set)
 Gunbarich:        PL1 Start (passes all, only if bit 0x40 is set)
 
 
@@ -116,32 +117,179 @@ TAKO-8
 0-2-9-1-0 All Data Initialised
 1-2-3-4-5 Best Score Erased
 
+--- Tetris The Grand Master 2 / TGM2+ ---
+
+4-1-5-7-3 All Data Initialised
+4-1-7-6-5 Best Score Erased
+
+The following 4 are also tested for, but appear to be disabled:
+1-3-5-7-9
+0-2-4-6-8
+4-1-3-7-3
+5-0-2-1-3
+
 ----------------------------------------------------------------*/
 
+/*
+
+Psikyo PS3-V1 hardware readme
+-----------------------------
+
+Strikers 1945 II
+Sol Divid
+Daraku
+Space Bomber
+
+PCB Layout
+----------
+
+PS3-V1
+|-------------------------------------------------|
+|HA13118         3771    PROG_L                   |
+|    VOL  YAC513         PROG_H      |-----|      |
+|      JRC4741                       | SH2 |      |
+|                          *U16      |     |      |
+|     YMF278B  SOUND.U32             |-----|      |
+|                                                 |
+|J                                                |
+|A                57.2727MHz   HY514260   HY514260|
+|M                                                |
+|M                 |-------|                      |
+|A                 |PSIKYO |                      |
+|                  |PS6406B|        *4L.10  0L.4  |
+|          62256   |       |                      |
+|93C56     62256   |-------|        *5L.9   1L.3  |
+|JP5                                              |
+|   *6H.37  *4H.31   2H.20   0H.13  *6L.8   2L.2  |
+|                                                 |
+|                                   *7L.7   3L.1  |
+|   *7H.36  *5H.30   3H.19   1H.12                |
+|-------------------------------------------------|
+Notes:
+      JP5 - hardwired jumper bank (x4) for region selection. Cut 2ND jumper from left
+            for International/English region. All jumpers shorted = Japan region (default)
+      SH2 - Hitachi HD6417604F28 SH-2 CPU, clock input 28.63635 [57.2727/2] (QFP144)
+      YMF278B - Yamaha YMF278B OPL4 sound chip, clock input 28.63635MHz [57.2727/2] (QFP80)
+      PROG_H/PROG_L - 27C4096 DIP40 EPROM
+      All other ROMs - 32M SOP44 MaskROM
+      * - ROM locations not populated
+      VSync - 60Hz
+      HSync - 15.27kHz
+
+
+Psikyo PS5 hardware readme
+--------------------------
+
+Gunbird 2
+Strikers 1945 III / Strikers 1999
+
+PCB Layout
+----------
+
+PS5
+|-------------------------------------------------|
+|HA13118      M514260      PROG_L.U16    DATA.U1  |
+| VOL    3771 M514260      PROG_H.U17             |
+|                                    *PROG_DATA.U2|
+|                          PAL                    |
+|                                                 |
+|   JRC4741                          0H.10   0L.3 |
+|J          |-----|                               |
+|A          | SH2 |      57.2727MHz  1H.11   1L.4 |
+|M  YAC513  |     |                               |
+|M          |-----|       |-------|  2H.12   2L.5 |
+|A                        |PSIKYO |               |
+|                         |PS6406B|  3H.13   3L.6 |
+|                         |       |               |
+|                         |-------| *4H.14  *4L.7 |
+|                                                 |
+|                           62256   *5H.15  *5L.8 |
+|                           62256                 |
+|                   93C56                         |
+|            JP4             YMF278B    SOUND.9   |
+|-------------------------------------------------|
+Notes:
+      JP4 - hardwired jumper bank (x4) for region selection. Cut leftmost jumper
+            for International/English region. All jumpers shorted = Japan region (default)
+      SH2 - Hitachi HD6417604F28 SH-2 CPU, clock input 28.63635 [57.2727/2] (QFP144)
+      YMF278B - Yamaha YMF278B OPL4 sound chip, clock input 28.63635MHz [57.2727/2] (QFP80)
+      PAL - AMD PALCE 16V8H stamped 'PS5-1' (DIP20)
+      PROG_H/PROG_L/DATA - 27C4096 DIP40 EPROM
+      All other ROMs - 64M/32M SOP44 MaskROM
+      * - ROM locations not populated
+      VSync - 60Hz
+      HSync - 15.27kHz
+
+
+Psikyo PS5V2 hardware readme
+----------------------------
+
+Dragon Blaze, Psikyo, 2000
+Gunbarich, Psikyo, 2001
+Tetris The Grand Master 2 , Psikyo, 2000
+Tetris The Grand Master 2+, Psikyo, 2000
+
+PCB Layout
+----------
+
+PS5V2
+|----------------------------------------------------|
+|HA13118  PS5-1  SM81C256  PROG_H.U21 *0H.U11 *0L.U3 |
+|VOL  JRC4741    SM81C256  PROG_L.U22                |
+|     YAC516  3771                    *1H.U12 *1L.U4 |
+|              |-----|          *U23                 |
+|              | SH2 |                *2H.U13 *2L.U5 |
+|              |     |                               |
+|J    YMF278B  |-----|                 3H.U14  3L.U6 |
+|A                          57.2727MHz               |
+|M                                     4H.U15  4L.U7 |
+|M    SND.U52               |-------|                |
+|A                          |PSIKYO |  5H.U16  5L.U8 |
+|                           |PS6406B|                |
+|                           |       | *6H.U17 *6L.U9 |
+|                    62256  |-------|                |
+|         JP3 93C56  62256            *7H.U18 *7L.U10|
+|                                                    |
+|  10L.U58    9L.U41    8L.U28    7L.U19     6L.U1   |
+|                                                    |
+|  10H.U59    9H.U42    8H.U29    7H.U20     6H.U2   |
+|----------------------------------------------------|
+Notes:
+      JP3     - hardwired jumper bank (x4) for region selection. Cut rightmost jumper
+                for International/English region. All jumpers shorted = Japan region (default)
+      SH2     - Hitachi HD6417604F28 SH-2 CPU, clock input 28.63635 [57.2727/2] (QFP144)
+      YMF278B - Yamaha YMF278B OPL4 sound chip, clock input 28.63635MHz [57.2727/2] (QFP80)
+      PROG_H/PROG_L - 27C4096 DIP40 EPROM
+      ROMs U1-U59 (at bottom of PCB) - 16M DIP42 MaskROM
+      ROMs U3-U10 & U11-U18 (at side of PCB) - 16M TSOP48 Type-II surface-mounted MaskROM
+      ROM U52 - 32M TSOP48 Type-II surface-mounted MaskROM
+      * - ROM locations not populated on tgm2 & tgm2+
+      VSync - 60Hz
+      HSync - 15.27kHz
+
+*/
+
 #include "driver.h"
-#include "state.h"
-#include "cpuintrf.h"
 
-#include "vidhrdw/generic.h"
 #include "cpu/sh2/sh2.h"
 #include "machine/eeprom.h"
 #include "sound/ymf278b.h"
 
 #include "psikyosh.h"
 
-#define ROMTEST 0 /* Does necessary stuff to perform rom test, uses RAM as it doesn't dispose of GFX after decoding */
+#define ROMTEST 1 /* Does necessary stuff to perform rom test, uses RAM as it doesn't dispose of GFX after decoding */
 
-static data8_t factory_eeprom[16]  = { 0x00,0x02,0x00,0x01,0x00,0x00,0x00,0x00,0x00,0x00,0x03,0x00,0x00,0x00,0x00,0x00 };
-static data8_t daraku_eeprom[16]   = { 0x03,0x02,0x00,0x48,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00 };
-static data8_t s1945iii_eeprom[16] = { 0x00,0x00,0x00,0x00,0x00,0x01,0x11,0x70,0x25,0x25,0x25,0x00,0x01,0x00,0x11,0xe0 };
-static data8_t dragnblz_eeprom[16] = { 0x00,0x01,0x11,0x70,0x25,0x25,0x25,0x00,0x01,0x00,0x11,0xe0,0x00,0x00,0x00,0x00 };
-static data8_t gnbarich_eeprom[16] = { 0x00,0x0f,0x42,0x40,0x08,0x0a,0x00,0x00,0x01,0x06,0x42,0x59,0x00,0x00,0x00,0x00 };
+static UINT8 factory_eeprom[16]  = { 0x00,0x02,0x00,0x01,0x00,0x00,0x00,0x00,0x00,0x00,0x03,0x00,0x00,0x00,0x00,0x00 };
+static UINT8 daraku_eeprom[16]   = { 0x03,0x02,0x00,0x48,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00 };
+static UINT8 s1945iii_eeprom[16] = { 0x00,0x00,0x00,0x00,0x00,0x01,0x11,0x70,0x25,0x25,0x25,0x00,0x01,0x00,0x11,0xe0 };
+static UINT8 dragnblz_eeprom[16] = { 0x00,0x01,0x11,0x70,0x25,0x25,0x25,0x00,0x01,0x00,0x11,0xe0,0x00,0x00,0x00,0x00 };
+static UINT8 gnbarich_eeprom[16] = { 0x00,0x0f,0x42,0x40,0x08,0x0a,0x00,0x00,0x01,0x06,0x42,0x59,0x00,0x00,0x00,0x00 };
 
 int use_factory_eeprom;
 
-data32_t *psikyosh_bgram, *psikyosh_zoomram, *psikyosh_vidregs, *psh_ram;
+UINT32 *psikyosh_bgram, *psikyosh_zoomram, *psikyosh_vidregs, *psh_ram;
 
-static struct GfxLayout layout_16x16x4 =
+static const gfx_layout layout_16x16x4 =
 {
 	16,16,
 	RGN_FRAC(1,1),
@@ -152,7 +300,7 @@ static struct GfxLayout layout_16x16x4 =
 	16*16*4
 };
 
-static struct GfxLayout layout_16x16x8 =
+static const gfx_layout layout_16x16x8 =
 {
 	16,16,
 	RGN_FRAC(1,1),
@@ -163,7 +311,7 @@ static struct GfxLayout layout_16x16x8 =
 	16*16*8
 };
 
-static struct GfxDecodeInfo gfxdecodeinfo[] =
+static const gfx_decode gfxdecodeinfo[] =
 {
 	{ REGION_GFX1, 0, &layout_16x16x4, 0x000, 0x100 }, /* 4bpp tiles */
 	{ REGION_GFX1, 0, &layout_16x16x8, 0x000, 0x100 }, /* 8bpp tiles */
@@ -206,7 +354,7 @@ static NVRAM_HANDLER(93C56)
 
  			if (use_factory_eeprom!=EEPROM_0) /* Set the EEPROM to Factory Defaults for games needing them*/
  			{
-				data8_t eeprom_data[0x100];
+				UINT8 eeprom_data[0x100];
 				int i;
 
 				for(i=0; i<0x100; i++) eeprom_data[i] = 0;
@@ -289,7 +437,7 @@ static WRITE32_HANDLER( psikyosh_vidregs_w )
 		if (!(mem_mask & 0x000000ff) || !(mem_mask & 0x0000ff00))	/* Bank */
 		{
 			unsigned char *ROM = memory_region(REGION_GFX1);
-			cpu_setbank(2,&ROM[0x20000 * (psikyosh_vidregs[offset]&0xfff)]); /* Bank comes from vidregs */
+			memory_set_bankptr(2,&ROM[0x20000 * (psikyosh_vidregs[offset]&0xfff)]); /* Bank comes from vidregs */
 		}
 	}
 #endif
@@ -478,6 +626,18 @@ static MACHINE_DRIVER_START( psikyo5 )
 	MDRV_CPU_PROGRAM_MAP(ps5_readmem,ps5_writemem)
 MACHINE_DRIVER_END
 
+static MACHINE_DRIVER_START( psikyo5_240 )
+	/* basic machine hardware */
+	MDRV_IMPORT_FROM(psikyo3v1)
+
+	MDRV_CPU_MODIFY("main")
+	MDRV_CPU_PROGRAM_MAP(ps5_readmem,ps5_writemem)
+
+	/* It probably has a register to change visarea */
+	MDRV_VISIBLE_AREA(0, 40*8-1, 0, 30*8-1)
+MACHINE_DRIVER_END
+
+
 #define UNUSED_PORT \
 	PORT_START_TAG("IN2")/* not read? */ \
 	PORT_BIT(  0x01, IP_ACTIVE_LOW, IPT_UNKNOWN ) \
@@ -646,6 +806,23 @@ INPUT_PORTS_START( gnbarich ) /* Same as S1945iii except only one button */
 	PORT_DIPSETTING(    0x01, "International Ver B." )
 INPUT_PORTS_END
 
+INPUT_PORTS_START( mjgtaste ) /* This will need the Mahjong inputs */
+	PORT_START_TAG("IN0")
+	PSIKYOSH_PORT_PLAYER( 1, IPT_START1, 3 )
+	PORT_START_TAG("IN1")
+	PSIKYOSH_PORT_PLAYER( 2, IPT_START2, 3 )
+
+	UNUSED_PORT
+	PORT_COIN( 0 )
+
+	PORT_START_TAG("IN4")/* jumper pads on the PCB */
+/*  PORT_DIPNAME( 0x03, 0x01, DEF_STR( Region ) ) */
+/*  PORT_DIPSETTING(    0x00, DEF_STR( Japan ) ) */
+/*  PORT_DIPSETTING(    0x02, "International Ver A." ) */
+/*  PORT_DIPSETTING(    0x01, "International Ver B." ) */
+INPUT_PORTS_END
+
+
 #if ROMTEST
 #define ROMTEST_GFX 0
 #else
@@ -854,6 +1031,37 @@ ROM_START( gnbarich )
 	ROM_LOAD( "snd0.u52", 0x000000, 0x200000, CRC(7b10436b) SHA1(c731fcce024e286a677ca10a91761c1ee06094a5) )
 ROM_END
 
+ROM_START( mjgtaste )
+	ROM_REGION( 0x100000, REGION_CPU1, 0)
+	ROM_LOAD32_WORD_SWAP( "2.u21",   0x000000, 0x080000, CRC(5f2041dc) SHA1(f3862ffdb8df0cf921ce1cb0236935731e7729a7) )
+	ROM_LOAD32_WORD_SWAP( "1.u22",   0x000002, 0x080000, CRC(f5ff7876) SHA1(4c909db9c97f29fd79df6dacd29762688701b973) )
+
+	/* exact number of gfx / sound roms may be incorrect */
+	ROM_REGION( 0x2c00000, REGION_GFX1, ROMTEST_GFX )	/* Sprites */
+	ROM_LOAD32_WORD( "1l.u4",  0x0400000, 0x200000, NO_DUMP )
+	ROM_LOAD32_WORD( "1h.u12", 0x0400002, 0x200000, NO_DUMP )
+	ROM_LOAD32_WORD( "2l.u5",  0x0800000, 0x200000, NO_DUMP )
+	ROM_LOAD32_WORD( "2h.u13", 0x0800002, 0x200000, NO_DUMP )
+	ROM_LOAD32_WORD( "3l.u6",  0x0c00000, 0x200000, NO_DUMP )
+	ROM_LOAD32_WORD( "3h.u14", 0x0c00002, 0x200000, NO_DUMP )
+	ROM_LOAD32_WORD( "4l.u7",  0x1000000, 0x200000, NO_DUMP )
+	ROM_LOAD32_WORD( "4h.u15", 0x1000002, 0x200000, NO_DUMP )
+	ROM_LOAD32_WORD( "5l.u8",  0x1400000, 0x200000, NO_DUMP )
+	ROM_LOAD32_WORD( "5h.u16", 0x1400002, 0x200000, NO_DUMP )
+	ROM_LOAD32_WORD( "6l.u1",  0x1800000, 0x200000, NO_DUMP )
+	ROM_LOAD32_WORD( "6h.u2",  0x1800002, 0x200000, NO_DUMP )
+	ROM_LOAD32_WORD( "7l.u19", 0x1c00000, 0x200000, NO_DUMP )
+	ROM_LOAD32_WORD( "7h.u20", 0x1c00002, 0x200000, NO_DUMP )
+	ROM_LOAD32_WORD( "8l.u28", 0x2000000, 0x200000, NO_DUMP )
+	ROM_LOAD32_WORD( "8h.u29", 0x2000002, 0x200000, NO_DUMP )
+	ROM_LOAD32_WORD( "9l.u41", 0x2400000, 0x200000, NO_DUMP )
+	ROM_LOAD32_WORD( "9h.u42", 0x2400002, 0x200000, NO_DUMP )
+	ROM_LOAD32_WORD( "10l.u58",0x2800000, 0x200000, NO_DUMP )
+	ROM_LOAD32_WORD( "10h.u59",0x2800002, 0x200000, NO_DUMP )
+
+	ROM_REGION( 0x800000, REGION_SOUND1, 0 ) /* Samples - Not Dumped */
+	ROM_LOAD( "snd0.u52", 0x000000, 0x200000, NO_DUMP )
+ROM_END
 
 /* are these right? should i fake the counter return?
    'speedups / idle skipping isn't needed for 'hotgmck, hgkairak'
@@ -990,6 +1198,19 @@ PC  :0602CAF2: BT      $0602CAE6
 	return psh_ram[0x006000C/4];
 }
 
+static READ32_HANDLER( mjgtaste_speedup_r )
+{
+
+	if (activecpu_get_pc()==0x6031f04) {cpu_spinuntil_int();return psh_ram[0x006000C/4];} /* title logos */
+	if (activecpu_get_pc()==0x603214c) {cpu_spinuntil_int();return psh_ram[0x006000C/4];} /* attract game */
+
+/*  printf("at %08x\n",activecpu_get_pc()); */
+
+	return psh_ram[0x006000C/4];
+}
+
+
+
 static DRIVER_INIT( soldivid )
 {
 	memory_install_read32_handler(0, ADDRESS_SPACE_PROGRAM, 0x600000c, 0x600000f, 0, 0, soldivid_speedup_r );
@@ -1005,7 +1226,7 @@ static DRIVER_INIT( s1945ii )
 static DRIVER_INIT( daraku )
 {
 	unsigned char *RAM = memory_region(REGION_CPU1);
-	cpu_setbank(1,&RAM[0x100000]);
+	memory_set_bankptr(1,&RAM[0x100000]);
 	memory_install_read32_handler(0, ADDRESS_SPACE_PROGRAM, 0x600000c, 0x600000f, 0, 0, daraku_speedup_r );
 	use_factory_eeprom=EEPROM_DARAKU;
 }
@@ -1019,7 +1240,7 @@ static DRIVER_INIT( sbomberb )
 static DRIVER_INIT( gunbird2 )
 {
 	unsigned char *RAM = memory_region(REGION_CPU1);
-	cpu_setbank(1,&RAM[0x100000]);
+	memory_set_bankptr(1,&RAM[0x100000]);
 	memory_install_read32_handler(0, ADDRESS_SPACE_PROGRAM, 0x604000c, 0x604000f, 0, 0, gunbird2_speedup_r );
 	use_factory_eeprom=EEPROM_DEFAULT;
 }
@@ -1027,7 +1248,7 @@ static DRIVER_INIT( gunbird2 )
 static DRIVER_INIT( s1945iii )
 {
 	unsigned char *RAM = memory_region(REGION_CPU1);
-	cpu_setbank(1,&RAM[0x100000]);
+	memory_set_bankptr(1,&RAM[0x100000]);
 	memory_install_read32_handler(0, ADDRESS_SPACE_PROGRAM, 0x606000c, 0x606000f, 0, 0, s1945iii_speedup_r );
 	use_factory_eeprom=EEPROM_S1945III;
 }
@@ -1044,18 +1265,27 @@ static DRIVER_INIT( gnbarich )
 	use_factory_eeprom=EEPROM_GNBARICH;
 }
 
+static DRIVER_INIT( mjgtaste )
+{
+	memory_install_read32_handler(0, ADDRESS_SPACE_PROGRAM, 0x606000c, 0x606000f, 0, 0, mjgtaste_speedup_r );
+	use_factory_eeprom=EEPROM_DEFAULT;
+	/* needs to install mahjong controls too (can select joystick in test mode tho) */
+}
+
+
 /*     YEAR  NAME      PARENT    MACHINE    INPUT     INIT      MONITOR COMPANY   FULLNAME FLAGS */
 
 /* ps3-v1 */
-GAMEX( 1997, soldivid, 0,        psikyo3v1, soldivid, soldivid, ROT0,   "Psikyo", "Sol Divide - The Sword Of Darkness", GAME_IMPERFECT_SOUND ) /* Music Tempo */
-GAMEX( 1997, s1945ii,  0,        psikyo3v1, s1945ii,  s1945ii,  ROT270, "Psikyo", "Strikers 1945 II", GAME_IMPERFECT_GRAPHICS ) /* linescroll/zoom */
-GAME ( 1998, daraku,   0,        psikyo3v1, daraku,   daraku,   ROT0,   "Psikyo", "Daraku Tenshi - The Fallen Angels" )
-GAME ( 1998, sbomberb, 0,        psikyo3v1, sbomberb, sbomberb, ROT270, "Psikyo", "Space Bomber (ver. B)" )
+GAME( 1997, soldivid, 0,        psikyo3v1,   soldivid, soldivid, ROT0,   "Psikyo", "Sol Divide - The Sword Of Darkness", GAME_IMPERFECT_SOUND ) /* Music Tempo */
+GAME( 1997, s1945ii,  0,        psikyo3v1,   s1945ii,  s1945ii,  ROT270, "Psikyo", "Strikers 1945 II", GAME_IMPERFECT_GRAPHICS ) /* linescroll/zoom */
+GAME( 1998, daraku,   0,        psikyo3v1,   daraku,   daraku,   ROT0,   "Psikyo", "Daraku Tenshi - The Fallen Angels", 0 )
+GAME( 1998, sbomberb, 0,        psikyo3v1,   sbomberb, sbomberb, ROT270, "Psikyo", "Space Bomber (ver. B)", 0 )
 
 /* ps5 */
-GAME ( 1998, gunbird2, 0,        psikyo5,   gunbird2, gunbird2, ROT270, "Psikyo", "Gunbird 2" )
-GAMEX( 1999, s1945iii, 0,        psikyo5,   s1945iii, s1945iii, ROT270, "Psikyo", "Strikers 1945 III (World) / Strikers 1999 (Japan)", GAME_IMPERFECT_GRAPHICS ) /* linescroll/zoom */
+GAME( 1998, gunbird2, 0,        psikyo5,     gunbird2, gunbird2, ROT270, "Psikyo", "Gunbird 2", 0 )
+GAME( 1999, s1945iii, 0,        psikyo5,     s1945iii, s1945iii, ROT270, "Psikyo", "Strikers 1945 III (World) / Strikers 1999 (Japan)", GAME_IMPERFECT_GRAPHICS ) /* linescroll/zoom */
 
 /* ps5v2 */
-GAME ( 2000, dragnblz, 0,        psikyo5,   dragnblz, dragnblz, ROT270, "Psikyo", "Dragon Blaze" )
-GAME ( 2001, gnbarich, 0,        psikyo5,   gnbarich, gnbarich, ROT270, "Psikyo", "Gunbarich" )
+GAME( 2000, dragnblz, 0,        psikyo5,     dragnblz, dragnblz, ROT270, "Psikyo", "Dragon Blaze", 0 )
+GAME( 2001, gnbarich, 0,        psikyo5,     gnbarich, gnbarich, ROT270, "Psikyo", "Gunbarich", 0 )
+GAME( 2002, mjgtaste, 0,        psikyo5,     mjgtaste, mjgtaste, ROT0,   "Psikyo", "Mahjong G-Taste", GAME_NOT_WORKING )
