@@ -310,7 +310,6 @@ The first sprite data is located at f20b,then f21b and so on.
 */
 
 #include "driver.h"
-#include "vidhrdw/generic.h"
 #include "sound/2203intf.h"
 
 
@@ -321,7 +320,7 @@ extern WRITE8_HANDLER( psychic5_title_screen_w );
 extern READ8_HANDLER( psychic5_paged_ram_r );
 extern READ8_HANDLER( psychic5_vram_page_select_r );
 
-extern MACHINE_INIT( psychic5 );
+extern MACHINE_RESET( psychic5 );
 
 extern VIDEO_START( psychic5 );
 extern VIDEO_UPDATE( psychic5 );
@@ -343,7 +342,7 @@ WRITE8_HANDLER( psychic5_bankselect_w )
 	{
 		psychic5_bank_latch = data;
 		bankaddress = 0x10000 + ((data & 3) * 0x4000);
-		cpu_setbank(1,&RAM[bankaddress]);	 /* Select 4 banks of 16k */
+		memory_set_bankptr(1,&RAM[bankaddress]);	 /* Select 4 banks of 16k */
 	}
 }
 
@@ -505,7 +504,7 @@ INPUT_PORTS_END
 
 
 
-static struct GfxLayout charlayout =
+static const gfx_layout charlayout =
 {
 	8,8,    /* 8x8 characters */
 	1024,	/* 1024 characters */
@@ -516,7 +515,7 @@ static struct GfxLayout charlayout =
 	32*8   	/* every char takes 32 consecutive bytes */
 };
 
-static struct GfxLayout spritelayout =
+static const gfx_layout spritelayout =
 {
 	16,16,  /* 16x16 characters */
 	1024,	/* 1024 characters */
@@ -527,7 +526,7 @@ static struct GfxLayout spritelayout =
 	128*8	/* every char takes 128 consecutive bytes */
 };
 
-static struct GfxDecodeInfo gfxdecodeinfo[] =
+static const gfx_decode gfxdecodeinfo[] =
 {
 	{ REGION_GFX1, 0, &spritelayout,  0*16, 16 },
 	{ REGION_GFX2, 0, &spritelayout, 16*16, 16 },
@@ -563,10 +562,10 @@ static MACHINE_DRIVER_START( psychic5 )
 	MDRV_VBLANK_DURATION(DEFAULT_60HZ_VBLANK_DURATION)
 	/* frames per second hand tuned to match game and music speed */
 	MDRV_INTERLEAVE(10)      /* Allow time for 2nd cpu to interleave*/
-	MDRV_MACHINE_INIT(psychic5)
+	MDRV_MACHINE_RESET(psychic5)
 
 	/* video hardware */
-	MDRV_VIDEO_ATTRIBUTES(VIDEO_TYPE_RASTER)
+	MDRV_VIDEO_ATTRIBUTES(VIDEO_TYPE_RASTER | VIDEO_NEEDS_6BITS_PER_GUN | VIDEO_RGB_DIRECT)
 	MDRV_SCREEN_SIZE(32*8, 32*8)
 	MDRV_VISIBLE_AREA(0*8, 32*8-1, 2*8, 30*8-1)
 	MDRV_GFXDECODE(gfxdecodeinfo)
@@ -621,4 +620,4 @@ ROM_END
 
 
 
-GAME( 1987, psychic5, 0, psychic5, psychic5, 0, ROT270, "Jaleco", "Psychic 5" )
+GAME( 1987, psychic5, 0, psychic5, psychic5, 0, ROT270, "Jaleco", "Psychic 5", 0 )
