@@ -95,7 +95,6 @@ write:
 ***************************************************************************/
 
 #include "driver.h"
-#include "vidhrdw/generic.h"
 #include "cpu/m6502/m6502.h"
 #include "sound/vlm5030.h"
 #include "sound/nes_apu.h"
@@ -681,7 +680,7 @@ INPUT_PORTS_START( armwrest )
 INPUT_PORTS_END
 
 
-static gfx_layout charlayout =
+static const gfx_layout charlayout =
 {
 	8,8,	/* 8*8 characters */
 	1024,	/* 1024 characters */
@@ -692,7 +691,7 @@ static gfx_layout charlayout =
 	8*8	/* every char takes 8 consecutive bytes */
 };
 
-static gfx_layout armwrest_charlayout =
+static const gfx_layout armwrest_charlayout =
 {
 	8,8,	/* 8*8 characters */
 	2048,	/* 2048 characters */
@@ -703,7 +702,7 @@ static gfx_layout armwrest_charlayout =
 	8*8	/* every char takes 8 consecutive bytes */
 };
 
-static gfx_layout armwrest_charlayout2 =
+static const gfx_layout armwrest_charlayout2 =
 {
 	8,8,	/* 8*8 characters */
 	2048,	/* 2048 characters */
@@ -714,7 +713,7 @@ static gfx_layout armwrest_charlayout2 =
 	8*8	/* every char takes 8 consecutive bytes */
 };
 
-static gfx_layout charlayout1 =
+static const gfx_layout charlayout1 =
 {
 	8,8,	/* 8*8 characters */
 	8192,	/* 8192 characters */
@@ -725,7 +724,7 @@ static gfx_layout charlayout1 =
 	8*8	/* every char takes 8 consecutive bytes */
 };
 
-static gfx_layout charlayout2 =
+static const gfx_layout charlayout2 =
 {
 	8,8,	/* 8*8 characters */
 	4096,	/* 4096 characters */
@@ -736,7 +735,7 @@ static gfx_layout charlayout2 =
 	8*8	/* every char takes 8 consecutive bytes */
 };
 
-static gfx_decode punchout_gfxdecodeinfo[] =
+static const gfx_decode punchout_gfxdecodeinfo[] =
 {
 	{ REGION_GFX1, 0, &charlayout,                 0, 128 },
 	{ REGION_GFX2, 0, &charlayout,             128*4, 128 },
@@ -745,7 +744,7 @@ static gfx_decode punchout_gfxdecodeinfo[] =
 	{ -1 } /* end of array */
 };
 
-static gfx_decode armwrest_gfxdecodeinfo[] =
+static const gfx_decode armwrest_gfxdecodeinfo[] =
 {
 	{ REGION_GFX1, 0, &armwrest_charlayout,        0, 256 },
 	{ REGION_GFX2, 0, &armwrest_charlayout2,   256*4,  64 },
@@ -789,7 +788,7 @@ static MACHINE_DRIVER_START( punchout )
 	MDRV_NVRAM_HANDLER(generic_0fill)
 
 	/* video hardware */
-	MDRV_VIDEO_ATTRIBUTES(VIDEO_TYPE_RASTER | VIDEO_DUAL_MONITOR)
+	MDRV_VIDEO_ATTRIBUTES(VIDEO_TYPE_RASTER)
 	MDRV_ASPECT_RATIO(4,6)
 	MDRV_SCREEN_SIZE(32*8, 28*8*2)
 	MDRV_VISIBLE_AREA(0*8, 32*8-1, 0*8, 28*8*2-1)
