@@ -22,7 +22,6 @@
 ***************************************************************************/
 
 #include "driver.h"
-#include "vidhrdw/generic.h"
 #include "cpu/z80/z80.h"
 #include "cpu/m6805/m6805.h"
 #include "sound/2203intf.h"
@@ -126,7 +125,7 @@ static WRITE8_HANDLER( pushman_68000_w )
 	shared_ram[offset]=data;
 }
 
-MACHINE_INIT( bballs )
+MACHINE_RESET( bballs )
 {
 	latch=0x400;
 }
@@ -376,7 +375,7 @@ INPUT_PORTS_END
 
 /******************************************************************************/
 
-static gfx_layout charlayout =
+static const gfx_layout charlayout =
 {
 	8,8,
 	RGN_FRAC(1,1),
@@ -387,7 +386,7 @@ static gfx_layout charlayout =
 	16*8
 };
 
-static gfx_layout spritelayout =
+static const gfx_layout spritelayout =
 {
 	16,16,
 	RGN_FRAC(1,4),
@@ -400,7 +399,7 @@ static gfx_layout spritelayout =
 	32*8
 };
 
-static gfx_layout tilelayout =
+static const gfx_layout tilelayout =
 {
 	32,32,
 	RGN_FRAC(1,2),
@@ -417,7 +416,7 @@ static gfx_layout tilelayout =
 	256*8
 };
 
-static gfx_decode pushman_gfxdecodeinfo[] =
+static const gfx_decode pushman_gfxdecodeinfo[] =
 {
 	{ REGION_GFX1, 0x000000, &charlayout,   0x300, 16 },	/* colors 0x300-0x33f */
 	{ REGION_GFX2, 0x000000, &spritelayout, 0x200, 16 },	/* colors 0x200-0x2ff */
@@ -495,7 +494,7 @@ static MACHINE_DRIVER_START( bballs )
 	MDRV_VBLANK_DURATION(DEFAULT_REAL_60HZ_VBLANK_DURATION)
 	MDRV_INTERLEAVE(60)
 
-	MDRV_MACHINE_INIT(bballs)
+	MDRV_MACHINE_RESET(bballs)
 
 	/* video hardware */
 	MDRV_VIDEO_ATTRIBUTES(VIDEO_TYPE_RASTER)
