@@ -180,7 +180,6 @@ TODO:
 ***************************************************************************/
 
 #include "driver.h"
-#include "vidhrdw/generic.h"
 #include "sndhrdw/timeplt.h"
 #include "sound/namco.h"
 #include "sound/samples.h"
@@ -201,6 +200,13 @@ DRIVER_INIT( locomotn );
 DRIVER_INIT( commsega );
 
 
+static WRITE8_HANDLER( rallyx_interrupt_vector_w )
+{
+	cpunum_set_input_line_vector(0, 0, data);
+	cpunum_set_input_line(0, 0, CLEAR_LINE);
+}
+
+
 
 static WRITE8_HANDLER( rallyx_bang_w )
 {
@@ -316,7 +322,7 @@ ADDRESS_MAP_END
 
 static ADDRESS_MAP_START( writeport, ADDRESS_SPACE_IO, 8 )
 	ADDRESS_MAP_FLAGS( AMEF_ABITS(8) )
-	AM_RANGE(0, 0) AM_WRITE(interrupt_vector_w)
+	AM_RANGE(0, 0) AM_WRITE(rallyx_interrupt_vector_w)
 ADDRESS_MAP_END
 
 
@@ -733,7 +739,7 @@ INPUT_PORTS_END
 
 
 
-static gfx_layout rallyx_charlayout =
+static const gfx_layout rallyx_charlayout =
 {
 	8,8,
 	RGN_FRAC(1,1),
@@ -744,7 +750,7 @@ static gfx_layout rallyx_charlayout =
 	16*8
 };
 
-static gfx_layout jungler_charlayout =
+static const gfx_layout jungler_charlayout =
 {
 	8,8,
 	RGN_FRAC(1,1),
@@ -755,7 +761,7 @@ static gfx_layout jungler_charlayout =
 	16*8
 };
 
-static gfx_layout rallyx_spritelayout =
+static const gfx_layout rallyx_spritelayout =
 {
 	16,16,
 	RGN_FRAC(1,1),
@@ -768,7 +774,7 @@ static gfx_layout rallyx_spritelayout =
 	64*8
 };
 
-static gfx_layout jungler_spritelayout =
+static const gfx_layout jungler_spritelayout =
 {
 	16,16,
 	RGN_FRAC(1,1),
@@ -781,7 +787,7 @@ static gfx_layout jungler_spritelayout =
 	64*8
 };
 
-static gfx_layout dotlayout =
+static const gfx_layout dotlayout =
 {
 	4,4,
 	8,
@@ -792,7 +798,7 @@ static gfx_layout dotlayout =
 	16*8
 };
 
-static gfx_decode rallyx_gfxdecodeinfo[] =
+static const gfx_decode rallyx_gfxdecodeinfo[] =
 {
 	{ REGION_GFX1, 0, &rallyx_charlayout,     0, 64 },
 	{ REGION_GFX1, 0, &rallyx_spritelayout,   0, 64 },
@@ -800,7 +806,7 @@ static gfx_decode rallyx_gfxdecodeinfo[] =
 	{ -1 } /* end of array */
 };
 
-static gfx_decode jungler_gfxdecodeinfo[] =
+static const gfx_decode jungler_gfxdecodeinfo[] =
 {
 	{ REGION_GFX1, 0, &jungler_charlayout,    0, 64 },
 	{ REGION_GFX1, 0, &jungler_spritelayout,  0, 64 },
