@@ -62,7 +62,7 @@ static void scanline_update(int scanline)
  *
  *************************************/
 
-static MACHINE_INIT( rampart )
+static MACHINE_RESET( rampart )
 {
 	atarigen_eeprom_reset();
 	atarigen_slapstic_reset();
@@ -352,7 +352,7 @@ INPUT_PORTS_END
  *
  *************************************/
 
-static gfx_layout molayout =
+static const gfx_layout molayout =
 {
 	8,8,
 	RGN_FRAC(1,1),
@@ -364,7 +364,7 @@ static gfx_layout molayout =
 };
 
 
-static gfx_decode gfxdecodeinfo[] =
+static const gfx_decode gfxdecodeinfo[] =
 {
 	{ REGION_GFX1, 0, &molayout,  256, 16 },
 	{ -1 }
@@ -388,7 +388,7 @@ static MACHINE_DRIVER_START( rampart )
 	MDRV_FRAMES_PER_SECOND(60)
 	MDRV_VBLANK_DURATION(DEFAULT_REAL_60HZ_VBLANK_DURATION)
 
-	MDRV_MACHINE_INIT(rampart)
+	MDRV_MACHINE_RESET(rampart)
 	MDRV_NVRAM_HANDLER(atarigen)
 
 	/* video hardware */
