@@ -81,8 +81,6 @@ TODO:
 ***************************************************************************/
 
 #include "driver.h"
-#include "state.h"
-#include "vidhrdw/generic.h"
 #include "vidhrdw/taitoic.h"
 #include "sndhrdw/taitosnd.h"
 #include "sound/2151intf.h"
@@ -287,7 +285,7 @@ INPUT_PORTS_END
 
 
 
-static gfx_layout tilelayout =
+static const gfx_layout tilelayout =
 {
 	8,8,
 	RGN_FRAC(1,2),
@@ -298,7 +296,7 @@ static gfx_layout tilelayout =
 	16*8
 };
 
-static gfx_layout spritelayout =
+static const gfx_layout spritelayout =
 {
 	16,16,
 	RGN_FRAC(1,2),
@@ -311,7 +309,7 @@ static gfx_layout spritelayout =
 	32*16
 };
 
-static gfx_decode gfxdecodeinfo[] =
+static const gfx_decode gfxdecodeinfo[] =
 {
 	{ REGION_GFX1, 0, &tilelayout,   0, 0x80 },
 	{ REGION_GFX2, 0, &spritelayout, 0, 0x80 },
