@@ -10,7 +10,6 @@ ask.  - Mike Balfour (mab22@po.cwru.edu)
 ***************************************************************************/
 
 #include "driver.h"
-#include "vidhrdw/generic.h"
 #include "machine/6821pia.h"
 #include "sound/ay8910.h"
 
@@ -253,7 +252,7 @@ INPUT_PORTS_START( demoneye )
 INPUT_PORTS_END
 
 
-static gfx_layout backlayout =
+static const gfx_layout backlayout =
 {
 	8,8,	/* 8*8 characters */
 	0x400,	  /* 1024 characters */
@@ -264,7 +263,7 @@ static gfx_layout backlayout =
 	8*8 /* every char takes 8 consecutive bytes */
 };
 
-static gfx_layout charlayout =
+static const gfx_layout charlayout =
 {
 	8,8,	/* 8*8 characters */
 	128,	/* 128 characters */
@@ -275,7 +274,7 @@ static gfx_layout charlayout =
 	8*8 /* every char takes 8 consecutive bytes */
 };
 
-static gfx_layout spritelayout =
+static const gfx_layout spritelayout =
 {
 	8,8,	/* 8*8 characters */
 	128,	/* 128 characters */
@@ -286,7 +285,7 @@ static gfx_layout spritelayout =
 	8*8 /* every char takes 8 consecutive bytes */
 };
 
-static gfx_decode redalert_gfxdecodeinfo[] =
+static const gfx_decode redalert_gfxdecodeinfo[] =
 {
 	{ 0, 0x3000, &backlayout,	0, 8 }, 	/* the game dynamically modifies this */
 	{ 0, 0x4800, &charlayout,	0, 8 }, 	/* the game dynamically modifies this */
@@ -294,7 +293,7 @@ static gfx_decode redalert_gfxdecodeinfo[] =
 	{ -1 } /* end of array */
 };
 
-static gfx_decode demoneye_gfxdecodeinfo[] =
+static const gfx_decode demoneye_gfxdecodeinfo[] =
 {
 	{ 0, 0x3000, &backlayout,	0, 8 }, 	/* the game dynamically modifies this */
 	{ 0, 0x4800, &spritelayout,16, 4 }, 	/* the game dynamically modifies this */
@@ -398,17 +397,21 @@ MACHINE_DRIVER_END
 
 
 /* PIA 0, sound CPU */
-static struct pia6821_interface pia_0_intf =
+static const pia6821_interface pia_0_intf =
 {
 	/*inputs : A/B,CA/B1,CA/B2 */ 0, 0, 0, 0, 0, 0,
 	/*outputs: A/B,CA/B2       */ 0, 0, 0, 0,
 	/*irqs   : A/B             */ 0, 0
 };
 
-MACHINE_INIT( demoneye )
+MACHINE_START( demoneye )
 {
-	pia_unconfig();
 	pia_config(0, PIA_STANDARD_ORDERING, &pia_0_intf);
+	return 0;
+}
+
+MACHINE_RESET( demoneye )
+{
 	pia_reset();
 }
 
@@ -426,7 +429,8 @@ static MACHINE_DRIVER_START( demoneye )
 	MDRV_FRAMES_PER_SECOND(60)
 	MDRV_VBLANK_DURATION(DEFAULT_60HZ_VBLANK_DURATION)
 
-	MDRV_MACHINE_INIT(demoneye)
+	MDRV_MACHINE_START(demoneye)
+	MDRV_MACHINE_RESET(demoneye)
 
 	/* video hardware */
 	MDRV_VIDEO_ATTRIBUTES(VIDEO_TYPE_RASTER)
