@@ -100,10 +100,9 @@ $8000 - $ffff   ROM
 ***************************************************************************/
 
 #include "driver.h"
-#include "vidhrdw/generic.h"
+#include "streams.h"
 #include "cpu/m6502/m6502.h"
 #include "cpu/m6809/m6809.h"
-#include "state.h"
 #include "sound/3812intf.h"
 #include "sound/okim6295.h"
 #include "sound/custom.h"
@@ -120,11 +119,11 @@ extern UINT8 *renegade_videoram2;
 
 #define MCU_BUFFER_MAX 6
 static UINT8 mcu_buffer[MCU_BUFFER_MAX];
-static int mcu_input_size;
-static int mcu_output_byte;
-static int mcu_key;
+static UINT8 mcu_input_size;
+static UINT8 mcu_output_byte;
+static INT8 mcu_key;
 
-static int bank;
+static UINT8 bank;
 
 /********************************************************************************************/
 
@@ -243,15 +242,16 @@ static void setbank(void)
 	memory_set_bankptr(1, &RAM[bank ? 0x10000 : 0x4000]);
 }
 
-static void setup_statesave(void)
+static MACHINE_START( renegade )
 {
-	state_save_register_UINT8("renegade", 0, "mcu_buffer", mcu_buffer, MCU_BUFFER_MAX);
-	state_save_register_int("renegade", 0, "mcu_input_size", &mcu_input_size);
-	state_save_register_int("renegade", 0, "mcu_output_byte", &mcu_output_byte);
-	state_save_register_int("renegade", 0, "mcu_key", &mcu_key);
+	state_save_register_global_array(mcu_buffer);
+	state_save_register_global(mcu_input_size);
+	state_save_register_global(mcu_output_byte);
+	state_save_register_global(mcu_key);
 
-	state_save_register_int("renegade", 0, "bank", &bank);
+	state_save_register_global(bank);
 	state_save_register_func_postload(setbank);
+	return 0;
 }
 
 DRIVER_INIT( kuniokun )
@@ -259,8 +259,6 @@ DRIVER_INIT( kuniokun )
 	mcu_type = 0x85;
 	mcu_encrypt_table = kuniokun_xor_table;
 	mcu_encrypt_table_len = 0x2a;
-
-	setup_statesave();
 }
 
 DRIVER_INIT( renegade )
@@ -268,8 +266,6 @@ DRIVER_INIT( renegade )
 	mcu_type = 0xda;
 	mcu_encrypt_table = renegade_xor_table;
 	mcu_encrypt_table_len = 0x37;
-
-	setup_statesave();
 }
 
 static READ8_HANDLER( mcu_reset_r )
@@ -372,7 +368,7 @@ static void mcu_process_command(void)
 		{
 			int difficulty = mcu_buffer[2] & 0x3;
 			int stage = mcu_buffer[3];
-			const UINT8 difficulty_table[4] = { 5, 3, 1, 2 };
+			static const UINT8 difficulty_table[4] = { 5, 3, 1, 2 };
 			int result = difficulty_table[difficulty];
 
 			if (stage == 0)
@@ -389,7 +385,7 @@ static void mcu_process_command(void)
 	case 0x55: /* 0x55, 0x00, 0x00, 0x00, DSW2 -> timer */
 		{
 			int difficulty = mcu_buffer[4] & 0x3;
-			const UINT16 table[4] =
+			static const UINT16 table[4] =
 			{
 				0x4001, 0x5001, 0x1502, 0x0002
 			};
@@ -439,7 +435,7 @@ static void mcu_process_command(void)
 			int indx = mcu_buffer[3];
 			int enemy_type=0;
 
-			static int table[] =
+			static const int table[] =
 			{
 				0x01, 0x06, 0x06, 0x05, 0x05, 0x05, 0x05, 0x05,	/* for stage#: 0 */
 				0x02, 0x0a, 0x0a, 0x09, 0x09, 0x09, 0x09,	/* for stage#: 1 */
@@ -548,7 +544,8 @@ static ADDRESS_MAP_START( main_writemem, ADDRESS_SPACE_PROGRAM, 8 )
 	AM_RANGE(0x3805, 0x3805) AM_WRITE(bankswitch_w)
 	AM_RANGE(0x3806, 0x3806) AM_WRITE(MWA8_NOP) /* ?? watchdog */
 	AM_RANGE(0x3807, 0x3807) AM_WRITE(renegade_coin_counter_w)
-	AM_RANGE(0x4000, 0xffff) AM_WRITE(MWA8_ROM)
+	AM_RANGE(0x4000, 0x7fff) AM_WRITE(MWA8_ROM)
+	AM_RANGE(0x8000, 0xffff) AM_WRITE(MWA8_ROM)
 ADDRESS_MAP_END
 
 static ADDRESS_MAP_START( sound_readmem, ADDRESS_SPACE_PROGRAM, 8 )
@@ -632,7 +629,7 @@ INPUT_PORTS_END
 
 
 
-static gfx_layout charlayout =
+static const gfx_layout charlayout =
 {
 	8,8, /* 8x8 characters */
 	1024, /* 1024 characters */
@@ -643,7 +640,7 @@ static gfx_layout charlayout =
 	32*8 /* offset to next character */
 };
 
-static gfx_layout tileslayout1 =
+static const gfx_layout tileslayout1 =
 {
 	16,16, /* tile size */
 	256, /* number of tiles */
@@ -663,7 +660,7 @@ static gfx_layout tileslayout1 =
 	64*8 /* offset to next tile */
 };
 
-static gfx_layout tileslayout2 =
+static const gfx_layout tileslayout2 =
 {
 	16,16, /* tile size */
 	256, /* number of tiles */
@@ -683,7 +680,7 @@ static gfx_layout tileslayout2 =
 	64*8 /* offset to next tile */
 };
 
-static gfx_layout tileslayout3 =
+static const gfx_layout tileslayout3 =
 {
 	16,16, /* tile size */
 	256, /* number of tiles */
@@ -703,7 +700,7 @@ static gfx_layout tileslayout3 =
 	64*8 /* offset to next tile */
 };
 
-static gfx_layout tileslayout4 =
+static const gfx_layout tileslayout4 =
 {
 	16,16, /* tile size */
 	256, /* number of tiles */
@@ -723,7 +720,7 @@ static gfx_layout tileslayout4 =
 	64*8 /* offset to next tile */
 };
 
-static gfx_decode gfxdecodeinfo[] =
+static const gfx_decode gfxdecodeinfo[] =
 {
 	/* 8x8 text, 8 colors */
 	{ REGION_GFX1, 0x00000, &charlayout,	 0, 4 },	/* colors   0- 32 */
@@ -781,6 +778,12 @@ static struct CustomSound_interface adpcm_interface =
 };
 
 
+static MACHINE_RESET( renegade )
+{
+	bank = 0;
+	setbank();
+}
+
 
 static MACHINE_DRIVER_START( renegade )
 
@@ -795,6 +798,8 @@ static MACHINE_DRIVER_START( renegade )
 								/* IRQs are caused by the main CPU */
 	MDRV_FRAMES_PER_SECOND(60)
 	MDRV_VBLANK_DURATION(DEFAULT_REAL_60HZ_VBLANK_DURATION*2)
+	MDRV_MACHINE_START(renegade)
+	MDRV_MACHINE_RESET(renegade)
 
 	/* video hardware */
 	MDRV_VIDEO_ATTRIBUTES(VIDEO_TYPE_RASTER)
