@@ -29,7 +29,6 @@ TODO:
 ***************************************************************************/
 
 #include "driver.h"
-#include "vidhrdw/generic.h"
 #include "sound/ay8910.h"
 #include "sound/msm5205.h"
 
@@ -172,7 +171,7 @@ logerror("banksw %d\n",bank);
 	memory_set_bankptr(2, rom + bank*0x4000 + 0x2000);
 }
 
-static MACHINE_INIT( themj )
+static MACHINE_RESET( themj )
 {
 	themj_rombank_w(0,0);
 }
@@ -484,7 +483,7 @@ INPUT_PORTS_END
 
 
 
-static gfx_layout charlayout =
+static const gfx_layout charlayout =
 {
 	8,8,
 	RGN_FRAC(1,2),
@@ -495,13 +494,13 @@ static gfx_layout charlayout =
 	16*8
 };
 
-static gfx_decode gfxdecodeinfo1[] =
+static const gfx_decode gfxdecodeinfo1[] =
 {
 	{ REGION_GFX1, 0, &charlayout, 0, 32 },
 	{ -1 } /* end of array */
 };
 
-static gfx_decode gfxdecodeinfo2[] =
+static const gfx_decode gfxdecodeinfo2[] =
 {
 	{ REGION_GFX1, 0, &charlayout, 0, 64 },
 	{ -1 } /* end of array */
@@ -576,7 +575,7 @@ static MACHINE_DRIVER_START( themj )
 	MDRV_CPU_PROGRAM_MAP(themj_readmem,writemem)
 	MDRV_CPU_IO_MAP(readport,themj_writeport)
 
-	MDRV_MACHINE_INIT(themj)
+	MDRV_MACHINE_RESET(themj)
 
 	/* video hardware */
 	MDRV_GFXDECODE(gfxdecodeinfo2)
