@@ -7,7 +7,6 @@ driver by Nicola Salmoria
 ***************************************************************************/
 
 #include "driver.h"
-#include "vidhrdw/generic.h"
 #include "vidhrdw/konamiic.h"
 #include "cpu/konami/konami.h" /* for the callback and the firq irq definition */
 #include "machine/eeprom.h"
@@ -15,7 +14,7 @@ driver by Nicola Salmoria
 #include "sound/k053260.h"
 
 /* prototypes */
-static MACHINE_INIT( rollerg );
+static MACHINE_RESET( rollerg );
 static void rollerg_banking( int lines );
 
 VIDEO_START( rollerg );
@@ -52,8 +51,7 @@ static READ8_HANDLER( rollerg_sound_r )
 {
 	/* If the sound CPU is running, read the status, otherwise
        just make it pass the test */
-	if (Machine->sample_rate != 0) 	return K053260_0_r(2 + offset);
-	else return 0x00;
+	return K053260_0_r(2 + offset);
 }
 
 static WRITE8_HANDLER( soundirq_w )
@@ -105,7 +103,7 @@ static ADDRESS_MAP_START( writemem, ADDRESS_SPACE_PROGRAM, 8 )
 	AM_RANGE(0x0300, 0x030f) AM_WRITE(K053244_w)
 	AM_RANGE(0x0800, 0x0fff) AM_WRITE(K051316_0_w)
 	AM_RANGE(0x1000, 0x17ff) AM_WRITE(K053245_w)
-	AM_RANGE(0x1800, 0x1fff) AM_WRITE(paletteram_xBBBBBGGGGGRRRRR_swap_w) AM_BASE(&paletteram)
+	AM_RANGE(0x1800, 0x1fff) AM_WRITE(paletteram_xBBBBBGGGGGRRRRR_be_w) AM_BASE(&paletteram)
 	AM_RANGE(0x2000, 0x3aff) AM_WRITE(MWA8_RAM)
 	AM_RANGE(0x4000, 0xffff) AM_WRITE(MWA8_ROM)
 ADDRESS_MAP_END
@@ -256,7 +254,7 @@ static MACHINE_DRIVER_START( rollerg )
 								/* NMIs are generated by the 053260 */
 	MDRV_FRAMES_PER_SECOND(60)
 	MDRV_VBLANK_DURATION(DEFAULT_REAL_60HZ_VBLANK_DURATION)
-	MDRV_MACHINE_INIT(rollerg)
+	MDRV_MACHINE_RESET(rollerg)
 
 	/* video hardware */
 	MDRV_VIDEO_ATTRIBUTES(VIDEO_TYPE_RASTER | VIDEO_HAS_SHADOWS)
@@ -342,10 +340,10 @@ static void rollerg_banking( int lines )
 
 	offs = 0x10000 + ((lines & 0x07) * 0x4000);
 	if (offs >= 0x28000) offs -= 0x20000;
-	cpu_setbank(1,&RAM[offs]);
+	memory_set_bankptr(1,&RAM[offs]);
 }
 
-static MACHINE_INIT( rollerg )
+static MACHINE_RESET( rollerg )
 {
 	cpunum_set_info_fct(0, CPUINFO_PTR_KONAMI_SETLINES_CALLBACK, (genf *)rollerg_banking);
 
@@ -359,5 +357,5 @@ static DRIVER_INIT( rollerg )
 
 
 
-GAME( 1991, rollerg,  0,       rollerg, rollerg, rollerg, ROT0, "Konami", "Rollergames (US)" )
-GAME( 1991, rollergj, rollerg, rollerg, rollerg, rollerg, ROT0, "Konami", "Rollergames (Japan)" )
+GAME( 1991, rollerg,  0,       rollerg, rollerg, rollerg, ROT0, "Konami", "Rollergames (US)", 0 )
+GAME( 1991, rollergj, rollerg, rollerg, rollerg, rollerg, ROT0, "Konami", "Rollergames (Japan)", 0 )
