@@ -68,6 +68,9 @@
  ***************************************************************************/
 
 #include "driver.h"
+#include "sound/dac.h"
+#include "sound/sn76477.h"
+#include "sound/ay8910.h"
 
 extern unsigned char *route16_sharedram;
 extern unsigned char *route16_videoram1;
@@ -104,7 +107,7 @@ READ8_HANDLER( routex_prot_read )
 
 static ADDRESS_MAP_START( cpu1_readmem, ADDRESS_SPACE_PROGRAM, 8 )
 	AM_RANGE(0x0000, 0x2fff) AM_READ(MRA8_ROM)
-  /*AM_RANGE(0x3000, 0x3001) AM_READ(MRA8_NOP)	 Route 16 protection device */
+  /*AM_RANGE(0x3000, 0x3001) AM_READ(MRA8_NOP)   Route 16 protection device */
 	AM_RANGE(0x4000, 0x43ff) AM_READ(route16_sharedram_r)
 	AM_RANGE(0x4800, 0x4800) AM_READ(input_port_0_r)
 	AM_RANGE(0x5000, 0x5000) AM_READ(input_port_1_r)
@@ -114,7 +117,7 @@ ADDRESS_MAP_END
 
 static ADDRESS_MAP_START( cpu1_writemem, ADDRESS_SPACE_PROGRAM, 8 )
 	AM_RANGE(0x0000, 0x2fff) AM_WRITE(MWA8_ROM)
- 	/*AM_RANGE(0x3001, 0x3001) AM_WRITE(MWA8_NOP)	 Route 16 protection device */
+ 	/*AM_RANGE(0x3001, 0x3001) AM_WRITE(MWA8_NOP)    Route 16 protection device */
 	AM_RANGE(0x4000, 0x43ff) AM_WRITE(route16_sharedram_w) AM_BASE(&route16_sharedram)
 	AM_RANGE(0x4800, 0x4800) AM_WRITE(route16_out0_w)
 	AM_RANGE(0x5000, 0x5000) AM_WRITE(route16_out1_w)
@@ -198,7 +201,7 @@ INPUT_PORTS_START( route16 )
 	PORT_DIPSETTING(    0x08, DEF_STR( 2C_1C ) )
 	PORT_DIPSETTING(    0x00, DEF_STR( 1C_1C ) )
 	PORT_DIPSETTING(    0x10, DEF_STR( 1C_2C ) )
-/*	PORT_DIPSETTING(    0x18, DEF_STR( 2C_1C ) ) // Same as 0x08 */
+/*  PORT_DIPSETTING(    0x18, DEF_STR( 2C_1C ) ) // Same as 0x08 */
 	PORT_DIPNAME( 0x20, 0x20, DEF_STR( Cabinet ) )
 	PORT_DIPSETTING(    0x20, DEF_STR( Upright ) )
 	PORT_DIPSETTING(    0x00, DEF_STR( Cocktail ) )
@@ -369,43 +372,31 @@ INPUT_PORTS_END
 
 static struct AY8910interface ay8910_interface =
 {
-	1,	/* 1 chip */
-	10000000/8,     /* 10MHz / 8 = 1.25MHz */
-	{ 50 },
-	{ 0 },
-	{ 0 },
-	{ stratvox_sn76477_w },  /* SN76477 commands (not used in Route 16?) */
-	{ 0 }
+	0,
+	0,
+	stratvox_sn76477_w,  /* SN76477 commands (not used in Route 16?) */
+	0
 };
 
 
 static struct SN76477interface sn76477_interface =
 {
-	1,	/* 1 chip */
-	{ 50 },  /* mixing level   pin description		 */
-	{ RES_K( 47)   },		/*	4  noise_res		 */
-	{ RES_K(150)   },		/*	5  filter_res		 */
-	{ CAP_U(0.001) },		/*	6  filter_cap		 */
-	{ RES_M(3.3)   },		/*	7  decay_res		 */
-	{ CAP_U(1.0)   },		/*	8  attack_decay_cap  */
-	{ RES_K(4.7)   },		/* 10  attack_res		 */
-	{ RES_K(200)   },		/* 11  amplitude_res	 */
-	{ RES_K( 55)   },		/* 12  feedback_res 	 */
-	{ 5.0*2/(2+10) },		/* 16  vco_voltage		 */
-	{ CAP_U(0.022) },		/* 17  vco_cap			 */
-	{ RES_K(100)   },		/* 18  vco_res			 */
-	{ 5.0		   },		/* 19  pitch_voltage	 */
-	{ RES_K( 75)   },		/* 20  slf_res			 */
-	{ CAP_U(1.0)   },		/* 21  slf_cap			 */
-	{ CAP_U(2.2)   },		/* 23  oneshot_cap		 */
-	{ RES_K(4.7)   }		/* 24  oneshot_res		 */
-};
-
-
-static struct DACinterface dac_interface =
-{
-	1,
-	{ 50 }
+	RES_K( 47)   ,		/*  4  noise_res         */
+	RES_K(150)   ,		/*  5  filter_res        */
+	CAP_U(0.001) ,		/*  6  filter_cap        */
+	RES_M(3.3)   ,		/*  7  decay_res         */
+	CAP_U(1.0)   ,		/*  8  attack_decay_cap  */
+	RES_K(4.7)   ,		/* 10  attack_res        */
+	RES_K(200)   ,		/* 11  amplitude_res     */
+	RES_K( 55)   ,		/* 12  feedback_res      */
+	5.0*2/(2+10) ,		/* 16  vco_voltage       */
+	CAP_U(0.022) ,		/* 17  vco_cap           */
+	RES_K(100)   ,		/* 18  vco_res           */
+	5.0		   ,		/* 19  pitch_voltage     */
+	RES_K( 75)   ,		/* 20  slf_res           */
+	CAP_U(1.0)   ,		/* 21  slf_cap           */
+	CAP_U(2.2)   ,		/* 23  oneshot_cap       */
+	RES_K(4.7)   		/* 24  oneshot_res       */
 };
 
 
@@ -413,7 +404,6 @@ static MACHINE_DRIVER_START( route16 )
 
 	/* basic machine hardware */
 	MDRV_CPU_ADD_TAG("cpu1", Z80, 2500000)	/* 10MHz / 4 = 2.5MHz */
-	MDRV_CPU_FLAGS(CPU_16BIT_PORT)
 	MDRV_CPU_PROGRAM_MAP(cpu1_readmem,cpu1_writemem)
 	MDRV_CPU_IO_MAP(0,cpu1_writeport)
 	MDRV_CPU_VBLANK_INT(irq0_line_hold,1)
@@ -435,7 +425,10 @@ static MACHINE_DRIVER_START( route16 )
 	MDRV_VIDEO_UPDATE(route16)
 
 	/* sound hardware */
-	MDRV_SOUND_ADD(AY8910, ay8910_interface)
+	MDRV_SPEAKER_STANDARD_MONO("mono")
+	MDRV_SOUND_ADD(AY8910, 10000000/8)
+	MDRV_SOUND_CONFIG(ay8910_interface)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.50)
 MACHINE_DRIVER_END
 
 static MACHINE_DRIVER_START( routex )
@@ -452,8 +445,12 @@ static MACHINE_DRIVER_START( stratvox )
 	MDRV_IMPORT_FROM(route16)
 
 	/* sound hardware */
-	MDRV_SOUND_ADD(SN76477, sn76477_interface)
-	MDRV_SOUND_ADD(DAC, dac_interface)
+	MDRV_SOUND_ADD(SN76477, 0)
+	MDRV_SOUND_CONFIG(sn76477_interface)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.50)
+
+	MDRV_SOUND_ADD(DAC, 0)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.50)
 MACHINE_DRIVER_END
 
 
@@ -639,7 +636,7 @@ DRIVER_INIT( route16 )
 {
 	unsigned char *rom = memory_region(REGION_CPU1);
 	/* Is this actually a bootleg? some of the protection has
-	   been removed */
+       been removed */
 
 	/* patch the protection */
 	rom[0x00e9] = 0x3a;
@@ -682,10 +679,10 @@ DRIVER_INIT( stratvox )
 
 
 
-GAME( 1981, route16,  0,        route16,  route16,  route16,  ROT270, "Tehkan/Sun (Centuri license)", "Route 16" )
-GAME( 1981, route16a, route16,  route16,  route16,  route16a, ROT270, "Tehkan/Sun (Centuri license)", "Route 16 (set 2)" )
-GAME( 1981, route16b, route16,  route16,  route16,  route16b, ROT270, "bootleg", "Route 16 (bootleg)" )
-GAME( 1981, routex,   route16,  routex,   route16,  route16b, ROT270, "bootleg", "Route X (bootleg)" )
-GAME( 1980, speakres, 0,        speakres, speakres, stratvox, ROT270, "Sun Electronics", "Speak & Rescue" )
-GAME( 1980, stratvox, speakres, stratvox, stratvox, stratvox, ROT270, "[Sun Electronics] (Taito license)", "Stratovox" )
-GAME( 1980, spacecho, speakres, spacecho, spacecho, stratvox, ROT270, "bootleg", "Space Echo" )
+GAME( 1981, route16,  0,        route16,  route16,  route16,  ROT270, "Tehkan/Sun (Centuri license)", "Route 16", 0 )
+GAME( 1981, route16a, route16,  route16,  route16,  route16a, ROT270, "Tehkan/Sun (Centuri license)", "Route 16 (set 2)", 0 )
+GAME( 1981, route16b, route16,  route16,  route16,  route16b, ROT270, "bootleg", "Route 16 (bootleg)", 0 )
+GAME( 1981, routex,   route16,  routex,   route16,  route16b, ROT270, "bootleg", "Route X (bootleg)", 0 )
+GAME( 1980, speakres, 0,        speakres, speakres, stratvox, ROT270, "Sun Electronics", "Speak & Rescue", 0 )
+GAME( 1980, stratvox, speakres, stratvox, stratvox, stratvox, ROT270, "[Sun Electronics] (Taito license)", "Stratovox", 0 )
+GAME( 1980, spacecho, speakres, spacecho, spacecho, stratvox, ROT270, "bootleg", "Space Echo", 0 )
