@@ -106,7 +106,6 @@
 
 #include "driver.h"
 #include "cpu/m6809/m6809.h"
-#include "vidhrdw/generic.h"
 #include "sound/2151intf.h"
 #include "sound/upd7759.h"
 #include <math.h>
@@ -151,7 +150,7 @@ static void ym2151_irq_gen(int state)
 }
 
 
-MACHINE_INIT( rpunch )
+MACHINE_RESET( rpunch )
 {
 	memcpy(memory_region(REGION_SOUND1), memory_region(REGION_SOUND1) + 0x20000, 0x20000);
 }
@@ -164,7 +163,7 @@ MACHINE_INIT( rpunch )
  *
  *************************************/
 
-READ16_HANDLER( common_port_r )
+static READ16_HANDLER( common_port_r )
 {
 	return readinputport(offset) | readinputport(2);
 }
@@ -177,7 +176,7 @@ READ16_HANDLER( common_port_r )
  *
  *************************************/
 
-void sound_command_w_callback(int data)
+static void sound_command_w_callback(int data)
 {
 	sound_busy = 1;
 	sound_data = data;
@@ -213,7 +212,7 @@ static READ16_HANDLER( sound_busy_r )
  *
  *************************************/
 
-WRITE8_HANDLER( upd_control_w )
+static WRITE8_HANDLER( upd_control_w )
 {
 	if ((data & 1) != upd_rom_bank)
 	{
@@ -224,7 +223,7 @@ WRITE8_HANDLER( upd_control_w )
 }
 
 
-WRITE8_HANDLER( upd_data_w )
+static WRITE8_HANDLER( upd_data_w )
 {
 	upd7759_port_w(0, data);
 	upd7759_start_w(0, 0);
@@ -554,7 +553,7 @@ INPUT_PORTS_END
  *
  *************************************/
 
-static gfx_layout bglayout =
+static const gfx_layout bglayout =
 {
 	8,8,
 	RGN_FRAC(1,1),
@@ -566,7 +565,7 @@ static gfx_layout bglayout =
 };
 
 
-static gfx_layout splayout =
+static const gfx_layout splayout =
 {
 	16,32,
 	RGN_FRAC(1,1),
@@ -581,7 +580,7 @@ static gfx_layout splayout =
 };
 
 
-static gfx_decode gfxdecodeinfo[] =
+static const gfx_decode gfxdecodeinfo[] =
 {
 	{ REGION_GFX1, 0, &bglayout,   0, 16 },
 	{ REGION_GFX2, 0, &bglayout, 256, 16 },
@@ -628,7 +627,7 @@ static MACHINE_DRIVER_START( rpunch )
 	MDRV_FRAMES_PER_SECOND(60)
 	MDRV_VBLANK_DURATION(DEFAULT_REAL_60HZ_VBLANK_DURATION)
 
-	MDRV_MACHINE_INIT(rpunch)
+	MDRV_MACHINE_RESET(rpunch)
 
 	/* video hardware */
 	MDRV_VIDEO_ATTRIBUTES(VIDEO_TYPE_RASTER)
@@ -662,7 +661,7 @@ MACHINE_DRIVER_END
  *************************************/
 
 ROM_START( rpunch )
-	ROM_REGION( 0x20000, REGION_CPU1, 0 )
+	ROM_REGION( 0x40000, REGION_CPU1, 0 )
 	ROM_LOAD16_BYTE( "rpunch.20", 0x00000, 0x08000, CRC(a2028d59) SHA1(d304811853ad68b3977edb90b94f3e2c7507be82) )
 	ROM_LOAD16_BYTE( "rpunch.21", 0x00001, 0x08000, CRC(1cdb13d3) SHA1(a51b2bbbd7b4553500b65aa6a20fabe03432e6ca) )
 	ROM_LOAD16_BYTE( "rpunch.2",  0x10000, 0x08000, CRC(9b9729bb) SHA1(3fcf8df9787137d331c062bc4ee97d865af29c78) )
@@ -696,7 +695,7 @@ ROM_START( rpunch )
 ROM_END
 
 ROM_START( rabiolep )
-	ROM_REGION( 0x20000, REGION_CPU1, 0 )
+	ROM_REGION( 0x40000, REGION_CPU1, 0 )
 	ROM_LOAD16_BYTE( "rl_e2.bin", 0x00000, 0x08000, CRC(7d936a12) SHA1(4f472ccbceb13b4d0b14c686d151faa8d4c466c7) )
 	ROM_LOAD16_BYTE( "rl_d2.bin", 0x00001, 0x08000, CRC(d8d85429) SHA1(dc52c30c18026300a4625bddc987a00396bcd079) )
 	ROM_LOAD16_BYTE( "rl_e4.bin", 0x10000, 0x08000, CRC(5bfaee12) SHA1(c918b1843ad96410f41915574cf12949658c6e90) )
