@@ -39,7 +39,6 @@ TODO:
 ****************************************************************************/
 
 #include "driver.h"
-#include "vidhrdw/generic.h"
 #include "sound/sn76477.h"
 
 
@@ -48,7 +47,7 @@ size_t safarir_ram_size;
 
 static UINT8 *safarir_ram;
 
-static struct tilemap *bg_tilemap, *fg_tilemap;
+static tilemap *bg_tilemap, *fg_tilemap;
 
 
 WRITE8_HANDLER( safarir_ram_w )
@@ -201,7 +200,7 @@ INPUT_PORTS_END
 
 
 
-static struct GfxLayout charlayout =
+static const gfx_layout charlayout =
 {
 	8,8,	/* 8*8 chars */
 	128,	/* 128 characters */
@@ -213,7 +212,7 @@ static struct GfxLayout charlayout =
 };
 
 
-static struct GfxDecodeInfo gfxdecodeinfo[] =
+static const gfx_decode gfxdecodeinfo[] =
 {
 	{ REGION_GFX1, 0, &charlayout, 0, 2 },
 	{ REGION_GFX2, 0, &charlayout, 0, 2 },
@@ -299,4 +298,4 @@ DRIVER_INIT( safarir )
 }
 
 
-GAMEX( 1979, safarir, 0, safarir, safarir, safarir, ROT90, "SNK", "Safari Rally (Japan)", GAME_NO_SOUND | GAME_WRONG_COLORS )
+GAME( 1979, safarir, 0, safarir, safarir, safarir, ROT90, "SNK", "Safari Rally (Japan)", GAME_NO_SOUND | GAME_WRONG_COLORS )
