@@ -38,7 +38,6 @@ PROMs : NEC B406 (1kx4) x2
 ***********************************************************/
 
 #include "driver.h"
-#include "vidhrdw/generic.h"
 #include "cpu/i8039/i8039.h"
 #include "vidhrdw/res_net.h"
 #include "sound/ay8910.h"
@@ -47,7 +46,7 @@ PROMs : NEC B406 (1kx4) x2
 static int bgmap = 0;
 
 static int sbw_system = 0;
-static struct tilemap *sb_tilemap;
+static tilemap *sb_tilemap;
 static UINT32 color_prom_address = 0;
 static UINT8 pix_sh = 0;
 static UINT8 pix[2] = {0, 0};
@@ -182,39 +181,24 @@ static READ8_HANDLER (controls_r)
 		return input_port_3_r(0);
 }
 
-static ADDRESS_MAP_START( readmem, ADDRESS_SPACE_PROGRAM, 8 )
-	AM_RANGE(0x0000, 0x2fff) AM_READ(MRA8_RAM)
-	AM_RANGE(0x8000, 0xbfff) AM_READ(MRA8_RAM)
-	AM_RANGE(0xf801, 0xf801) AM_READ(AY8910_read_port_0_r)
-	AM_RANGE(0xfc00, 0xffff) AM_READ(MRA8_RAM)
-ADDRESS_MAP_END
-
-static ADDRESS_MAP_START( writemem, ADDRESS_SPACE_PROGRAM, 8 )
-	AM_RANGE(0x0000, 0x2fff) AM_WRITE(MWA8_ROM)
-	AM_RANGE(0x8000, 0xbfff) AM_WRITE(sbw_videoram_w) AM_BASE(&videoram) AM_SIZE(&videoram_size)
+static ADDRESS_MAP_START( main_map, ADDRESS_SPACE_PROGRAM, 8 )
+	AM_RANGE(0x0000, 0x2fff) AM_ROM
+	AM_RANGE(0x8000, 0xbfff) AM_READWRITE(MRA8_RAM, sbw_videoram_w) AM_BASE(&videoram) AM_SIZE(&videoram_size)
 	AM_RANGE(0xf800, 0xf800) AM_WRITE(AY8910_control_port_0_w)
-	AM_RANGE(0xf801, 0xf801) AM_WRITE(AY8910_write_port_0_w)
-	AM_RANGE(0xfc00, 0xffff) AM_WRITE(MWA8_RAM)
+	AM_RANGE(0xf801, 0xf801) AM_READWRITE(AY8910_read_port_0_r, AY8910_write_port_0_w)
+	AM_RANGE(0xfc00, 0xffff) AM_RAM
 ADDRESS_MAP_END
 
 
-static ADDRESS_MAP_START( readport, ADDRESS_SPACE_IO, 8 )
-	AM_RANGE(0x00, 0x00) AM_READ(input_port_0_r)
-	AM_RANGE(0x01, 0x01) AM_READ(controls_r)
-	AM_RANGE(0x02, 0x02) AM_READ(pix_data_r)
-	AM_RANGE(0x03, 0x03) AM_READ(input_port_1_r)
-	AM_RANGE(0x04, 0x04) AM_READ(input_port_4_r)
-	AM_RANGE(0x05, 0x05) AM_READ(input_port_5_r)
+static ADDRESS_MAP_START( port_map, ADDRESS_SPACE_IO, 8 )
+	AM_RANGE(0x00, 0x00) AM_READWRITE(input_port_0_r, watchdog_reset_w)
+	AM_RANGE(0x01, 0x01) AM_READWRITE(controls_r, pix_data_w)
+	AM_RANGE(0x02, 0x02) AM_READWRITE(pix_data_r, pix_shift_w)
+	AM_RANGE(0x03, 0x03) AM_READWRITE(input_port_1_r, MWA8_NOP)
+	AM_RANGE(0x04, 0x04) AM_READWRITE(input_port_4_r, system_w)
+	AM_RANGE(0x05, 0x05) AM_READWRITE(input_port_5_r, graph_control_w)
 ADDRESS_MAP_END
 
-static ADDRESS_MAP_START( writeport, ADDRESS_SPACE_IO, 8 )
-	AM_RANGE(0x00, 0x00) AM_WRITE(watchdog_reset_w)
-	AM_RANGE(0x01, 0x01) AM_WRITE(pix_data_w)
-	AM_RANGE(0x02, 0x02) AM_WRITE(pix_shift_w)
-	AM_RANGE(0x03, 0x03) AM_WRITE(MWA8_NOP)
-	AM_RANGE(0x04, 0x04) AM_WRITE(system_w)
-	AM_RANGE(0x05, 0x05) AM_WRITE(graph_control_w)
-ADDRESS_MAP_END
 
 
 INPUT_PORTS_START( sbowling )
@@ -286,7 +270,7 @@ INPUT_PORTS_START( sbowling )
 	PORT_DIPSETTING(    0x80, DEF_STR( On ) )
 INPUT_PORTS_END
 
-static struct GfxLayout charlayout =
+static const gfx_layout charlayout =
 {
 	8,8,
 	256,
@@ -297,7 +281,7 @@ static struct GfxLayout charlayout =
 	8*8
 };
 
-static struct GfxDecodeInfo gfxdecodeinfo[] =
+static const gfx_decode gfxdecodeinfo[] =
 {
 	{ REGION_GFX1, 0, &charlayout,   0x18, 1 },
 	{ -1 }
@@ -308,8 +292,8 @@ static PALETTE_INIT( sbowling )
 {
 	int i;
 
-	const int resistances_rg[3] = { 470, 270, 100 };
-	const int resistances_b[2]  = { 270, 100 };
+	static const int resistances_rg[3] = { 470, 270, 100 };
+	static const int resistances_b[2]  = { 270, 100 };
 	double outputs_r[1<<3], outputs_g[1<<3], outputs_b[1<<2];
 
 	/* the game uses output collector PROMs type: NEC B406  */
@@ -346,8 +330,8 @@ static PALETTE_INIT( sbowling )
 static MACHINE_DRIVER_START( sbowling )
 
 	MDRV_CPU_ADD(8080, 19968000/10 )
-	MDRV_CPU_PROGRAM_MAP(readmem,writemem)
-	MDRV_CPU_IO_MAP(readport,writeport)
+	MDRV_CPU_PROGRAM_MAP(main_map,0)
+	MDRV_CPU_IO_MAP(port_map,0)
 	MDRV_CPU_VBLANK_INT(sbw_interrupt, 2)
 	MDRV_FRAMES_PER_SECOND(60)
 	MDRV_VBLANK_DURATION(DEFAULT_60HZ_VBLANK_DURATION)
@@ -388,5 +372,5 @@ ROM_START( sbowling )
 	ROM_LOAD( "kb09.6m",        0x0400, 0x0400, CRC(e29191a6) SHA1(9a2c78a96ef6d118f4dacbea0b7d454b66a452ae))
 ROM_END
 
-GAMEX( 1982, sbowling, 0, sbowling, sbowling, 0, ROT90, "Taito Corporation", "Strike Bowling",GAME_IMPERFECT_SOUND)
+GAME( 1982, sbowling, 0, sbowling, sbowling, 0, ROT90, "Taito Corporation", "Strike Bowling",GAME_IMPERFECT_SOUND)
 
