@@ -100,7 +100,7 @@ static void hangon_generic_init(void)
  *
  *************************************/
 
-static MACHINE_INIT( hangon )
+static MACHINE_RESET( hangon )
 {
 	/* reset misc components */
 	segaic16_tilemap_reset(0);
@@ -775,7 +775,7 @@ static struct SEGAPCMinterface segapcm_interface =
  *
  *************************************/
 
-static gfx_layout charlayout =
+static const gfx_layout charlayout =
 {
 	8,8,
 	RGN_FRAC(1,3),
@@ -787,7 +787,7 @@ static gfx_layout charlayout =
 };
 
 
-static gfx_decode gfxdecodeinfo[] =
+static const gfx_decode gfxdecodeinfo[] =
 {
 	{ REGION_GFX1, 0, &charlayout,	0, 1024 },
 	{ -1 }
@@ -814,7 +814,7 @@ static MACHINE_DRIVER_START( hangon_base )
 	MDRV_FRAMES_PER_SECOND(60)
 	MDRV_VBLANK_DURATION(1000000 * (262 - 224) / (262 * 60))
 
-	MDRV_MACHINE_INIT(hangon)
+	MDRV_MACHINE_RESET(hangon)
 	MDRV_INTERLEAVE(100)
 
 	/* video hardware */
@@ -865,10 +865,10 @@ static MACHINE_DRIVER_START( sound_board_2203 )
 	MDRV_SOUND_ROUTE(3, "left",  0.37)
 	MDRV_SOUND_ROUTE(3, "right", 0.37)
 
-	MDRV_SOUND_ADD_TAG("pcm", SEGAPCM, SEGAPCM_SAMPLE32K)
+	MDRV_SOUND_ADD_TAG("pcm", SEGAPCM, 8000000)
 	MDRV_SOUND_CONFIG(segapcm_interface)
 	MDRV_SOUND_ROUTE(0, "left", 1.0)
-	MDRV_SOUND_ROUTE(0, "right", 1.0)
+	MDRV_SOUND_ROUTE(1, "right", 1.0)
 MACHINE_DRIVER_END
 
 
@@ -903,10 +903,10 @@ static MACHINE_DRIVER_START( sound_board_2203x2 )
 	MDRV_SOUND_ROUTE(3, "left",  0.37)
 	MDRV_SOUND_ROUTE(3, "right", 0.37)
 
-	MDRV_SOUND_ADD_TAG("pcm", SEGAPCM, SEGAPCM_SAMPLE15K)
+	MDRV_SOUND_ADD_TAG("pcm", SEGAPCM, 4000000)
 	MDRV_SOUND_CONFIG(segapcm_interface)
 	MDRV_SOUND_ROUTE(0, "left", 1.0)
-	MDRV_SOUND_ROUTE(0, "right", 1.0)
+	MDRV_SOUND_ROUTE(1, "right", 1.0)
 MACHINE_DRIVER_END
 
 
@@ -925,10 +925,10 @@ static MACHINE_DRIVER_START( sound_board_2151 )
 	MDRV_SOUND_ROUTE(0, "left", 0.43)
 	MDRV_SOUND_ROUTE(1, "right", 0.43)
 
-	MDRV_SOUND_ADD_TAG("pcm", SEGAPCM, SEGAPCM_SAMPLE15K)
+	MDRV_SOUND_ADD_TAG("pcm", SEGAPCM, 4000000)
 	MDRV_SOUND_CONFIG(segapcm_interface)
 	MDRV_SOUND_ROUTE(0, "left", 1.0)
-	MDRV_SOUND_ROUTE(0, "right", 1.0)
+	MDRV_SOUND_ROUTE(1, "right", 1.0)
 MACHINE_DRIVER_END
 
 
@@ -1103,18 +1103,93 @@ ROM_END
  **************************************************************************************************************************
  **************************************************************************************************************************
     Space Harrier
-    CPU: 68000 (317-????)
+    CPU: 68000 + i8751 (315-5163A)
 */
 ROM_START( sharrier )
 	ROM_REGION( 0x40000, REGION_CPU1, 0 ) /* 68000 code */
-	ROM_LOAD16_BYTE( "ic97.bin",  0x000000, 0x8000, CRC(7c30a036) SHA1(d3902342be714b4e181c87ad2bad7102e3eeec20) )
-	ROM_LOAD16_BYTE( "ic84.bin",  0x000001, 0x8000, CRC(16deaeb1) SHA1(bdf85b924a914865bf876eda7fc2b20131a4cf2d) )
-	ROM_LOAD16_BYTE( "ic98.bin",  0x010000, 0x8000, CRC(40b1309f) SHA1(9b050983f043a88f414745d02c912b59bbf1b121) )
-	ROM_LOAD16_BYTE( "ic85.bin",  0x010001, 0x8000, CRC(ce78045c) SHA1(ce640f05bed64ff5b47f1064b5fc13e58bc422a4) )
-	ROM_LOAD16_BYTE( "ic99.bin",  0x020000, 0x8000, CRC(f6391091) SHA1(3160b342b6447cccf67c932c7c1a42354cdfb058) )
-	ROM_LOAD16_BYTE( "ic86.bin",  0x020001, 0x8000, CRC(79b367d7) SHA1(e901036b1b9fac460415d513837c8f852f7750b0) )
-	ROM_LOAD16_BYTE( "ic100.bin", 0x030000, 0x8000, CRC(6171e9d3) SHA1(72f8736f421dc93139859fd47f0c8c3c32b6ff0b) )
-	ROM_LOAD16_BYTE( "ic87.bin",  0x030001, 0x8000, CRC(70cb72ef) SHA1(d1d89bd133b6905f81c25513d852b7e3a05a7312) )
+	ROM_LOAD16_BYTE( "epr7188a.97",  0x000000, 0x8000, CRC(45e173c3) SHA1(cbab555c5053f3e4a3f75ff78c41528e2d9d34c7) )
+	ROM_LOAD16_BYTE( "epr7184a.84",  0x000001, 0x8000, CRC(e1934a51) SHA1(67817a360b3f1f6c2440986272975bd696a38e70) )
+	ROM_LOAD16_BYTE( "ic98.bin",     0x010000, 0x8000, CRC(40b1309f) SHA1(9b050983f043a88f414745d02c912b59bbf1b121) )
+	ROM_LOAD16_BYTE( "ic85.bin",     0x010001, 0x8000, CRC(ce78045c) SHA1(ce640f05bed64ff5b47f1064b5fc13e58bc422a4) )
+	ROM_LOAD16_BYTE( "ic99.bin",     0x020000, 0x8000, CRC(f6391091) SHA1(3160b342b6447cccf67c932c7c1a42354cdfb058) )
+	ROM_LOAD16_BYTE( "ic86.bin",     0x020001, 0x8000, CRC(79b367d7) SHA1(e901036b1b9fac460415d513837c8f852f7750b0) )
+	ROM_LOAD16_BYTE( "ic100.bin",    0x030000, 0x8000, CRC(6171e9d3) SHA1(72f8736f421dc93139859fd47f0c8c3c32b6ff0b) )
+	ROM_LOAD16_BYTE( "ic87.bin",     0x030001, 0x8000, CRC(70cb72ef) SHA1(d1d89bd133b6905f81c25513d852b7e3a05a7312) )
+
+	ROM_REGION( 0x40000, REGION_CPU2, 0 ) /* second 68000 CPU */
+	ROM_LOAD16_BYTE( "ic54.bin", 0x0000, 0x8000, CRC(d7c535b6) SHA1(c0659a678c0c3776387a4a675016e9a2e9c67ee3) )
+	ROM_LOAD16_BYTE( "ic67.bin", 0x0001, 0x8000, CRC(a6153af8) SHA1(b56ba472e4afb474c7a3f7dc11d7428ebbe1a9c7) )
+
+	ROM_REGION( 0x18000, REGION_GFX1, ROMREGION_DISPOSE ) /* tiles */
+	ROM_LOAD( "sic31.bin", 0x00000, 0x08000, CRC(347fa325) SHA1(9076b16de9598b52a75e5084651ee5a220b0e88b) )
+	ROM_LOAD( "sic46.bin", 0x08000, 0x08000, CRC(39d98bd1) SHA1(5aab91bdd08b0f1ea537cd43ccc2e82fd01dd031) )
+	ROM_LOAD( "sic60.bin", 0x10000, 0x08000, CRC(3da3ea6b) SHA1(9a6ce304a14e6ef0be41d867284a63b941f960fb) )
+
+	ROM_REGION32_LE( 0x100000, REGION_GFX2, 0 ) /* sprites */
+	ROM_LOAD32_BYTE( "ic36.bin", 0x00000, 0x8000, CRC(93e2d264) SHA1(ca56de13756ab77408506d88f291da1da8134435) )
+	ROM_LOAD32_BYTE( "ic28.bin", 0x00001, 0x8000, CRC(edbf5fc3) SHA1(a93f8c431075741c181eb422b24c9303487ca16c) )
+	ROM_LOAD32_BYTE( "ic118.bin",0x00002, 0x8000, CRC(e8c537d8) SHA1(c9b3c0f33272c47d32e6aa349d72f7e355468e0e) )
+	ROM_LOAD32_BYTE( "ic8.bin",  0x00003, 0x8000, CRC(22844fa4) SHA1(6d0f177082084c8c92085cd53e1d7ddc62d09a4c) )
+	ROM_LOAD32_BYTE( "ic35.bin", 0x20000, 0x8000, CRC(cd6e7500) SHA1(6f0e42eb28ad3f5df93d8bb39dc41aba66eee144) )
+	ROM_LOAD32_BYTE( "ic27.bin", 0x20001, 0x8000, CRC(41f25a9c) SHA1(bebbd4c4600028205aeff54190b32b664e4710d0) )
+	ROM_LOAD32_BYTE( "ic17.bin", 0x20002, 0x8000, CRC(5bb09a67) SHA1(8bedefd2fa29a1a5e36f1d81c4e9067e3c7f28e9) )
+	ROM_LOAD32_BYTE( "ic7.bin",  0x20003, 0x8000, CRC(dcaa2ebf) SHA1(9cf77bb966859febc5e5f1447cb719db64aa4db4) )
+	ROM_LOAD32_BYTE( "ic34.bin", 0x40000, 0x8000, CRC(d5e15e66) SHA1(2bd81c5c736d725577adf85532de7802bef057f2) )
+	ROM_LOAD32_BYTE( "ic26.bin", 0x40001, 0x8000, CRC(ac62ae2e) SHA1(d472dcc1d9b7889d04870920d5c6e5578597b8dc) )
+	ROM_LOAD32_BYTE( "ic16.bin", 0x40002, 0x8000, CRC(9c782295) SHA1(c1627f3d849d2fdb02a590502bafbe133212b943) )
+	ROM_LOAD32_BYTE( "ic6.bin",  0x40003, 0x8000, CRC(3711105c) SHA1(075197f614786f89bee28ed944371223bc75c9be) )
+	ROM_LOAD32_BYTE( "ic33.bin", 0x60000, 0x8000, CRC(60d7c1bb) SHA1(19ddc1d8f269b50343266d508ad04d4c0fff69d1) )
+	ROM_LOAD32_BYTE( "ic25.bin", 0x60001, 0x8000, CRC(f6330038) SHA1(805d4ed664972c0773c837d62f094858c1804148) )
+	ROM_LOAD32_BYTE( "ic15.bin", 0x60002, 0x8000, CRC(60737b98) SHA1(5e91498bc473f099a1b2887baf980486e922af97) )
+	ROM_LOAD32_BYTE( "ic5.bin",  0x60003, 0x8000, CRC(70fb5ebb) SHA1(38755a9be92865d2c5da8112d8d9c0fe8e778cff) )
+	ROM_LOAD32_BYTE( "ic32.bin", 0x80000, 0x8000, CRC(6d7b5c97) SHA1(94c27e4ef1e197ee136f9399b07520cae00a366f) )
+	ROM_LOAD32_BYTE( "ic24.bin", 0x80001, 0x8000, CRC(cebf797c) SHA1(d3d5aeba1a0e70a322ec86b930814fa8bc744829) )
+	ROM_LOAD32_BYTE( "ic14.bin", 0x80002, 0x8000, CRC(24596a8b) SHA1(f580022c4f7dcaefb7209058c310a329479b5fcd) )
+	ROM_LOAD32_BYTE( "ic4.bin",  0x80003, 0x8000, CRC(b537d082) SHA1(f87a644d9af8477c9eb94e5d3aeb5f6376264418) )
+	ROM_LOAD32_BYTE( "ic31.bin", 0xa0000, 0x8000, CRC(5e784271) SHA1(063bd83b7f42dec556a7bdf736cb51456ba7184b) )
+	ROM_LOAD32_BYTE( "ic23.bin", 0xa0001, 0x8000, CRC(510e5e10) SHA1(47b9f1bc8df0690c37d1d045bd361f8599e8a903) )
+	ROM_LOAD32_BYTE( "ic13.bin", 0xa0002, 0x8000, CRC(7a2dad15) SHA1(227865447027f8669aa0d06d059f3d61da6d59dd) )
+	ROM_LOAD32_BYTE( "ic3.bin",  0xa0003, 0x8000, CRC(f5ba4e08) SHA1(443b07c996cbb213fe57dfdd3879c1d4da27c001) )
+	ROM_LOAD32_BYTE( "ic30.bin", 0xc0000, 0x8000, CRC(ec42c9ef) SHA1(313d908f3a964529b18e09825552879817a2e159) )
+	ROM_LOAD32_BYTE( "ic22.bin", 0xc0001, 0x8000, CRC(6d4a7d7a) SHA1(997ac38e47d84f0166ca3ece50ac5f2d3435d8d3) )
+	ROM_LOAD32_BYTE( "ic12.bin", 0xc0002, 0x8000, CRC(0f732717) SHA1(6a19c88d5d52f4ec4adb32c511fed4caae81c65f) )
+	ROM_LOAD32_BYTE( "ic2.bin",  0xc0003, 0x8000, CRC(fc3bf8f3) SHA1(d9168b9bce110bfd531410179a107895c641e105) )
+	ROM_LOAD32_BYTE( "ic29.bin", 0xe0000, 0x8000, CRC(ed51fdc4) SHA1(a2696b15a0911ac3b6b330b7d8df58ca51d629de) )
+	ROM_LOAD32_BYTE( "ic21.bin", 0xe0001, 0x8000, CRC(dfe75f3d) SHA1(ff908419066494bc28cbd6afe72bd30350b20c4b) )
+	ROM_LOAD32_BYTE( "ic11.bin", 0xe0002, 0x8000, CRC(a2c07741) SHA1(747c029ab399c4110dbe360b8913f5c2e57c87cc) )
+	ROM_LOAD32_BYTE( "ic1.bin",  0xe0003, 0x8000, CRC(b191e22f) SHA1(406c7f4eed0b8fe93fa0bef370e496894f4d46a4) )
+
+	ROM_REGION( 0x8000, REGION_GFX3, 0 ) /* road gfx */
+	ROM_LOAD( "pic2.bin", 0x0000, 0x8000, CRC(b4740419) SHA1(8ece2dc85692e32d0ba0b427c260c3d10ac0b7cc) )
+
+	ROM_REGION( 0x10000, REGION_CPU3, 0 ) /* sound CPU */
+	ROM_LOAD( "ic73.bin", 0x00000, 0x004000, CRC(d6397933) SHA1(b85bb47efb6c113b3676b10ab86f1798a89d45b4) )
+	ROM_LOAD( "ic72.bin", 0x04000, 0x004000, CRC(504e76d9) SHA1(302af9101da01c97ca4be6acd21fb5b8e8f0b7ef) )
+
+	ROM_REGION( 0x10000, REGION_SOUND1, 0 ) /* Sega PCM sound data */
+	ROM_LOAD( "snd7231.256", 0x00000, 0x8000, CRC(871c6b14) SHA1(6d04ddc32fdf1db409cb519890821bd10fc9e58b) )
+	ROM_LOAD( "snd7232.256", 0x08000, 0x8000, CRC(4b59340c) SHA1(a01ba8580b65dd17bfd92560265e502d95d3ff16) )
+
+	ROM_REGION( 0x10000, REGION_CPU4, 0 )	/* protection MCU */
+	ROM_LOAD( "mcu.bin", 0x00000, 0x1000, NO_DUMP )
+
+	ROM_REGION( 0x2000, REGION_PROMS, 0 ) /* zoom table */
+	ROM_LOAD( "sic123.bin", 0x0000, 0x2000, CRC(e3ec7bd6) SHA1(feec0fe664e16fac0fde61cf64b401b9b0575323) )
+ROM_END
+/**************************************************************************************************************************
+    Space Harrier
+    CPU: 68000 + i8751 (315-5163)
+*/
+ROM_START( sharrirb )
+	ROM_REGION( 0x40000, REGION_CPU1, 0 ) /* 68000 code */
+	ROM_LOAD16_BYTE( "epr7188.97",  0x000000, 0x8000, CRC(7c30a036) SHA1(d3902342be714b4e181c87ad2bad7102e3eeec20) )
+	ROM_LOAD16_BYTE( "epr7184.84",  0x000001, 0x8000, CRC(16deaeb1) SHA1(bdf85b924a914865bf876eda7fc2b20131a4cf2d) )
+	ROM_LOAD16_BYTE( "ic98.bin",    0x010000, 0x8000, CRC(40b1309f) SHA1(9b050983f043a88f414745d02c912b59bbf1b121) )
+	ROM_LOAD16_BYTE( "ic85.bin",    0x010001, 0x8000, CRC(ce78045c) SHA1(ce640f05bed64ff5b47f1064b5fc13e58bc422a4) )
+	ROM_LOAD16_BYTE( "ic99.bin",    0x020000, 0x8000, CRC(f6391091) SHA1(3160b342b6447cccf67c932c7c1a42354cdfb058) )
+	ROM_LOAD16_BYTE( "ic86.bin",    0x020001, 0x8000, CRC(79b367d7) SHA1(e901036b1b9fac460415d513837c8f852f7750b0) )
+	ROM_LOAD16_BYTE( "ic100.bin",   0x030000, 0x8000, CRC(6171e9d3) SHA1(72f8736f421dc93139859fd47f0c8c3c32b6ff0b) )
+	ROM_LOAD16_BYTE( "ic87.bin",    0x030001, 0x8000, CRC(70cb72ef) SHA1(d1d89bd133b6905f81c25513d852b7e3a05a7312) )
 
 	ROM_REGION( 0x40000, REGION_CPU2, 0 ) /* second 68000 CPU */
 	ROM_LOAD16_BYTE( "ic54.bin", 0x0000, 0x8000, CRC(d7c535b6) SHA1(c0659a678c0c3776387a4a675016e9a2e9c67ee3) )
@@ -1194,8 +1269,8 @@ ROM_START( enduror )
 	ROM_LOAD16_BYTE( "7638.rom", 0x20001, 0x8000, CRC(70544779) SHA1(e6403edd7fc0ad5d447c25be5d7f10889aa109ff) )
 
 	ROM_REGION( 0x40000, REGION_CPU2, 0 ) /* second 68000 CPU */
-	ROM_LOAD16_BYTE("7634.rom", 0x0000, 0x8000, CRC(3e07fd32) SHA1(7acb9e9712ecfe928c421c84dece783e75077746) )
-	ROM_LOAD16_BYTE("7635.rom", 0x0001, 0x8000, CRC(22f762ab) SHA1(70fa87da76c714db7213c42128a0b6a27644a1d4) )
+	ROM_LOAD16_BYTE("7634a.bin", 0x0000, 0x8000, CRC(aec83731) SHA1(3fe2d0f1a8806b850836741d664c07754a701459) )
+	ROM_LOAD16_BYTE("7635a.bin", 0x0001, 0x8000, CRC(b2fce96f) SHA1(9d6c1a7c2bdbf86430b849a5f6c6fdb5595dc91c) )
 
 	ROM_REGION( 0x18000, REGION_GFX1, ROMREGION_DISPOSE ) /* tiles */
 	ROM_LOAD( "7644.rom", 0x00000, 0x08000, CRC(e7a4ff90) SHA1(06d18470019041e32be9a969870cd995de626cd6) )
@@ -1334,7 +1409,7 @@ ROM_START( endurobl )
 	ROM_LOAD16_BYTE( "8.14j", 0x010000, 0x08000, CRC(2153154a) SHA1(145d8ed59812d26ca412a01ae77cd7872adaba5a) )
 	ROM_LOAD16_BYTE( "5.14h", 0x010001, 0x08000, CRC(0a97992c) SHA1(7a6fc8c575637107ed07a30f6f0f8cb8877cbb43) )
 	ROM_LOAD16_BYTE( "9.15j", 0x020000, 0x08000, CRC(db3bff1c) SHA1(343ed27a690800683cdd5128dcdb28c7b45288a3) )	/* one byte difference from */
-	ROM_LOAD16_BYTE( "6.15h", 0x020001, 0x08000, CRC(54b1885a) SHA1(f53d906390e5414e73c4cdcbc102d3cb3e719e67) )	/* enduro.a06 / enduro.a09 */
+	ROM_LOAD16_BYTE( "6.15h", 0x020001, 0x08000, CRC(54b1885a) SHA1(f53d906390e5414e73c4cdcbc102d3cb3e719e67) )	/* 7638.rom / 7642.rom */
 
 	ROM_REGION( 0x40000, REGION_CPU2, 0 ) /* second 68000 CPU */
 	ROM_LOAD16_BYTE("7634.rom", 0x0000, 0x8000, CRC(3e07fd32) SHA1(7acb9e9712ecfe928c421c84dece783e75077746) )
@@ -1499,10 +1574,10 @@ static DRIVER_INIT( enduror )
 static DRIVER_INIT( endurobl )
 {
 	UINT16 *rom = (UINT16 *)memory_region(REGION_CPU1);
-	UINT16 *decrypt = (UINT16 *)auto_malloc(0x50000);
+	UINT16 *decrypt = (UINT16 *)auto_malloc(0x40000);
 
 	hangon_generic_init();
-	memory_set_opcode_base(0, decrypt);
+	memory_set_decrypted_region(0, 0x000000, 0x03ffff, decrypt);
 
 	memcpy(decrypt + 0x00000/2, rom + 0x30000/2, 0x10000);
 	memcpy(decrypt + 0x10000/2, rom + 0x10000/2, 0x20000);
@@ -1512,10 +1587,10 @@ static DRIVER_INIT( endurobl )
 static DRIVER_INIT( endurob2 )
 {
 	UINT16 *rom = (UINT16 *)memory_region(REGION_CPU1);
-	UINT16 *decrypt = (UINT16 *)auto_malloc(0x50000);
+	UINT16 *decrypt = (UINT16 *)auto_malloc(0x40000);
 
 	hangon_generic_init();
-	memory_set_opcode_base(0, decrypt);
+	memory_set_decrypted_region(0, 0x000000, 0x03ffff, decrypt);
 
 	memcpy(decrypt, rom, 0x30000);
 	/* missing data ROM */
@@ -1531,7 +1606,8 @@ static DRIVER_INIT( endurob2 )
 
 GAME( 1985, hangon,   0,        hangon,   hangon,   hangon,   ROT0, "Sega",    "Hang-On", 0 )
 GAME( 1992, shangupb, shangon,  shangupb, shangupb, hangon,   ROT0, "bootleg", "Super Hang-On (Hang-On upgrade, bootleg)", 0 )
-GAME( 1985, sharrier, 0,        sharrier, sharrier, sharrier, ROT0, "Sega",    "Space Harrier", 0 )
+GAME( 1985, sharrier, 0,        sharrier, sharrier, sharrier, ROT0, "Sega",    "Space Harrier (Rev A, 8751 315-5163A)", 0 )
+GAME( 1985, sharrirb, sharrier, sharrier, sharrier, sharrier, ROT0, "Sega",    "Space Harrier (8751 315-5163)", 0 )
 GAME( 1986, enduror,  0,        enduror,  enduror,  enduror,  ROT0, "Sega",    "Enduro Racer (YM2151, FD1089B 317-0013A)", 0 )
 GAME( 1986, enduror1, enduror,  enduror1, enduror,  enduror,  ROT0, "Sega",    "Enduro Racer (YM2203, FD1089B 317-0013A)", 0 )
 GAME( 1986, endurobl, enduror,  enduror1, enduror,  endurobl, ROT0, "bootleg", "Enduro Racer (bootleg set 1)", 0 )
