@@ -31,7 +31,7 @@
     TODO:
     - locate Pig Newton cocktail mode?
     - verify Pig Newton and Sindbad Mystery DIPs
-    - attempt Pig Newton, 005 sound
+    - attempt 005 sound
     - fix transparency issues (Pig Newton, Sindbad Mystery)
     - fix Space Odyssey background
     - figure out why Astro Blaster version 1 ends the game right away
@@ -47,7 +47,6 @@
 ***************************************************************************/
 
 #include "driver.h"
-#include "vidhrdw/generic.h"
 #include "cpu/i8039/i8039.h"
 #include "cpu/z80/z80.h"
 #include "machine/segacrpt.h"
@@ -60,6 +59,49 @@
 #include "sound/sp0250.h"
 
 
+
+
+/*************************************
+ *
+ *  Machine setup and config
+ *
+ *************************************/
+
+static void service_switch(void *param, UINT32 oldval, UINT32 newval)
+{
+	/* pressing the service switch sends an NMI */
+	if (newval)
+		cpunum_set_input_line(0, INPUT_LINE_NMI, PULSE_LINE);
+}
+
+
+static MACHINE_RESET( pignewt )
+{
+	sega_usb_reset(0x10);
+}
+
+
+static offs_t decrypt_offset(offs_t offset)
+{
+	offs_t pc;
+
+	/* if no active CPU, don't do anything */
+	if (cpu_getactivecpu() == -1)
+		return offset;
+
+	/* ignore anything but accesses via opcode $32 (LD $(XXYY),A) */
+	pc = activecpu_get_previouspc();
+	if ((UINT16)pc == 0xffff || program_read_byte(pc) != 0x32)
+		return offset;
+
+	/* fetch the low byte of the address and munge it */
+	return (offset & 0xff00) | (*sega_decrypt)(pc, program_read_byte(pc + 1));
+}
+
+static WRITE8_HANDLER( usb_ram_w ) { sega_usb_ram_w(decrypt_offset(offset), data); }
+
+
+
 /*************************************
  *
  *  Interrupt handling
@@ -246,8 +288,9 @@ static WRITE8_HANDLER( sindbadm_SN76496_1_w )
  *************************************/
 
 static ADDRESS_MAP_START( readmem, ADDRESS_SPACE_PROGRAM, 8 )
-	AM_RANGE(0x0000, 0xc7ff) AM_READ(MRA8_ROM)
-	AM_RANGE(0xc800, 0xcfff) AM_READ(MRA8_RAM)	/* Misc RAM */
+	AM_RANGE(0x0000, 0x7fff) AM_READ(MRA8_ROM)
+	AM_RANGE(0x8000, 0xc7ff) AM_READ(MRA8_ROM)
+	AM_RANGE(0xc800, 0xcfff) AM_READ(MRA8_RAM)  /* Misc RAM */
 	AM_RANGE(0xe000, 0xe3ff) AM_READ(MRA8_RAM)
 	AM_RANGE(0xe400, 0xe7ff) AM_READ(MRA8_RAM)	/* Used by at least Monster Bash? */
 	AM_RANGE(0xe800, 0xefff) AM_READ(MRA8_RAM)
@@ -259,17 +302,21 @@ ADDRESS_MAP_END
 
 
 static ADDRESS_MAP_START( writemem, ADDRESS_SPACE_PROGRAM, 8 )
-	AM_RANGE(0x0000, 0xffff) AM_WRITE(segar_w) AM_BASE(&segar_mem)
+	AM_RANGE(0x0000, 0xffff) AM_WRITE(segar_w)
+	AM_RANGE(0xc800, 0xcfff) AM_WRITE(MWA8_RAM) AM_BASE(&segar_miscram1)
 	AM_RANGE(0xe000, 0xe3ff) AM_WRITE(MWA8_RAM) AM_BASE(&videoram) AM_SIZE(&videoram_size)	/* handled by */
+	AM_RANGE(0xe400, 0xe7ff) AM_WRITE(MWA8_RAM) AM_BASE(&segar_monsterbram)
 	AM_RANGE(0xe800, 0xefff) AM_WRITE(MWA8_RAM) AM_BASE(&segar_characterram)    	/* the above, */
 	AM_RANGE(0xf000, 0xf03f) AM_WRITE(MWA8_RAM) AM_BASE(&segar_mem_colortable)     /* here only */
 	AM_RANGE(0xf040, 0xf07f) AM_WRITE(MWA8_RAM) AM_BASE(&segar_mem_bcolortable)    /* to initialize */
+	AM_RANGE(0xf080, 0xf7ff) AM_WRITE(MWA8_RAM) AM_BASE(&segar_miscram2)
 	AM_RANGE(0xf800, 0xffff) AM_WRITE(MWA8_RAM) AM_BASE(&segar_characterram2)    	/* the pointers */
 ADDRESS_MAP_END
 
 
 static ADDRESS_MAP_START( sindbadm_writemem, ADDRESS_SPACE_PROGRAM, 8 )
-	AM_RANGE(0x0000, 0xc7ff) AM_WRITE(MWA8_ROM)
+	AM_RANGE(0x0000, 0x7fff) AM_WRITE(MWA8_ROM)
+	AM_RANGE(0x8000, 0xc7ff) AM_WRITE(MWA8_ROM)
 	AM_RANGE(0xc800, 0xcfff) AM_WRITE(MWA8_RAM)
 	AM_RANGE(0xe000, 0xe3ff) AM_WRITE(videoram_w) AM_BASE(&videoram) AM_SIZE(&videoram_size)
 	AM_RANGE(0xe400, 0xe7ff) AM_WRITE(MWA8_RAM)
@@ -290,7 +337,6 @@ ADDRESS_MAP_END
 
 static ADDRESS_MAP_START( readport, ADDRESS_SPACE_IO, 8 )
 	ADDRESS_MAP_FLAGS( AMEF_ABITS(8) )
-/*AM_RANGE(0x3f, 0x3f) AM_READ(MRA8_NOP)    Pig Newton - read from 1D87    */
 	AM_RANGE(0x0e, 0x0e) AM_READ(monsterb_audio_8255_r)
 	AM_RANGE(0x81, 0x81) AM_READ(input_port_8_r)     /* only used by Sindbad Mystery */
 	AM_RANGE(0xf8, 0xfc) AM_READ(segar_ports_r)
@@ -771,9 +817,9 @@ SEGAR_COMMON2C
 	PORT_DIPSETTING(    0x10, "4" )
 	PORT_DIPSETTING(    0x20, "5" )
 	PORT_DIPSETTING(    0x30, "6" )
-	PORT_DIPNAME( 0x40, 0x00, DEF_STR( Unknown ) )
-	PORT_DIPSETTING(    0x40, DEF_STR( Off ) )
-	PORT_DIPSETTING(    0x00, DEF_STR( On ) )
+	PORT_DIPNAME( 0x40, 0x40, DEF_STR( Demo_Sounds ) )
+	PORT_DIPSETTING(    0x00, DEF_STR( Off ) )
+	PORT_DIPSETTING(    0x40, DEF_STR( On ) )
 	PORT_DIPNAME( 0x80, 0x00, DEF_STR( Unknown ) )
 	PORT_DIPSETTING(    0x80, DEF_STR( Off ) )
 	PORT_DIPSETTING(    0x00, DEF_STR( On ) )
@@ -828,9 +874,9 @@ SEGAR_COMMON1
 	PORT_DIPSETTING(    0x10, "4" )
 	PORT_DIPSETTING(    0x20, "5" )
 	PORT_DIPSETTING(    0x30, "6" )
-	PORT_DIPNAME( 0x40, 0x00, DEF_STR( Unknown ) )
-	PORT_DIPSETTING(    0x40, DEF_STR( Off ) )
-	PORT_DIPSETTING(    0x00, DEF_STR( On ) )
+	PORT_DIPNAME( 0x40, 0x40, DEF_STR( Demo_Sounds ) )
+	PORT_DIPSETTING(    0x00, DEF_STR( Off ) )
+	PORT_DIPSETTING(    0x40, DEF_STR( On ) )
 	PORT_DIPNAME( 0x80, 0x00, DEF_STR( Unknown ) )
 	PORT_DIPSETTING(    0x80, DEF_STR( Off ) )
 	PORT_DIPSETTING(    0x00, DEF_STR( On ) )
@@ -935,7 +981,7 @@ INPUT_PORTS_END
  *
  *************************************/
 
-static struct GfxLayout charlayout =
+static const gfx_layout charlayout =
 {
 	8,8,
 	256,
@@ -947,7 +993,7 @@ static struct GfxLayout charlayout =
 };
 
 
-static struct GfxLayout backlayout =
+static const gfx_layout backlayout =
 {
 	8,8,
 	256,
@@ -959,7 +1005,7 @@ static struct GfxLayout backlayout =
 };
 
 
-static struct GfxLayout spaceod_layout =
+static const gfx_layout spaceod_layout =
 {
 	8,8,
 	256,
@@ -971,14 +1017,14 @@ static struct GfxLayout spaceod_layout =
 };
 
 
-static struct GfxDecodeInfo gfxdecodeinfo[] =
+static const gfx_decode gfxdecodeinfo[] =
 {
 	{ REGION_CPU1, 0xe800, &charlayout, 0x01, 0x10 },
 	{ -1 } /* end of array */
 };
 
 
-static struct GfxDecodeInfo monsterb_gfxdecodeinfo[] =
+static const gfx_decode monsterb_gfxdecodeinfo[] =
 {
 	{ REGION_CPU1, 0xe800, &charlayout, 0x01, 0x10 },
 	{ REGION_GFX1, 0x0000, &backlayout, 0x41, 0x10 },
@@ -989,7 +1035,7 @@ static struct GfxDecodeInfo monsterb_gfxdecodeinfo[] =
 };
 
 
-static struct GfxDecodeInfo spaceod_gfxdecodeinfo[] =
+static const gfx_decode spaceod_gfxdecodeinfo[] =
 {
 	{ REGION_CPU1, 0xe800, &charlayout,     0x01, 0x10 },
 	{ REGION_GFX1, 0x0000, &spaceod_layout, 0x41, 1 },
@@ -1049,7 +1095,7 @@ static struct TMS36XXinterface monsterb_tms3617_interface =
 static MACHINE_DRIVER_START( segar )
 
 	/* basic machine hardware */
-	MDRV_CPU_ADD_TAG("main", Z80, 3867120)
+	MDRV_CPU_ADD_TAG("main", Z80, 4000000)
 	MDRV_CPU_PROGRAM_MAP(readmem,writemem)
 	MDRV_CPU_IO_MAP(readport,writeport)
 	MDRV_CPU_VBLANK_INT(segar_interrupt,1)
@@ -1078,19 +1124,13 @@ static MACHINE_DRIVER_START( astrob )
 	/* basic machine hardware */
 	MDRV_IMPORT_FROM(segar)
 
-	MDRV_CPU_ADD(I8035, 3120000)
-	/* audio CPU */
-	MDRV_CPU_PROGRAM_MAP(sega_speechboard_readmem, sega_speechboard_writemem)
-	MDRV_CPU_IO_MAP (sega_speechboard_readport,sega_speechboard_writeport)
-
 	/* sound hardware */
 	MDRV_SOUND_ADD(SAMPLES, 0)
 	MDRV_SOUND_CONFIG(astrob_samples_interface)
 	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.25)
 
-	MDRV_SOUND_ADD(SP0250, 0)
-	MDRV_SOUND_CONFIG(sega_sp0250_interface)
-	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 1.0)
+	/* speech board */
+	MDRV_IMPORT_FROM(sega_speech_board)
 MACHINE_DRIVER_END
 
 
@@ -1165,6 +1205,8 @@ static MACHINE_DRIVER_START( pignewt )
 	/* basic machine hardware */
 	MDRV_IMPORT_FROM(segar)
 
+	MDRV_MACHINE_RESET(pignewt)
+
 	/* video hardware */
 	MDRV_GFXDECODE(monsterb_gfxdecodeinfo)
 	MDRV_PALETTE_LENGTH(16*4*2+1)
@@ -1172,6 +1214,9 @@ static MACHINE_DRIVER_START( pignewt )
 
 	MDRV_VIDEO_START(monsterb)
 	MDRV_VIDEO_UPDATE(sindbadm)
+
+	/* universal sound board */
+	MDRV_IMPORT_FROM(sega_universal_sound_board)
 MACHINE_DRIVER_END
 
 
@@ -1421,7 +1466,7 @@ ROM_START( monsterb )
 ROM_END
 
 ROM_START( monster2 )
-	ROM_REGION( 0x14000, REGION_CPU1, 0 )     /* 64k for code + space for background */
+	ROM_REGION( 2*0x10000, REGION_CPU1, 0 )     /* 64k for code + 64k for decrypted opcodes */
 	ROM_LOAD( "epr-1548",     0x0000, 0x2000, CRC(239f77c1) SHA1(2945e4b135c1c46bf3e0d947b3d9be052f12e8d8) )
 	ROM_LOAD( "epr-1549",     0x2000, 0x2000, CRC(40aeb223) SHA1(8e0cc1b53ded819673719ffe1fd69feb1ca6fa29) )
 	ROM_LOAD( "epr-1550",     0x4000, 0x2000, CRC(b42bb2b3) SHA1(88bd5b027c46cde9f89e90f50ae2c381681ae483) )
@@ -1459,6 +1504,7 @@ ROM_START( monster2 )
 ROM_END
 
 
+
 ROM_START( spaceod )
 	ROM_REGION( 0x10000, REGION_CPU1, 0 )     /* 64k for code */
 	ROM_LOAD( "so-959.dat",   0x0000, 0x0800, CRC(bbae3cd1) SHA1(2e99fd4b0db60462721b174b0db1b10b2fd13d25) ) /* U25 */
@@ -1531,8 +1577,6 @@ ROM_START( pignewt )
 	ROM_LOAD( "1906c.bg",  0x0000, 0x1000, CRC(c79d33ce) SHA1(8a5332a801d0db6e5f33c0d39d165819f9914e65) ) /* ??? */
 	ROM_LOAD( "1907c.bg",  0x1000, 0x1000, CRC(bc839d3c) SHA1(80b1c96cac7c51e49ca40a1c5fbc156b12529d2f) ) /* ??? */
 	ROM_LOAD( "1908c.bg",  0x2000, 0x1000, CRC(92cb14da) SHA1(257db7bb2758d579bcf171cda410acff1877122c) ) /* ??? */
-
-	/* SOUND ROMS ARE PROBABLY MISSING! */
 ROM_END
 
 
@@ -1571,8 +1615,6 @@ ROM_START( pignewta )
 	ROM_LOAD( "1906a.bg",  0x0000, 0x1000, BAD_DUMP CRC(c79d33ce) SHA1(8a5332a801d0db6e5f33c0d39d165819f9914e65)  ) /* ??? */
 	ROM_LOAD( "1907a.bg",  0x1000, 0x1000, BAD_DUMP CRC(bc839d3c) SHA1(80b1c96cac7c51e49ca40a1c5fbc156b12529d2f)  ) /* ??? */
 	ROM_LOAD( "1908a.bg",  0x2000, 0x1000, BAD_DUMP CRC(92cb14da) SHA1(257db7bb2758d579bcf171cda410acff1877122c)  ) /* ??? */
-
-	/* SOUND ROMS ARE PROBABLY MISSING! */
 ROM_END
 
 
@@ -1612,7 +1654,8 @@ static DRIVER_INIT( astrob )
 	/* This game uses the 315-0062 security chip */
 	sega_security(62);
 
-	memory_install_write8_handler(0, ADDRESS_SPACE_IO, 0x38, 0x38, 0, 0, sega_sh_speechboard_w);
+	memory_install_write8_handler(0, ADDRESS_SPACE_IO, 0x38, 0x38, 0, 0, sega_speech_data_w);
+	memory_install_write8_handler(0, ADDRESS_SPACE_IO, 0x3b, 0x3b, 0, 0, sega_speech_control_w);
 	memory_install_write8_handler(0, ADDRESS_SPACE_IO, 0x3e, 0x3f, 0, 0, astrob_audio_ports_w);
 }
 
@@ -1635,19 +1678,49 @@ static DRIVER_INIT( monsterb )
 
 static DRIVER_INIT( monster2 )
 {
-
-	/* This game uses an encrypted CPU */
-/*  monster2_decode(); */
+	/* This game uses the 315-5006 encrypted CPU */
 	spatter_decode();
 
-	/* This game uses the 315-0082 security chip */
-	sega_security(82);
+	sega_security(0);
 
 	memory_install_write8_handler(0, ADDRESS_SPACE_IO, 0x0c, 0x0f, 0, 0, monsterb_audio_8255_w);
-	memory_install_write8_handler(0, ADDRESS_SPACE_IO, 0xbc, 0xbc, 0, 0, monsterb_back_port_w);
+	memory_install_write8_handler(0, ADDRESS_SPACE_IO, 0xb9, 0xb9, 0, 0, monster2_b9_back_port_w);
+	memory_install_write8_handler(0, ADDRESS_SPACE_IO, 0xbb, 0xbb, 0, 0, monster2_bb_back_port_w);
+/*
+cpu #0 (PC=000064CD): unmapped I/O byte write to 000000BC = 03
+cpu #0 (PC=000064DB): unmapped I/O byte write to 000000B8 = 00
+cpu #0 (PC=000064E5): unmapped I/O byte write to 000000BA = 00
+cpu #0 (PC=000064E9): unmapped I/O byte write to 000000BB = 01
+*/
+	/* the background tilemap rom has a different layout, rearrange it to match the set 1 format */
+	{
+		UINT8 *rom = memory_region(REGION_USER1);
+		int length = memory_region_length(REGION_USER1);
+		UINT8 *buf1 = malloc(length);
+		int x;
+
+
+		for (x=0;x<length;x++)
+		{
+			UINT16 addr;
+
+			addr = BITSWAP16(x,
+			                    15,14,13,12,6,
+			                    5,11,10,
+			                    9, 8,7, 4,
+			                    3, 2, 1, 0 );
+
+			buf1[addr] = rom[x];
+		}
+
+		memcpy(rom,buf1,length);
+		free (buf1);
+	}
+
 }
 
 
+
 static DRIVER_INIT( spaceod )
 {
 	/* This game uses the 315-0063 security chip */
@@ -1670,6 +1743,11 @@ static DRIVER_INIT( pignewt )
 	memory_install_write8_handler(0, ADDRESS_SPACE_IO, 0xb4, 0xb5, 0, 0, pignewt_back_color_w);  /* Just guessing */
 	memory_install_write8_handler(0, ADDRESS_SPACE_IO, 0xb8, 0xbc, 0, 0, pignewt_back_ports_w);   /* Just guessing */
 	memory_install_write8_handler(0, ADDRESS_SPACE_IO, 0xbe, 0xbe, 0, 0, MWA8_NOP);
+
+	memory_install_read8_handler(0, ADDRESS_SPACE_IO, 0x3f, 0x3f, 0, 0, sega_usb_status_r);
+	memory_install_write8_handler(0, ADDRESS_SPACE_IO, 0x3f, 0x3f, 0, 0, sega_usb_data_w);
+	memory_install_read8_handler(0, ADDRESS_SPACE_PROGRAM, 0xd000, 0xdfff, 0, 0, sega_usb_ram_r);
+	memory_install_write8_handler(0, ADDRESS_SPACE_PROGRAM, 0xd000, 0xdfff, 0, 0, usb_ram_w);
 }
 
 
@@ -1687,14 +1765,14 @@ static DRIVER_INIT( sindbadm )
  *
  *************************************/
 
-GAME( 1981, astrob,   0,       astrob,   astrob,   astrob,   ROT270, "Sega", "Astro Blaster (version 3)" )
-GAME( 1981, astrob2,  astrob,  astrob,   astrob2,  astrob,   ROT270, "Sega", "Astro Blaster (version 2)" )
-GAME( 1981, astrob2a, astrob,  astrob,   astrob2,  astrob,   ROT270, "Sega", "Astro Blaster (version 2a)" )
-GAMEX(1981, astrob1,  astrob,  astrob,   astrob1,  astrob,   ROT270, "Sega", "Astro Blaster (version 1)", GAME_NOT_WORKING )
-GAMEX(1981, 005,      0,       005,      005,      005,      ROT270, "Sega", "005", GAME_NO_SOUND )
-GAME( 1982, monsterb, 0,       monsterb, monsterb, monsterb, ROT270, "Sega", "Monster Bash" )
-GAMEX(1982, monster2, monsterb,monsterb, monsterb, monster2, ROT270, "Sega", "Monster Bash (2 board version)", GAME_NOT_WORKING )
-GAME( 1981, spaceod,  0,       spaceod,  spaceod,  spaceod,  ROT270, "Sega", "Space Odyssey" )
-GAMEX(1983, pignewt,  0,       pignewt,  pignewt,  pignewt,  ROT270, "Sega", "Pig Newton (version C)", GAME_NO_SOUND )
-GAMEX(1983, pignewta, pignewt, pignewt,  pignewta, pignewt,  ROT270, "Sega", "Pig Newton (version A)", GAME_NO_SOUND )
-GAME( 1983, sindbadm, 0,       sindbadm, sindbadm, sindbadm, ROT270, "Sega", "Sindbad Mystery" )
+GAME( 1981, astrob,   0,       astrob,   astrob,   astrob,   ROT270, "Sega", "Astro Blaster (version 3)", 0 )
+GAME( 1981, astrob2,  astrob,  astrob,   astrob2,  astrob,   ROT270, "Sega", "Astro Blaster (version 2)", 0 )
+GAME( 1981, astrob2a, astrob,  astrob,   astrob2,  astrob,   ROT270, "Sega", "Astro Blaster (version 2a)", 0 )
+GAME( 1981, astrob1,  astrob,  astrob,   astrob1,  astrob,   ROT270, "Sega", "Astro Blaster (version 1)", GAME_NOT_WORKING )
+GAME( 1981, 005,      0,       005,      005,      005,      ROT270, "Sega", "005", GAME_NO_SOUND )
+GAME( 1982, monsterb, 0,       monsterb, monsterb, monsterb, ROT270, "Sega", "Monster Bash", 0 )
+GAME( 1982, monster2, monsterb,monsterb, monsterb, monster2, ROT270, "Sega", "Monster Bash (2 board version)",GAME_IMPERFECT_GRAPHICS )
+GAME( 1981, spaceod,  0,       spaceod,  spaceod,  spaceod,  ROT270, "Sega", "Space Odyssey", 0 )
+GAME( 1983, pignewt,  0,       pignewt,  pignewt,  pignewt,  ROT270, "Sega", "Pig Newton (version C)", GAME_IMPERFECT_SOUND )
+GAME( 1983, pignewta, pignewt, pignewt,  pignewta, pignewt,  ROT270, "Sega", "Pig Newton (version A)", GAME_IMPERFECT_SOUND )
+GAME( 1983, sindbadm, 0,       sindbadm, sindbadm, sindbadm, ROT270, "Sega", "Sindbad Mystery", 0 )
