@@ -34,13 +34,15 @@ secondary crystal, numbers unknown for the TMS9928
 #include "machine/segacrpt.h"
 
 static ADDRESS_MAP_START( readmem, ADDRESS_SPACE_PROGRAM, 8 )
-    AM_RANGE(0x0000, 0xbFFF) AM_READ(MRA8_ROM)
+    AM_RANGE(0x0000, 0x7FFF) AM_READ(MRA8_ROM)
+    AM_RANGE(0x8000, 0xbFFF) AM_READ(MRA8_ROM)
     AM_RANGE(0xc000, 0xc3ff) AM_READ(MRA8_RAM)
 
 ADDRESS_MAP_END
 
 static ADDRESS_MAP_START( writemem, ADDRESS_SPACE_PROGRAM, 8 )
-    AM_RANGE(0x0000, 0xbFFF) AM_WRITE(MWA8_ROM)
+    AM_RANGE(0x0000, 0x7FFF) AM_WRITE(MWA8_ROM)
+    AM_RANGE(0x8000, 0xbFFF) AM_WRITE(MWA8_ROM)
     AM_RANGE(0xc000, 0xc3ff) AM_WRITE(MWA8_RAM)
 ADDRESS_MAP_END
 
@@ -188,6 +190,6 @@ DRIVER_INIT(chwrestl)
 	regulus_decode();
 }
 
-GAME( 1984, chboxing, 0, sg1000a, chboxing, 0, ROT0, "Sega", "Champion Boxing")
-GAME( 1985, chwrestl, 0, sg1000a, chwrestl, chwrestl, ROT0, "Sega", "Champion Pro Wrestling")
+GAME( 1984, chboxing, 0, sg1000a, chboxing, 0, ROT0, "Sega", "Champion Boxing", 0)
+GAME( 1985, chwrestl, 0, sg1000a, chwrestl, chwrestl, ROT0, "Sega", "Champion Pro Wrestling", 0)
 
