@@ -77,7 +77,7 @@ static const char *instruction_name[64] =
 	"RGCPY","RGCPY","RGCPY","RGCPY" 	/* Fx */
 };
 
-int HD63484_start(void)
+static int HD63484_start(void)
 {
 	fifo_counter = 0;
 	HD63484_ram = auto_malloc(HD63484_RAM_SIZE);
@@ -86,10 +86,6 @@ int HD63484_start(void)
 	return 0;
 }
 
-void HD63484_stop(void)
-{
-}
-
 static void doclr(int opcode,UINT16 fill,int *dst,INT16 _ax,INT16 _ay)
 {
 	INT16 ax,ay;
@@ -607,7 +603,7 @@ rwp /= 2;
 		else
 {
 logerror("unsupported command\n");
-usrintf_showmessage("unsupported command %s (%04x)",instruction_name[fifo[0]>>10],fifo[0]);
+ui_popup("unsupported command %s (%04x)",instruction_name[fifo[0]>>10],fifo[0]);
 }
 
 		fifo_counter = 0;
@@ -717,11 +713,6 @@ VIDEO_START( shanghai )
 	return HD63484_start();
 }
 
-VIDEO_STOP( shanghai )
-{
-	HD63484_stop();
-}
-
 VIDEO_UPDATE( shanghai )
 {
 	int x,y,b;
@@ -808,7 +799,7 @@ ADDRESS_MAP_END
 
 static ADDRESS_MAP_START( shangha2_writemem, ADDRESS_SPACE_PROGRAM, 8 )
 	AM_RANGE(0x00000, 0x03fff) AM_WRITE(MWA8_RAM)
-	AM_RANGE(0x04000, 0x041ff) AM_WRITE(paletteram_xxxxBBBBGGGGRRRR_w) AM_BASE(&paletteram)
+	AM_RANGE(0x04000, 0x041ff) AM_WRITE(paletteram_xxxxBBBBGGGGRRRR_le_w) AM_BASE(&paletteram)
 	AM_RANGE(0x80000, 0xfffff) AM_WRITE(MWA8_ROM)
 ADDRESS_MAP_END
 
@@ -850,7 +841,7 @@ static ADDRESS_MAP_START( kothello_mem, ADDRESS_SPACE_PROGRAM, 8 )
 	AM_RANGE(0x08010, 0x08011) AM_READ(kothello_HD63484_status_r) AM_WRITE(HD63484_address_w)
 	AM_RANGE(0x08012, 0x08013) AM_READ(HD63484_data_r) AM_WRITE(HD63484_data_w)
 	AM_RANGE(0x09010, 0x0901f) AM_READ(shanghai_rand_r)AM_WRITENOP /* unknown, sub cpu communication ? */
-	AM_RANGE(0x0a000, 0x0a1ff) AM_WRITE(paletteram_xxxxBBBBGGGGRRRR_w) AM_BASE(&paletteram)
+	AM_RANGE(0x0a000, 0x0a1ff) AM_WRITE(paletteram_xxxxBBBBGGGGRRRR_le_w) AM_BASE(&paletteram)
 	AM_RANGE(0x0b010, 0x0b01f) AM_READ(seibu_main_v30_r) AM_WRITE(seibu_main_v30_w)
 	AM_RANGE(0x80000, 0xfffff) AM_ROM
 ADDRESS_MAP_END
@@ -1109,7 +1100,7 @@ static MACHINE_DRIVER_START( kothello )
 	MDRV_VBLANK_DURATION(DEFAULT_60HZ_VBLANK_DURATION)
 	MDRV_INTERLEAVE(200)
 
-	MDRV_MACHINE_INIT(seibu_sound_1)
+	MDRV_MACHINE_RESET(seibu_sound_1)
 
 	/* video hardware */
 	MDRV_VIDEO_ATTRIBUTES(VIDEO_TYPE_RASTER)
@@ -1220,7 +1211,7 @@ ROM_END
 
 
 
-GAMEX(1988, shanghai, 0, shanghai, shanghai, 0, ROT0, "Sunsoft", "Shanghai (Japan)", GAME_IMPERFECT_GRAPHICS )
-GAME( 1989, shangha2, 0, shangha2, shangha2, 0, ROT0, "Sunsoft", "Shanghai II (Japan)" )
-GAMEX(1990, kothello, 0, kothello, kothello, 0, ROT0, "Success", "Kyuukyoku no Othello", GAME_NOT_WORKING )
+GAME( 1988, shanghai, 0, shanghai, shanghai, 0, ROT0, "Sunsoft", "Shanghai (Japan)", GAME_IMPERFECT_GRAPHICS )
+GAME( 1989, shangha2, 0, shangha2, shangha2, 0, ROT0, "Sunsoft", "Shanghai II (Japan)", 0 )
+GAME( 1990, kothello, 0, kothello, kothello, 0, ROT0, "Success", "Kyuukyoku no Othello", GAME_NOT_WORKING )
 
