@@ -51,7 +51,7 @@ static void update_interrupts(void)
  *
  *************************************/
 
-static MACHINE_INIT( shuuz )
+static MACHINE_RESET( shuuz )
 {
 	atarigen_eeprom_reset();
 	atarivc_reset(atarivc_eof_data, 1);
@@ -245,7 +245,7 @@ INPUT_PORTS_END
  *
  *************************************/
 
-static gfx_layout pfmolayout =
+static const gfx_layout pfmolayout =
 {
 	8,8,
 	RGN_FRAC(1,2),
@@ -257,7 +257,7 @@ static gfx_layout pfmolayout =
 };
 
 
-static gfx_decode gfxdecodeinfo[] =
+static const gfx_decode gfxdecodeinfo[] =
 {
 	{ REGION_GFX1, 0, &pfmolayout,  256, 16 },		/* sprites & playfield */
 	{ REGION_GFX2, 0, &pfmolayout,    0, 16 },		/* sprites & playfield */
@@ -281,7 +281,7 @@ static MACHINE_DRIVER_START( shuuz )
 	MDRV_FRAMES_PER_SECOND(60)
 	MDRV_VBLANK_DURATION(DEFAULT_REAL_60HZ_VBLANK_DURATION)
 
-	MDRV_MACHINE_INIT(shuuz)
+	MDRV_MACHINE_RESET(shuuz)
 	MDRV_NVRAM_HANDLER(atarigen)
 
 	/* video hardware */
