@@ -82,8 +82,6 @@ extern void decrypt156(void);
 #include "deco32.h"
 #include "cpu/arm/arm.h"
 #include "machine/eeprom.h"
-#include "vidhrdw/generic.h"
-#include "machine/random.h"
 #include "sound/okim6295.h"
 #include "deco16ic.h"
 
@@ -412,7 +410,7 @@ static ADDRESS_MAP_START( joemacr_map, ADDRESS_SPACE_PROGRAM, 32 )
 ADDRESS_MAP_END
 
 
-static gfx_layout tile_8x8_layout =
+static const gfx_layout tile_8x8_layout =
 {
 	8,8,
 	RGN_FRAC(1,2),
@@ -423,7 +421,7 @@ static gfx_layout tile_8x8_layout =
 	8*16
 };
 
-static gfx_layout tile_16x16_layout =
+static const gfx_layout tile_16x16_layout =
 {
 	16,16,
 	RGN_FRAC(1,2),
@@ -434,7 +432,7 @@ static gfx_layout tile_16x16_layout =
 	32*16
 };
 
-static gfx_layout spritelayout =
+static const gfx_layout spritelayout =
 {
 	16,16,
 	RGN_FRAC(1,1),
@@ -446,7 +444,7 @@ static gfx_layout spritelayout =
 	32*32
 };
 
-static gfx_decode gfxdecodeinfo[] =
+static const gfx_decode gfxdecodeinfo[] =
 {
 	{ REGION_GFX1, 0, &tile_8x8_layout,     0,     32 },	/* Tiles (8x8) */
 	{ REGION_GFX1, 0, &tile_16x16_layout,   0,     32 },	/* Tiles (16x16) */
