@@ -16,7 +16,6 @@ Notes:
 ***************************************************************************/
 
 #include "driver.h"
-#include "vidhrdw/generic.h"
 #include "cpu/m6800/m6800.h"
 #include "sound/namco.h"
 
@@ -315,7 +314,7 @@ INPUT_PORTS_END
 
 
 
-static gfx_layout text_layout =
+static const gfx_layout text_layout =
 {
 	8,8,
 	RGN_FRAC(1,1),
@@ -326,7 +325,7 @@ static gfx_layout text_layout =
 	16*8
 };
 
-static gfx_layout tile_layout =
+static const gfx_layout tile_layout =
 {
 	8,8,
 	RGN_FRAC(1,1),
@@ -337,7 +336,7 @@ static gfx_layout tile_layout =
 	16*8
 };
 
-static gfx_layout sprite_layout =
+static const gfx_layout sprite_layout =
 {
 	16,16,
 	RGN_FRAC(1,2),
@@ -350,7 +349,7 @@ static gfx_layout sprite_layout =
 	64*8
 };
 
-static gfx_decode gfxdecodeinfo[] =
+static const gfx_decode gfxdecodeinfo[] =
 {
 	{ REGION_GFX1, 0, &text_layout,   0, 64 },
 	{ REGION_GFX2, 0, &tile_layout,   64*4, 128 },
