@@ -3,6 +3,7 @@
 Splash! (c) 1992 Gaelco
 Return of Ladyfrog (c) 1993 Microhard   (hack/bootleg of splash)
 Funny Strip (c)199? Microhard / MagicGames
+Rebus (c)1995 Microhard
 
 Driver by Manuel Abadia <manu@teleline.es>
 
@@ -28,10 +29,14 @@ BIOS-D
 note:
 Sound not working on Return of Lady Frog
 
+----
+
+Rebus seems to have some pretty nasty protection, I haven't yet managed to
+figure out what it involves
+
 ***************************************************************************/
 
 #include "driver.h"
-#include "vidhrdw/generic.h"
 #include "cpu/z80/z80.h"
 #include "cpu/m68000/m68000.h"
 #include "sound/2203intf.h"
@@ -39,15 +44,16 @@ Sound not working on Return of Lady Frog
 #include "sound/msm5205.h"
 
 
-extern data16_t *splash_vregs;
-extern data16_t *splash_videoram;
-extern data16_t *splash_spriteram;
-extern data16_t *splash_pixelram;
-extern data16_t *roldfrog_bitmap_mode;
-data16_t *roldfrog_protdata;
+extern UINT16 *splash_vregs;
+extern UINT16 *splash_videoram;
+extern UINT16 *splash_spriteram;
+extern UINT16 *splash_pixelram;
+extern UINT16 *roldfrog_bitmap_mode;
+UINT16 *roldfrog_protdata;
 
 extern int splash_bitmap_type;
-/* from vidhrdw/gaelco.c */
+extern int splash_sprite_attr2_shift;
+
 READ16_HANDLER( splash_vram_r );
 WRITE16_HANDLER( splash_vram_w );
 VIDEO_START( splash );
@@ -160,7 +166,7 @@ static READ16_HANDLER( roldfrog_bombs_r )
 
 static ADDRESS_MAP_START( roldfrog_readmem, ADDRESS_SPACE_PROGRAM, 16 )
 	AM_RANGE(0x000000, 0x3fffff) AM_READ(MRA16_ROM)			/* ROM */
-	AM_RANGE(0x400000, 0x407fff) AM_READ(MRA16_ROM)			/* Protection Data */
+	AM_RANGE(0x400000, 0x407fff) AM_ROM	AM_BASE(&roldfrog_protdata)					/* Protection Data */
 	AM_RANGE(0x408000, 0x4087ff) AM_READ(MRA16_RAM)			/* Extra Ram */
 	AM_RANGE(0x800000, 0x83ffff) AM_READ(MRA16_RAM)			/* Pixel Layer */
 	AM_RANGE(0x840000, 0x840001) AM_READ(input_port_0_word_r)/* DIPSW #1 */
@@ -178,7 +184,6 @@ ADDRESS_MAP_END
 
 static ADDRESS_MAP_START( roldfrog_writemem, ADDRESS_SPACE_PROGRAM, 16 )
 	AM_RANGE(0x000000, 0x3fffff) AM_WRITE(MWA16_ROM)										/* ROM */
-	AM_RANGE(0x400000, 0x407fff) AM_WRITE(MWA16_ROM) AM_BASE(&roldfrog_protdata)			/* Protection Data */
 	AM_RANGE(0x408000, 0x4087ff) AM_WRITE(MWA16_RAM) 										/* Extra Ram */
 	AM_RANGE(0x800000, 0x83ffff) AM_WRITE(MWA16_RAM) AM_BASE(&splash_pixelram)			/* Pixel Layer */
 	AM_RANGE(0x84000e, 0x84000f) AM_WRITE(roldf_sh_irqtrigger_w)							/* Sound command */
@@ -385,7 +390,7 @@ INPUT_PORTS_START( funystrp )
 	PORT_BIT( 0x80, IP_ACTIVE_LOW, IPT_START2 )
 INPUT_PORTS_END
 
-static struct GfxLayout tilelayout8 =
+static const gfx_layout tilelayout8 =
 {
 	8,8,									/* 8x8 tiles */
 	0x20000/8,								/* number of tiles */
@@ -396,7 +401,7 @@ static struct GfxLayout tilelayout8 =
 	8*8
 };
 
-static struct GfxLayout tilelayout16 =
+static const gfx_layout tilelayout16 =
 {
 	16,16,									/* 16x16 tiles */
 	0x20000/32,								/* number of tiles */
@@ -407,7 +412,7 @@ static struct GfxLayout tilelayout16 =
 	32*8
 };
 
-static struct GfxDecodeInfo gfxdecodeinfo[] =
+static const gfx_decode gfxdecodeinfo[] =
 {
 	{ REGION_GFX1, 0x000000, &tilelayout8 ,0,128 },
 	{ REGION_GFX1, 0x000000, &tilelayout16,0,128 },
@@ -474,7 +479,7 @@ static MACHINE_DRIVER_START( roldfrog )
 	MDRV_CPU_PROGRAM_MAP(roldfrog_readmem,roldfrog_writemem)
 	MDRV_CPU_VBLANK_INT(irq6_line_hold,1)
 
-	MDRV_CPU_ADD(Z80,30000000)			/* 3 MHz - verified */
+	MDRV_CPU_ADD(Z80,3000000)			/* 3 MHz - verified */
 	/* audio CPU */
 	MDRV_CPU_PROGRAM_MAP(roldf_sound_map,0)
 	MDRV_CPU_IO_MAP(roldf_sound_io_map,0)
@@ -586,7 +591,7 @@ The z80 rom (used for sound) is a hack of the main program from dynax's
 ***************************************************************************/
 
 ROM_START( roldfrog )
-	ROM_REGION( 0x400000, REGION_CPU1, 0 )	/* 68000 code */
+	ROM_REGION( 0x408000, REGION_CPU1, 0 )	/* 68000 code */
 	ROM_LOAD16_BYTE( "roldfrog.002",	0x000000, 0x080000, CRC(724cf022) SHA1(f8cddfb785ae7900cb95b854811ec3fb250fa7fe) )
 	ROM_LOAD16_BYTE( "roldfrog.006",	0x000001, 0x080000, CRC(e52a7ae2) SHA1(5c6ecbc2711376afdd7b8da11f84d36ffc464c8a) )
 	ROM_LOAD16_BYTE( "roldfrog.003",	0x100000, 0x080000, CRC(a1d49967) SHA1(54d73c1db1090b7d5109906525ce95ee8c00ad1f) )
@@ -595,9 +600,8 @@ ROM_START( roldfrog )
 	ROM_LOAD16_BYTE( "roldfrog.008",	0x200001, 0x080000, CRC(39adcba4) SHA1(6c8c945b6383fa2549e6654b427a7ce4c7ff46b5) )
 	ROM_LOAD16_BYTE( "roldfrog.005",	0x300000, 0x080000, CRC(b683160c) SHA1(526a772108a6bf71207a7b6de7cbd14f8e9496bc) )
 	ROM_LOAD16_BYTE( "roldfrog.009",	0x300001, 0x080000, CRC(e475fb76) SHA1(9ab56db86530647ea4a5d2109a02119710ff9b7e) )
-
-	ROM_REGION( 0x8000, REGION_USER1, 0 )	/* 68000 code - supplied by protection device? */
-	ROM_LOAD( "protdata.bin", 0x00000, 0x8000, CRC(ecaa8dd1) SHA1(b15f583d1a96b6b7ce50bcdca8cb28508f92b6a5) )
+	/* 68000 code - supplied by protection device? */
+	ROM_LOAD16_WORD_SWAP( "protdata.bin", 0x400000, 0x8000, CRC(ecaa8dd1) SHA1(b15f583d1a96b6b7ce50bcdca8cb28508f92b6a5) )
 
 	ROM_REGION( 0x90000, REGION_CPU2, 0 )	/* Z80 Code */
 	ROM_LOAD( "roldfrog.001", 0x00000, 0x20000, CRC(ba9eb1c6) SHA1(649d1103f3188554eaa3fc87a1f52c53233932b2) )
@@ -611,7 +615,7 @@ ROM_START( roldfrog )
 ROM_END
 
 ROM_START( roldfrga )
-	ROM_REGION( 0x400000, REGION_CPU1, 0 )	/* 68000 code */
+	ROM_REGION( 0x408000, REGION_CPU1, 0 )	/* 68000 code */
 	ROM_LOAD16_BYTE( "roldfrog.002",	0x000000, 0x080000, CRC(724cf022) SHA1(f8cddfb785ae7900cb95b854811ec3fb250fa7fe) )
 	ROM_LOAD16_BYTE( "roldfrog.006",	0x000001, 0x080000, CRC(e52a7ae2) SHA1(5c6ecbc2711376afdd7b8da11f84d36ffc464c8a) )
 	ROM_LOAD16_BYTE( "roldfrog.003",	0x100000, 0x080000, CRC(a1d49967) SHA1(54d73c1db1090b7d5109906525ce95ee8c00ad1f) )
@@ -620,9 +624,8 @@ ROM_START( roldfrga )
 	ROM_LOAD16_BYTE( "roldfrog.008",	0x200001, 0x080000, CRC(39adcba4) SHA1(6c8c945b6383fa2549e6654b427a7ce4c7ff46b5) )
 	ROM_LOAD16_BYTE( "roldfrog.005",	0x300000, 0x080000, CRC(b683160c) SHA1(526a772108a6bf71207a7b6de7cbd14f8e9496bc) )
 	ROM_LOAD16_BYTE( "9",	            0x300001, 0x080000, CRC(fd515b58) SHA1(7926ab9afbc260219351a02b56b82ede883f9aab) )	/* differs with roldfrog.009 by 1 byte */
-
-	ROM_REGION( 0x8000, REGION_USER1, 0 )	/* 68000 code - supplied by protection device? */
-	ROM_LOAD( "protdata.bin", 0x00000, 0x8000, CRC(ecaa8dd1) SHA1(b15f583d1a96b6b7ce50bcdca8cb28508f92b6a5) )
+	/* 68000 code - supplied by protection device? */
+	ROM_LOAD16_WORD_SWAP( "protdata.bin", 0x400000, 0x8000, CRC(ecaa8dd1) SHA1(b15f583d1a96b6b7ce50bcdca8cb28508f92b6a5) )
 
 	ROM_REGION( 0x90000, REGION_CPU2, 0 )	/* Z80 Code */
 	ROM_LOAD( "roldfrog.001", 0x00000, 0x20000, CRC(ba9eb1c6) SHA1(649d1103f3188554eaa3fc87a1f52c53233932b2) )
@@ -635,6 +638,62 @@ ROM_START( roldfrga )
 	ROM_LOAD( "roldfrog.013",       0x60000, 0x20000, CRC(fad3e8be) SHA1(eccd7b1440d3a0d433c92ff33213326e0d57422a) )
 ROM_END
 
+/*
+Game    Rebus
+Anno    1995
+Produttore  Microhard
+
+CPU
+
+1x MC68000P12-2C91E-QQYS9247 (main)(u1)
+1x STZ8400BB1-Z80BCPU (sound)(u162)
+1x YAMAHA YM3812-9030EALB (sound)(u165)
+1x oscillator 24.000000MHz (osc1)
+1x oscillator 30.000MHz (osc2)
+
+ROMs
+
+1x S27C512 (sound)(1)
+6x M27C4001 (main)(2,3,4,5,6,7)
+1x M27C040Q (main)(8)
+1x AM27C040 (main)(9)
+2x D27C010 (gfx)(10,11)
+1x STM27C1001 (gfx)(12)
+1x AM27C010 (gfx)(13)
+
+Note
+
+6x MCM2018AN45 (ram)
+5x KM681000ALP (ram)
+1x HY18CV8S (PEEL)
+5x GAL16V8
+2x GAL16V8H
+1x PALCE20V8H
+001-937
+*/
+
+ROM_START( rebus )
+	ROM_REGION( 0x408000, REGION_CPU1, 0 )	/* 68000 code */
+	ROM_LOAD16_BYTE( "2.u16",	0x000000, 0x080000, CRC(7c8a717f) SHA1(00b1e7986046a7705fc65a5c7d4701a002b2ea6f) )
+	ROM_LOAD16_BYTE( "6.u12",	0x000001, 0x080000, CRC(8f73d548) SHA1(210d95dc0db41da3252a09e598719d98bca41983) )
+	ROM_LOAD16_BYTE( "3.u17",	0x100000, 0x080000, CRC(7495409b) SHA1(b4d75713d31c0b01d7cb7d50a2a89fb3ea4ea42b) )
+	ROM_LOAD16_BYTE( "7.u13",	0x100001, 0x080000, CRC(615bc4dc) SHA1(f1c8ee3eb8a48721f1f2e4f35fdc9bb0bb9d167b) )
+	ROM_LOAD16_BYTE( "4.u18",	0x200000, 0x080000, CRC(c27674fc) SHA1(06f3f1543331bd00f08cde51beb73934f2f1e6c8) )
+	ROM_LOAD16_BYTE( "8.u14",	0x200001, 0x080000, CRC(f0c04b7e) SHA1(92117b05666afa42d7669e5aa630e5143fac1d74) )
+	ROM_LOAD16_BYTE( "5.u19",	0x300000, 0x080000, CRC(2702f341) SHA1(de862cacbb3e8e322128315d87a22c7cdfe4fcb9) )
+	ROM_LOAD16_BYTE( "9.u15",	0x300001, 0x080000, CRC(f5ae3d73) SHA1(6a9d955023c704023b722cf863ba19ccb9b34ee1) )
+
+	ROM_REGION( 0x90000, REGION_CPU2, 0 )	/* Z80 Code */
+	ROM_LOAD( "1.u163", 0x00000, 0x10000,  CRC(88a7b1f8) SHA1(b34fa26dbc613bf3b525d19df90fa3ba4efb6e5d) )
+	ROM_RELOAD(               0x20000, 0x10000 )
+
+	ROM_REGION( 0x80000, REGION_GFX1, ROMREGION_DISPOSE )
+	ROM_LOAD( "10.u102",       0x00000, 0x20000, CRC(6f75a28b) SHA1(75f0bd6bd8c04ea9f832c22fbe1d17b0351f1102) )
+	ROM_LOAD( "11.u103",       0x20000, 0x20000, CRC(0af65b78) SHA1(9522ad17d26d866e5b11b4fec47781a00a297977) )
+	ROM_LOAD( "12.u104",       0x40000, 0x20000, CRC(3ed6ce19) SHA1(0d574071053157e4ef973a844795e48ec69dc7c4) )
+	ROM_LOAD( "13.u105",       0x60000, 0x20000, CRC(8b54553d) SHA1(5cb776e551527b0e717fe0d76296f5f895523de5) )
+ROM_END
+
 
 ROM_START( splash )
 	ROM_REGION( 0x400000, REGION_CPU1, 0 )	/* 68000 code + gfx */
@@ -657,6 +716,27 @@ ROM_START( splash )
 	ROM_LOAD( "13i",	0x060000, 0x020000, CRC(febb9893) SHA1(bb607a608c6c1658748a17a62431e8c30323c7ec) )
 ROM_END
 
+ROM_START( splash10 )
+	ROM_REGION( 0x400000, REGION_CPU1, 0 )	/* 68000 code + gfx */
+	ROM_LOAD16_BYTE(	"splash10.g4",	0x000000, 0x020000, CRC(38ba6632) SHA1(ca1425120fcb427e1b2c83eb3bf104363d9571be) )
+	ROM_LOAD16_BYTE(	"splash10.i4",	0x000001, 0x020000, CRC(0edc3373) SHA1(edf28baa6ef2442a37eb81a51ab66485d89f802e) )
+	ROM_LOAD16_BYTE(	"5g",	0x100000, 0x080000, CRC(a4e8ed18) SHA1(64ce47193ee4bb3a8014d7c14c559b4ebb3af083) )
+	ROM_LOAD16_BYTE(	"5i",	0x100001, 0x080000, CRC(73e1154d) SHA1(2c055ad29a32c6c1e712cc35b5972f1e69cdebb7) )
+	ROM_LOAD16_BYTE(	"6g",	0x200000, 0x080000, CRC(ffd56771) SHA1(35ad9874b6ea5aa3ba38a31d723093b4dd2cfdb8) )
+	ROM_LOAD16_BYTE(	"6i",	0x200001, 0x080000, CRC(16e9170c) SHA1(96fc237cb172039df153dc70d15ed7d9ee750363) )
+	ROM_LOAD16_BYTE(	"8g",	0x300000, 0x080000, CRC(dc3a3172) SHA1(2b322b52e3e8da00f26dd276cb72bd2d48c2deaa) )
+	ROM_LOAD16_BYTE(	"8i",	0x300001, 0x080000, CRC(2e23e6c3) SHA1(baf9ab4c3261c3f06f5e43c1e50aba9222acb71d) )
+
+	ROM_REGION( 0x010000, REGION_CPU2, 0 )	/* Z80 code + sound data */
+	ROM_LOAD( "5c",	0x00000, 0x10000, CRC(0ed7ebc9) SHA1(28ef16e20d754deef49be6a5c9f63311e9ec94a3) )
+
+	ROM_REGION( 0x080000, REGION_GFX1, ROMREGION_DISPOSE )
+	ROM_LOAD( "18i",	0x000000, 0x020000, CRC(028a4a68) SHA1(19384988e3690886ed55886ecdc4e4c566dbe4ba) )
+	ROM_LOAD( "15i",	0x020000, 0x020000, CRC(2a8cb830) SHA1(bc54dfb03fade154085aa2f66784e07664a7a3d8) )
+	ROM_LOAD( "16i",	0x040000, 0x020000, CRC(21aeff2c) SHA1(0c307e94f4a814c674ba0ab471a6bdd57e43c265) )
+	ROM_LOAD( "13i",	0x060000, 0x020000, CRC(febb9893) SHA1(bb607a608c6c1658748a17a62431e8c30323c7ec) )
+ROM_END
+
 /***************************************************************************
 
 Painted Lady (US, version 1.3)
@@ -772,44 +852,68 @@ ROM_START( funystrp )
 	ROM_LOAD( "14.u51",	0x060000, 0x020000, CRC(ed565a0b) SHA1(50789e0f04038d174b5529546c1ff430416b32d6) )
 ROM_END
 
+ROM_START( puckpepl )
+	ROM_REGION( 0x400000, REGION_CPU1, 0 )	/* 68000 code + gfx */
+	ROM_LOAD16_BYTE(	"pp22.u87",	0x000000, 0x010000, CRC(1ceb522d) SHA1(216cd24bc2cc3fbd389ab96bc8b729c4d919faab) )
+	ROM_LOAD16_BYTE(	"pp23.111",	0x000001, 0x010000, CRC(84336569) SHA1(4358c48bf65dfdb6f52326ec5f026e1b9614a108) )
+
+	ROM_REGION( 0x080000, REGION_CPU2, 0 )	/* Z80 code + sound data */
+	ROM_LOAD( "pp31.130",	0x000000, 0x040000, NO_DUMP ) /* dump was all 0xff */
+	ROM_LOAD( "pp30.181",	0x040000, 0x040000, CRC(a5697b3d) SHA1(28ef3cfea82b3016c7c042a18509ba2bf83048e5) )
+
+	ROM_REGION( 0x080000, REGION_GFX1, ROMREGION_DISPOSE )
+	ROM_LOAD( "pp37.u54",	0x000000, 0x020000, CRC(23c136b0) SHA1(bf3a6379934e205dcb6c0389d9dd5d0ffb92bdd4) )
+	ROM_LOAD( "pp36.u53",	0x020000, 0x020000, CRC(210e7579) SHA1(1a2d175a83f5ad933961a3c8b26cd8786527ea7f) )
+	ROM_LOAD( "pp35.u52",	0x040000, 0x020000, CRC(cd4cc5df) SHA1(b4dd9e97bdad46340e79e9c7747484aae49680a2) )
+	ROM_LOAD( "pp34.u51",	0x060000, 0x020000, CRC(93f2d483) SHA1(eb6981b0228acb1ec92325924d0aa295f9e2cfe1) )
+ROM_END
+
 
 /* DRIVER INITs */
 
-void init_protection_data (void)
-{
-	data16_t *PROTDATA = (data16_t*)memory_region(REGION_USER1);
-	int i;
-
-	for (i = 0;i < 0x8000/2;i++)
-	roldfrog_protdata[i] = PROTDATA[i];
-}
-
 DRIVER_INIT( splash )
 {
 	splash_bitmap_type = 0;
+	splash_sprite_attr2_shift = 8;
+}
+
+DRIVER_INIT( splash10 )
+{
+	splash_bitmap_type = 0;
+	splash_sprite_attr2_shift = 0;
 }
 
 DRIVER_INIT( roldfrog )
 {
 	splash_bitmap_type = 1;
-	init_protection_data();
+	splash_sprite_attr2_shift = 8;
 }
 
+DRIVER_INIT( rebus )
+{
+	splash_bitmap_type = 1;
+	splash_sprite_attr2_shift = 0;
+}
+
+
 DRIVER_INIT( funystrp )
 {
-	data16_t *ROM = (data16_t *)memory_region(REGION_CPU1);
+	UINT16 *ROM = (UINT16 *)memory_region(REGION_CPU1);
 
 	splash_bitmap_type = 0;
+	splash_sprite_attr2_shift = 0;
 
 	/* part of the protection? */
 	ROM[0x04770/2] = 0x4e71;
 	ROM[0x04772/2] = 0x4e71;
 }
 
-GAME( 1992, splash,   0,        splash, splash, splash, ROT0, "Gaelco",    "Splash! (Ver. 1.2 World)" )
-GAME( 1992, paintlad, splash,   splash, splash, splash, ROT0, "Gaelco",    "Painted Lady (Splash) (Ver. 1.3 US)" )
+GAME( 1992, splash,   0,        splash,   splash,   splash,   ROT0, "Gaelco",    "Splash! (Ver. 1.2 World)", 0 )
+GAME( 1992, splash10, splash,   splash,   splash,   splash10, ROT0, "Gaelco",    "Splash! (Ver. 1.0 World)", 0 )
+GAME( 1992, paintlad, splash,   splash,   splash,   splash,   ROT0, "Gaelco",    "Painted Lady (Splash) (Ver. 1.3 US)", 0 )
 
-GAMEX(1993, roldfrog, 0,        roldfrog, splash, roldfrog, ROT0, "Microhard", "The Return of Lady Frog", GAME_NO_SOUND )
-GAMEX(1993, roldfrga, roldfrog, roldfrog, splash, roldfrog, ROT0, "Microhard", "The Return of Lady Frog (set 2)", GAME_NO_SOUND )
-
-GAMEX(199?, funystrp, 0,        funystrp, funystrp, funystrp, ROT0, "Microhard / MagicGames",    "Funny Strip",GAME_NOT_WORKING|GAME_UNEMULATED_PROTECTION|GAME_NO_SOUND )
+GAME( 1993, roldfrog, 0,        roldfrog, splash,   roldfrog, ROT0, "Microhard", "The Return of Lady Frog", GAME_NO_SOUND )
+GAME( 1993, roldfrga, roldfrog, roldfrog, splash,   roldfrog, ROT0, "Microhard", "The Return of Lady Frog (set 2)", GAME_NO_SOUND )
+GAME( 1995, rebus,    0,        roldfrog, splash,   rebus,    ROT0, "Microhard", "Rebus", GAME_NOT_WORKING|GAME_UNEMULATED_PROTECTION|GAME_NO_SOUND )
+GAME( 199?, funystrp, 0,        funystrp, funystrp, funystrp, ROT0, "Microhard / MagicGames",    "Funny Strip",GAME_NOT_WORKING|GAME_UNEMULATED_PROTECTION|GAME_NO_SOUND )
+GAME( 199?, puckpepl, funystrp, funystrp, funystrp, funystrp, ROT0, "Microhard",    "Puck People",GAME_NOT_WORKING|GAME_UNEMULATED_PROTECTION|GAME_NO_SOUND )
