@@ -25,18 +25,6 @@
 #define GAME_IS_SPRINT2   (game == 2)
 #define GAME_IS_DOMINOS   (game == 3)
 
-extern READ8_HANDLER( sprint2_collision1_r );
-extern READ8_HANDLER( sprint2_collision2_r );
-
-extern WRITE8_HANDLER( sprint2_collision_reset1_w );
-extern WRITE8_HANDLER( sprint2_collision_reset2_w );
-extern WRITE8_HANDLER( sprint2_video_ram_w );
-
-extern VIDEO_UPDATE( sprint2 );
-extern VIDEO_START( sprint2 );
-extern VIDEO_EOF( sprint2 );
-
-extern UINT8* sprint2_video_ram;
 
 
 static int attract;
@@ -501,7 +489,7 @@ INPUT_PORTS_START( dominos )
 INPUT_PORTS_END
 
 
-static gfx_layout tile_layout =
+static const gfx_layout tile_layout =
 {
 	16, 8,
 	64,
@@ -517,7 +505,7 @@ static gfx_layout tile_layout =
 };
 
 
-static gfx_layout car_layout =
+static const gfx_layout car_layout =
 {
 	16, 8,
 	32,
@@ -534,7 +522,7 @@ static gfx_layout car_layout =
 };
 
 
-static gfx_decode gfxdecodeinfo[] =
+static const gfx_decode gfxdecodeinfo[] =
 {
 	{ REGION_GFX1, 0, &tile_layout, 0, 2 },
 	{ REGION_GFX2, 0, &car_layout, 4, 4 },
