@@ -122,7 +122,7 @@ static PALETTE_INIT( sprint8 )
 }
 
 
-static MACHINE_INIT( sprint8 )
+static MACHINE_RESET( sprint8 )
 {
 	collision_reset = 0;
 	collision_index = 0;
@@ -479,7 +479,7 @@ INPUT_PORTS_START( sprint8p )
 INPUT_PORTS_END
 
 
-static gfx_layout tile_layout_1 =
+static const gfx_layout tile_layout_1 =
 {
 	16, 8,
 	64,
@@ -495,7 +495,7 @@ static gfx_layout tile_layout_1 =
 };
 
 
-static gfx_layout tile_layout_2 =
+static const gfx_layout tile_layout_2 =
 {
 	16, 8,
 	64,
@@ -513,7 +513,7 @@ static gfx_layout tile_layout_2 =
 };
 
 
-static gfx_layout car_layout =
+static const gfx_layout car_layout =
 {
 	16, 8,
 	8,
@@ -530,7 +530,7 @@ static gfx_layout car_layout =
 };
 
 
-static gfx_decode gfxdecodeinfo[] =
+static const gfx_decode gfxdecodeinfo[] =
 {
 	{ REGION_GFX1, 0, &tile_layout_1, 0, 18 },
 	{ REGION_GFX1, 0, &tile_layout_2, 0, 18 },
@@ -547,7 +547,7 @@ static MACHINE_DRIVER_START( sprint8 )
 
 	MDRV_FRAMES_PER_SECOND(60)
 	MDRV_VBLANK_DURATION(29 * 1000000 / 15750)
-	MDRV_MACHINE_INIT(sprint8)
+	MDRV_MACHINE_RESET(sprint8)
 
 	/* video hardware */
 	MDRV_VIDEO_ATTRIBUTES(VIDEO_TYPE_RASTER | VIDEO_UPDATE_AFTER_VBLANK)
