@@ -18,7 +18,6 @@ Revisions:
 ***************************************************************************/
 
 #include "driver.h"
-#include "vidhrdw/generic.h"
 #include "cpu/m6809/m6809.h"
 #include "vidhrdw/konamiic.h"
 #include "sound/3812intf.h"
@@ -28,7 +27,7 @@ Revisions:
 VIDEO_START( spy );
 VIDEO_UPDATE( spy );
 
-static data8_t *pmcram;
+static UINT8 *pmcram;
 
 
 static INTERRUPT_GEN( spy_interrupt )
@@ -68,7 +67,7 @@ static WRITE8_HANDLER( spy_bankedram1_w )
 {
 	if (rambank & 1)
 	{
-		paletteram_xBBBBBGGGGGRRRRR_swap_w(offset,data);
+		paletteram_xBBBBBGGGGGRRRRR_be_w(offset,data);
 	}
 	else if (rambank & 2)
 	{
@@ -158,12 +157,12 @@ static WRITE8_HANDLER( bankswitch_w )
 	int offs;
 
 	/* bit 0 = RAM bank? */
-if ((data & 1) == 0) usrintf_showmessage("bankswitch RAM bank 0");
+if ((data & 1) == 0) ui_popup("bankswitch RAM bank 0");
 
 	/* bit 1-4 = ROM bank */
 	if (data & 0x10) offs = 0x20000 + (data & 0x06) * 0x1000;
 	else offs = 0x10000 + (data & 0x0e) * 0x1000;
-	cpu_setbank(1,&rom[offs]);
+	memory_set_bankptr(1,&rom[offs]);
 }
 
 /*AT */
@@ -652,5 +651,5 @@ static DRIVER_INIT( spy )
 
 
 
-GAME( 1989, spy,  0,   spy, spy, spy, ROT0, "Konami", "S.P.Y. - Special Project Y (World ver. N)")
-GAME( 1989, spyu, spy, spy, spy, spy, ROT0, "Konami", "S.P.Y. - Special Project Y (US ver. M)")
+GAME( 1989, spy,  0,   spy, spy, spy, ROT0, "Konami", "S.P.Y. - Special Project Y (World ver. N)", 0)
+GAME( 1989, spyu, spy, spy, spy, spy, ROT0, "Konami", "S.P.Y. - Special Project Y (US ver. M)", 0)
