@@ -56,7 +56,6 @@ Note:
 
 
 #include "driver.h"
-#include "vidhrdw/generic.h"
 #include "sound/ay8910.h"
 #include "sound/msm5205.h"
 
@@ -133,12 +132,12 @@ static DRIVER_INIT( srmp3 )
 	RAM[0x00000 + 0x7850] = 0x00;							/* NOP */
 }
 
-static MACHINE_INIT( srmp2 )
+static MACHINE_RESET( srmp2 )
 {
 	srmp2_port_select = 0;
 }
 
-static MACHINE_INIT( srmp3 )
+static MACHINE_RESET( srmp3 )
 {
 	srmp2_port_select = 0;
 }
@@ -1050,7 +1049,7 @@ static struct MSM5205interface msm5205_interface =
 };
 
 
-static gfx_layout charlayout =
+static const gfx_layout charlayout =
 {
 	16, 16,
 	RGN_FRAC(1, 2),
@@ -1062,13 +1061,13 @@ static gfx_layout charlayout =
 	16*16*2
 };
 
-static gfx_decode srmp2_gfxdecodeinfo[] =
+static const gfx_decode srmp2_gfxdecodeinfo[] =
 {
 	{ REGION_GFX1, 0, &charlayout, 0, 64 },
 	{ -1 }
 };
 
-static gfx_decode srmp3_gfxdecodeinfo[] =
+static const gfx_decode srmp3_gfxdecodeinfo[] =
 {
 	{ REGION_GFX1, 0, &charlayout, 0, 32 },
 	{ -1 }
@@ -1085,7 +1084,7 @@ static MACHINE_DRIVER_START( srmp2 )
 	MDRV_FRAMES_PER_SECOND(60)
 	MDRV_VBLANK_DURATION(DEFAULT_60HZ_VBLANK_DURATION)
 
-	MDRV_MACHINE_INIT(srmp2)
+	MDRV_MACHINE_RESET(srmp2)
 	MDRV_NVRAM_HANDLER(generic_0fill)
 
 	/* video hardware */
@@ -1125,7 +1124,7 @@ static MACHINE_DRIVER_START( srmp3 )
 	MDRV_FRAMES_PER_SECOND(60)
 	MDRV_VBLANK_DURATION(DEFAULT_60HZ_VBLANK_DURATION)
 
-	MDRV_MACHINE_INIT(srmp3)
+	MDRV_MACHINE_RESET(srmp3)
 	MDRV_NVRAM_HANDLER(generic_0fill)
 
 	/* video hardware */
@@ -1161,7 +1160,7 @@ static MACHINE_DRIVER_START( mjyuugi )
 	MDRV_FRAMES_PER_SECOND(60)
 	MDRV_VBLANK_DURATION(DEFAULT_60HZ_VBLANK_DURATION)
 
-	MDRV_MACHINE_INIT(srmp2)
+	MDRV_MACHINE_RESET(srmp2)
 	MDRV_NVRAM_HANDLER(generic_0fill)
 
 	/* video hardware */
