@@ -52,7 +52,6 @@ Stephh's notes (based on the games M68000 code and some tests) :
 ***************************************************************************/
 
 #include "driver.h"
-#include "vidhrdw/generic.h"
 #include "sound/2203intf.h"
 #include "sound/okim6295.h"
 
@@ -67,11 +66,11 @@ WRITE16_HANDLER( sshangha_control_0_w );
 WRITE16_HANDLER( sshangha_palette_24bit_w );
 WRITE16_HANDLER (sshangha_video_w);
 
-extern data16_t *sshangha_pf1_data;
-extern data16_t *sshangha_pf2_data;
-extern data16_t *sshangha_pf1_rowscroll, *sshangha_pf2_rowscroll;
+extern UINT16 *sshangha_pf1_data;
+extern UINT16 *sshangha_pf2_data;
+extern UINT16 *sshangha_pf1_rowscroll, *sshangha_pf2_rowscroll;
 
-static data16_t *sshangha_prot_data;
+static UINT16 *sshangha_prot_data;
 
 /******************************************************************************/
 
@@ -134,7 +133,7 @@ static READ16_HANDLER( deco_71_r )
 
 /******************************************************************************/
 
-static MACHINE_INIT( sshangha )
+static MACHINE_RESET( sshangha )
 {
 	/* Such thing is needed as there is no code to turn the screen
        to normal orientation when the game is reset.
@@ -247,23 +246,23 @@ INPUT_PORTS_START( sshangha )
 	PORT_DIPSETTING(    0x10, "Mode 1" )
 	PORT_DIPSETTING(    0x00, "Mode 2" )
 	PORT_DIPNAME( 0x0c, 0x0c, DEF_STR( Coin_A ) )
-	PORT_DIPSETTING(    0x08, DEF_STR( 2C_1C ) )PORT_DIPCONDITION(3,0x10,PORTCOND_EQUALS,0x10)/*Mode 1 */
-	PORT_DIPSETTING(    0x0c, DEF_STR( 1C_1C ) )PORT_DIPCONDITION(3,0x10,PORTCOND_EQUALS,0x10)/*Mode 1 */
-	PORT_DIPSETTING(    0x00, DEF_STR( 2C_3C ) )PORT_DIPCONDITION(3,0x10,PORTCOND_EQUALS,0x10)/*Mode 1 */
-	PORT_DIPSETTING(    0x04, DEF_STR( 1C_2C ) )PORT_DIPCONDITION(3,0x10,PORTCOND_EQUALS,0x10)/*Mode 1 */
-	PORT_DIPSETTING(    0x00, DEF_STR( 4C_1C ) )PORT_DIPCONDITION(3,0x10,PORTCOND_NOTEQUALS,0x10)/*Mode 2 */
-	PORT_DIPSETTING(    0x08, DEF_STR( 3C_1C ) )PORT_DIPCONDITION(3,0x10,PORTCOND_NOTEQUALS,0x10)/*Mode 2 */
-	PORT_DIPSETTING(    0x0c, DEF_STR( 1C_1C ) )PORT_DIPCONDITION(3,0x10,PORTCOND_NOTEQUALS,0x10)/*Mode 2 */
-	PORT_DIPSETTING(    0x04, DEF_STR( 1C_4C ) )PORT_DIPCONDITION(3,0x10,PORTCOND_NOTEQUALS,0x10)/*Mode 2 */
+	PORT_DIPSETTING(    0x08, DEF_STR( 2C_1C ) )PORT_CONDITION("DSW1",0x10,PORTCOND_EQUALS,0x10)/*Mode 1 */
+	PORT_DIPSETTING(    0x0c, DEF_STR( 1C_1C ) )PORT_CONDITION("DSW1",0x10,PORTCOND_EQUALS,0x10)/*Mode 1 */
+	PORT_DIPSETTING(    0x00, DEF_STR( 2C_3C ) )PORT_CONDITION("DSW1",0x10,PORTCOND_EQUALS,0x10)/*Mode 1 */
+	PORT_DIPSETTING(    0x04, DEF_STR( 1C_2C ) )PORT_CONDITION("DSW1",0x10,PORTCOND_EQUALS,0x10)/*Mode 1 */
+	PORT_DIPSETTING(    0x00, DEF_STR( 4C_1C ) )PORT_CONDITION("DSW1",0x10,PORTCOND_NOTEQUALS,0x10)/*Mode 2 */
+	PORT_DIPSETTING(    0x08, DEF_STR( 3C_1C ) )PORT_CONDITION("DSW1",0x10,PORTCOND_NOTEQUALS,0x10)/*Mode 2 */
+	PORT_DIPSETTING(    0x0c, DEF_STR( 1C_1C ) )PORT_CONDITION("DSW1",0x10,PORTCOND_NOTEQUALS,0x10)/*Mode 2 */
+	PORT_DIPSETTING(    0x04, DEF_STR( 1C_4C ) )PORT_CONDITION("DSW1",0x10,PORTCOND_NOTEQUALS,0x10)/*Mode 2 */
 	PORT_DIPNAME( 0x03, 0x03, DEF_STR( Coin_B ) )
-	PORT_DIPSETTING(    0x02, DEF_STR( 2C_1C ) )PORT_DIPCONDITION(3,0x10,PORTCOND_EQUALS,0x10)/*Mode 1 */
-	PORT_DIPSETTING(    0x03, DEF_STR( 1C_1C ) )PORT_DIPCONDITION(3,0x10,PORTCOND_EQUALS,0x10)/*Mode 1 */
-	PORT_DIPSETTING(    0x00, DEF_STR( 2C_3C ) )PORT_DIPCONDITION(3,0x10,PORTCOND_EQUALS,0x10)/*Mode 1 */
-	PORT_DIPSETTING(    0x01, DEF_STR( 1C_2C ) )PORT_DIPCONDITION(3,0x10,PORTCOND_EQUALS,0x10)/*Mode 1 */
-	PORT_DIPSETTING(    0x00, DEF_STR( 4C_1C ) )PORT_DIPCONDITION(3,0x10,PORTCOND_NOTEQUALS,0x10)/*Mode 2 */
-	PORT_DIPSETTING(    0x02, DEF_STR( 3C_1C ) )PORT_DIPCONDITION(3,0x10,PORTCOND_NOTEQUALS,0x10)/*Mode 2 */
-	PORT_DIPSETTING(    0x03, DEF_STR( 1C_1C ) )PORT_DIPCONDITION(3,0x10,PORTCOND_NOTEQUALS,0x10)/*Mode 2 */
-	PORT_DIPSETTING(    0x01, DEF_STR( 1C_4C ) )PORT_DIPCONDITION(3,0x10,PORTCOND_NOTEQUALS,0x10)/*Mode 2 */
+	PORT_DIPSETTING(    0x02, DEF_STR( 2C_1C ) )PORT_CONDITION("DSW1",0x10,PORTCOND_EQUALS,0x10)/*Mode 1 */
+	PORT_DIPSETTING(    0x03, DEF_STR( 1C_1C ) )PORT_CONDITION("DSW1",0x10,PORTCOND_EQUALS,0x10)/*Mode 1 */
+	PORT_DIPSETTING(    0x00, DEF_STR( 2C_3C ) )PORT_CONDITION("DSW1",0x10,PORTCOND_EQUALS,0x10)/*Mode 1 */
+	PORT_DIPSETTING(    0x01, DEF_STR( 1C_2C ) )PORT_CONDITION("DSW1",0x10,PORTCOND_EQUALS,0x10)/*Mode 1 */
+	PORT_DIPSETTING(    0x00, DEF_STR( 4C_1C ) )PORT_CONDITION("DSW1",0x10,PORTCOND_NOTEQUALS,0x10)/*Mode 2 */
+	PORT_DIPSETTING(    0x02, DEF_STR( 3C_1C ) )PORT_CONDITION("DSW1",0x10,PORTCOND_NOTEQUALS,0x10)/*Mode 2 */
+	PORT_DIPSETTING(    0x03, DEF_STR( 1C_1C ) )PORT_CONDITION("DSW1",0x10,PORTCOND_NOTEQUALS,0x10)/*Mode 2 */
+	PORT_DIPSETTING(    0x01, DEF_STR( 1C_4C ) )PORT_CONDITION("DSW1",0x10,PORTCOND_NOTEQUALS,0x10)/*Mode 2 */
 
 	PORT_START_TAG("DSW2")	/* Dip switch bank 2 (0xfec04b.b, inverted bits order) */
 	PORT_DIPNAME( 0xc0, 0xc0, DEF_STR( Difficulty ) )
@@ -297,7 +296,7 @@ INPUT_PORTS_END
 
 /******************************************************************************/
 
-static struct GfxLayout charlayout =
+static const gfx_layout charlayout =
 {
 	8,8,	/* 8*8 chars */
 	4096,
@@ -308,7 +307,7 @@ static struct GfxLayout charlayout =
 	16*8
 };
 
-static struct GfxLayout tilelayout =
+static const gfx_layout tilelayout =
 {
 	16,16,
 	RGN_FRAC(1,2),
@@ -321,7 +320,7 @@ static struct GfxLayout tilelayout =
 	64*8
 };
 
-static struct GfxDecodeInfo gfxdecodeinfo[] =
+static const gfx_decode gfxdecodeinfo[] =
 {
 	{ REGION_GFX1, 0, &charlayout,  256, 64 }, /* Characters 8x8 */
 	{ REGION_GFX1, 0, &tilelayout,  256, 64 }, /* Tiles 16x16 */
@@ -354,7 +353,7 @@ static MACHINE_DRIVER_START( sshangha )
 
 	MDRV_FRAMES_PER_SECOND(60)
 	MDRV_VBLANK_DURATION(529)
-	MDRV_MACHINE_INIT(sshangha)	/* init machine */
+	MDRV_MACHINE_RESET(sshangha)	/* init machine */
 
 	/* video hardware */
 	MDRV_VIDEO_ATTRIBUTES(VIDEO_TYPE_RASTER | VIDEO_NEEDS_6BITS_PER_GUN /*| VIDEO_BUFFERS_SPRITERAM*/)
@@ -428,7 +427,7 @@ static DRIVER_INIT( sshangha )
 #if SSHANGHA_HACK
 	/* This is a hack to allow you to use the extra features
          of the first "Unused" Dip Switch (see notes above). */
-	data16_t *RAM = (data16_t *)memory_region(REGION_CPU1);
+	UINT16 *RAM = (UINT16 *)memory_region(REGION_CPU1);
 	RAM[0x000384/2] = 0x4e71;
 	RAM[0x000386/2] = 0x4e71;
 	RAM[0x000388/2] = 0x4e71;
@@ -440,5 +439,5 @@ static DRIVER_INIT( sshangha )
 }
 
 
-GAMEX( 1992, sshangha, 0,        sshangha, sshangha, sshangha, ROT0, "Hot-B.",   "Super Shanghai Dragon's Eye (Japan)", GAME_UNEMULATED_PROTECTION | GAME_NO_SOUND )
-GAMEX( 1992, sshanghb, sshangha, sshangha, sshangha, sshangha, ROT0, "bootleg", "Super Shanghai Dragon's Eye (World, bootleg)", GAME_NO_SOUND )
+GAME( 1992, sshangha, 0,        sshangha, sshangha, sshangha, ROT0, "Hot-B.",   "Super Shanghai Dragon's Eye (Japan)", GAME_UNEMULATED_PROTECTION | GAME_NO_SOUND )
+GAME( 1992, sshanghb, sshangha, sshangha, sshangha, sshangha, ROT0, "bootleg", "Super Shanghai Dragon's Eye (World, bootleg)", GAME_NO_SOUND )
