@@ -229,14 +229,13 @@ DONE? (check on real board)
 *****************************************************************************/
 
 #include "driver.h"
-#include "vidhrdw/generic.h"
 #include "sound/2203intf.h"
 #include "sound/msm5205.h"
 
 /* machine */
 DRIVER_INIT( empcity );
 DRIVER_INIT( stfight );
-MACHINE_INIT( stfight );
+MACHINE_RESET( stfight );
 INTERRUPT_GEN( stfight_vb_interrupt );
 INTERRUPT_GEN( stfight_interrupt_1 );
 READ8_HANDLER( stfight_dsw_r );
@@ -397,7 +396,7 @@ INPUT_PORTS_END
 
 
 /* text-layer characters */
-static gfx_layout charlayout =
+static const gfx_layout charlayout =
 {
 	8,8,	    /* 8*8 pixels */
 	512,	    /* 512 characters */
@@ -409,7 +408,7 @@ static gfx_layout charlayout =
 };
 
 /* foreground tiles */
-static gfx_layout fglayout =
+static const gfx_layout fglayout =
 {
 	16,16,	    /* 16*16 pixels */
 	1024,	    /* 1024 tiles */
@@ -433,7 +432,7 @@ static gfx_layout fglayout =
  */
 
 /* background tiles */
-static gfx_layout bglayout =
+static const gfx_layout bglayout =
 {
 	16,16,	    /* 16*16 pixels */
 	512,	    /* 512 tiles */
@@ -451,7 +450,7 @@ static gfx_layout bglayout =
 };
 
 /* sprites */
-static gfx_layout spritelayout =
+static const gfx_layout spritelayout =
 {
 	16,16,	    /* 16*16 pixels */
 	1024,	    /* 1024 sprites */
@@ -469,7 +468,7 @@ static gfx_layout spritelayout =
 };
 
 
-static gfx_decode gfxdecodeinfo[] =
+static const gfx_decode gfxdecodeinfo[] =
 {
 	{ REGION_GFX1, 0x0000, &charlayout,   0,                16 },
 	{ REGION_GFX2, 0x0000, &fglayout,     16*4,             16 },
@@ -502,7 +501,7 @@ static MACHINE_DRIVER_START( stfight )
 	MDRV_VBLANK_DURATION(DEFAULT_60HZ_VBLANK_DURATION)
 	MDRV_INTERLEAVE(10)
 
-	MDRV_MACHINE_INIT(stfight)
+	MDRV_MACHINE_RESET(stfight)
 
 	/* video hardware */
 	MDRV_VIDEO_ATTRIBUTES(VIDEO_TYPE_RASTER)
