@@ -9,7 +9,6 @@ Strength & Skill (c) 1984 Sun Electronics
 *****************************************************************************/
 
 #include "driver.h"
-#include "vidhrdw/generic.h"
 #include "sound/sn76496.h"
 
 static UINT8 *strnskil_sharedram;
@@ -300,7 +299,7 @@ INPUT_PORTS_END
 
 /****************************************************************************/
 
-static gfx_layout charlayout =
+static const gfx_layout charlayout =
 {
 	8,8,    /* 8*8 characters */
 	1024,   /* 1024 characters */
@@ -311,7 +310,7 @@ static gfx_layout charlayout =
 	8*8
 };
 
-static gfx_layout spritelayout =
+static const gfx_layout spritelayout =
 {
 	16,16,  /* 16*16 characters */
 	256,    /* 256 characters */
@@ -324,7 +323,7 @@ static gfx_layout spritelayout =
 	8*8*4
 };
 
-static gfx_decode gfxdecodeinfo[] =
+static const gfx_decode gfxdecodeinfo[] =
 {
 	{ REGION_GFX2, 0x0000, &charlayout,   512, 64 },
 	{ REGION_GFX1, 0x0000, &spritelayout, 0,   64 },
@@ -466,7 +465,7 @@ ROM_START( pettanp )
 	ROM_LOAD( "16-2.97",  0x0500,  0x0200, CRC(7f95d4b2) SHA1(68dc311739a4d5d72f4cfbace27f3a82f05316ff) ) /* bg */
 
 	ROM_REGION( 0x0100, REGION_USER1, 0 ) /* scroll control PROM */
-/*  ROM_LOAD( "16-6",     0x0000,  0x0100, NO_DUMP ) */
+	ROM_LOAD( "16-6",     0x0000,  0x0100, NO_DUMP )
 
 	ROM_REGION( 0x1000, REGION_USER2, 0 ) /* protection? */
 	ROM_LOAD( "tvg12-16.2", 0x0000,  0x1000, CRC(3abc6ba8) SHA1(15e0b0f9d068f6094e2be4f4f1dea0ff6e85686b) )
