@@ -20,7 +20,6 @@ Year + Game                 By      Hardware
 ***************************************************************************/
 
 #include "driver.h"
-#include "vidhrdw/generic.h"
 #include "sound/dac.h"
 #include "sound/2151intf.h"
 
@@ -47,8 +46,7 @@ WRITE16_HANDLER( suna16_soundlatch_w )
 {
 	if (ACCESSING_LSB)
 	{
-		if (Machine->sample_rate != 0)
-			soundlatch_w( 0, data & 0xff );
+		soundlatch_w( 0, data & 0xff );
 	}
 	if (data & ~0xff)	logerror("CPU#0 PC %06X - Sound latch unknown bits: %04X\n", activecpu_get_pc(), data);
 }
@@ -538,7 +536,7 @@ INPUT_PORTS_END
 
 /* Tiles are 8x8x4 but the minimum sprite size is 2x2 tiles */
 
-static gfx_layout layout_8x8x4 =
+static const gfx_layout layout_8x8x4 =
 {
 	8,8,
 	RGN_FRAC(1,2),
@@ -549,7 +547,7 @@ static gfx_layout layout_8x8x4 =
 	8*8*4/2
 };
 
-static gfx_decode suna16_gfxdecodeinfo[] =
+static const gfx_decode suna16_gfxdecodeinfo[] =
 {
 	{ REGION_GFX1, 0, &layout_8x8x4, 0, 16*2 }, /* [0] Sprites */
 	{ -1 }
