@@ -36,7 +36,6 @@ Notes:
 ***************************************************************************/
 
 #include "driver.h"
-#include "vidhrdw/generic.h"
 #include "cpu/z80/z80.h"
 #include "sound/ay8910.h"
 #include "sound/2203intf.h"
@@ -99,15 +98,15 @@ DRIVER_INIT( hardhead )
 		if (swaptable[table])
 			rom[i] = BITSWAP8(rom[i], 7,6,5,3,4,2,1,0) ^ 0x58;
 	}
+
+	memory_configure_bank(1, 0, 16, memory_region(REGION_CPU1) + 0x10000, 0x4000);
 }
 
 /* Non encrypted bootleg */
 static DRIVER_INIT( hardhedb )
 {
-	UINT8 *rom = memory_region(REGION_CPU1);
-	offs_t diff = memory_region_length(REGION_CPU1) / 2;
-
-	memory_set_opcode_base(0,rom+diff);
+	memory_set_decrypted_region(0, 0x0000, 0x7fff, memory_region(REGION_CPU1) + 0x48000);
+	memory_configure_bank(1, 0, 16, memory_region(REGION_CPU1) + 0x10000, 0x4000);
 }
 
 /***************************************************************************
@@ -116,14 +115,14 @@ static DRIVER_INIT( hardhedb )
 
 /* !! BRICKZN3 !! */
 
-static void brickzn_decrypt(void)
+static UINT8 *brickzn_decrypt(void)
 {
 	UINT8	*RAM	=	memory_region(REGION_CPU1);
-	size_t	size	=	memory_region_length(REGION_CPU1)/2;
+	size_t	size	=	memory_region_length(REGION_CPU1);
+	UINT8   *decrypt = auto_malloc(size);
 	int i;
 
-	memory_set_opcode_base(0,RAM + size);
-
+	memory_set_decrypted_region(0, 0x0000, 0x7fff, decrypt);
 
 	/* Opcodes and data */
 	for (i = 0; i < 0x50000; i++)
@@ -152,18 +151,18 @@ static void brickzn_decrypt(void)
 		if (opcode_swap || data_swap)
 			x = BITSWAP8(x, 7,2,3,4,5,6,1,0) ^ 0x10;
 
-		RAM[i + size] = x;
+		decrypt[i] = x;
 	}
+
+	return decrypt;
 }
 
 DRIVER_INIT( brickzn )
 {
 	UINT8	*RAM	=	memory_region(REGION_CPU1);
-	size_t	size	=	memory_region_length(REGION_CPU1)/2;
+	UINT8   *decrypt = brickzn_decrypt();
 	int i;
 
-	brickzn_decrypt();
-
 	/* restore opcodes which for some reason shouldn't be decrypted...    */
 	for (i = 0; i < 0x8000; i++)
 	{
@@ -172,28 +171,29 @@ DRIVER_INIT( brickzn )
 				((i >= 0x7393) && (i <= 0x73ba)) ||
 				((i >= 0x7a79) && (i <= 0x7aa9)) )
 		{
-			RAM[i+size] = RAM[i];
+			decrypt[i] = RAM[i];
 		}
 	}
 
 
 	/* !!!!!! PATCHES !!!!!! */
 
-	RAM[0x3349+size] = 0xc9;	/* RET Z -> RET (to avoid: jp $C800) */
+	decrypt[0x3349] = 0xc9;	/* RET Z -> RET (to avoid: jp $C800) */
 
-	RAM[0x1431+size] = 0x00;	/* HALT -> NOP (NMI source??) */
-	RAM[0x24b5+size] = 0x00;	/* HALT -> NOP */
-	RAM[0x2583+size] = 0x00;	/* HALT -> NOP */
+	decrypt[0x1431] = 0x00;	/* HALT -> NOP (NMI source??) */
+	decrypt[0x24b5] = 0x00;	/* HALT -> NOP */
+	decrypt[0x2583] = 0x00;	/* HALT -> NOP */
+
+	memory_configure_bank(1, 0, 16, memory_region(REGION_CPU1) + 0x10000, 0x4000);
+	memory_configure_bank_decrypted(1, 0, 16, decrypt + 0x10000, 0x4000);
 }
 
 DRIVER_INIT( brickzn3 )
 {
 	UINT8	*RAM	=	memory_region(REGION_CPU1);
-	size_t	size	=	memory_region_length(REGION_CPU1)/2;
+	UINT8   *decrypt = brickzn_decrypt();
 	int i;
 
-	brickzn_decrypt();
-
 	/* restore opcodes which for some reason shouldn't be decrypted...    */
 	for (i = 0; i < 0x8000; i++)
 	{
@@ -202,18 +202,21 @@ DRIVER_INIT( brickzn3 )
 				((i >= 0x72f3) && (i <= 0x731a)) ||
 				((i >= 0x79d9) && (i <= 0x7a09)) )
 		{
-			RAM[i+size] = RAM[i];
+			decrypt[i] = RAM[i];
 		}
 	}
 
 
 	/* !!!!!! PATCHES !!!!!! */
 
-	RAM[0x3337+size] = 0xc9;	/* RET Z -> RET (to avoid: jp $C800) */
+	decrypt[0x3337] = 0xc9;	/* RET Z -> RET (to avoid: jp $C800) */
 
-	RAM[0x1406+size] = 0x00;	/* HALT -> NOP (NMI source??) */
-	RAM[0x2487+size] = 0x00;	/* HALT -> NOP */
-	RAM[0x256c+size] = 0x00;	/* HALT -> NOP */
+	decrypt[0x1406] = 0x00;	/* HALT -> NOP (NMI source??) */
+	decrypt[0x2487] = 0x00;	/* HALT -> NOP */
+	decrypt[0x256c] = 0x00;	/* HALT -> NOP */
+
+	memory_configure_bank(1, 0, 16, memory_region(REGION_CPU1) + 0x10000, 0x4000);
+	memory_configure_bank_decrypted(1, 0, 16, decrypt + 0x10000, 0x4000);
 }
 
 
@@ -224,15 +227,15 @@ DRIVER_INIT( brickzn3 )
 DRIVER_INIT( hardhea2 )
 {
 	UINT8	*RAM	=	memory_region(REGION_CPU1);
-	size_t	size	=	memory_region_length(REGION_CPU1)/2;
+	size_t	size	=	memory_region_length(REGION_CPU1);
+	UINT8   *decrypt = 	auto_malloc(size);
 	UINT8 x;
 	int i;
 
-	memory_set_opcode_base(0,RAM + size);
-
+	memory_set_decrypted_region(0, 0x0000, 0x7fff, decrypt);
 
 	/* Address lines scrambling */
-	memcpy(RAM + size, RAM, size);
+	memcpy(decrypt, RAM, size);
 	for (i = 0x00000; i < 0x50000; i++)
 	{
 /*
@@ -262,7 +265,7 @@ rom13:  0?, 1y, 2n, 3n      ?,?,?,? (palettes)
 		if (swaptable[(i & 0xff000) >> 12])
 			addr = (addr & 0xf0000) | BITSWAP16(addr, 15,14,13,12,11,10,9,8,6,7,5,4,3,2,1,0);
 
-		RAM[i] = RAM[addr + size];
+		RAM[i] = decrypt[addr];
 	}
 
 	/* Opcodes */
@@ -286,7 +289,7 @@ rom13:  0?, 1y, 2n, 3n      ?,?,?,? (palettes)
 		if (swaptable[table])
 			x = BITSWAP8(x, 5,6,7,4,3,2,1,0);
 
-		RAM[i + size] = x;
+		decrypt[i] = x;
 	}
 
 	/* Data */
@@ -297,6 +300,9 @@ rom13:  0?, 1y, 2n, 3n      ?,?,?,? (palettes)
 		if (swaptable[(i & 0x7000) >> 12])
 			RAM[i] = BITSWAP8(RAM[i], 5,6,7,4,3,2,1,0) ^ 0x41;
 	}
+
+	memory_configure_bank(1, 0, 16, memory_region(REGION_CPU1) + 0x10000, 0x4000);
+	memory_configure_bank(2, 0, 2, auto_malloc(0x2000 * 2), 0x2000);
 }
 
 
@@ -307,14 +313,15 @@ rom13:  0?, 1y, 2n, 3n      ?,?,?,? (palettes)
 DRIVER_INIT( starfigh )
 {
 	UINT8	*RAM	=	memory_region(REGION_CPU1);
-	size_t	size	=	memory_region_length(REGION_CPU1)/2;
+	size_t	size	=	memory_region_length(REGION_CPU1);
+	UINT8   *decrypt = 	auto_malloc(size);
 	UINT8 x;
 	int i;
 
-	memory_set_opcode_base(0,RAM + size);
+	memory_set_decrypted_region(0, 0x0000, 0x7fff, decrypt);
 
 	/* Address lines scrambling */
-	memcpy(RAM + size, RAM, size);
+	memcpy(decrypt, RAM, size);
 	for (i = 0; i < 0x8000; i++)
 	{
 		static const UINT8 swaptable[8] =
@@ -326,7 +333,7 @@ DRIVER_INIT( starfigh )
 		if (swaptable[(i & 0x7000) >> 12])
 			addr = BITSWAP16(addr, 15,14,13,12,11,10,9,8,6,7,5,4,3,2,1,0);
 
-		RAM[i] = RAM[addr + size];
+		RAM[i] = decrypt[addr];
 	}
 
 	/* Opcodes */
@@ -350,7 +357,7 @@ DRIVER_INIT( starfigh )
 		if (swaptable[table])
 			x = BITSWAP8(x, 5,6,7,4,3,2,1,0) ^ 0x04;
 
-		RAM[i + size] = x;
+		decrypt[i] = x;
 	}
 
 	/* Data */
@@ -361,6 +368,8 @@ DRIVER_INIT( starfigh )
 		if (swaptable[(i & 0x7000) >> 12])
 			RAM[i] = BITSWAP8(RAM[i], 5,6,7,4,3,2,1,0) ^ 0x45;
 	}
+
+	memory_configure_bank(1, 0, 16, memory_region(REGION_CPU1) + 0x10000, 0x4000);
 }
 
 
@@ -371,14 +380,15 @@ DRIVER_INIT( starfigh )
 static DRIVER_INIT( sparkman )
 {
 	UINT8	*RAM	=	memory_region(REGION_CPU1);
-	size_t	size	=	memory_region_length(REGION_CPU1)/2;
+	size_t	size	=	memory_region_length(REGION_CPU1);
+	UINT8   *decrypt = 	auto_malloc(size);
 	UINT8 x;
 	int i;
 
-	memory_set_opcode_base(0,RAM + size);
+	memory_set_decrypted_region(0, 0x0000, 0x7fff, decrypt);
 
 	/* Address lines scrambling */
-	memcpy(RAM + size, RAM, size);
+	memcpy(decrypt, RAM, size);
 	for (i = 0; i < 0x8000; i++)
 	{
 		static const UINT8 swaptable[8] =
@@ -390,7 +400,7 @@ static DRIVER_INIT( sparkman )
 		if (swaptable[(i & 0x7000) >> 12])
 			addr = BITSWAP16(addr, 15,14,13,12,11,10,9,7,8,6,5,4,3,2,1,0);
 
-		RAM[i] = RAM[addr + size];
+		RAM[i] = decrypt[addr];
 	}
 
 	/* Opcodes */
@@ -414,7 +424,7 @@ static DRIVER_INIT( sparkman )
 		if (swaptable[table])
 			x = BITSWAP8(x, 5,6,7,4,3,2,1,0) ^ 0x04;
 
-		RAM[i + size] = x;
+		decrypt[i] = x;
 	}
 
 	/* Data */
@@ -425,6 +435,8 @@ static DRIVER_INIT( sparkman )
 		if (swaptable[(i & 0x7000) >> 12])
 			RAM[i] = BITSWAP8(RAM[i], 5,6,7,4,3,2,1,0) ^ 0x44;
 	}
+
+	memory_configure_bank(1, 0, 16, memory_region(REGION_CPU1) + 0x10000, 0x4000);
 }
 
 /***************************************************************************
@@ -494,13 +506,10 @@ static READ8_HANDLER( hardhead_ip_r )
 */
 static WRITE8_HANDLER( hardhead_bankswitch_w )
 {
-	UINT8 *RAM = memory_region(REGION_CPU1);
 	int bank = data & 0x0f;
 
 	if (data & ~0xef) 	logerror("CPU #0 - PC %04X: unknown bank bits: %02X\n",activecpu_get_pc(),data);
-
-	RAM = &RAM[0x4000 * bank + 0x10000];
-	memory_set_bankptr(1, RAM);
+	memory_set_bank(1, bank);
 }
 
 
@@ -532,7 +541,7 @@ static ADDRESS_MAP_START( hardhead_writemem, ADDRESS_SPACE_PROGRAM, 8 )
 	AM_RANGE(0x0000, 0x7fff) AM_WRITE(MWA8_ROM				)	/* ROM */
 	AM_RANGE(0x8000, 0xbfff) AM_WRITE(MWA8_ROM				)	/* Banked ROM */
 	AM_RANGE(0xc000, 0xd7ff) AM_WRITE(MWA8_RAM				)	/* RAM */
-	AM_RANGE(0xd800, 0xd9ff) AM_WRITE(paletteram_RRRRGGGGBBBBxxxx_swap_w) AM_BASE(&paletteram	)	/* Palette */
+	AM_RANGE(0xd800, 0xd9ff) AM_WRITE(paletteram_RRRRGGGGBBBBxxxx_be_w) AM_BASE(&paletteram	)	/* Palette */
 	AM_RANGE(0xda00, 0xda00) AM_WRITE(MWA8_RAM) AM_BASE(&hardhead_ip	)	/* Input Port Select */
 	AM_RANGE(0xda80, 0xda80) AM_WRITE(hardhead_bankswitch_w	)	/* ROM Banking */
 	AM_RANGE(0xdb00, 0xdb00) AM_WRITE(soundlatch_w			)	/* To Sound CPU */
@@ -567,15 +576,12 @@ ADDRESS_MAP_END
 */
 static WRITE8_HANDLER( rranger_bankswitch_w )
 {
-	UINT8 *RAM = memory_region(REGION_CPU1);
 	int bank = data & 0x07;
 	if ((~data & 0x10) && (bank >= 4))	bank += 4;
 
 	if (data & ~0xf7) 	logerror("CPU #0 - PC %04X: unknown bank bits: %02X\n",activecpu_get_pc(),data);
 
-	RAM = &RAM[0x4000 * bank + 0x10000];
-
-	memory_set_bankptr(1, RAM);
+	memory_set_bank(1, bank);
 
 	flip_screen_set(    data & 0x20);
 	coin_lockout_w ( 0,	data & 0x40);
@@ -617,7 +623,7 @@ static ADDRESS_MAP_START( rranger_writemem, ADDRESS_SPACE_PROGRAM, 8 )
 	AM_RANGE(0xc002, 0xc002) AM_WRITE(rranger_bankswitch_w	)	/* ROM Banking */
 	AM_RANGE(0xc200, 0xc200) AM_WRITE(MWA8_NOP				)	/* Protection? */
 	AM_RANGE(0xc280, 0xc280) AM_WRITE(MWA8_NOP				)	/* ? NMI Ack */
-	AM_RANGE(0xc600, 0xc7ff) AM_WRITE(paletteram_RRRRGGGGBBBBxxxx_swap_w) AM_BASE(&paletteram	)	/* Palette */
+	AM_RANGE(0xc600, 0xc7ff) AM_WRITE(paletteram_RRRRGGGGBBBBxxxx_be_w) AM_BASE(&paletteram	)	/* Palette */
 	AM_RANGE(0xc800, 0xdfff) AM_WRITE(MWA8_RAM				)	/* RAM */
 	AM_RANGE(0xe000, 0xffff) AM_WRITE(suna8_spriteram_w) AM_BASE(&spriteram	)	/* Sprites */
 ADDRESS_MAP_END
@@ -678,14 +684,11 @@ static WRITE8_HANDLER( brickzn_unknown_w )
 */
 static WRITE8_HANDLER( brickzn_rombank_w )
 {
-	UINT8 *RAM = memory_region(REGION_CPU1);
 	int bank = data & 0x0f;
 
 	if (data & ~0x0f) 	logerror("CPU #0 - PC %04X: unknown rom bank bits: %02X\n",activecpu_get_pc(),data);
 
-	RAM = &RAM[0x4000 * bank + 0x10000];
-
-	memory_set_bankptr(1, RAM);
+	memory_set_bank(1, bank);
 	suna8_rombank = data;
 }
 
@@ -773,12 +776,11 @@ static WRITE8_HANDLER( hardhea2_spritebank_w )
 */
 static WRITE8_HANDLER( hardhea2_rombank_w )
 {
-	UINT8 *ROM = memory_region(REGION_CPU1);
 	int bank = data & 0x0f;
 
 	if (data & ~0x0f) 	logerror("CPU #0 - PC %04X: unknown rom bank bits: %02X\n",activecpu_get_pc(),data);
 
-	memory_set_bankptr(1,&ROM[0x4000 * bank + 0x10000]);
+	memory_set_bank(1, bank);
 	suna8_rombank = data;
 }
 
@@ -793,13 +795,11 @@ static WRITE8_HANDLER( hardhea2_spritebank_1_w )
 
 static WRITE8_HANDLER( hardhea2_rambank_0_w )
 {
-	UINT8 *RAM = memory_region(REGION_USER3);
-	memory_set_bankptr(2,&RAM[0x2000 * 0]);
+	memory_set_bank(2, 0);
 }
 static WRITE8_HANDLER( hardhea2_rambank_1_w )
 {
-	UINT8 *RAM = memory_region(REGION_USER3);
-	memory_set_bankptr(2,&RAM[0x2000 * 1]);
+	memory_set_bank(2, 1);
 }
 
 
@@ -846,7 +846,7 @@ static ADDRESS_MAP_START( hardhea2_writemem, ADDRESS_SPACE_PROGRAM, 8 )
 	AM_RANGE(0xc533, 0xc533) AM_WRITE(hardhea2_rambank_0_w )
 	/* Protection *** */
 
-	AM_RANGE(0xc600, 0xc7ff) AM_WRITE(paletteram_RRRRGGGGBBBBxxxx_swap_w) AM_BASE(&paletteram	)	/* Palette (Banked??) */
+	AM_RANGE(0xc600, 0xc7ff) AM_WRITE(paletteram_RRRRGGGGBBBBxxxx_be_w) AM_BASE(&paletteram	)	/* Palette (Banked??) */
 	AM_RANGE(0xc800, 0xdfff) AM_WRITE(MWA8_BANK2					)	/* RAM (Banked?) */
 	AM_RANGE(0xe000, 0xffff) AM_WRITE(suna8_banked_spriteram_w	)	/* Sprites (Banked) */
 ADDRESS_MAP_END
@@ -889,7 +889,7 @@ static ADDRESS_MAP_START( starfigh_writemem, ADDRESS_SPACE_PROGRAM, 8 )
 	AM_RANGE(0xc300, 0xc300) AM_WRITE(hardhea2_flipscreen_w			)	/* Flip Screen */
 	AM_RANGE(0xc400, 0xc400) AM_WRITE(hardhea2_leds_w				)	/* Leds + Coin Counter */
 	AM_RANGE(0xc500, 0xc500) AM_WRITE(soundlatch_w					)	/* To Sound CPU */
-	AM_RANGE(0xc600, 0xc7ff) AM_WRITE(paletteram_RRRRGGGGBBBBxxxx_swap_w) AM_BASE(&paletteram	)	/* Palette (Banked??) */
+	AM_RANGE(0xc600, 0xc7ff) AM_WRITE(paletteram_RRRRGGGGBBBBxxxx_be_w) AM_BASE(&paletteram	)	/* Palette (Banked??) */
 	AM_RANGE(0xc800, 0xdfff) AM_WRITE(MWA8_RAM						)	/* RAM */
 	AM_RANGE(0xe000, 0xffff) AM_WRITE(suna8_banked_spriteram_w		)	/* Sprites (Banked) */
 ADDRESS_MAP_END
@@ -949,14 +949,11 @@ static WRITE8_HANDLER( sparkman_spritebank_w )
 */
 static WRITE8_HANDLER( sparkman_rombank_w )
 {
-	UINT8 *RAM = memory_region(REGION_CPU1);
 	int bank = data & 0x0f;
 
 	if (data & ~0x0f) 	logerror("CPU #0 - PC %04X: unknown rom bank bits: %02X\n",activecpu_get_pc(),data);
 
-	RAM = &RAM[0x4000 * bank + 0x10000];
-
-	memory_set_bankptr(1, RAM);
+	memory_set_bank(1, bank);
 	suna8_rombank = data;
 }
 
@@ -988,7 +985,7 @@ static ADDRESS_MAP_START( sparkman_writemem, ADDRESS_SPACE_PROGRAM, 8 )
 	AM_RANGE(0xc380, 0xc380) AM_WRITE(sparkman_nmi_w			)	/* ? NMI related ? */
 	AM_RANGE(0xc400, 0xc400) AM_WRITE(sparkman_leds_w			)	/* Leds + Coin Counter */
 	AM_RANGE(0xc500, 0xc500) AM_WRITE(soundlatch_w				)	/* To Sound CPU */
-	AM_RANGE(0xc600, 0xc7ff) AM_WRITE(paletteram_RRRRGGGGBBBBxxxx_swap_w) AM_BASE(&paletteram	)	/* Palette (Banked??) */
+	AM_RANGE(0xc600, 0xc7ff) AM_WRITE(paletteram_RRRRGGGGBBBBxxxx_be_w) AM_BASE(&paletteram	)	/* Palette (Banked??) */
 	AM_RANGE(0xc800, 0xdfff) AM_WRITE(MWA8_RAM					)	/* RAM */
 	AM_RANGE(0xe000, 0xffff) AM_WRITE(suna8_banked_spriteram_w	)	/* Sprites (Banked) */
 ADDRESS_MAP_END
@@ -1495,7 +1492,7 @@ INPUT_PORTS_END
 ***************************************************************************/
 
 /* 8x8x4 tiles (2 bitplanes per ROM) */
-static gfx_layout layout_8x8x4 =
+static const gfx_layout layout_8x8x4 =
 {
 	8,8,
 	RGN_FRAC(1,2),
@@ -1506,7 +1503,7 @@ static gfx_layout layout_8x8x4 =
 	8*8*2
 };
 
-static gfx_decode suna8_gfxdecodeinfo[] =
+static const gfx_decode suna8_gfxdecodeinfo[] =
 {
 	{ REGION_GFX1, 0, &layout_8x8x4, 0, 16 }, /* [0] Sprites */
 	{ -1 }
@@ -1735,7 +1732,7 @@ INTERRUPT_GEN( hardhea2_interrupt )
 	else cpunum_set_input_line(0, 0, HOLD_LINE);
 }
 
-static MACHINE_INIT( hardhea2 )
+static MACHINE_RESET( hardhea2 )
 {
 	hardhea2_rambank_0_w(0,0);
 }
@@ -1747,7 +1744,7 @@ static MACHINE_DRIVER_START( hardhea2 )
 	MDRV_CPU_PROGRAM_MAP(hardhea2_readmem,hardhea2_writemem)
 	MDRV_CPU_VBLANK_INT(hardhea2_interrupt,2)	/* IRQ & NMI */
 
-	MDRV_MACHINE_INIT(hardhea2)
+	MDRV_MACHINE_RESET(hardhea2)
 	MDRV_PALETTE_LENGTH(256)
 MACHINE_DRIVER_END
 
@@ -1935,28 +1932,21 @@ ROM_START( hardhead )
 	ROM_LOAD( "p12", 0x30000, 0x8000, CRC(9582e6db) SHA1(a2b34d740e07bd35a3184365e7f3ab7476075d70) )
 	ROM_RELOAD(      0x38000, 0x8000             )
 
-	ROM_REGION( 0x8000, REGION_SOUND1, ROMREGION_SOUNDONLY )	/* Samples */
+	ROM_REGION( 0x8000, REGION_SOUND1, 0 )	/* Samples */
 	ROM_LOAD( "p14", 0x0000, 0x8000, CRC(41314ac1) SHA1(1ac9213b0ac4ce9fe6256e93875672e128a5d069) )
 ROM_END
 
 ROM_START( hardhedb )
-	ROM_REGION( 0x50000*2, REGION_CPU1, 0 ) /* Main Z80 Code */
-	ROM_LOAD( "1_27512.l6",  0x50000, 0x8000, CRC(bb4aa9ac) SHA1(da6310a1034cf610139d74fc30dd13e5fbd1d8dd) ) /* 1988,9,14 (already decrypted) */
+	ROM_REGION( 0x48000+0x8000, REGION_CPU1, 0 ) /* Main Z80 Code */
+	ROM_LOAD( "1_27512.l6",  0x48000, 0x8000, CRC(bb4aa9ac) SHA1(da6310a1034cf610139d74fc30dd13e5fbd1d8dd) ) /* 1988,9,14 (already decrypted) */
 	ROM_CONTINUE(			 0x00000, 0x8000 )
 	ROM_LOAD( "p2",			 0x10000, 0x8000, CRC(faa2cf9a) SHA1(5987f146b58fcbc3aaa9c010d86022b5172bcfb4) )
-	ROM_RELOAD(			     0x60000, 0x8000 )
 	ROM_LOAD( "p3",			 0x18000, 0x8000, CRC(3d24755e) SHA1(519a179594956f7c3ddfaca362c42b453c928e25) )
-	ROM_RELOAD(			     0x68000, 0x8000 )
 	ROM_LOAD( "p4",			 0x20000, 0x8000, CRC(0241ac79) SHA1(b3c3b98fb29836cbc9fd35ac49e02bfefd3b0c79) )
-	ROM_RELOAD(			     0x70000, 0x8000 )
 	ROM_LOAD( "p7",			 0x28000, 0x8000, CRC(beba8313) SHA1(20aa4e07ec560a89d07ec73cc93311ceaed899a3) )
-	ROM_RELOAD(			     0x78000, 0x8000 )
 	ROM_LOAD( "p8",			 0x30000, 0x8000, CRC(211a9342) SHA1(85bdafe1a2c683eea391cc663caabd958fdf5197) )
-	ROM_RELOAD(			     0x80000, 0x8000 )
 	ROM_LOAD( "p9",			 0x38000, 0x8000, CRC(2ad430c4) SHA1(286a5b1042e077c3ae741d01311d4c91f8f87054) )
-	ROM_RELOAD(			     0x88000, 0x8000 )
 	ROM_LOAD( "p10",		 0x40000, 0x8000, CRC(b6894517) SHA1(e114a5f92b83d98215aab6e2cd943a110d118f56) )
-	ROM_RELOAD(			     0x90000, 0x8000 )
 
 	ROM_REGION( 0x10000, REGION_CPU2, 0 )		/* Sound Z80 Code */
 	ROM_LOAD( "p13", 0x0000, 0x8000, CRC(493c0b41) SHA1(994a334253e905c39ec912765e8b0f4b1be900bc) )
@@ -1972,28 +1962,21 @@ ROM_START( hardhedb )
 	ROM_LOAD( "p12", 0x30000, 0x8000, CRC(9582e6db) SHA1(a2b34d740e07bd35a3184365e7f3ab7476075d70) )
 	ROM_RELOAD(      0x38000, 0x8000             )
 
-	ROM_REGION( 0x8000, REGION_SOUND1, ROMREGION_SOUNDONLY )	/* Samples */
+	ROM_REGION( 0x8000, REGION_SOUND1, 0 )	/* Samples */
 	ROM_LOAD( "p14", 0x0000, 0x8000, CRC(41314ac1) SHA1(1ac9213b0ac4ce9fe6256e93875672e128a5d069) )
 ROM_END
 
 ROM_START( pop_hh )
-	ROM_REGION( 0x50000*2, REGION_CPU1, 0 ) /* Main Z80 Code */
-	ROM_LOAD( "1_27512.l6",  0x50000, 0x8000, CRC(bb4aa9ac) SHA1(da6310a1034cf610139d74fc30dd13e5fbd1d8dd) ) /* 1988,9,14 (already decrypted) */
+	ROM_REGION( 0x48000+0x8000, REGION_CPU1, 0 ) /* Main Z80 Code */
+	ROM_LOAD( "1_27512.l6",  0x48000, 0x8000, CRC(bb4aa9ac) SHA1(da6310a1034cf610139d74fc30dd13e5fbd1d8dd) ) /* 1988,9,14 (already decrypted) */
 	ROM_CONTINUE(			 0x00000, 0x8000 )
 	ROM_LOAD( "2_27256.k6",  0x10000, 0x8000, CRC(8fcc1248) SHA1(5da0b7dc63f7bc00e81e9e5bac02ee6b0076ffaa) )
-	ROM_RELOAD(			     0x60000, 0x8000 )
 	ROM_LOAD( "p3",          0x18000, 0x8000, CRC(3d24755e) SHA1(519a179594956f7c3ddfaca362c42b453c928e25) ) /* 3_27256.j6 */
-	ROM_RELOAD(			     0x68000, 0x8000 )
 	ROM_LOAD( "p4",          0x20000, 0x8000, CRC(0241ac79) SHA1(b3c3b98fb29836cbc9fd35ac49e02bfefd3b0c79) ) /* 4_27256.i6 */
-	ROM_RELOAD(			     0x70000, 0x8000 )
 	ROM_LOAD( "p7",          0x28000, 0x8000, CRC(beba8313) SHA1(20aa4e07ec560a89d07ec73cc93311ceaed899a3) ) /* 7_27256.l8 */
-	ROM_RELOAD(			     0x78000, 0x8000 )
 	ROM_LOAD( "8_27256.k8",  0x30000, 0x8000, CRC(87a8b4b4) SHA1(83d30cf184c5dccdf2666c0ef9e078541d6a146e) )
-	ROM_RELOAD(			     0x80000, 0x8000 )
 	ROM_LOAD( "p9",          0x38000, 0x8000, CRC(2ad430c4) SHA1(286a5b1042e077c3ae741d01311d4c91f8f87054) ) /* 9_27256.j8 */
-	ROM_RELOAD(			     0x88000, 0x8000 )
 	ROM_LOAD( "10_27256.i8", 0x40000, 0x8000, CRC(84fc6574) SHA1(ab33e6c656f25e65bb08d0a2689693df83cab43d) )
-	ROM_RELOAD(			     0x90000, 0x8000 )
 
 	ROM_REGION( 0x10000, REGION_CPU2, 0 )		/* Sound Z80 Code */
 	ROM_LOAD( "p13", 0x0000, 0x8000, CRC(493c0b41) SHA1(994a334253e905c39ec912765e8b0f4b1be900bc) ) /* 13_27256.i10 */
@@ -2008,7 +1991,7 @@ ROM_START( pop_hh )
 	ROM_LOAD( "p12", 0x30000, 0x8000, CRC(9582e6db) SHA1(a2b34d740e07bd35a3184365e7f3ab7476075d70) ) /* 12_27256.a8 */
 	ROM_RELOAD(      0x38000, 0x8000             )
 
-	ROM_REGION( 0x8000, REGION_SOUND1, ROMREGION_SOUNDONLY )	/* Samples */
+	ROM_REGION( 0x8000, REGION_SOUND1, 0 )	/* Samples */
 	ROM_LOAD( "p14", 0x0000, 0x8000, CRC(41314ac1) SHA1(1ac9213b0ac4ce9fe6256e93875672e128a5d069) ) /* 14_27256.m11 */
 ROM_END
 
@@ -2083,7 +2066,7 @@ ROM_START( rranger )
 	ROM_REGION( 0x10000, REGION_CPU2, 0 )		/* Sound Z80 Code */
 	ROM_LOAD( "14", 0x0000, 0x8000, CRC(11c83aa1) SHA1(d1f75096528b220a3f858eac62e3b4111fa013de) )
 
-	ROM_REGION( 0x8000, REGION_SOUND1, ROMREGION_SOUNDONLY )	/* Samples */
+	ROM_REGION( 0x8000, REGION_SOUND1, 0 )	/* Samples */
 	ROM_LOAD( "15", 0x0000, 0x8000, CRC(28c2c87e) SHA1(ec0d92140ef44df822f2229e79b915e051caa033) )
 
 	ROM_REGION( 0x40000, REGION_GFX1, ROMREGION_DISPOSE | ROMREGION_INVERT )	/* Sprites */
@@ -2110,7 +2093,7 @@ ROM_START( sranger )
 	ROM_REGION( 0x10000, REGION_CPU2, 0 )		/* Sound Z80 Code */
 	ROM_LOAD( "14", 0x0000, 0x8000, CRC(11c83aa1) SHA1(d1f75096528b220a3f858eac62e3b4111fa013de) )
 
-	ROM_REGION( 0x8000, REGION_SOUND1, ROMREGION_SOUNDONLY )	/* Samples */
+	ROM_REGION( 0x8000, REGION_SOUND1, 0 )	/* Samples */
 	ROM_LOAD( "15", 0x0000, 0x8000, CRC(28c2c87e) SHA1(ec0d92140ef44df822f2229e79b915e051caa033) )
 
 	ROM_REGION( 0x40000, REGION_GFX1, ROMREGION_DISPOSE | ROMREGION_INVERT )	/* Sprites */
@@ -2138,7 +2121,7 @@ ROM_START( srangerb )
 	ROM_REGION( 0x10000, REGION_CPU2, 0 )		/* Sound Z80 Code */
 	ROM_LOAD( "14", 0x0000, 0x8000, CRC(11c83aa1) SHA1(d1f75096528b220a3f858eac62e3b4111fa013de) )
 
-	ROM_REGION( 0x8000, REGION_SOUND1, ROMREGION_SOUNDONLY )	/* Samples */
+	ROM_REGION( 0x8000, REGION_SOUND1, 0 )	/* Samples */
 	ROM_LOAD( "15", 0x0000, 0x8000, CRC(28c2c87e) SHA1(ec0d92140ef44df822f2229e79b915e051caa033) )
 
 	ROM_REGION( 0x40000, REGION_GFX1, ROMREGION_DISPOSE | ROMREGION_INVERT )	/* Sprites */
@@ -2165,7 +2148,7 @@ ROM_START( srangerw )
 	ROM_REGION( 0x10000, REGION_CPU2, 0 )		/* Sound Z80 Code */
 	ROM_LOAD( "14", 0x0000, 0x8000, CRC(11c83aa1) SHA1(d1f75096528b220a3f858eac62e3b4111fa013de) )
 
-	ROM_REGION( 0x8000, REGION_SOUND1, ROMREGION_SOUNDONLY )	/* Samples */
+	ROM_REGION( 0x8000, REGION_SOUND1, 0 )	/* Samples */
 	ROM_LOAD( "15", 0x0000, 0x8000, CRC(28c2c87e) SHA1(ec0d92140ef44df822f2229e79b915e051caa033) )
 
 	ROM_REGION( 0x40000, REGION_GFX1, ROMREGION_DISPOSE | ROMREGION_INVERT )	/* Sprites */
@@ -2210,7 +2193,7 @@ Large epoxy(?) module near the cpu's.
 ***************************************************************************/
 
 ROM_START( brickzn )
-	ROM_REGION( 0x50000 * 2, REGION_CPU1, 0 )		/* Main Z80 Code */
+	ROM_REGION( 0x50000, REGION_CPU1, 0 )		/* Main Z80 Code */
 	ROM_LOAD( "brickzon.009", 0x00000, 0x08000, CRC(1ea68dea) SHA1(427152a26b062c5e77089de49c1da69369d4d557) )	/* V5.0 1992,3,3 */
 	ROM_LOAD( "brickzon.008", 0x10000, 0x20000, CRC(c61540ba) SHA1(08c0ede591b229427b910ca6bb904a6146110be8) )
 	ROM_LOAD( "brickzon.007", 0x30000, 0x20000, CRC(ceed12f1) SHA1(9006726b75a65455afb1194298bade8fa2207b4a) )
@@ -2228,13 +2211,10 @@ ROM_START( brickzn )
 	ROM_LOAD( "brickzon.005", 0x60000, 0x20000, CRC(118f8392) SHA1(598fa4df3ae348ec9796cd6d90c3045bec546da3) )
 	ROM_LOAD( "brickzon.004", 0x80000, 0x20000, CRC(2be5f335) SHA1(dc870a3c5303cb2ea1fea4a25f53db016ed5ecee) )
 	ROM_LOAD( "brickzon.006", 0xa0000, 0x20000, CRC(bbf31081) SHA1(1fdbd0e0853082345225e18df340184a7a604b78) )
-
-	ROM_REGION( 0x0200 * 2, REGION_USER1, 0 )	/* Palette RAM Banks */
-	ROM_REGION( 0x2000 * 2, REGION_USER2, 0 )	/* Sprite  RAM Banks */
 ROM_END
 
 ROM_START( brickzn3 )
-	ROM_REGION( 0x50000 * 2, REGION_CPU1, 0 )		/* Main Z80 Code */
+	ROM_REGION( 0x50000, REGION_CPU1, 0 )		/* Main Z80 Code */
 	ROM_LOAD( "39",           0x00000, 0x08000, CRC(043380bd) SHA1(7eea7cc7d754815df233879b4a9d3d88eac5b28d) )	/* V3.0 1992,1,23 */
 	ROM_LOAD( "38",           0x10000, 0x20000, CRC(e16216e8) SHA1(e88ae97e8a632823d5f1fe500954b6f6542407d5) )
 	ROM_LOAD( "brickzon.007", 0x30000, 0x20000, CRC(ceed12f1) SHA1(9006726b75a65455afb1194298bade8fa2207b4a) )
@@ -2252,9 +2232,6 @@ ROM_START( brickzn3 )
 	ROM_LOAD( "32",           0x60000, 0x20000, CRC(32dbf2dd) SHA1(b9ab8b93a062b871b7f824e4be2f214cc832d585) )
 	ROM_LOAD( "brickzon.001", 0x80000, 0x20000, CRC(6970ada9) SHA1(5cfe5dcf25af7aff67ee5d78eb963d598251025f) )
 	ROM_LOAD( "brickzon.003", 0xa0000, 0x20000, CRC(2e4f194b) SHA1(86da1a582ea274f2af96d3e3e2ac72bcaf3638cb) )
-
-	ROM_REGION( 0x0200 * 2, REGION_USER1, 0 )	/* Palette RAM Banks */
-	ROM_REGION( 0x2000 * 2, REGION_USER2, 0 )	/* Sprite  RAM Banks */
 ROM_END
 
 
@@ -2296,7 +2273,7 @@ Sound is a Yamaha YM3812 and a  AY-3-8910A
 ***************************************************************************/
 
 ROM_START( hardhea2 )
-	ROM_REGION( 0x50000 * 2, REGION_CPU1, 0 )		/* Main Z80 Code */
+	ROM_REGION( 0x50000, REGION_CPU1, 0 )		/* Main Z80 Code */
 	ROM_LOAD( "hrd-hd9",  0x00000, 0x08000, CRC(69c4c307) SHA1(0dfde1dcda51b5b1740aff9e96cb877a428a3e04) )	/* V 2.0 1991,2,12 */
 	ROM_LOAD( "hrd-hd10", 0x10000, 0x10000, CRC(77ec5b0a) SHA1(2d3e24c208904a7884e585e08e5818fd9f8b5391) )
 	ROM_LOAD( "hrd-hd11", 0x20000, 0x10000, CRC(12af8f8e) SHA1(1b33a060b70900042fdae00f7dec325228d566f5) )
@@ -2318,10 +2295,6 @@ ROM_START( hardhea2 )
 	ROM_LOAD( "hrd-hd6",  0x50000, 0x10000, CRC(bf90d3ca) SHA1(2d0533d93fc5155fe879c1890bc7bc4581308e16) )
 	ROM_LOAD( "hrd-hd7",  0x60000, 0x10000, CRC(992ce8cb) SHA1(21c0dd227138ec64003c7cb090855ec27d41719e) )
 	ROM_LOAD( "hrd-hd8",  0x70000, 0x10000, CRC(359597a4) SHA1(ae024dd61c5d12813a661abe8ea63ae6112ddc9c) )
-
-	ROM_REGION( 0x0200 * 2, REGION_USER1, 0 )	/* Palette RAM Banks */
-	ROM_REGION( 0x2000 * 2, REGION_USER2, 0 )	/* Sprite  RAM Banks */
-	ROM_REGION( 0x2000 * 2, REGION_USER3, 0 )	/* Scratch RAM Banks(protection) */
 ROM_END
 
 
@@ -2332,7 +2305,7 @@ ROM_END
 ***************************************************************************/
 
 ROM_START( starfigh )
-	ROM_REGION( 0x50000 * 2, REGION_CPU1, 0 )		/* Main Z80 Code */
+	ROM_REGION( 0x50000, REGION_CPU1, 0 )		/* Main Z80 Code */
 	ROM_LOAD( "starfgtr.l1", 0x00000, 0x08000, CRC(f93802c6) SHA1(4005b06b69dd440dfb6385766386a1168e73288f) )	/* V.1 */
 	ROM_LOAD( "starfgtr.j1", 0x10000, 0x10000, CRC(fcfcf08a) SHA1(65fe1666aa5092f820b337bcbcbed7accdec440d) )
 	ROM_LOAD( "starfgtr.i1", 0x20000, 0x10000, CRC(6935fcdb) SHA1(f47812f6716ccf52dd7ab8522c29e059f1e38f31) )
@@ -2342,7 +2315,7 @@ ROM_START( starfigh )
 	ROM_REGION( 0x10000, REGION_CPU2, 0 )		/* Music Z80 Code */
 	ROM_LOAD( "starfgtr.m8", 0x0000, 0x8000, CRC(ae3b0691) SHA1(41e004d09522cf7ddce6e4adc68841ad5553264a) )
 
-	ROM_REGION( 0x8000, REGION_SOUND1, ROMREGION_SOUNDONLY )	/* Samples */
+	ROM_REGION( 0x8000, REGION_SOUND1, 0 )	/* Samples */
 	ROM_LOAD( "starfgtr.q10", 0x0000, 0x8000, CRC(fa510e94) SHA1(e2742385a4ba152dbc89534e4350d1d9ad49730f) )
 
 	ROM_REGION( 0x100000, REGION_GFX1, ROMREGION_DISPOSE | ROMREGION_INVERT )	/* Sprites */
@@ -2362,9 +2335,6 @@ ROM_START( starfigh )
 	ROM_RELOAD(              0xe0000, 0x10000             )
 	ROM_LOAD( "starfgtr.a6", 0xd0000, 0x10000, CRC(4a33f6f3) SHA1(daa0a1a43b1b60e2f05b9934fdd6b5f285a0b93a) )
 	ROM_RELOAD(              0xf0000, 0x10000             )
-
-	ROM_REGION( 0x0200 * 2, REGION_USER1, 0 )	/* Palette RAM Banks */
-	ROM_REGION( 0x2000 * 2, REGION_USER2, 0 )	/* Sprite  RAM Banks */
 ROM_END
 
 
@@ -2383,7 +2353,7 @@ Sound is a Yamaha YM3812 and a  AY-3-8910A
 ***************************************************************************/
 
 ROM_START( sparkman )
-	ROM_REGION( 0x50000 * 2, REGION_CPU1, 0 )		/* Main Z80 Code */
+	ROM_REGION( 0x50000, REGION_CPU1, 0 )		/* Main Z80 Code */
 	ROM_LOAD( "sparkman.e7", 0x00000, 0x08000, CRC(d89c5780) SHA1(177f0ae21c00575a7eb078e86f3a790fc95211e4) )	/* "SPARK MAN MAIN PROGRAM 1989,8,12 K.H.T (SUNA ELECTRPNICS) V 2.0 SOULE KOREA" */
 	ROM_LOAD( "sparkman.g7", 0x10000, 0x10000, CRC(48b4a31e) SHA1(771d1f1a2ce950ce2b661a4081471e98a7a7d53e) )
 	ROM_LOAD( "sparkman.g8", 0x20000, 0x10000, CRC(b8a4a557) SHA1(10251b49fb44fb1e7c71fde8fe9544df29d27346) )
@@ -2409,9 +2379,6 @@ ROM_START( sparkman )
 
 	ROM_REGION( 0x8000, REGION_SOUND2, 0 )		/* Samples */
 	ROM_LOAD( "sprkman.b11", 0x0000, 0x8000, CRC(d6823a62) SHA1(f8ce748aa7bdc9c95799dd111fd872717e46d416) )
-
-	ROM_REGION( 0x0200 * 2, REGION_USER1, 0 )	/* Palette RAM Banks */
-	ROM_REGION( 0x2000 * 2, REGION_USER2, 0 )	/* Sprite  RAM Banks */
 ROM_END
 
 
@@ -2423,17 +2390,22 @@ ROM_END
 
 ***************************************************************************/
 
+static DRIVER_INIT( suna8 )
+{
+	memory_configure_bank(1, 0, 16, memory_region(REGION_CPU1) + 0x10000, 0x4000);
+}
+
 /* Working Games */
-GAME( 1988, rranger,  0,        rranger,  rranger,  0,        ROT0,  "SunA (Sharp Image license)", "Rough Ranger (v2.0)", GAME_IMPERFECT_SOUND )
+GAME( 1988, rranger,  0,        rranger,  rranger,  suna8,    ROT0,  "SunA (Sharp Image license)", "Rough Ranger (v2.0)", GAME_IMPERFECT_SOUND )
 GAME( 1988, hardhead, 0,        hardhead, hardhead, hardhead, ROT0,  "SunA",                       "Hard Head"									, 0)
 GAME( 1988, hardhedb, hardhead, hardhead, hardhead, hardhedb, ROT0,  "bootleg",                    "Hard Head (bootleg)"						, 0)
 GAME( 1988, pop_hh,   hardhead, hardhead, hardhead, hardhedb, ROT0,  "bootleg",                    "Popper (Hard Head bootleg)"				, 0)
 GAME( 1991, hardhea2, 0,        hardhea2, hardhea2, hardhea2, ROT0,  "SunA",                       "Hard Head 2 (v2.0)"                       , 0 )
 
 /* Non Working Games */
-GAME( 1988, sranger,  rranger, rranger,  rranger,	0,        ROT0,  "SunA",    "Super Ranger (v2.0)",           GAME_NOT_WORKING )
-GAME( 1988, srangerb, rranger, rranger,  rranger,	0,        ROT0,  "bootleg", "Super Ranger (bootleg)",        GAME_NOT_WORKING )
-GAME( 1988, srangerw, rranger, rranger,  rranger,	0,        ROT0,  "SunA (WDK license)", "Super Ranger (WDK)", GAME_NOT_WORKING )
+GAME( 1988, sranger,  rranger, rranger,  rranger,	suna8,        ROT0,  "SunA",    "Super Ranger (v2.0)",           GAME_NOT_WORKING )
+GAME( 1988, srangerb, rranger, rranger,  rranger,	suna8,        ROT0,  "bootleg", "Super Ranger (bootleg)",        GAME_NOT_WORKING )
+GAME( 1988, srangerw, rranger, rranger,  rranger,	suna8,        ROT0,  "SunA (WDK license)", "Super Ranger (WDK)", GAME_NOT_WORKING )
 GAME( 1989, sparkman, 0,       sparkman, sparkman, sparkman, ROT0,  "SunA",    "Spark Man (v 2.0)",             GAME_NOT_WORKING )
 GAME( 1990, starfigh, 0,       starfigh, hardhea2, starfigh, ROT90, "SunA",    "Star Fighter (v1)",             GAME_NOT_WORKING )
 GAME( 1992, brickzn,  0,       brickzn,  brickzn,  brickzn,  ROT90, "SunA",    "Brick Zone (v5.0)",             GAME_NOT_WORKING )
