@@ -35,11 +35,11 @@
 
 #include "driver.h"
 #include "cpu/m68000/m68000.h"
-#include "vidhrdw/generic.h"
 #include "vidhrdw/taitoic.h"
 #include "sndhrdw/taitosnd.h"
 #include "machine/eeprom.h"
 #include "sound/es5506.h"
+#include "includes/taito_f3.h"
 
 VIDEO_START( superchs );
 VIDEO_UPDATE( superchs );
@@ -47,22 +47,10 @@ VIDEO_UPDATE( superchs );
 static UINT16 coin_word;
 static UINT32 *superchs_ram;
 static UINT32 *shared_ram;
-extern UINT32 *f3_shared_ram;
+static UINT16 *sound_ram;
 
 static int steer=0;
 
-/* from sndhrdw/taito_f3.c */
-READ16_HANDLER(f3_68000_share_r);
-WRITE16_HANDLER(f3_68000_share_w);
-READ16_HANDLER(f3_68681_r);
-WRITE16_HANDLER(f3_68681_w);
-READ16_HANDLER(es5510_dsp_r);
-WRITE16_HANDLER(es5510_dsp_w);
-WRITE16_HANDLER(f3_volume_w);
-WRITE16_HANDLER(f3_es5505_bank_w);
-void f3_68681_reset(void);
-extern WRITE16_HANDLER( es5505_bank_w ); /* drivers/f3 */
-
 /*********************************************************************/
 
 static READ16_HANDLER( shared_ram_r )
@@ -295,7 +283,7 @@ static ADDRESS_MAP_START( sound_readmem, ADDRESS_SPACE_PROGRAM, 16 )
 ADDRESS_MAP_END
 
 static ADDRESS_MAP_START( sound_writemem, ADDRESS_SPACE_PROGRAM, 16 )
-	AM_RANGE(0x000000, 0x03ffff) AM_WRITE(MWA16_RAM)
+	AM_RANGE(0x000000, 0x03ffff) AM_WRITE(MWA16_RAM) AM_BASE(&sound_ram)
 	AM_RANGE(0x140000, 0x140fff) AM_WRITE(f3_68000_share_w)
 	AM_RANGE(0x200000, 0x20001f) AM_WRITE(ES5505_data_0_w)
 	AM_RANGE(0x260000, 0x2601ff) AM_WRITE(es5510_dsp_w)
@@ -370,7 +358,7 @@ INPUT_PORTS_END
                 GFX DECODING
 **********************************************************/
 
-static gfx_layout tile16x16_layout =
+static const gfx_layout tile16x16_layout =
 {
 	16,16,	/* 16*16 sprites */
 	RGN_FRAC(1,1),
@@ -382,7 +370,7 @@ static gfx_layout tile16x16_layout =
 	64*16	/* every sprite takes 128 consecutive bytes */
 };
 
-static gfx_layout charlayout =
+static const gfx_layout charlayout =
 {
 	16,16,    /* 16*16 characters */
 	RGN_FRAC(1,1),
@@ -393,7 +381,7 @@ static gfx_layout charlayout =
 	128*8     /* every sprite takes 128 consecutive bytes */
 };
 
-static gfx_decode superchs_gfxdecodeinfo[] =
+static const gfx_decode superchs_gfxdecodeinfo[] =
 {
 	{ REGION_GFX2, 0x0, &tile16x16_layout,  0, 512 },
 	{ REGION_GFX1, 0x0, &charlayout,        0, 512 },
@@ -405,16 +393,16 @@ static gfx_decode superchs_gfxdecodeinfo[] =
                  MACHINE DRIVERS
 ***********************************************************/
 
-static MACHINE_INIT( superchs )
+static MACHINE_RESET( superchs )
 {
 	/* Sound cpu program loads to 0xc00000 so we use a bank */
-	UINT16 *RAM = (UINT16 *)memory_region(REGION_CPU2);
-	memory_set_bankptr(1,&RAM[0x80000]);
+	UINT16 *ROM = (UINT16 *)memory_region(REGION_CPU2);
+	memory_set_bankptr(1,&ROM[0x80000]);
 
-	RAM[0]=RAM[0x80000]; /* Stack and Reset vectors */
-	RAM[1]=RAM[0x80001];
-	RAM[2]=RAM[0x80002];
-	RAM[3]=RAM[0x80003];
+	sound_ram[0]=ROM[0x80000]; /* Stack and Reset vectors */
+	sound_ram[1]=ROM[0x80001];
+	sound_ram[2]=ROM[0x80002];
+	sound_ram[3]=ROM[0x80003];
 
 	f3_68681_reset();
 }
@@ -482,7 +470,7 @@ static MACHINE_DRIVER_START( superchs )
 	MDRV_VBLANK_DURATION(DEFAULT_60HZ_VBLANK_DURATION)
 	MDRV_INTERLEAVE(8)	/* CPU slices - Need to interleave Cpu's 1 & 3 */
 
-	MDRV_MACHINE_INIT(superchs)
+	MDRV_MACHINE_RESET(superchs)
 	MDRV_NVRAM_HANDLER(superchs)
 
 	/* video hardware */
@@ -534,7 +522,7 @@ ROM_START( superchs )
 	ROM_REGION16_LE( 0x80000, REGION_USER1, 0 )
 	ROM_LOAD16_WORD( "d46-07.34", 0x00000, 0x80000, CRC(c3b8b093) SHA1(f34364248ca7fdaaa1a0f8f6f795f9b4bc935fb9) )	/* STY, used to create big sprites on the fly */
 
-	ROM_REGION16_BE( 0x1000000, REGION_SOUND1 , ROMREGION_SOUNDONLY | ROMREGION_ERASE00 )
+	ROM_REGION16_BE( 0x1000000, REGION_SOUND1 , ROMREGION_ERASE00 )
 	ROM_LOAD16_BYTE( "d46-10.2", 0xc00000, 0x200000, CRC(306256be) SHA1(e6e5d4a4c0b98470f2aff2e94624dd19af73ec5d) )
 	ROM_LOAD16_BYTE( "d46-12.4", 0x000000, 0x200000, CRC(a24a53a8) SHA1(5d5fb87a94ceabda89360064d7d9b6d23c4c606b) )
 	ROM_RELOAD     (             0x400000, 0x200000 )
