@@ -178,8 +178,6 @@ cpu #2 (PC=0000060E): unmapped memory word read from 0000683A & FFFF
 ****************************************************************************/
 
 #include "driver.h"
-#include "state.h"
-#include "vidhrdw/generic.h"
 #include "sndhrdw/taitosnd.h"
 #include "vidhrdw/taitoic.h"
 #include "cpu/tms32025/tms32025.h"
@@ -195,6 +193,7 @@ VIDEO_START( taitoair );
 VIDEO_UPDATE( taitoair );
 
 
+
 /***********************************************************
                 MEMORY handlers
 ***********************************************************/
@@ -308,7 +307,7 @@ static READ16_HANDLER( stick2_input_r )
 }
 
 
-static int banknum = -1;
+static INT32 banknum = -1;
 
 static void reset_sound_region(void)
 {
@@ -322,6 +321,16 @@ static WRITE8_HANDLER( sound_bankswitch_w )
 }
 
 
+static MACHINE_START( taitoair )
+{
+	dsp_HOLD_signal = ASSERT_LINE;
+
+	state_save_register_global(banknum);
+	state_save_register_func_postload(reset_sound_region);
+	return 0;
+}
+
+
 /***********************************************************
              MEMORY STRUCTURES
 ***********************************************************/
@@ -592,7 +601,7 @@ INPUT_PORTS_END
                 GFX DECODING
 ************************************************************/
 
-static gfx_layout tilelayout =
+static const gfx_layout tilelayout =
 {
 	16,16,	/* 16x16 pixels */
 	RGN_FRAC(1,4),
@@ -607,7 +616,7 @@ static gfx_layout tilelayout =
 	16*16
 };
 
-static gfx_decode airsys_gfxdecodeinfo[] =
+static const gfx_decode airsys_gfxdecodeinfo[] =
 {
 	{ REGION_GFX1, 0, &tilelayout, 0, 32*16 },
 	{ -1 } /* end of array */
@@ -655,6 +664,8 @@ static MACHINE_DRIVER_START( airsys )
 	MDRV_VBLANK_DURATION(DEFAULT_60HZ_VBLANK_DURATION)
 	MDRV_INTERLEAVE(10)
 
+	MDRV_MACHINE_START(taitoair)
+
 	/* video hardware */
 	MDRV_VIDEO_ATTRIBUTES(VIDEO_TYPE_RASTER)
 	MDRV_SCREEN_SIZE(64*16, 64*16)
@@ -767,16 +778,7 @@ ROM_START( ainferno )
 ROM_END
 
 
-static DRIVER_INIT( taitoair )
-{
-	dsp_HOLD_signal = ASSERT_LINE;
-
-	state_save_register_int("sound1", 0, "sound region", &banknum);
-	state_save_register_func_postload(reset_sound_region);
-}
-
-
 
 /*   ( YEAR  NAME      PARENT    MACHINE   INPUT     INIT      MONITOR  COMPANY  FULLNAME */
-GAME( 1988, topland,  0,        airsys,   topland,  taitoair, ROT0,    "Taito Corporation Japan", "Top Landing (World)", GAME_NOT_WORKING )
-GAME( 1990, ainferno, 0,        airsys,   ainferno, taitoair, ROT0,    "Taito America Corporation", "Air Inferno (US)", GAME_NOT_WORKING )
+GAME( 1988, topland,  0,        airsys,   topland,  0,        ROT0,    "Taito Corporation Japan", "Top Landing (World)", GAME_NOT_WORKING )
+GAME( 1990, ainferno, 0,        airsys,   ainferno, 0,        ROT0,    "Taito America Corporation", "Air Inferno (US)", GAME_NOT_WORKING )
