@@ -4,22 +4,11 @@ Atari Tank 8 driver
 
 ***************************************************************************/
 
+#include <time.h>
 #include "driver.h"
 #include "tank8.h"
-#include "time.h"
 #include "sound/discrete.h"
 
-extern VIDEO_EOF( tank8 );
-extern VIDEO_START( tank8 );
-extern VIDEO_UPDATE( tank8 );
-
-extern WRITE8_HANDLER( tank8_video_ram_w );
-
-extern UINT8* tank8_video_ram;
-extern UINT8* tank8_pos_h_ram;
-extern UINT8* tank8_pos_v_ram;
-extern UINT8* tank8_pos_d_ram;
-
 static int collision_index;
 
 
@@ -80,7 +69,7 @@ static PALETTE_INIT( tank8 )
 }
 
 
-static MACHINE_INIT( tank8 )
+static MACHINE_RESET( tank8 )
 {
 	collision_index = 0;
 }
@@ -332,7 +321,7 @@ INPUT_PORTS_START( tank8 )
 INPUT_PORTS_END
 
 
-static gfx_layout tile_layout_1 =
+static const gfx_layout tile_layout_1 =
 {
 	16, 16,
 	64,
@@ -349,7 +338,7 @@ static gfx_layout tile_layout_1 =
 };
 
 
-static gfx_layout tile_layout_2 =
+static const gfx_layout tile_layout_2 =
 {
 	16, 16,
 	64,
@@ -367,7 +356,7 @@ static gfx_layout tile_layout_2 =
 };
 
 
-static gfx_layout tank_layout =
+static const gfx_layout tank_layout =
 {
 	16, 16,
 	4,
@@ -385,7 +374,7 @@ static gfx_layout tank_layout =
 };
 
 
-static gfx_decode tank8_gfxdecodeinfo[] =
+static const gfx_decode tank8_gfxdecodeinfo[] =
 {
 	{ REGION_GFX1, 0, &tile_layout_1, 0, 10 },
 	{ REGION_GFX1, 0, &tile_layout_2, 0, 10 },
@@ -403,7 +392,7 @@ static MACHINE_DRIVER_START( tank8 )
 
 	MDRV_FRAMES_PER_SECOND(60)
 	MDRV_VBLANK_DURATION(30 * 1000000 / 15681)
-	MDRV_MACHINE_INIT(tank8)
+	MDRV_MACHINE_RESET(tank8)
 
 	/* video hardware */
 	MDRV_VIDEO_ATTRIBUTES(VIDEO_TYPE_RASTER | VIDEO_UPDATE_AFTER_VBLANK)
