@@ -5,7 +5,6 @@ Taxi Driver  (c) 1984 Graphic Techno
 ***************************************************************************/
 
 #include "driver.h"
-#include "vidhrdw/generic.h"
 #include "machine/8255ppi.h"
 #include "taxidrvr.h"
 #include "sound/ay8910.h"
@@ -52,7 +51,7 @@ static WRITE8_HANDLER( p0c_w )
 
 	flip_screen_set(data & 8);
 
-/*  usrintf_showmessage("%02x",data&0x0f); */
+/*  ui_popup("%02x",data&0x0f); */
 }
 
 static READ8_HANDLER( p1b_r )
@@ -105,7 +104,7 @@ static ppi8255_interface ppi8255_intf =
 	{ p0c_w, p1c_w, p2c_w, p3c_w, p4c_w }	/* Port C write */
 };
 
-MACHINE_INIT( taxidrvr )
+MACHINE_RESET( taxidrvr )
 {
 	ppi8255_init(&ppi8255_intf);
 }
@@ -310,7 +309,7 @@ INPUT_PORTS_END
 
 
 
-static struct GfxLayout charlayout =
+static const gfx_layout charlayout =
 {
 	8,8,
 	RGN_FRAC(1,1),
@@ -321,7 +320,7 @@ static struct GfxLayout charlayout =
 	32*8
 };
 
-static struct GfxLayout charlayout2 =
+static const gfx_layout charlayout2 =
 {
 	4,4,
 	RGN_FRAC(1,1),
@@ -333,7 +332,7 @@ static struct GfxLayout charlayout2 =
 };
 
 
-static struct GfxDecodeInfo gfxdecodeinfo[] =
+static const gfx_decode gfxdecodeinfo[] =
 {
 	{ REGION_GFX1, 0, &charlayout, 0, 1 },
 	{ REGION_GFX2, 0, &charlayout, 0, 1 },
@@ -380,7 +379,7 @@ static MACHINE_DRIVER_START( taxidrvr )
 	MDRV_VBLANK_DURATION(DEFAULT_60HZ_VBLANK_DURATION)
 	MDRV_INTERLEAVE(100)	/* 100 CPU slices per frame - an high value to ensure proper */
 							/* synchronization of the CPUs */
-	MDRV_MACHINE_INIT(taxidrvr)
+	MDRV_MACHINE_RESET(taxidrvr)
 
 	/* video hardware */
 	MDRV_VIDEO_ATTRIBUTES(VIDEO_TYPE_RASTER)
@@ -446,4 +445,4 @@ ROM_END
 
 
 
-GAMEX( 1984, taxidrvr, 0, taxidrvr, taxidrvr, 0, ROT90, "Graphic Techno", "Taxi Driver", GAME_IMPERFECT_GRAPHICS | GAME_NO_COCKTAIL )
+GAME( 1984, taxidrvr, 0, taxidrvr, taxidrvr, 0, ROT90, "Graphic Techno", "Taxi Driver", GAME_IMPERFECT_GRAPHICS | GAME_NO_COCKTAIL )
