@@ -7,7 +7,6 @@
  */
 
 #include "driver.h"
-#include "state.h"
 #include "cpu/m6502/m6502.h"
 #include "cpu/m6809/m6809.h"
 #include "cpu/m6800/m6800.h"
@@ -41,9 +40,9 @@ static UINT8 *m6502_a_shared_ram;
 static UINT8 *m6502_b_shared_ram;
 static UINT8 *m68k_shared_ram;
 
-static int m6809_irq_enable;
-static int m68k_irq_enable;
-static int mcu_irq_enable;
+static UINT8 m6809_irq_enable;
+static UINT8 m68k_irq_enable;
+static UINT8 mcu_irq_enable;
 
 
 /*******************************************************************/
@@ -464,7 +463,7 @@ INPUT_PORTS_END
 
 /*******************************************************************/
 
-static gfx_layout tile_layout =
+static const gfx_layout tile_layout =
 {
 	8, 8,
 	512,
@@ -475,7 +474,7 @@ static gfx_layout tile_layout =
 	2*8*8
 };
 
-static gfx_decode gfxdecodeinfo[] =
+static const gfx_decode gfxdecodeinfo[] =
 {
 	{ REGION_GFX1, 0, &tile_layout,     0,  256 },
 
@@ -499,7 +498,18 @@ static struct namco_interface namco_interface =
 
 /*******************************************************************/
 
-static MACHINE_INIT( tceptor )
+static MACHINE_START( tceptor )
+{
+	state_save_register_global(m6809_irq_enable);
+	state_save_register_global(m68k_irq_enable);
+	state_save_register_global(mcu_irq_enable);
+	return 0;
+}
+
+
+/*******************************************************************/
+
+static MACHINE_RESET( tceptor )
 {
 	m6809_irq_enable = 0;
 	m68k_irq_enable = 0;
@@ -538,7 +548,8 @@ static MACHINE_DRIVER_START( tceptor )
 
 	MDRV_NVRAM_HANDLER(generic_1fill)
 
-	MDRV_MACHINE_INIT(tceptor)
+	MDRV_MACHINE_START(tceptor)
+	MDRV_MACHINE_RESET(tceptor)
 
 	/* video hardware */
 	MDRV_VIDEO_ATTRIBUTES(VIDEO_TYPE_RASTER | VIDEO_NEEDS_6BITS_PER_GUN)
@@ -570,16 +581,6 @@ static MACHINE_DRIVER_START( tceptor )
 MACHINE_DRIVER_END
 
 
-/*******************************************************************/
-
-static DRIVER_INIT( tceptor )
-{
-	state_save_register_int("tceptor", 0, "m6809_irq_enable",  &m6809_irq_enable);
-	state_save_register_int("tceptor", 0, "m68k_irq_enable",   &m68k_irq_enable);
-	state_save_register_int("tceptor", 0, "mcu_irq_enable",    &mcu_irq_enable);
-}
-
-
 /***************************************************************************
 
   Game driver(s)
@@ -695,5 +696,5 @@ ROM_END
 
 
 /*  ( YEAR  NAME      PARENT    MACHINE   INPUT     INIT      MONITOR   COMPANY FULLNAME ) */
-GAME( 1986, tceptor,  0,        tceptor,  tceptor,  tceptor,  ROT0,     "Namco",  "Thunder Ceptor", 0)
-GAME( 1986, tceptor2, tceptor,  tceptor,  tceptor2, tceptor,  ROT0,     "Namco",  "Thunder Ceptor II", 0)
+GAME( 1986, tceptor,  0,        tceptor,  tceptor,  0,        ROT0,     "Namco",  "Thunder Ceptor", 0)
+GAME( 1986, tceptor2, tceptor,  tceptor,  tceptor2, 0,        ROT0,     "Namco",  "Thunder Ceptor II", 0)
