@@ -37,7 +37,6 @@ Notes:
 */
 
 #include "driver.h"
-#include "vidhrdw/generic.h"
 #include "machine/8255ppi.h"
 #include "sound/ay8910.h"
 
@@ -59,7 +58,7 @@ INPUT_PORTS_START( tcl )
 	PORT_START
 INPUT_PORTS_END
 
-static struct GfxLayout charlayout =
+static const gfx_layout charlayout =
 {
 	8,8,
 	RGN_FRAC(1,3),
@@ -70,7 +69,7 @@ static struct GfxLayout charlayout =
 	8*8
 };
 
-static struct GfxLayout charlayout2 =
+static const gfx_layout charlayout2 =
 {
 	8,8,
 	RGN_FRAC(1,4),
@@ -82,7 +81,7 @@ static struct GfxLayout charlayout2 =
 };
 
 
-static struct GfxDecodeInfo gfxdecodeinfo[] =
+static const gfx_decode gfxdecodeinfo[] =
 {
 	{ REGION_GFX1, 0, &charlayout,     0, 16 },
 	{ REGION_GFX2, 0, &charlayout2,     0, 16 }, /* wrong */
@@ -100,7 +99,7 @@ static ppi8255_interface ppi8255_intf =
 	{ NULL, NULL },
 };
 
-MACHINE_INIT( tcl )
+MACHINE_RESET( tcl )
 {
 	ppi8255_init(&ppi8255_intf);
 }
@@ -125,7 +124,7 @@ static MACHINE_DRIVER_START( tcl )
 	MDRV_VIDEO_START(tcl)
 	MDRV_VIDEO_UPDATE(tcl)
 
-	MDRV_MACHINE_INIT(tcl)
+	MDRV_MACHINE_RESET(tcl)
 
 	/* sound hardware */
 	MDRV_SPEAKER_STANDARD_MONO("mono")
@@ -141,7 +140,8 @@ MACHINE_DRIVER_END
 ***************************************************************************/
 
 ROM_START( tcl )
-	ROM_REGION( 0x10000*4, REGION_CPU1, 0 )
+	ROM_REGION( 0x10000*2, REGION_CPU1, 0 )
+	ROM_LOAD( "tcl.16f",   0x00000, 0x20000, CRC(8e694a58) SHA1(7a3c20a7c740065b71fe66ec581edce0dd32f145) )
 
 	ROM_REGION( 0x8000*3, REGION_GFX1, ROMREGION_DISPOSE )
 	ROM_LOAD( "tcl.1e",   0x00000, 0x8000, CRC(37edf9b8) SHA1(9225728116d6edfe8476e565a12e1f1e59766d26) )
@@ -158,10 +158,6 @@ ROM_START( tcl )
 	ROM_LOAD( "tcl_pr1.15c",   0x000, 0x100, CRC(21eb5b19) SHA1(9b8425bdb97f11f4855c998c7792c3291fd07470) )
 	ROM_LOAD( "tcl_pr2.16c",   0x100, 0x100, CRC(0489b760) SHA1(78f8632b17a76335183c5c204cdec856988368b0) )
 	ROM_LOAD( "tcl_pr3.9e",    0x200, 0x100, CRC(50ec383b) SHA1(ae95b92bd3946b40134bcdc22708d5c6b0f4c23e) )
-
-	ROM_REGION( 0x20000, REGION_USER1, 0 ) /* encrypted  program ROM */
-	ROM_LOAD( "tcl.16f",   0x00000, 0x20000, CRC(8e694a58) SHA1(7a3c20a7c740065b71fe66ec581edce0dd32f145) )
-
 ROM_END
 
 #define ROL(x,n) (BITSWAP8((x),(7+8-n)&7,(6+8-n)&7,(5+8-n)&7,(4+8-n)&7,(3+8-n)&7,(2+8-n)&7,(1+8-n)&7,(0+8-n)&7))
@@ -175,10 +171,11 @@ DRIVER_INIT(tcl)
 {
 	/* only the first part is decrypted (and verified)*/
 
-	unsigned char *dest = memory_region(REGION_CPU1);
-	unsigned char *src = memory_region(REGION_USER1);
+	UINT8 *dest = memory_region(REGION_CPU1);
+	UINT8 *src = malloc_or_die(memory_region_length(REGION_CPU1));
 
 	int i,idx=0;
+	memcpy(src, dest, memory_region_length(REGION_CPU1));
 	for(i=0;i<64*1024;i+=4)
 	{
 		if(i&0x8000)
@@ -196,8 +193,9 @@ DRIVER_INIT(tcl)
 			WRITEDEST((src[idx]^0x11)^0xf0); /* abcdefgh -> ABCdefgH */
 		}
 	}
+	free(src);
 
-	memory_set_opcode_base(0,dest+0x10000);
+	memory_set_decrypted_region(0, 0x0000, 0x7fff, dest+0x10000);
 }
 
-GAMEX( 1995, tcl,  0,       tcl,  tcl,  tcl, ROT0, "Uniwang", "Taiwan Chess Legend", GAME_NOT_WORKING )
+GAME( 1995, tcl,  0,       tcl,  tcl,  tcl, ROT0, "Uniwang", "Taiwan Chess Legend", GAME_NOT_WORKING )
