@@ -25,7 +25,6 @@ Notes:
 ***************************************************************************/
 
 #include "driver.h"
-#include "vidhrdw/generic.h"
 #include "thedeep.h"
 #include "sound/2203intf.h"
 
@@ -52,7 +51,7 @@ static UINT8 protection_command, protection_data;
 static int protection_index, protection_irq;
 static int rombank;
 
-static MACHINE_INIT( thedeep )
+static MACHINE_RESET( thedeep )
 {
 	memory_set_bankptr(1, memory_region(REGION_CPU1) + 0x10000 + 0 * 0x4000);
 	thedeep_scroll[0] = 0;
@@ -285,7 +284,7 @@ INPUT_PORTS_END
 
 ***************************************************************************/
 
-static gfx_layout layout_8x8x2 =
+static const gfx_layout layout_8x8x2 =
 {
 	8,8,
 	RGN_FRAC(1,2),
@@ -296,7 +295,7 @@ static gfx_layout layout_8x8x2 =
 	8*8
 };
 
-static gfx_layout layout_16x16x4 =
+static const gfx_layout layout_16x16x4 =
 {
 	16,16,
 	RGN_FRAC(1,4),
@@ -307,7 +306,7 @@ static gfx_layout layout_16x16x4 =
 	16*16
 };
 
-static gfx_decode thedeep_gfxdecodeinfo[] =
+static const gfx_decode thedeep_gfxdecodeinfo[] =
 {
 	{ REGION_GFX1, 0, &layout_16x16x4,	0x080,  8 }, /* [0] Sprites */
 	{ REGION_GFX2, 0, &layout_16x16x4,	0x100, 16 }, /* [1] Background Layer */
@@ -378,7 +377,7 @@ static MACHINE_DRIVER_START( thedeep )
 	MDRV_FRAMES_PER_SECOND(60)
 	MDRV_VBLANK_DURATION(DEFAULT_60HZ_VBLANK_DURATION)
 
-	MDRV_MACHINE_INIT(thedeep)
+	MDRV_MACHINE_RESET(thedeep)
 
 	/* video hardware */
 	MDRV_VIDEO_ATTRIBUTES(VIDEO_TYPE_RASTER)
