@@ -9,23 +9,20 @@ K052591 emulation by Eddie Edwards
 ***************************************************************************/
 
 #include "driver.h"
-#include "vidhrdw/generic.h"
 #include "cpu/konami/konami.h" /* for the callback and the firq irq definition */
 #include "vidhrdw/konamiic.h"
-#include "mamedbg.h"
 #include "sound/2151intf.h"
 #include "sound/k007232.h"
 
-static MACHINE_INIT( scontra );
-static MACHINE_INIT( thunderx );
+static MACHINE_RESET( scontra );
+static MACHINE_RESET( thunderx );
 static void thunderx_banking(int lines);
 
 extern int scontra_priority;
 VIDEO_START( scontra );
 VIDEO_UPDATE( scontra );
 
-static int unknown_enable = 0;
-extern int debug_key_pressed;
+static UINT8 thunderx_1f98_data = 0;
 
 /***************************************************************************/
 
@@ -56,7 +53,7 @@ static READ8_HANDLER( scontra_bankedram_r )
 static WRITE8_HANDLER( scontra_bankedram_w )
 {
 	if (palette_selected)
-		paletteram_xBBBBBGGGGGRRRRR_swap_w(offset,data);
+		paletteram_xBBBBBGGGGGRRRRR_be_w(offset,data);
 	else
 		ram[offset] = data;
 }
@@ -98,7 +95,7 @@ static WRITE8_HANDLER( thunderx_bankedram_w )
 			logerror("%04x pmc internal ram %04x = %02x\n",activecpu_get_pc(),offset,data);
 	}
 	else
-		paletteram_xBBBBBGGGGGRRRRR_swap_w(offset,data);
+		paletteram_xBBBBBGGGGGRRRRR_be_w(offset,data);
 }
 
 /*
@@ -290,6 +287,11 @@ static void calculate_collisions( void )
 	run_collisions(X0,Y0,X1,Y1,CM,HM);
 }
 
+static READ8_HANDLER( thunderx_1f98_r )
+{
+	return thunderx_1f98_data;
+}
+
 static WRITE8_HANDLER( thunderx_1f98_w )
 {
 /* logerror("%04x: 1f98_w %02x\n",activecpu_get_pc(),data); */
@@ -301,7 +303,7 @@ static WRITE8_HANDLER( thunderx_1f98_w )
 	pmcbank = (data & 0x02) >> 1;
 
 	/* bit 2 = do collision detection when 0->1 */
-	if ((data & 4) && !(unknown_enable & 4))
+	if ((data & 4) && !(thunderx_1f98_data & 4))
 	{
 		calculate_collisions();
 
@@ -309,7 +311,7 @@ static WRITE8_HANDLER( thunderx_1f98_w )
 		timer_set(TIME_IN_CYCLES(100,0),0, thunderx_firq_callback);
 	}
 
-	unknown_enable = data;
+	thunderx_1f98_data = data;
 }
 
 WRITE8_HANDLER( scontra_bankswitch_w )
@@ -321,7 +323,7 @@ WRITE8_HANDLER( scontra_bankswitch_w )
 
 	/* bits 0-3 ROM bank */
 	offs = 0x10000 + (data & 0x0f)*0x2000;
-	cpu_setbank( 1, &RAM[offs] );
+	memory_set_bankptr( 1, &RAM[offs] );
 
 	/* bit 4 select work RAM or palette RAM at 5800-5fff */
 	palette_selected = ~data & 0x10;
@@ -389,6 +391,7 @@ static ADDRESS_MAP_START( thunderx_readmem, ADDRESS_SPACE_PROGRAM, 8 )
 	AM_RANGE(0x1f93, 0x1f93) AM_READ(input_port_5_r) /* Dip 3 */
 	AM_RANGE(0x1f94, 0x1f94) AM_READ(input_port_3_r) /* Dip 1 */
 	AM_RANGE(0x1f95, 0x1f95) AM_READ(input_port_4_r) /* Dip 2 */
+	AM_RANGE(0x1f98, 0x1f98) AM_READ(thunderx_1f98_r) /* registers */
 
 	AM_RANGE(0x0000, 0x3fff) AM_READ(K052109_051960_r)
 	AM_RANGE(0x4000, 0x57ff) AM_READ(MRA8_RAM)
@@ -704,7 +707,7 @@ static MACHINE_DRIVER_START( scontra )
 	MDRV_FRAMES_PER_SECOND(60)
 	MDRV_VBLANK_DURATION(DEFAULT_60HZ_VBLANK_DURATION)
 
-	MDRV_MACHINE_INIT(scontra)
+	MDRV_MACHINE_RESET(scontra)
 
 	/* video hardware */
 	MDRV_VIDEO_ATTRIBUTES(VIDEO_TYPE_RASTER | VIDEO_HAS_SHADOWS)
@@ -743,7 +746,7 @@ static MACHINE_DRIVER_START( thunderx )
 	MDRV_FRAMES_PER_SECOND(60)
 	MDRV_VBLANK_DURATION(DEFAULT_60HZ_VBLANK_DURATION)
 
-	MDRV_MACHINE_INIT(thunderx)
+	MDRV_MACHINE_RESET(thunderx)
 
 	/* video hardware */
 	MDRV_VIDEO_ATTRIBUTES(VIDEO_TYPE_RASTER | VIDEO_HAS_SHADOWS)
@@ -945,6 +948,39 @@ ROM_START( thnderxa ) /* Alternate Starting stage then the other 2 sets, Perhaps
 	ROM_LOAD( "873a08.f20",   0x0000, 0x0100, CRC(e2d09a1b) SHA1(a9651e137486b2df367c39eb43f52d0833589e87) )	/* priority encoder (not used) */
 ROM_END
 
+ROM_START( thnderxb ) /* Set had no labels, same starting stage as parent set */
+	ROM_REGION( 0x29000, REGION_CPU1, 0 )	/* ROMs + banked RAM */
+	ROM_LOAD( "873-03.k15", 0x10000, 0x10000, CRC(36680a4e) SHA1(9b3b6bf75a9c04e764448cd958277bd081cc4a53) )
+	ROM_LOAD( "873-02.k13", 0x20000, 0x08000, CRC(c58b2c34) SHA1(4050d2edc579ffedba3d40782a08e43ac89b1b86) )
+	ROM_CONTINUE(           0x08000, 0x08000 )
+
+	ROM_REGION( 0x10000, REGION_CPU2, 0 )	/* 64k for the audio CPU */
+	ROM_LOAD( "873-f01.f8",   0x0000, 0x8000, CRC(ea35ffa3) SHA1(91e82b77d4f3af8238fb198db26182bebc5026e4) )
+
+	ROM_REGION( 0x80000, REGION_GFX1, 0 )	/* temporary space for graphics (disposed after conversion) */
+	ROM_LOAD16_BYTE( "873c06a.f6",   0x00000, 0x10000, CRC(0e340b67) SHA1(a76b1ee4bd4c99826a02b63a705447d0ba4e7b01) ) /* Chars */
+	ROM_LOAD16_BYTE( "873c06c.f5",   0x00001, 0x10000, CRC(ef0e72cd) SHA1(85b77a303378386f2d395da8707f4b638d37833e) )
+	ROM_LOAD16_BYTE( "873c06b.e6",   0x20000, 0x10000, CRC(97ad202e) SHA1(fd155aeb691814950711ead3bc2c93c67b7b0434) )
+	ROM_LOAD16_BYTE( "873c06d.e5",   0x20001, 0x10000, CRC(8393d42e) SHA1(ffcb5eca3f58994e05c49d803fa4831c0213e2e2) )
+	ROM_LOAD16_BYTE( "873c07a.f4",   0x40000, 0x10000, CRC(a8aab84f) SHA1(a68521a9abf45c3292b3090a2483edbf31356c7d) )
+	ROM_LOAD16_BYTE( "873c07c.f3",   0x40001, 0x10000, CRC(2521009a) SHA1(6546b88943615389c81b753ff5bb6aa9378c3266) )
+	ROM_LOAD16_BYTE( "873c07b.e4",   0x60000, 0x10000, CRC(12a2b8ba) SHA1(ffa32ca116e0b6ca65bb9ce83dd28f5c027956a5) )
+	ROM_LOAD16_BYTE( "873c07d.e3",   0x60001, 0x10000, CRC(fae9f965) SHA1(780c234507835c37bde445ab34f069714cc7a506) )
+
+	ROM_REGION( 0x80000, REGION_GFX2, 0 )
+	ROM_LOAD16_BYTE( "873c04a.f11",  0x00000, 0x10000, CRC(f7740bf3) SHA1(f64b7e807f19a9523a517024a9eb56736cdda6bb) ) /* Sprites */
+	ROM_LOAD16_BYTE( "873c04c.f10",  0x00001, 0x10000, CRC(5dacbd2b) SHA1(deb943b99fd296d20be9c4250b2348549f65ba37) )
+	ROM_LOAD16_BYTE( "873c04b.e11",  0x20000, 0x10000, CRC(9ac581da) SHA1(fd0a603de8586621444055bbff8bb83349b8a0d8) )
+	ROM_LOAD16_BYTE( "873c04d.e10",  0x20001, 0x10000, CRC(44a4668c) SHA1(6d1526ed3408ddc763a071604e7b1e0773c87b99) )
+	ROM_LOAD16_BYTE( "873c05a.f9",   0x40000, 0x10000, CRC(d73e107d) SHA1(ba63b195e20a98c476e7d0f8d0187bc3327a8822) )
+	ROM_LOAD16_BYTE( "873c05c.f8",   0x40001, 0x10000, CRC(59903200) SHA1(d076802c53aa604df8c5fdd33cb41876ba2a3385) )
+	ROM_LOAD16_BYTE( "873c05b.e9",   0x60000, 0x10000, CRC(81059b99) SHA1(1e1a22ca45599abe0dce32fc0b188281deb3b8ac) )
+	ROM_LOAD16_BYTE( "873c05d.e8",   0x60001, 0x10000, CRC(7fa3d7df) SHA1(c78b9a949abdf44366d872daa1f2041158fae790) )
+
+	ROM_REGION( 0x0100, REGION_PROMS, 0 )
+	ROM_LOAD( "873a08.f20",   0x0000, 0x0100, CRC(e2d09a1b) SHA1(a9651e137486b2df367c39eb43f52d0833589e87) )	/* priority encoder (not used) */
+ROM_END
+
 ROM_START( thnderxj )
 	ROM_REGION( 0x29000, REGION_CPU1, 0 )	/* ROMs + banked RAM */
 	ROM_LOAD( "873-n03.k15", 0x10000, 0x10000, CRC(a01e2e3e) SHA1(eba0d95dc0c5eed18743a96e4bbda5e60d5d9c97) )
@@ -989,22 +1025,22 @@ static void thunderx_banking( int lines )
 
 	offs = 0x10000 + (((lines & 0x0f) ^ 0x08) * 0x2000);
 	if (offs >= 0x28000) offs -= 0x20000;
-	cpu_setbank( 1, &RAM[offs] );
+	memory_set_bankptr( 1, &RAM[offs] );
 }
 
-static MACHINE_INIT( scontra )
+static MACHINE_RESET( scontra )
 {
 	unsigned char *RAM = memory_region(REGION_CPU1);
 
 	paletteram = &RAM[0x30000];
 }
 
-static MACHINE_INIT( thunderx )
+static MACHINE_RESET( thunderx )
 {
 	unsigned char *RAM = memory_region(REGION_CPU1);
 
 	cpunum_set_info_fct(0, CPUINFO_PTR_KONAMI_SETLINES_CALLBACK, (genf *)thunderx_banking);
-	cpu_setbank( 1, &RAM[0x10000] ); /* init the default bank */
+	memory_set_bankptr( 1, &RAM[0x10000] ); /* init the default bank */
 
 	paletteram = &RAM[0x28000];
 	pmcram = &RAM[0x28800];
@@ -1018,8 +1054,9 @@ static DRIVER_INIT( scontra )
 
 
 
-GAME( 1988, scontra,  0,        scontra,  scontra,  scontra, ROT90, "Konami", "Super Contra" )
-GAME( 1988, scontraj, scontra,  scontra,  scontra,  scontra, ROT90, "Konami", "Super Contra (Japan)" )
-GAME( 1988, thunderx, 0,        thunderx, thunderx, scontra, ROT0, "Konami", "Thunder Cross" )
-GAME( 1988, thnderxa, thunderx, thunderx, thunderx, scontra, ROT0, "Konami", "Thunder Cross (Set 2)" )
-GAME( 1988, thnderxj, thunderx, thunderx, thunderx, scontra, ROT0, "Konami", "Thunder Cross (Japan)" )
+GAME( 1988, scontra,  0,        scontra,  scontra,  scontra, ROT90, "Konami", "Super Contra", 0 )
+GAME( 1988, scontraj, scontra,  scontra,  scontra,  scontra, ROT90, "Konami", "Super Contra (Japan)", 0 )
+GAME( 1988, thunderx, 0,        thunderx, thunderx, scontra, ROT0,  "Konami", "Thunder Cross", 0 )
+GAME( 1988, thnderxa, thunderx, thunderx, thunderx, scontra, ROT0,  "Konami", "Thunder Cross (Set 2)", 0 )
+GAME( 1988, thnderxb, thunderx, thunderx, thunderx, scontra, ROT0,  "Konami", "Thunder Cross (Set 3)", 0 )
+GAME( 1988, thnderxj, thunderx, thunderx, thunderx, scontra, ROT0,  "Konami", "Thunder Cross (Japan)", 0 )
