@@ -20,7 +20,6 @@ Memory Overview:
 ***************************************************************************/
 
 #include "driver.h"
-#include "vidhrdw/generic.h"
 #include "cpu/z80/z80.h"
 #include "sound/2203intf.h"
 #include "sound/msm5205.h"
@@ -473,7 +472,7 @@ INPUT_PORTS_END
 
 
 
-static gfx_layout text_layout =
+static const gfx_layout text_layout =
 {
 	8,8,
 	RGN_FRAC(1,1),
@@ -484,7 +483,7 @@ static gfx_layout text_layout =
 	16*8
 };
 
-static gfx_layout tile_layout =
+static const gfx_layout tile_layout =
 {
 	32,32,
 	RGN_FRAC(1,2),
@@ -505,7 +504,7 @@ static gfx_layout tile_layout =
 	256*8
 };
 
-static gfx_layout sprite_layout =
+static const gfx_layout sprite_layout =
 {
 	16,16,
 	RGN_FRAC(1,4),
@@ -518,7 +517,7 @@ static gfx_layout sprite_layout =
 	32*8
 };
 
-static gfx_decode gfxdecodeinfo[] =
+static const gfx_decode gfxdecodeinfo[] =
 {
 	{ REGION_GFX1, 0, &text_layout,   512, 16 },   /* colors 512-575 */
 	{ REGION_GFX2, 0, &tile_layout,     0, 16 },   /* colors   0-255 */
