@@ -19,7 +19,6 @@ for now. Even at 12 this slowdown still happens a little.
 ***************************************************************************/
 
 #include "driver.h"
-#include "vidhrdw/generic.h"
 #include "cpu/z80/z80.h"
 #include "sndhrdw/seibu.h"
 #include "sound/3812intf.h"
@@ -342,7 +341,7 @@ INPUT_PORTS_END
 
 /*****************************************************************************/
 
-static gfx_layout toki_charlayout =
+static const gfx_layout toki_charlayout =
 {
 	8,8,
 	4096,
@@ -353,7 +352,7 @@ static gfx_layout toki_charlayout =
 	16*8
 };
 
-static gfx_layout toki_tilelayout =
+static const gfx_layout toki_tilelayout =
 {
 	16,16,
 	4096,
@@ -366,7 +365,7 @@ static gfx_layout toki_tilelayout =
 	128*8
 };
 
-static gfx_layout toki_spritelayout =
+static const gfx_layout toki_spritelayout =
 {
 	16,16,
 	8192,
@@ -379,7 +378,7 @@ static gfx_layout toki_spritelayout =
 	128*8
 };
 
-static gfx_decode toki_gfxdecodeinfo[] =
+static const gfx_decode toki_gfxdecodeinfo[] =
 {
 	{ REGION_GFX1, 0, &toki_charlayout,  16*16, 16 },
 	{ REGION_GFX2, 0, &toki_spritelayout, 0*16, 16 },
@@ -388,7 +387,7 @@ static gfx_decode toki_gfxdecodeinfo[] =
 	{ -1 } /* end of array */
 };
 
-static gfx_layout tokib_charlayout =
+static const gfx_layout tokib_charlayout =
 {
 	8,8,	/* 8 by 8 */
 	4096,	/* 4096 characters */
@@ -399,7 +398,7 @@ static gfx_layout tokib_charlayout =
 	8*8
 };
 
-static gfx_layout tokib_tilelayout =
+static const gfx_layout tokib_tilelayout =
 {
 	16,16,	/* 16 by 16 */
 	4096,	/* 4096 characters */
@@ -415,7 +414,7 @@ static gfx_layout tokib_tilelayout =
 	8*8
 };
 
-static gfx_layout tokib_spriteslayout =
+static const gfx_layout tokib_spriteslayout =
 {
 	16,16,	/* 16 by 16 */
 	8192,	/* 8192 sprites */
@@ -427,7 +426,7 @@ static gfx_layout tokib_spriteslayout =
 	16*16
 };
 
-static gfx_decode tokib_gfxdecodeinfo[] =
+static const gfx_decode tokib_gfxdecodeinfo[] =
 {
 	{ REGION_GFX1, 0, &tokib_charlayout,	16*16, 16 },
 	{ REGION_GFX2, 0, &tokib_spriteslayout,  0*16, 16 },
@@ -461,7 +460,7 @@ static MACHINE_DRIVER_START( toki ) /* KOYO 20.000MHz near the cpu */
 
 	MDRV_FRAMES_PER_SECOND(60)
 	MDRV_VBLANK_DURATION(DEFAULT_60HZ_VBLANK_DURATION)
-	MDRV_MACHINE_INIT(seibu_sound_1)
+	MDRV_MACHINE_RESET(seibu_sound_1)
 
 	/* video hardware */
 	MDRV_VIDEO_ATTRIBUTES(VIDEO_TYPE_RASTER | VIDEO_BUFFERS_SPRITERAM)
@@ -530,7 +529,7 @@ ROM_START( tokij )
 	ROM_LOAD16_BYTE( "tokijp.005",   0x40000, 0x10000, CRC(d6a82808) SHA1(9fcd3e97f7eaada5374347383dc8a6cea2378f7f) )
 	ROM_LOAD16_BYTE( "tokijp.003",   0x40001, 0x10000, CRC(a01a5b10) SHA1(76d6da114105402aab9dd5167c0c00a0bddc3bba) )
 
-	ROM_REGION( 0x20000*2, REGION_CPU2, 0 )	/* Z80 code, banked data */
+	ROM_REGION( 0x20000, REGION_CPU2, 0 )	/* Z80 code, banked data */
 	ROM_LOAD( "tokijp.008",   0x00000, 0x02000, CRC(6c87c4c5) SHA1(d76822bcde3d42afae72a0945b6acbf3c6a1d955) )	/* encrypted */
 	ROM_LOAD( "tokijp.007",   0x10000, 0x10000, CRC(a67969c4) SHA1(99781fbb005b6ba4a19a9cc83c8b257a3b425fa6) )	/* banked stuff */
 
@@ -559,7 +558,7 @@ ROM_START( tokia )
 	ROM_LOAD16_BYTE( "tokijp.005",   0x40000, 0x10000, CRC(d6a82808) SHA1(9fcd3e97f7eaada5374347383dc8a6cea2378f7f) )
 	ROM_LOAD16_BYTE( "tokijp.003",   0x40001, 0x10000, CRC(a01a5b10) SHA1(76d6da114105402aab9dd5167c0c00a0bddc3bba) )
 
-	ROM_REGION( 0x20000*2, REGION_CPU2, 0 )	/* Z80 code, banked data */
+	ROM_REGION( 0x20000, REGION_CPU2, 0 )	/* Z80 code, banked data */
 	ROM_LOAD( "tokijp.008",   0x00000, 0x02000, CRC(6c87c4c5) SHA1(d76822bcde3d42afae72a0945b6acbf3c6a1d955) )	/* encrypted */
 	ROM_LOAD( "tokijp.007",   0x10000, 0x10000, CRC(a67969c4) SHA1(99781fbb005b6ba4a19a9cc83c8b257a3b425fa6) )	/* banked stuff */
 
@@ -588,7 +587,7 @@ ROM_START( toki )
 	ROM_LOAD16_BYTE( "tokijp.005",   0x40000, 0x10000, CRC(d6a82808) SHA1(9fcd3e97f7eaada5374347383dc8a6cea2378f7f) )
 	ROM_LOAD16_BYTE( "tokijp.003",   0x40001, 0x10000, CRC(a01a5b10) SHA1(76d6da114105402aab9dd5167c0c00a0bddc3bba) )
 
-	ROM_REGION( 0x20000*2, REGION_CPU2, 0 )	/* Z80 code, banked data */
+	ROM_REGION( 0x20000, REGION_CPU2, 0 )	/* Z80 code, banked data */
 	ROM_LOAD( "tokijp.008",   0x00000, 0x02000, CRC(6c87c4c5) SHA1(d76822bcde3d42afae72a0945b6acbf3c6a1d955) )	/* encrypted */
 	ROM_LOAD( "tokijp.007",   0x10000, 0x10000, CRC(a67969c4) SHA1(99781fbb005b6ba4a19a9cc83c8b257a3b425fa6) )	/* banked stuff */
 
@@ -617,7 +616,7 @@ ROM_START( tokiu )
 	ROM_LOAD16_BYTE( "tokijp.005",   0x40000, 0x10000, CRC(d6a82808) SHA1(9fcd3e97f7eaada5374347383dc8a6cea2378f7f) )
 	ROM_LOAD16_BYTE( "tokijp.003",   0x40001, 0x10000, CRC(a01a5b10) SHA1(76d6da114105402aab9dd5167c0c00a0bddc3bba) )
 
-	ROM_REGION( 0x20000*2, REGION_CPU2, 0 )	/* Z80 code, banked data */
+	ROM_REGION( 0x20000, REGION_CPU2, 0 )	/* Z80 code, banked data */
 	ROM_LOAD( "tokijp.008",   0x00000, 0x02000, CRC(6c87c4c5) SHA1(d76822bcde3d42afae72a0945b6acbf3c6a1d955) )	/* encrypted */
 	ROM_LOAD( "tokijp.007",   0x10000, 0x10000, CRC(a67969c4) SHA1(99781fbb005b6ba4a19a9cc83c8b257a3b425fa6) )	/* banked stuff */
 
