@@ -192,9 +192,7 @@ Maybe the second area for each layer contains colscroll ?
 ***************************************************************************/
 
 #include "driver.h"
-#include "state.h"
 #include "cpu/m68000/m68000.h"
-#include "vidhrdw/generic.h"
 #include "vidhrdw/taitoic.h"
 #include "sndhrdw/taitosnd.h"
 #include "sound/2151intf.h"
@@ -207,7 +205,7 @@ VIDEO_START( topspeed );
 VIDEO_UPDATE( topspeed );
 
 static UINT16 cpua_ctrl = 0xff;
-static int ioc220_port = 0;
+static INT32 ioc220_port = 0;
 
 extern UINT16 *topspeed_spritemap;
 
@@ -360,7 +358,7 @@ logerror("CPU #0 PC %06x: warning - write %04x to motor cpu %03x\n",activecpu_ge
                         SOUND
 *****************************************************/
 
-static int banknum = -1;
+static INT32 banknum = -1;
 
 static void reset_sound_region(void)
 {
@@ -761,7 +759,7 @@ INPUT_PORTS_END
                         GFX DECODING
 **************************************************************/
 
-static gfx_layout tile16x8_layout =
+static const gfx_layout tile16x8_layout =
 {
 	16,8,	/* 16*8 sprites */
 	RGN_FRAC(1,1),
@@ -772,7 +770,7 @@ static gfx_layout tile16x8_layout =
 	64*8	/* every sprite takes 64 consecutive bytes */
 };
 
-static gfx_layout charlayout =
+static const gfx_layout charlayout =
 {
 	8,8,	/* 8*8 characters */
 	RGN_FRAC(1,1),
@@ -783,7 +781,7 @@ static gfx_layout charlayout =
 	32*8	/* every sprite takes 32 consecutive bytes */
 };
 
-static gfx_decode topspeed_gfxdecodeinfo[] =
+static const gfx_decode topspeed_gfxdecodeinfo[] =
 {
 	{ REGION_GFX2, 0x0, &tile16x8_layout,  0, 256 },	/* sprite parts */
 	{ REGION_GFX1, 0x0, &charlayout,  0, 256 },		/* sprites & playfield */
@@ -820,6 +818,18 @@ static struct MSM5205interface msm5205_interface =
                      MACHINE DRIVERS
 ***********************************************************/
 
+static MACHINE_START( topspeed )
+{
+	state_save_register_global(cpua_ctrl);
+	state_save_register_func_postload(parse_control);
+
+	state_save_register_global(ioc220_port);
+
+	state_save_register_global(banknum);
+	state_save_register_func_postload(reset_sound_region);
+	return 0;
+}
+
 static MACHINE_DRIVER_START( topspeed )
 
 	/* basic machine hardware */
@@ -835,6 +845,8 @@ static MACHINE_DRIVER_START( topspeed )
 	MDRV_CPU_PROGRAM_MAP(topspeed_cpub_readmem,topspeed_cpub_writemem)
 	MDRV_CPU_VBLANK_INT(topspeed_cpub_interrupt,1)
 
+	MDRV_MACHINE_START(topspeed)
+
 	MDRV_FRAMES_PER_SECOND(60)
 	MDRV_VBLANK_DURATION(DEFAULT_60HZ_VBLANK_DURATION)
 
@@ -999,16 +1011,8 @@ DRIVER_INIT( topspeed )
 /*  taitosnd_setz80_soundcpu( 2 ); */
 
 	cpua_ctrl = 0xff;
-	state_save_register_UINT16("main1", 0, "control", &cpua_ctrl, 1);
-	state_save_register_func_postload(parse_control);
-
-	state_save_register_int   ("main2", 0, "register", &ioc220_port);
-
-	state_save_register_int   ("sound1", 0, "sound region", &banknum);
-	state_save_register_func_postload(reset_sound_region);
 }
 
-
 GAME( 1987, topspeed, 0,        topspeed, topspeed, topspeed, ROT0, "Taito Corporation Japan", "Top Speed (World)", 0 )
 GAME( 1987, topspedu, topspeed, topspeed, topspedu, topspeed, ROT0, "Taito America Corporation (Romstar license)", "Top Speed (US)", 0 )
 GAME( 1987, fullthrl, topspeed, topspeed, fullthrl, topspeed, ROT0, "Taito Corporation", "Full Throttle (Japan)", 0 )
