@@ -30,7 +30,6 @@ TODO:
 ****************************************/
 
 #include "driver.h"
-#include "vidhrdw/generic.h"
 #include "machine/namcoio.h"
 #include "sound/namco.h"
 
@@ -211,7 +210,7 @@ WRITE8_HANDLER( toypop_m68000_assert_w )
 	cpunum_set_input_line(2, INPUT_LINE_RESET, ASSERT_LINE);
 }
 
-MACHINE_INIT( toypop )
+static void disable_interrupts(int param)
 {
 	cpu_interrupt_enable(0,0);
 	cpunum_set_input_line(0, 0, CLEAR_LINE);
@@ -220,6 +219,13 @@ MACHINE_INIT( toypop )
 	interrupt_enable_68k = 0;
 }
 
+MACHINE_RESET( toypop )
+{
+	/* we must do this on a timer in order to have it take effect */
+	/* otherwise, the reset process will override our changes */
+	timer_set(TIME_NOW, 0, disable_interrupts);
+}
+
 INTERRUPT_GEN( toypop_m68000_interrupt )
 {
 	if (interrupt_enable_68k)
@@ -520,7 +526,7 @@ INPUT_PORTS_END
 
 
 
-static gfx_layout charlayout =
+static const gfx_layout charlayout =
 {
 	8,8,
 	RGN_FRAC(1,1),
@@ -531,7 +537,7 @@ static gfx_layout charlayout =
 	16*8
 };
 
-static gfx_layout spritelayout =
+static const gfx_layout spritelayout =
 {
 	16,16,
 	RGN_FRAC(1,1),
@@ -544,7 +550,7 @@ static gfx_layout spritelayout =
 	64*8
 };
 
-static gfx_decode gfxdecodeinfo[] =
+static const gfx_decode gfxdecodeinfo[] =
 {
 	{ REGION_GFX1, 0, &charlayout,       0, 128 },
 	{ REGION_GFX2, 0, &spritelayout, 128*4,  64 },
@@ -581,7 +587,7 @@ static MACHINE_DRIVER_START( liblrabl )
 	MDRV_VBLANK_DURATION(DEFAULT_60HZ_VBLANK_DURATION)
 	MDRV_INTERLEAVE(100)    /* 100 CPU slices per frame - an high value to ensure proper */
 							/* synchronization of the CPUs */
-	MDRV_MACHINE_INIT(toypop)
+	MDRV_MACHINE_RESET(toypop)
 
 	/* video hardware */
 	MDRV_VIDEO_ATTRIBUTES(VIDEO_TYPE_RASTER)
