@@ -48,7 +48,6 @@ and 2764 eprom (swapped D3/D4 and D5/D6 data lines)
 ****************************************************************************/
 
 #include "driver.h"
-#include "vidhrdw/generic.h"
 #include "sndhrdw/irem.h"
 
 extern unsigned char *travrusa_videoram;
@@ -283,7 +282,7 @@ INPUT_PORTS_END
 
 
 
-static struct GfxLayout charlayout =
+static const gfx_layout charlayout =
 {
 	8,8,
 	RGN_FRAC(1,3),
@@ -294,7 +293,7 @@ static struct GfxLayout charlayout =
 	8*8
 };
 
-static struct GfxLayout spritelayout =
+static const gfx_layout spritelayout =
 {
 	16,16,
 	RGN_FRAC(1,3),
@@ -307,7 +306,7 @@ static struct GfxLayout spritelayout =
 	32*8
 };
 
-static struct GfxLayout sht_spritelayout =
+static const gfx_layout sht_spritelayout =
 {
 	16,16,
 	RGN_FRAC(1,3),
@@ -320,14 +319,14 @@ static struct GfxLayout sht_spritelayout =
 	32*8
 };
 
-static struct GfxDecodeInfo gfxdecodeinfo[] =
+static const gfx_decode gfxdecodeinfo[] =
 {
 	{ REGION_GFX1, 0, &charlayout,      0, 16 },
 	{ REGION_GFX2, 0, &spritelayout, 16*8, 16 },
 	{ -1 } /* end of array */
 };
 
-static struct GfxDecodeInfo sht_gfxdecodeinfo[] =
+static const gfx_decode sht_gfxdecodeinfo[] =
 {
 	{ REGION_GFX1, 0, &charlayout,          0, 16 },
 	{ REGION_GFX2, 0, &sht_spritelayout, 16*8, 16 },
@@ -495,7 +494,7 @@ DRIVER_INIT( motorace )
 {
 	int A,j;
 	unsigned char *rom = memory_region(REGION_CPU1);
-	data8_t *buffer = malloc(0x2000);
+	UINT8 *buffer = malloc(0x2000);
 
 	if (buffer)
 	{
@@ -524,7 +523,7 @@ static DRIVER_INIT( shtridra )
 
 
 
-GAME( 1983, travrusa, 0,        travrusa, travrusa, 0,        ROT270, "Irem", "Traverse USA / Zippy Race" )
-GAME( 1983, motorace, travrusa, travrusa, motorace, motorace, ROT270, "Irem (Williams license)", "MotoRace USA" )
-GAME( 1985, shtrider, 0,        shtrider, shtrider, 0,        ROT270|ORIENTATION_FLIP_X, "Seibu Kaihatsu", "Shot Rider" )
-GAME( 1984, shtridra, shtrider, shtrider, shtrider, shtridra, ROT270|ORIENTATION_FLIP_X, "Seibu Kaihatsu (Sigma license)", "Shot Rider (Sigma license)" )
+GAME( 1983, travrusa, 0,        travrusa, travrusa, 0,        ROT270, "Irem", "Traverse USA / Zippy Race", 0 )
+GAME( 1983, motorace, travrusa, travrusa, motorace, motorace, ROT270, "Irem (Williams license)", "MotoRace USA", 0 )
+GAME( 1985, shtrider, 0,        shtrider, shtrider, 0,        ROT270|ORIENTATION_FLIP_X, "Seibu Kaihatsu", "Shot Rider", 0 )
+GAME( 1984, shtridra, shtrider, shtrider, shtrider, shtridra, ROT270|ORIENTATION_FLIP_X, "Seibu Kaihatsu (Sigma license)", "Shot Rider (Sigma license)", 0 )
