@@ -4,24 +4,19 @@ Atari Triple Hunt Driver
 
   Calibrate controls in service mode the first time you run this game.
 
+To Do:
+ The two 8-Tracks need to be found and recorded.  And then tape emulation
+ needs to be added.  1 tape is for Witch Hunt.  The other is used for
+ both Bear and Racoon Hunt.
+ The 3 different overlays need to be found, scanned and added as artwork
+ to really make the game complete.
+
 ***************************************************************************/
 
 #include "driver.h"
 #include "triplhnt.h"
 #include "sound/discrete.h"
 
-extern VIDEO_START( triplhnt );
-extern VIDEO_UPDATE( triplhnt );
-
-extern UINT8* triplhnt_playfield_ram;
-extern UINT8* triplhnt_vpos_ram;
-extern UINT8* triplhnt_hpos_ram;
-extern UINT8* triplhnt_code_ram;
-extern UINT8* triplhnt_orga_ram;
-
-extern int triplhnt_sprite_zoom;
-extern int triplhnt_sprite_bank;
-
 static UINT8 triplhnt_cmos[16];
 static UINT8 triplhnt_da_latch;
 static UINT8 triplhnt_misc_flags;
@@ -91,18 +86,6 @@ WRITE8_HANDLER( triplhnt_misc_w )
 }
 
 
-WRITE8_HANDLER( triplhnt_zeropage_w )
-{
-	memory_region(REGION_CPU1)[offset & 0xff] = data;
-}
-
-
-READ8_HANDLER( triplhnt_zeropage_r )
-{
-	return memory_region(REGION_CPU1)[offset & 0xff];
-}
-
-
 READ8_HANDLER( triplhnt_cmos_r )
 {
 	triplhnt_cmos_latch = offset;
@@ -141,8 +124,7 @@ READ8_HANDLER( triplhnt_da_latch_r )
 
 
 static ADDRESS_MAP_START( triplhnt_readmem, ADDRESS_SPACE_PROGRAM, 8 )
-	AM_RANGE(0x0000, 0x00ff) AM_READ(MRA8_RAM)
-	AM_RANGE(0x0100, 0x03ff) AM_READ(triplhnt_zeropage_r)
+	AM_RANGE(0x0000, 0x00ff) AM_READ(MRA8_RAM) AM_MIRROR(0x300)
 	AM_RANGE(0x0c00, 0x0c00) AM_READ(input_port_0_r)
 	AM_RANGE(0x0c08, 0x0c08) AM_READ(input_port_1_r)
 	AM_RANGE(0x0c09, 0x0c09) AM_READ(input_port_2_r)
@@ -158,8 +140,7 @@ static ADDRESS_MAP_START( triplhnt_readmem, ADDRESS_SPACE_PROGRAM, 8 )
 ADDRESS_MAP_END
 
 static ADDRESS_MAP_START( triplhnt_writemem, ADDRESS_SPACE_PROGRAM, 8 )
-	AM_RANGE(0x0000, 0x00ff) AM_WRITE(MWA8_RAM)
-	AM_RANGE(0x0100, 0x03ff) AM_WRITE(triplhnt_zeropage_w)
+	AM_RANGE(0x0000, 0x00ff) AM_WRITE(MWA8_RAM) AM_MIRROR(0x300)
 	AM_RANGE(0x0400, 0x04ff) AM_WRITE(MWA8_RAM) AM_BASE(&triplhnt_playfield_ram)
 	AM_RANGE(0x0800, 0x080f) AM_WRITE(MWA8_RAM) AM_BASE(&triplhnt_vpos_ram)
 	AM_RANGE(0x0810, 0x081f) AM_WRITE(MWA8_RAM) AM_BASE(&triplhnt_hpos_ram)
@@ -222,11 +203,11 @@ INPUT_PORTS_START( triplhnt )
 	PORT_BIT( 0xff, 0x78, IPT_LIGHTGUN_Y ) PORT_MINMAX(0x00,0xef) PORT_SENSITIVITY(25) PORT_KEYDELTA(15)
 
 	PORT_START		/* 10 */
-	PORT_ADJUSTER( 50, "Bear Roar Frequency" )
+	PORT_ADJUSTER( 35, "Bear Roar Frequency" )
 INPUT_PORTS_END
 
 
-static gfx_layout triplhnt_small_sprite_layout =
+static const gfx_layout triplhnt_small_sprite_layout =
 {
 	32, 32,   /* width, height */
 	16,       /* total         */
@@ -249,14 +230,8 @@ static gfx_layout triplhnt_small_sprite_layout =
 };
 
 
-static gfx_layout triplhnt_large_sprite_layout =
+static const UINT32 triplhnt_large_sprite_layout_xoffset[64] =
 {
-	64, 64,   /* width, height */
-	16,       /* total         */
-	2,        /* planes        */
-	          /* plane offsets */
-	{ 0x0000, 0x4000 },
-	{
 		0x00, 0x00, 0x01, 0x01, 0x02, 0x02, 0x03, 0x03,
 		0x04, 0x04, 0x05, 0x05, 0x06, 0x06, 0x07, 0x07,
 		0x08, 0x08, 0x09, 0x09, 0x0A, 0x0A, 0x0B, 0x0B,
@@ -265,8 +240,10 @@ static gfx_layout triplhnt_large_sprite_layout =
 		0x14, 0x14, 0x15, 0x15, 0x16, 0x16, 0x17, 0x17,
 		0x18, 0x18, 0x19, 0x19, 0x1A, 0x1A, 0x1B, 0x1B,
 		0x1C, 0x1C, 0x1D, 0x1D, 0x1E, 0x1E, 0x1F, 0x1F
-	},
-	{
+};
+
+static const UINT32 triplhnt_large_sprite_layout_yoffset[64] =
+{
 		0x000, 0x000, 0x020, 0x020, 0x040, 0x040, 0x060, 0x060,
 		0x080, 0x080, 0x0A0, 0x0A0, 0x0C0, 0x0C0, 0x0E0, 0x0E0,
 		0x100, 0x100, 0x120, 0x120, 0x140, 0x140, 0x160, 0x160,
@@ -275,12 +252,23 @@ static gfx_layout triplhnt_large_sprite_layout =
 		0x280, 0x280, 0x2A0, 0x2A0, 0x2C0, 0x2C0, 0x2E0, 0x2E0,
 		0x300, 0x300, 0x320, 0x320, 0x340, 0x340, 0x360, 0x360,
 		0x380, 0x380, 0x3A0, 0x3A0, 0x3C0, 0x3C0, 0x3E0, 0x3E0
-	},
-	0x400     /* increment */
+};
+
+static const gfx_layout triplhnt_large_sprite_layout =
+{
+	64, 64,   /* width, height */
+	16,       /* total         */
+	2,        /* planes        */
+	{ 0x0000, 0x4000 },
+	EXTENDED_XOFFS,
+	EXTENDED_YOFFS,
+	0x400,
+	triplhnt_large_sprite_layout_xoffset,
+	triplhnt_large_sprite_layout_yoffset
 };
 
 
-static gfx_layout triplhnt_tile_layout =
+static const gfx_layout triplhnt_tile_layout =
 {
 	16, 16,   /* width, height */
 	64,       /* total         */
@@ -297,7 +285,7 @@ static gfx_layout triplhnt_tile_layout =
 };
 
 
-static gfx_decode triplhnt_gfx_decode_info[] =
+static const gfx_decode triplhnt_gfx_decode_info[] =
 {
 	{ REGION_GFX1, 0, &triplhnt_small_sprite_layout, 0, 1 },
 	{ REGION_GFX1, 0, &triplhnt_large_sprite_layout, 0, 1 },
