@@ -43,7 +43,6 @@ TODO:
 
 #include "driver.h"
 #include "cpu/z80/z80.h"
-#include "vidhrdw/generic.h"
 #include "sound/ay8910.h"
 #include "sound/dac.h"
 
@@ -694,7 +693,7 @@ INPUT_PORTS_END
 
 
 
-static gfx_layout char_layout =
+static const gfx_layout char_layout =
 {
 	8,8,
 	RGN_FRAC(1,3),
@@ -705,7 +704,7 @@ static gfx_layout char_layout =
 	8*8
 };
 
-static gfx_layout sprite_layout =
+static const gfx_layout sprite_layout =
 {
 	32,32,
 	RGN_FRAC(1,3),
@@ -726,7 +725,7 @@ static gfx_layout sprite_layout =
 	4*256
 };
 
-static gfx_layout tile_layout =
+static const gfx_layout tile_layout =
 {
 	8,8,
 	RGN_FRAC(1,3),
@@ -737,7 +736,7 @@ static gfx_layout tile_layout =
 	8*8
 };
 
-static gfx_decode gfxdecodeinfo[] =
+static const gfx_decode gfxdecodeinfo[] =
 {
 	{ REGION_GFX1, 0, &tile_layout,   0, 32 },
 	{ REGION_GFX2, 0, &char_layout,   0, 32 },
