@@ -23,7 +23,6 @@ Year + Game         PCB             Notes
 ***************************************************************************/
 
 #include "driver.h"
-#include "vidhrdw/generic.h"
 #include "machine/eeprom.h"
 #include "unico.h"
 #include "sound/2151intf.h"
@@ -613,7 +612,7 @@ INPUT_PORTS_END
 ***************************************************************************/
 
 /* 16x16x8 */
-static struct GfxLayout layout_16x16x8 =
+static const gfx_layout layout_16x16x8 =
 {
 	16,16,
 	RGN_FRAC(1,4),
@@ -627,7 +626,7 @@ static struct GfxLayout layout_16x16x8 =
 	16*16*2
 };
 
-static struct GfxDecodeInfo unico_gfxdecodeinfo[] =
+static const gfx_decode unico_gfxdecodeinfo[] =
 {
 	{ REGION_GFX1, 0, &layout_16x16x8, 0x0, 0x20 }, /* [0] Sprites */
 	{ REGION_GFX2, 0, &layout_16x16x8, 0x0, 0x20 }, /* [1] Layers */
@@ -644,7 +643,7 @@ static struct GfxDecodeInfo unico_gfxdecodeinfo[] =
 
 ***************************************************************************/
 
-MACHINE_INIT( unico )
+MACHINE_RESET( unico )
 {
 	unico_has_lightgun = 0;
 }
@@ -689,7 +688,7 @@ static MACHINE_DRIVER_START( burglarx )
 	MDRV_FRAMES_PER_SECOND(60)
 	MDRV_VBLANK_DURATION(DEFAULT_60HZ_VBLANK_DURATION)
 
-	MDRV_MACHINE_INIT(unico)
+	MDRV_MACHINE_RESET(unico)
 
 	/* video hardware */
 	MDRV_VIDEO_ATTRIBUTES(VIDEO_TYPE_RASTER)
@@ -720,9 +719,9 @@ MACHINE_DRIVER_END
                                 Zero Point
 ***************************************************************************/
 
-MACHINE_INIT( zeropt )
+MACHINE_RESET( zeropt )
 {
-	machine_init_unico();
+	machine_reset_unico();
 	unico_has_lightgun = 1;
 }
 
@@ -736,7 +735,7 @@ static MACHINE_DRIVER_START( zeropnt )
 	MDRV_FRAMES_PER_SECOND(60)
 	MDRV_VBLANK_DURATION(DEFAULT_60HZ_VBLANK_DURATION)
 
-	MDRV_MACHINE_INIT(zeropt)
+	MDRV_MACHINE_RESET(zeropt)
 
 	/* video hardware */
 	MDRV_VIDEO_ATTRIBUTES(VIDEO_TYPE_RASTER)
@@ -777,7 +776,7 @@ static MACHINE_DRIVER_START( zeropnt2 )
 	MDRV_FRAMES_PER_SECOND(60)
 	MDRV_VBLANK_DURATION(DEFAULT_60HZ_VBLANK_DURATION)
 
-	MDRV_MACHINE_INIT(zeropt)
+	MDRV_MACHINE_RESET(zeropt)
 
 	MDRV_NVRAM_HANDLER(zeropnt2)
 
@@ -1137,8 +1136,8 @@ ROM_END
 
 ***************************************************************************/
 
-GAME( 1997, burglarx, 0,       burglarx, burglarx, 0, ROT0, "Unico", "Burglar X"  )
-GAME( 1998, zeropnt,  0,       zeropnt,  zeropnt,  0, ROT0, "Unico", "Zero Point (set 1)" )
-GAME( 1998, zeropnta, zeropnt, zeropnt,  zeropnt,  0, ROT0, "Unico", "Zero Point (set 2)" )
-GAME( 1999, zeropnt2, 0,       zeropnt2, zeropnt2, 0, ROT0, "Unico", "Zero Point 2" )
+GAME( 1997, burglarx, 0,       burglarx, burglarx, 0, ROT0, "Unico", "Burglar X" , 0 )
+GAME( 1998, zeropnt,  0,       zeropnt,  zeropnt,  0, ROT0, "Unico", "Zero Point (set 1)", 0 )
+GAME( 1998, zeropnta, zeropnt, zeropnt,  zeropnt,  0, ROT0, "Unico", "Zero Point (set 2)", 0 )
+GAME( 1999, zeropnt2, 0,       zeropnt2, zeropnt2, 0, ROT0, "Unico", "Zero Point 2", 0 )
 
