@@ -88,7 +88,6 @@ VBlank = 58Hz
   *********************************************************************************************************************/
 
 #include "driver.h"
-#include "vidhrdw/generic.h"
 #include "cpu/m6502/m6502.h"
 #include "cpu/z80/z80.h"
 #include "sound/2151intf.h"
@@ -130,7 +129,7 @@ INTERRUPT_GEN( vball_interrupt );
 static WRITE8_HANDLER( vb_bankswitch_w )
 {
 	unsigned char *RAM = memory_region(REGION_CPU1);
-	cpu_setbank( 1,&RAM[ 0x10000 + ( 0x4000 * ( data & 1 ) ) ] );
+	memory_set_bankptr( 1,&RAM[ 0x10000 + ( 0x4000 * ( data & 1 ) ) ] );
 
 	if (vball_gfxset != ((data  & 0x20) ^ 0x20)) {
 		vball_gfxset = (data  & 0x20) ^ 0x20;
@@ -142,7 +141,7 @@ static WRITE8_HANDLER( vb_bankswitch_w )
 /* The sound system comes all but verbatim from Double Dragon */
 
 
-WRITE8_HANDLER( cpu_sound_command_w ) {
+static WRITE8_HANDLER( cpu_sound_command_w ) {
 	soundlatch_w( offset, data );
 	cpunum_set_input_line( 1, INPUT_LINE_NMI, PULSE_LINE );
 }
@@ -157,7 +156,7 @@ WRITE8_HANDLER( cpu_sound_command_w ) {
    bit 6 = sp prom bank
    bit 7 = sp prom bank
 */
-WRITE8_HANDLER( vb_scrollx_hi_w )
+static WRITE8_HANDLER( vb_scrollx_hi_w )
 {
 	flip_screen_set(~data&1);
 	vb_scrollx_hi = (data & 0x02) << 7;
@@ -357,7 +356,7 @@ INPUT_PORTS_START (vball2pj)
 INPUT_PORTS_END
 
 
-static struct GfxLayout charlayout =
+static const gfx_layout charlayout =
 {
 	8,8,
 	RGN_FRAC(1,1),
@@ -368,7 +367,7 @@ static struct GfxLayout charlayout =
 	32*8
 };
 
-static struct GfxLayout spritelayout =
+static const gfx_layout spritelayout =
 {
 	16,16,
 	RGN_FRAC(1,2),
@@ -382,7 +381,7 @@ static struct GfxLayout spritelayout =
 };
 
 
-static struct GfxDecodeInfo vb_gfxdecodeinfo[] =
+static const gfx_decode vb_gfxdecodeinfo[] =
 {
 	{ REGION_GFX1, 0, &charlayout,     0, 8 },	/* 8x8 chars */
 	{ REGION_GFX2, 0, &spritelayout, 128, 8 },	/* 16x16 sprites */
@@ -544,5 +543,5 @@ ROM_START( vball2pj )
 ROM_END
 
 
-GAME( 1988, vball,    0,     vball,    vball,    0, ROT0, "Technos", "U.S. Championship V'ball (set 1)" )
-GAME( 1988, vball2pj, vball, vball2pj, vball2pj, 0, ROT0, "Technos", "U.S. Championship V'ball (Japan)" )
+GAME( 1988, vball,    0,     vball,    vball,    0, ROT0, "Technos", "U.S. Championship V'ball (set 1)", 0 )
+GAME( 1988, vball2pj, vball, vball2pj, vball2pj, 0, ROT0, "Technos", "U.S. Championship V'ball (Japan)", 0 )
