@@ -99,7 +99,6 @@
 #include "exidy.h"
 #include "machine/6821pia.h"
 #include "sound/5220intf.h"
-#include "vidhrdw/generic.h"
 
 
 #define LOG_SOUND		0
@@ -440,5 +439,5 @@ ROM_END
  *
  *************************************/
 
-GAME( 1982, victory,  0,        victory, victory, 0,     ROT0, "Exidy", "Victory" )
-GAME( 1982, victorba, victory,  victory, victory, 0,     ROT0, "Exidy", "Victor Banana" )
+GAME( 1982, victory,  0,        victory, victory, 0,     ROT0, "Exidy", "Victory", 0 )
+GAME( 1982, victorba, victory,  victory, victory, 0,     ROT0, "Exidy", "Victor Banana", 0 )
