@@ -15,14 +15,6 @@
 #include "videopin.h"
 #include "sound/discrete.h"
 
-extern UINT8* videopin_video_ram;
-
-extern WRITE8_HANDLER( videopin_video_ram_w );
-extern WRITE8_HANDLER( videopin_ball_w );
-
-extern VIDEO_START( videopin );
-extern VIDEO_UPDATE( videopin );
-
 static double time_pushed;
 static double time_released;
 
@@ -75,7 +67,7 @@ static void interrupt_callback(int scanline)
 }
 
 
-static MACHINE_INIT( videopin )
+static MACHINE_RESET( videopin )
 {
 	timer_set(cpu_getscanlinetime(32), 32, interrupt_callback);
 
@@ -295,7 +287,7 @@ INPUT_PORTS_END
  *
  *************************************/
 
-static gfx_layout tile_layout =
+static const gfx_layout tile_layout =
 {
 	8, 8,
 	64,
@@ -311,7 +303,7 @@ static gfx_layout tile_layout =
 };
 
 
-static gfx_layout ball_layout =
+static const gfx_layout ball_layout =
 {
 	16, 16,
 	1,
@@ -330,7 +322,7 @@ static gfx_layout ball_layout =
 };
 
 
-static gfx_decode videopin_gfxdecodeinfo[] =
+static const gfx_decode videopin_gfxdecodeinfo[] =
 {
 	{ REGION_GFX1, 0x0000, &tile_layout, 0, 1 },
 	{ REGION_GFX2, 0x0000, &ball_layout, 0, 1 },
@@ -353,7 +345,7 @@ static MACHINE_DRIVER_START( videopin )
 
 	MDRV_FRAMES_PER_SECOND(60)
 	MDRV_VBLANK_DURATION(23. * 1000000 / 15750)
-	MDRV_MACHINE_INIT(videopin)
+	MDRV_MACHINE_RESET(videopin)
 
 	/* video hardware */
 	MDRV_VIDEO_ATTRIBUTES(VIDEO_TYPE_RASTER)
