@@ -15,7 +15,6 @@ Buccaneers has a 5.6888 Mhz and a 18.432 Mhz OSC
 ***************************************************************************/
 
 #include "driver.h"
-#include "vidhrdw/generic.h"
 #include "sndhrdw/m72.h"
 #include "sound/dac.h"
 #include "sound/2203intf.h"
@@ -465,7 +464,7 @@ INPUT_PORTS_START( buccanra )
 INPUT_PORTS_END
 
 
-static gfx_layout text_layout =
+static const gfx_layout text_layout =
 {
 	8,8, /* tile size */
 	RGN_FRAC(1,2), /* number of tiles */
@@ -476,7 +475,7 @@ static gfx_layout text_layout =
 	128
 };
 
-static gfx_layout sprite_layout =
+static const gfx_layout sprite_layout =
 {
 	16,16,	/* tile size */
 	RGN_FRAC(1,2),	/* number of sprites ($1000) */
@@ -497,7 +496,7 @@ static gfx_layout sprite_layout =
 	0x40*8
 };
 
-static gfx_layout sprite_layout_buccanrs =
+static const gfx_layout sprite_layout_buccanrs =
 {
 	16,16,	/* tile size */
 	RGN_FRAC(1,2),	/* number of sprites ($1000) */
@@ -519,7 +518,7 @@ static gfx_layout sprite_layout_buccanrs =
 };
 
 
-static gfx_layout back_layout =
+static const gfx_layout back_layout =
 {
 	32,1, /* tile size */
 	RGN_FRAC(1,1), /* number of tiles */
@@ -532,7 +531,7 @@ static gfx_layout back_layout =
 	16*8
 };
 
-static gfx_layout buccaneer_back_layout =
+static const gfx_layout buccaneer_back_layout =
 {
 	32,1, /* tile size */
 	RGN_FRAC(1,1), /* number of tiles */
@@ -545,7 +544,7 @@ static gfx_layout buccaneer_back_layout =
 	16*8
 };
 
-static gfx_decode vigilant_gfxdecodeinfo[] =
+static const gfx_decode vigilant_gfxdecodeinfo[] =
 {
 	{ REGION_GFX1, 0, &text_layout,   256, 16 },	/* colors 256-511 */
 	{ REGION_GFX2, 0, &sprite_layout,   0, 16 },	/* colors   0-255 */
@@ -555,7 +554,7 @@ static gfx_decode vigilant_gfxdecodeinfo[] =
 	{ -1 } /* end of array */
 };
 
-static gfx_decode buccanrs_gfxdecodeinfo[] =
+static const gfx_decode buccanrs_gfxdecodeinfo[] =
 {
 	{ REGION_GFX1, 0, &text_layout,   256, 16 },	/* colors 256-511 */
 	{ REGION_GFX2, 0, &sprite_layout_buccanrs,   0, 16 },	/* colors   0-255 */
@@ -565,7 +564,7 @@ static gfx_decode buccanrs_gfxdecodeinfo[] =
 	{ -1 } /* end of array */
 };
 
-static gfx_decode kikcubic_gfxdecodeinfo[] =
+static const gfx_decode kikcubic_gfxdecodeinfo[] =
 {
 	{ REGION_GFX1, 0, &text_layout,   0, 16 },
 	{ REGION_GFX2, 0, &sprite_layout, 0, 16 },
@@ -601,7 +600,7 @@ static MACHINE_DRIVER_START( vigilant )
 								/* IRQs are generated by main Z80 and YM2151 */
 	MDRV_FRAMES_PER_SECOND(55)
 	MDRV_VBLANK_DURATION(DEFAULT_REAL_60HZ_VBLANK_DURATION)
-	MDRV_MACHINE_INIT(m72_sound)
+	MDRV_MACHINE_RESET(m72_sound)
 
 	/* video hardware */
 	MDRV_VIDEO_ATTRIBUTES(VIDEO_TYPE_RASTER)
@@ -642,7 +641,7 @@ static MACHINE_DRIVER_START( buccanrs )
 								/* IRQs are generated by main Z80 and YM2151 */
 	MDRV_FRAMES_PER_SECOND(55)
 	MDRV_VBLANK_DURATION(DEFAULT_REAL_60HZ_VBLANK_DURATION)
-	MDRV_MACHINE_INIT(m72_sound)
+	MDRV_MACHINE_RESET(m72_sound)
 
 	/* video hardware */
 	MDRV_VIDEO_ATTRIBUTES(VIDEO_TYPE_RASTER)
@@ -699,7 +698,7 @@ static MACHINE_DRIVER_START( kikcubic )
 								/* IRQs are generated by main Z80 and YM2151 */
 	MDRV_FRAMES_PER_SECOND(55)
 	MDRV_VBLANK_DURATION(DEFAULT_REAL_60HZ_VBLANK_DURATION)
-	MDRV_MACHINE_INIT(m72_sound)
+	MDRV_MACHINE_RESET(m72_sound)
 
 	/* video hardware */
 	MDRV_VIDEO_ATTRIBUTES(VIDEO_TYPE_RASTER)
