@@ -48,11 +48,10 @@ Thanks to HIGHWAYMAN for providing info on how to get to these epoxies
 ****************************************************************************/
 
 #include "driver.h"
-#include "vidhrdw/generic.h"
 #include "vidhrdw/res_net.h"
 #include "sound/ay8910.h"
 
-static struct tilemap *bg_tilemap;
+static tilemap *bg_tilemap;
 
 /***************************************************************************
 
@@ -82,8 +81,8 @@ static PALETTE_INIT( wallc )
 {
 	int i;
 
-	const int resistances_rg[2] = { 330, 220 };
-	const int resistances_b[3] = { 655, 330, 220 };
+	static const int resistances_rg[2] = { 330, 220 };
+	static const int resistances_b[3] = { 655, 330, 220 };
 	double weights_r[2], weights_g[2], weights_b[3];
 
 	compute_resistor_weights(0,	255,	-1.0,
@@ -226,7 +225,7 @@ INPUT_PORTS_END
 
 
 
-static struct GfxLayout charlayout =
+static const gfx_layout charlayout =
 {
 	8,8,	/* 8*8 characters */
 	RGN_FRAC(1,3),
@@ -237,7 +236,7 @@ static struct GfxLayout charlayout =
 	8*8 /* every char takes 8 consecutive bytes */
 };
 
-static struct GfxDecodeInfo gfxdecodeinfo[] =
+static const gfx_decode gfxdecodeinfo[] =
 {
 	{ REGION_GFX1, 0     , &charlayout, 0, 4 },
 	{ -1 } /* end of array */
@@ -248,7 +247,7 @@ static DRIVER_INIT( wallc )
 	unsigned char c;
 	unsigned int i;
 
-	data8_t *ROM = memory_region(REGION_CPU1);
+	UINT8 *ROM = memory_region(REGION_CPU1);
 
 	for (i=0; i<0x2000*2; i++)
 	{
@@ -263,7 +262,7 @@ static DRIVER_INIT( wallca )
 	unsigned char c;
 	unsigned int i;
 
-	data8_t *ROM = memory_region(REGION_CPU1);
+	UINT8 *ROM = memory_region(REGION_CPU1);
 
 	for (i=0; i<0x4000; i++)
 	{
@@ -345,5 +344,5 @@ ROM_START( wallca )
 	ROM_LOAD( "74s288.c2",  0x0000, 0x0020, CRC(83e3e293) SHA1(a98c5e63b688de8d175adb6539e0cdc668f313fd) )
 ROM_END
 
-GAME( 1984, wallc,  0,      wallc,  wallc, wallc,  ROT0, "Midcoin", "Wall Crash (set 1)" )
-GAME( 1984, wallca, wallc,  wallc,  wallc, wallca, ROT0, "Midcoin", "Wall Crash (set 2)" )
+GAME( 1984, wallc,  0,      wallc,  wallc, wallc,  ROT0, "Midcoin", "Wall Crash (set 1)", 0 )
+GAME( 1984, wallca, wallc,  wallc,  wallc, wallca, ROT0, "Midcoin", "Wall Crash (set 2)", 0 )
