@@ -52,21 +52,20 @@ Press one of the start buttons to exit.
 */
 
 #include "driver.h"
-#include "vidhrdw/generic.h"
 #include "cpu/z80/z80.h"
 #include "sound/2608intf.h"
 
 
-extern data8_t *wc90_fgvideoram,*wc90_bgvideoram,*wc90_txvideoram;
+extern UINT8 *wc90_fgvideoram,*wc90_bgvideoram,*wc90_txvideoram;
 
 
-extern data8_t *wc90_scroll0xlo, *wc90_scroll0xhi;
-extern data8_t *wc90_scroll1xlo, *wc90_scroll1xhi;
-extern data8_t *wc90_scroll2xlo, *wc90_scroll2xhi;
+extern UINT8 *wc90_scroll0xlo, *wc90_scroll0xhi;
+extern UINT8 *wc90_scroll1xlo, *wc90_scroll1xhi;
+extern UINT8 *wc90_scroll2xlo, *wc90_scroll2xhi;
 
-extern data8_t *wc90_scroll0ylo, *wc90_scroll0yhi;
-extern data8_t *wc90_scroll1ylo, *wc90_scroll1yhi;
-extern data8_t *wc90_scroll2ylo, *wc90_scroll2yhi;
+extern UINT8 *wc90_scroll0ylo, *wc90_scroll0yhi;
+extern UINT8 *wc90_scroll1ylo, *wc90_scroll1yhi;
+extern UINT8 *wc90_scroll2ylo, *wc90_scroll2yhi;
 
 VIDEO_START( wc90 );
 VIDEO_START( wc90t );
@@ -76,7 +75,7 @@ WRITE8_HANDLER( wc90_txvideoram_w );
 VIDEO_UPDATE( wc90 );
 
 
-static data8_t *wc90_shared;
+static UINT8 *wc90_shared;
 
 static READ8_HANDLER( wc90_shared_r )
 {
@@ -91,21 +90,21 @@ static WRITE8_HANDLER( wc90_shared_w )
 static WRITE8_HANDLER( wc90_bankswitch_w )
 {
 	int bankaddress;
-	data8_t *RAM = memory_region(REGION_CPU1);
+	UINT8 *RAM = memory_region(REGION_CPU1);
 
 
 	bankaddress = 0x10000 + ( ( data & 0xf8 ) << 8 );
-	cpu_setbank( 1,&RAM[bankaddress] );
+	memory_set_bankptr( 1,&RAM[bankaddress] );
 }
 
 static WRITE8_HANDLER( wc90_bankswitch1_w )
 {
 	int bankaddress;
-	data8_t *RAM = memory_region(REGION_CPU2);
+	UINT8 *RAM = memory_region(REGION_CPU2);
 
 
 	bankaddress = 0x10000 + ( ( data & 0xf8 ) << 8 );
-	cpu_setbank( 2,&RAM[bankaddress] );
+	memory_set_bankptr( 2,&RAM[bankaddress] );
 }
 
 static WRITE8_HANDLER( wc90_sound_command_w )
@@ -175,7 +174,7 @@ static ADDRESS_MAP_START( wc90_writemem2, ADDRESS_SPACE_PROGRAM, 8 )
 	AM_RANGE(0xc000, 0xcfff) AM_WRITE(MWA8_RAM)
 	AM_RANGE(0xd000, 0xd7ff) AM_WRITE(MWA8_RAM) AM_BASE(&spriteram) AM_SIZE(&spriteram_size)
 	AM_RANGE(0xd800, 0xdfff) AM_WRITE(MWA8_RAM)
-	AM_RANGE(0xe000, 0xe7ff) AM_WRITE(paletteram_xxxxBBBBRRRRGGGG_swap_w) AM_BASE(&paletteram)
+	AM_RANGE(0xe000, 0xe7ff) AM_WRITE(paletteram_xxxxBBBBRRRRGGGG_be_w) AM_BASE(&paletteram)
 	AM_RANGE(0xf000, 0xf7ff) AM_WRITE(MWA8_ROM)
 	AM_RANGE(0xf800, 0xfbff) AM_WRITE(wc90_shared_w)
 	AM_RANGE(0xfc00, 0xfc00) AM_WRITE(wc90_bankswitch1_w)
@@ -287,7 +286,7 @@ INPUT_PORTS_END
 
 
 
-static struct GfxLayout charlayout =
+static const gfx_layout charlayout =
 {
 	8,8,
 	RGN_FRAC(1,1),
@@ -298,7 +297,7 @@ static struct GfxLayout charlayout =
 	32*8
 };
 
-static struct GfxLayout tilelayout =
+static const gfx_layout tilelayout =
 {
 	16,16,
 	RGN_FRAC(1,1),
@@ -311,7 +310,7 @@ static struct GfxLayout tilelayout =
 	128*8
 };
 
-static struct GfxLayout spritelayout =
+static const gfx_layout spritelayout =
 {
 	16,16,
 	RGN_FRAC(1,2),
@@ -324,7 +323,7 @@ static struct GfxLayout spritelayout =
 	64*8
 };
 
-static struct GfxDecodeInfo gfxdecodeinfo[] =
+static const gfx_decode gfxdecodeinfo[] =
 {
 	{ REGION_GFX1, 0x00000, &charlayout,      	1*16*16, 16*16 },
 	{ REGION_GFX2, 0x00000, &tilelayout,		2*16*16, 16*16 },
@@ -492,6 +491,6 @@ ROM_END
 
 
 
-GAMEX( 1989, wc90,  0,    wc90, wc90, 0, ROT0, "Tecmo", "Tecmo World Cup '90 (set 1)", GAME_IMPERFECT_SOUND | GAME_NO_COCKTAIL )
-GAMEX( 1989, wc90a, wc90, wc90, wc90, 0, ROT0, "Tecmo", "Tecmo World Cup '90 (set 2)", GAME_IMPERFECT_SOUND | GAME_NO_COCKTAIL )
-GAMEX( 1989, wc90t, wc90, wc90t,wc90, 0, ROT0, "Tecmo", "Tecmo World Cup '90 (trackball)", GAME_IMPERFECT_SOUND | GAME_NO_COCKTAIL )
+GAME( 1989, wc90,  0,    wc90, wc90, 0, ROT0, "Tecmo", "Tecmo World Cup '90 (set 1)", GAME_IMPERFECT_SOUND | GAME_NO_COCKTAIL )
+GAME( 1989, wc90a, wc90, wc90, wc90, 0, ROT0, "Tecmo", "Tecmo World Cup '90 (set 2)", GAME_IMPERFECT_SOUND | GAME_NO_COCKTAIL )
+GAME( 1989, wc90t, wc90, wc90t,wc90, 0, ROT0, "Tecmo", "Tecmo World Cup '90 (trackball)", GAME_IMPERFECT_SOUND | GAME_NO_COCKTAIL )
