@@ -270,14 +270,13 @@ TODO:
 ***************************************************************************/
 
 #include "driver.h"
-#include "vidhrdw/generic.h"
 #include "vidhrdw/konamiic.h"
 #include "cpu/m6809/m6809.h"
 #include "sound/2151intf.h"
 #include "sound/k007232.h"
 
 /* Variables only used here: */
-static UINT16 *sharedram, *blitter_regs;
+static UINT16 *blitter_regs;
 static int multiply_reg[2];
 static UINT16 *wecleman_protection_ram;
 static int spr_color_offs;
@@ -344,10 +343,6 @@ static WRITE16_HANDLER( wecleman_protection_w )
 }
 
 
-/* Data is read from and written to *sharedram* */
-static READ16_HANDLER( sharedram_r )    { return sharedram[offset]; }
-static WRITE16_HANDLER( sharedram_w )   { COMBINE_DATA(&sharedram[offset]); }
-
 
 /* 140005.b (WEC Le Mans 24 Schematics)
 
@@ -535,40 +530,28 @@ static WRITE16_HANDLER( blitter_w )
 
 static WRITE16_HANDLER( wecleman_soundlatch_w );
 
-static ADDRESS_MAP_START( wecleman_readmem, ADDRESS_SPACE_PROGRAM, 16 )
-	AM_RANGE(0x000000, 0x03ffff) AM_READ(MRA16_ROM)	/* ROM */
-	AM_RANGE(0x040000, 0x043fff) AM_READ(MRA16_RAM)	/* RAM */
-	AM_RANGE(0x060006, 0x060007) AM_READ(wecleman_protection_r)	/* MCU read */
-	AM_RANGE(0x080000, 0x080011) AM_READ(MRA16_RAM)	/* Blitter (reading is for debug) */
-	AM_RANGE(0x100000, 0x103fff) AM_READ(MRA16_RAM)	/* Background Layers */
-	AM_RANGE(0x108000, 0x108fff) AM_READ(MRA16_RAM)	/* Text Layer */
-	AM_RANGE(0x110000, 0x110fff) AM_READ(MRA16_RAM)	/* Palette */
-	AM_RANGE(0x124000, 0x127fff) AM_READ(sharedram_r)	/* Shared with sub CPU */
-	AM_RANGE(0x130000, 0x130fff) AM_READ(MRA16_RAM)	/* Sprites */
-	/* Input Ports: */
-	AM_RANGE(0x140010, 0x140011) AM_READ(input_port_0_word_r)	/* Coins + brake + gear */
-	AM_RANGE(0x140012, 0x140013) AM_READ(input_port_1_word_r)	/* ?? */
-	AM_RANGE(0x140014, 0x140015) AM_READ(input_port_2_word_r)	/* DSW */
-	AM_RANGE(0x140016, 0x140017) AM_READ(input_port_3_word_r)	/* DSW */
-	AM_RANGE(0x140020, 0x140021) AM_READ(selected_ip_r)	/* Accelerator or Wheel or .. */
-ADDRESS_MAP_END
-
-static ADDRESS_MAP_START( wecleman_writemem, ADDRESS_SPACE_PROGRAM, 16 )
-	AM_RANGE(0x000000, 0x03ffff) AM_WRITE(MWA16_ROM)	/* ROM (03c000-03ffff used as RAM sometimes!) */
+static ADDRESS_MAP_START( wecleman_map, ADDRESS_SPACE_PROGRAM, 16 )
+	AM_RANGE(0x000000, 0x03ffff) AM_ROM	/* ROM (03c000-03ffff used as RAM sometimes!) */
 	AM_RANGE(0x040494, 0x040495) AM_WRITE(wecleman_videostatus_w) AM_BASE(&wecleman_videostatus)	/* cloud blending control (HACK) */
-	AM_RANGE(0x040000, 0x043fff) AM_WRITE(MWA16_RAM)	/* RAM */
+	AM_RANGE(0x040000, 0x043fff) AM_RAM	/* RAM */
 	AM_RANGE(0x060000, 0x060005) AM_WRITE(wecleman_protection_w) AM_BASE(&wecleman_protection_ram)
-	AM_RANGE(0x080000, 0x080011) AM_WRITE(blitter_w) AM_BASE(&blitter_regs)	/* Blitter */
-	AM_RANGE(0x100000, 0x103fff) AM_WRITE(wecleman_pageram_w) AM_BASE(&wecleman_pageram)	/* Background Layers */
-	AM_RANGE(0x108000, 0x108fff) AM_WRITE(wecleman_txtram_w) AM_BASE(&wecleman_txtram)	/* Text Layer */
-	AM_RANGE(0x110000, 0x110fff) AM_WRITE(wecleman_paletteram16_SSSSBBBBGGGGRRRR_word_w) AM_BASE(&paletteram16)
-	AM_RANGE(0x124000, 0x127fff) AM_WRITE(sharedram_w) AM_BASE(&sharedram)	/* Shared with main CPU */
-	AM_RANGE(0x130000, 0x130fff) AM_WRITE(MWA16_RAM) AM_BASE(&spriteram16)	/* Sprites */
+	AM_RANGE(0x060006, 0x060007) AM_READ(wecleman_protection_r)	/* MCU read */
+	AM_RANGE(0x080000, 0x080011) AM_READWRITE(MRA16_RAM, blitter_w) AM_BASE(&blitter_regs)	/* Blitter */
+	AM_RANGE(0x100000, 0x103fff) AM_READWRITE(MRA16_RAM, wecleman_pageram_w) AM_BASE(&wecleman_pageram)	/* Background Layers */
+	AM_RANGE(0x108000, 0x108fff) AM_READWRITE(MRA16_RAM, wecleman_txtram_w) AM_BASE(&wecleman_txtram)	/* Text Layer */
+	AM_RANGE(0x110000, 0x110fff) AM_READWRITE(MRA16_RAM, wecleman_paletteram16_SSSSBBBBGGGGRRRR_word_w) AM_BASE(&paletteram16)
+	AM_RANGE(0x124000, 0x127fff) AM_RAM AM_SHARE(1)	/* Shared with main CPU */
+	AM_RANGE(0x130000, 0x130fff) AM_RAM AM_BASE(&spriteram16)	/* Sprites */
 	AM_RANGE(0x140000, 0x140001) AM_WRITE(wecleman_soundlatch_w)	/* To sound CPU */
 	AM_RANGE(0x140002, 0x140003) AM_WRITE(selected_ip_w)	/* Selects accelerator / wheel / .. */
 	AM_RANGE(0x140004, 0x140005) AM_WRITE(irqctrl_w)	/* Main CPU controls the other CPUs */
 	AM_RANGE(0x140006, 0x140007) AM_WRITE(MWA16_NOP)	/* Watchdog reset */
+	AM_RANGE(0x140010, 0x140011) AM_READ(input_port_0_word_r)	/* Coins + brake + gear */
+	AM_RANGE(0x140012, 0x140013) AM_READ(input_port_1_word_r)	/* ?? */
+	AM_RANGE(0x140014, 0x140015) AM_READ(input_port_2_word_r)	/* DSW */
+	AM_RANGE(0x140016, 0x140017) AM_READ(input_port_3_word_r)	/* DSW */
 	AM_RANGE(0x140020, 0x140021) AM_WRITE(MWA16_RAM)	/* Paired with writes to $140003 */
+	AM_RANGE(0x140020, 0x140021) AM_READ(selected_ip_r)	/* Accelerator or Wheel or .. */
 	AM_RANGE(0x140030, 0x140031) AM_WRITE(MWA16_NOP)	/* toggles between 0 & 1 on hitting bumps and crashes (vibration?) */
 ADDRESS_MAP_END
 
@@ -609,41 +592,28 @@ static WRITE16_HANDLER( hotchase_K051316_ctrl_1_w )
 
 WRITE16_HANDLER( hotchase_soundlatch_w );
 
-static ADDRESS_MAP_START( hotchase_readmem, ADDRESS_SPACE_PROGRAM, 16 )
-	AM_RANGE(0x000000, 0x03ffff) AM_READ(MRA16_ROM)	/* ROM */
-	AM_RANGE(0x040000, 0x063fff) AM_READ(MRA16_RAM)	/* RAM (weird size!?) */
-	AM_RANGE(0x080000, 0x080011) AM_READ(MRA16_RAM)	/* Blitter */
-	AM_RANGE(0x100000, 0x100fff) AM_READ(hotchase_K051316_0_r)	/* Background */
-	AM_RANGE(0x102000, 0x102fff) AM_READ(hotchase_K051316_1_r)	/* Foreground */
-	AM_RANGE(0x110000, 0x111fff) AM_READ(MRA16_RAM)	/* Palette (only the first 2048 colors used) */
-	AM_RANGE(0x120000, 0x123fff) AM_READ(sharedram_r)	/* Shared with sub CPU */
-	AM_RANGE(0x130000, 0x130fff) AM_READ(MRA16_RAM)	/* Sprites */
+static ADDRESS_MAP_START( hotchase_map, ADDRESS_SPACE_PROGRAM, 16 )
+	AM_RANGE(0x000000, 0x03ffff) AM_ROM
+	AM_RANGE(0x040000, 0x063fff) AM_RAM										/* RAM (weird size!?) */
+	AM_RANGE(0x080000, 0x080011) AM_READWRITE(MRA16_RAM, blitter_w) AM_BASE(&blitter_regs)	/* Blitter */
+	AM_RANGE(0x100000, 0x100fff) AM_READWRITE(hotchase_K051316_0_r, hotchase_K051316_0_w)	/* Background */
+	AM_RANGE(0x101000, 0x10101f) AM_WRITE(hotchase_K051316_ctrl_0_w)	/* Background Ctrl */
+	AM_RANGE(0x102000, 0x102fff) AM_READWRITE(hotchase_K051316_1_r, hotchase_K051316_1_w)	/* Foreground */
+	AM_RANGE(0x103000, 0x10301f) AM_WRITE(hotchase_K051316_ctrl_1_w)	/* Foreground Ctrl */
+	AM_RANGE(0x110000, 0x111fff) AM_READWRITE(MRA16_RAM, hotchase_paletteram16_SBGRBBBBGGGGRRRR_word_w) AM_BASE(&paletteram16)
+	AM_RANGE(0x120000, 0x123fff) AM_RAM AM_SHARE(1)					/* Shared with sub CPU */
+	AM_RANGE(0x130000, 0x130fff) AM_RAM AM_BASE(&spriteram16)	/* Sprites */
 	/* Input Ports: */
+	AM_RANGE(0x140000, 0x140001) AM_WRITE(hotchase_soundlatch_w)	/* To sound CPU */
+	AM_RANGE(0x140002, 0x140003) AM_WRITE(selected_ip_w)	/* Selects accelerator / wheel / */
+	AM_RANGE(0x140004, 0x140005) AM_WRITE(irqctrl_w)	/* Main CPU controls the other CPUs */
 	AM_RANGE(0x140006, 0x140007) AM_READ(MRA16_NOP)	/* Watchdog reset */
 	AM_RANGE(0x140010, 0x140011) AM_READ(input_port_0_word_r)	/* Coins + brake + gear */
 	AM_RANGE(0x140012, 0x140013) AM_READ(input_port_1_word_r)	/* ?? bit 4 from sound cpu */
 	AM_RANGE(0x140014, 0x140015) AM_READ(input_port_2_word_r)	/* DSW 2 */
 	AM_RANGE(0x140016, 0x140017) AM_READ(input_port_3_word_r)	/* DSW 1 */
-	AM_RANGE(0x140020, 0x140021) AM_READ(selected_ip_r)	/* Accelerator or Wheel */
+	AM_RANGE(0x140020, 0x140021) AM_READWRITE(selected_ip_r, MWA16_NOP)	/* Paired with writes to $140003 */
 	AM_RANGE(0x140022, 0x140023) AM_READ(MRA16_NOP)	/* ?? */
-ADDRESS_MAP_END
-
-static ADDRESS_MAP_START( hotchase_writemem, ADDRESS_SPACE_PROGRAM, 16 )
-	AM_RANGE(0x000000, 0x03ffff) AM_WRITE(MWA16_ROM)	/* ROM */
-	AM_RANGE(0x040000, 0x063fff) AM_WRITE(MWA16_RAM)	/* RAM (weird size!?) */
-	AM_RANGE(0x080000, 0x080011) AM_WRITE(blitter_w) AM_BASE(&blitter_regs)	/* Blitter */
-	AM_RANGE(0x100000, 0x100fff) AM_WRITE(hotchase_K051316_0_w)	/* Background */
-	AM_RANGE(0x101000, 0x10101f) AM_WRITE(hotchase_K051316_ctrl_0_w)	/* Background Ctrl */
-	AM_RANGE(0x102000, 0x102fff) AM_WRITE(hotchase_K051316_1_w)	/* Foreground */
-	AM_RANGE(0x103000, 0x10301f) AM_WRITE(hotchase_K051316_ctrl_1_w)	/* Foreground Ctrl */
-	AM_RANGE(0x110000, 0x111fff) AM_WRITE(hotchase_paletteram16_SBGRBBBBGGGGRRRR_word_w) AM_BASE(&paletteram16)
-	AM_RANGE(0x120000, 0x123fff) AM_WRITE(sharedram_w) AM_BASE(&sharedram)	/* Shared with sub CPU */
-	AM_RANGE(0x130000, 0x130fff) AM_WRITE(MWA16_RAM) AM_BASE(&spriteram16)	/* Sprites */
-	/* Input Ports: */
-	AM_RANGE(0x140000, 0x140001) AM_WRITE(hotchase_soundlatch_w)	/* To sound CPU */
-	AM_RANGE(0x140002, 0x140003) AM_WRITE(selected_ip_w)	/* Selects accelerator / wheel / */
-	AM_RANGE(0x140004, 0x140005) AM_WRITE(irqctrl_w)	/* Main CPU controls the other CPUs */
-	AM_RANGE(0x140020, 0x140021) AM_WRITE(MWA16_NOP)	/* Paired with writes to $140003 */
 	AM_RANGE(0x140030, 0x140031) AM_WRITE(MWA16_NOP)	/* signal to cabinet vibration motors? */
 ADDRESS_MAP_END
 
@@ -652,16 +622,10 @@ ADDRESS_MAP_END
                     WEC Le Mans 24 Sub CPU Handlers
 ***************************************************************************/
 
-static ADDRESS_MAP_START( wecleman_sub_readmem, ADDRESS_SPACE_PROGRAM, 16 )
-	AM_RANGE(0x000000, 0x00ffff) AM_READ(MRA16_ROM)	/* ROM */
-	AM_RANGE(0x060000, 0x060fff) AM_READ(MRA16_RAM)	/* Road */
-	AM_RANGE(0x070000, 0x073fff) AM_READ(&sharedram_r)	/* RAM (Shared with main CPU) */
-ADDRESS_MAP_END
-
-static ADDRESS_MAP_START( wecleman_sub_writemem, ADDRESS_SPACE_PROGRAM, 16 )
-	AM_RANGE(0x000000, 0x00ffff) AM_WRITE(MWA16_ROM)	/* ROM */
-	AM_RANGE(0x060000, 0x060fff) AM_WRITE(MWA16_RAM) AM_BASE(&wecleman_roadram) AM_SIZE(&wecleman_roadram_size)	/* Road */
-	AM_RANGE(0x070000, 0x073fff) AM_WRITE(sharedram_w)	/* RAM (Shared with main CPU) */
+static ADDRESS_MAP_START( wecleman_sub_map, ADDRESS_SPACE_PROGRAM, 16 )
+	AM_RANGE(0x000000, 0x00ffff) AM_ROM	/* ROM */
+	AM_RANGE(0x060000, 0x060fff) AM_RAM AM_BASE(&wecleman_roadram) AM_SIZE(&wecleman_roadram_size)	/* Road */
+	AM_RANGE(0x070000, 0x073fff) AM_RAM AM_SHARE(1)	/* RAM (Shared with main CPU) */
 ADDRESS_MAP_END
 
 
@@ -669,18 +633,11 @@ ADDRESS_MAP_END
                         Hot Chase Sub CPU Handlers
 ***************************************************************************/
 
-static ADDRESS_MAP_START( hotchase_sub_readmem, ADDRESS_SPACE_PROGRAM, 16 )
-	AM_RANGE(0x000000, 0x01ffff) AM_READ(MRA16_ROM)	/* ROM */
-	AM_RANGE(0x020000, 0x020fff) AM_READ(MRA16_RAM)	/* Road */
-	AM_RANGE(0x060000, 0x060fff) AM_READ(MRA16_RAM)	/* RAM */
-	AM_RANGE(0x040000, 0x043fff) AM_READ(&sharedram_r)	/* Shared with main CPU */
-ADDRESS_MAP_END
-
-static ADDRESS_MAP_START( hotchase_sub_writemem, ADDRESS_SPACE_PROGRAM, 16 )
-	AM_RANGE(0x000000, 0x01ffff) AM_WRITE(MWA16_ROM)	/* ROM */
-	AM_RANGE(0x020000, 0x020fff) AM_WRITE(MWA16_RAM) AM_BASE(&wecleman_roadram) AM_SIZE(&wecleman_roadram_size)	/* Road */
-	AM_RANGE(0x060000, 0x060fff) AM_WRITE(MWA16_RAM)	/* RAM */
-	AM_RANGE(0x040000, 0x043fff) AM_WRITE(sharedram_w)	/* Shared with main CPU */
+static ADDRESS_MAP_START( hotchase_sub_map, ADDRESS_SPACE_PROGRAM, 16 )
+	AM_RANGE(0x000000, 0x01ffff) AM_ROM	/* ROM */
+	AM_RANGE(0x020000, 0x020fff) AM_RAM AM_BASE(&wecleman_roadram) AM_SIZE(&wecleman_roadram_size)	/* Road */
+	AM_RANGE(0x040000, 0x043fff) AM_RAM AM_SHARE(1)	/* Shared with main CPU */
+	AM_RANGE(0x060000, 0x060fff) AM_RAM				/* RAM */
 ADDRESS_MAP_END
 
 
@@ -1051,7 +1008,7 @@ INPUT_PORTS_END
                             WEC Le Mans 24 Graphics Layout
 ***************************************************************************/
 
-static gfx_layout wecleman_bg_layout =
+static const gfx_layout wecleman_bg_layout =
 {
 	8,8,
 	8*0x8000*3/(8*8*3),
@@ -1062,14 +1019,9 @@ static gfx_layout wecleman_bg_layout =
 	8*8
 };
 
-/* We draw the road, made of 512 pixel lines, using 64x1 tiles */
-static gfx_layout wecleman_road_layout =
+static const UINT32 wecleman_road_layout_xoffset[64] =
 {
-	64,1,
-	8*0x4000*3/(64*1*3),
-	3,
-	{ 0x4000*8*2,0x4000*8*1,0x4000*8*0 },
-	{0,7,6,5,4,3,2,1,
+	 0,7,6,5,4,3,2,1,
 	 8,15,14,13,12,11,10,9,
 	 16,23,22,21,20,19,18,17,
 	 24,31,30,29,28,27,26,25,
@@ -1077,12 +1029,24 @@ static gfx_layout wecleman_road_layout =
 	 0+32,7+32,6+32,5+32,4+32,3+32,2+32,1+32,
 	 8+32,15+32,14+32,13+32,12+32,11+32,10+32,9+32,
 	 16+32,23+32,22+32,21+32,20+32,19+32,18+32,17+32,
-	 24+32,31+32,30+32,29+32,28+32,27+32,26+32,25+32},
-	{0},
-	64*1
+	 24+32,31+32,30+32,29+32,28+32,27+32,26+32,25+32
 };
 
-static gfx_decode wecleman_gfxdecodeinfo[] =
+/* We draw the road, made of 512 pixel lines, using 64x1 tiles */
+static const gfx_layout wecleman_road_layout =
+{
+	64,1,
+	8*0x4000*3/(64*1*3),
+	3,
+	{ 0x4000*8*2,0x4000*8*1,0x4000*8*0 },
+	EXTENDED_XOFFS,
+	{0},
+	64*1,
+	wecleman_road_layout_xoffset,
+	NULL
+};
+
+static const gfx_decode wecleman_gfxdecodeinfo[] =
 {
 	/* REGION_GFX1 holds sprite, which are not decoded here */
 	{ REGION_GFX2, 0, &wecleman_bg_layout,   0, 2048/8 },	/* [0] bg + fg + txt */
@@ -1095,23 +1059,30 @@ static gfx_decode wecleman_gfxdecodeinfo[] =
                             Hot Chase Graphics Layout
 ***************************************************************************/
 
+static const UINT32 hotchase_road_layout_xoffset[64] =
+{
+	  0*4,0*4,1*4,1*4,2*4,2*4,3*4,3*4,4*4,4*4,5*4,5*4,6*4,6*4,7*4,7*4,
+	  8*4,8*4,9*4,9*4,10*4,10*4,11*4,11*4,12*4,12*4,13*4,13*4,14*4,14*4,15*4,15*4,
+	 16*4,16*4,17*4,17*4,18*4,18*4,19*4,19*4,20*4,20*4,21*4,21*4,22*4,22*4,23*4,23*4,
+	 24*4,24*4,25*4,25*4,26*4,26*4,27*4,27*4,28*4,28*4,29*4,29*4,30*4,30*4,31*4,31*4
+};
+
 /* We draw the road, made of 512 pixel lines, using 64x1 tiles */
 /* tiles are doubled horizontally */
-static gfx_layout hotchase_road_layout =
+static const gfx_layout hotchase_road_layout =
 {
 	64,1,
 	RGN_FRAC(1,1),
 	4,
 	{ 0, 1, 2, 3 },
-	{ 0*4,0*4,1*4,1*4,2*4,2*4,3*4,3*4,4*4,4*4,5*4,5*4,6*4,6*4,7*4,7*4,
-	  8*4,8*4,9*4,9*4,10*4,10*4,11*4,11*4,12*4,12*4,13*4,13*4,14*4,14*4,15*4,15*4,
-	 16*4,16*4,17*4,17*4,18*4,18*4,19*4,19*4,20*4,20*4,21*4,21*4,22*4,22*4,23*4,23*4,
-	 24*4,24*4,25*4,25*4,26*4,26*4,27*4,27*4,28*4,28*4,29*4,29*4,30*4,30*4,31*4,31*4 },
+	EXTENDED_XOFFS,
 	{0},
-	32*4
+	32*4,
+	hotchase_road_layout_xoffset,
+	NULL
 };
 
-static gfx_decode hotchase_gfxdecodeinfo[] =
+static const gfx_decode hotchase_gfxdecodeinfo[] =
 {
 	/* REGION_GFX1 holds sprite, which are not decoded here */
 	/* REGION_GFX2 and 3 are for the 051316 */
@@ -1137,7 +1108,7 @@ static struct K007232_interface wecleman_k007232_interface =
 	REGION_SOUND1	/* but the 2 channels use different ROMs !*/
 };
 
-MACHINE_INIT( wecleman )
+MACHINE_RESET( wecleman )
 {
 	K007232_set_bank( 0, 0, 1 );
 }
@@ -1146,11 +1117,11 @@ static MACHINE_DRIVER_START( wecleman )
 
 	/* basic machine hardware */
 	MDRV_CPU_ADD(M68000, 10000000)	/* Schems show 10MHz */
-	MDRV_CPU_PROGRAM_MAP(wecleman_readmem,wecleman_writemem)
+	MDRV_CPU_PROGRAM_MAP(wecleman_map,0)
 	MDRV_CPU_VBLANK_INT(wecleman_interrupt,5 + 1)	/* in order to read the inputs once per frame */
 
 	MDRV_CPU_ADD(M68000, 10000000)	/* Schems show 10MHz */
-	MDRV_CPU_PROGRAM_MAP(wecleman_sub_readmem,wecleman_sub_writemem)
+	MDRV_CPU_PROGRAM_MAP(wecleman_sub_map,0)
 
 	/* Schems: can be reset, no nmi, soundlatch, 3.58MHz */
 	MDRV_CPU_ADD(Z80, 3579545)
@@ -1161,7 +1132,7 @@ static MACHINE_DRIVER_START( wecleman )
 	MDRV_VBLANK_DURATION(DEFAULT_60HZ_VBLANK_DURATION)
 	MDRV_INTERLEAVE(100)
 
-	MDRV_MACHINE_INIT(wecleman)
+	MDRV_MACHINE_RESET(wecleman)
 
 	/* video hardware */
 	MDRV_VIDEO_ATTRIBUTES(VIDEO_TYPE_RASTER | VIDEO_RGB_DIRECT)
@@ -1201,11 +1172,11 @@ static MACHINE_DRIVER_START( hotchase )
 
 	/* basic machine hardware */
 	MDRV_CPU_ADD(M68000, 10000000)	/* 10 MHz - PCB is drawn in one set's readme */
-	MDRV_CPU_PROGRAM_MAP(hotchase_readmem,hotchase_writemem)
+	MDRV_CPU_PROGRAM_MAP(hotchase_map,0)
 	MDRV_CPU_VBLANK_INT(irq4_line_hold,1)
 
 	MDRV_CPU_ADD(M68000, 10000000)	/* 10 MHz - PCB is drawn in one set's readme */
-	MDRV_CPU_PROGRAM_MAP(hotchase_sub_readmem,hotchase_sub_writemem)
+	MDRV_CPU_PROGRAM_MAP(hotchase_sub_map,0)
 
 	MDRV_CPU_ADD(M6809, 3579545 / 2)
 	/* audio CPU */	/* 3.579/2 MHz - PCB is drawn in one set's readme */
