@@ -22,7 +22,6 @@ TODO:
 ***************************************************************************/
 
 #include "driver.h"
-#include "vidhrdw/generic.h"
 #include "cpu/i8039/i8039.h"
 #include "sound/ay8910.h"
 #include "sound/samples.h"
@@ -469,7 +468,7 @@ INPUT_PORTS_START( fghtbskt )
 INPUT_PORTS_END
 
 
-static gfx_layout charlayout =
+static const gfx_layout charlayout =
 {
 	8,8,
 	RGN_FRAC(1,2),
@@ -480,7 +479,7 @@ static gfx_layout charlayout =
 	8*8
 };
 
-static gfx_layout tilelayout =
+static const gfx_layout tilelayout =
 {
 	8,8,
 	RGN_FRAC(1,3),
@@ -491,7 +490,7 @@ static gfx_layout tilelayout =
 	8*8
 };
 
-static gfx_layout spritelayout =
+static const gfx_layout spritelayout =
 {
 	16,16,
 	RGN_FRAC(1,6),
@@ -505,7 +504,7 @@ static gfx_layout spritelayout =
 	16*8
 };
 
-static gfx_decode gfxdecodeinfo[] =
+static const gfx_decode gfxdecodeinfo[] =
 {
 	{ REGION_GFX1, 0, &charlayout,   256, 1 },
 	{ REGION_GFX2, 0, &tilelayout,     0, 32 },
@@ -513,7 +512,7 @@ static gfx_decode gfxdecodeinfo[] =
 	{ -1 } /* end of array */
 };
 
-static gfx_decode fghtbskt_gfxdecodeinfo[] =
+static const gfx_decode fghtbskt_gfxdecodeinfo[] =
 {
 	{ REGION_GFX1, 0, &charlayout,   16, 1 },
 	{ REGION_GFX2, 0, &tilelayout,    0, 32 },
