@@ -842,7 +842,7 @@ struct ES8712interface es8712_interface =
 };
 
 
-static gfx_layout tiles8x8_layout =
+static const gfx_layout tiles8x8_layout =
 {
 	8,8,
 	RGN_FRAC(1,2),
@@ -853,7 +853,7 @@ static gfx_layout tiles8x8_layout =
 	16*8
 };
 
-static gfx_decode gfxdecodeinfo[] =
+static const gfx_decode gfxdecodeinfo[] =
 {
 	{ REGION_GFX1, 0, &tiles8x8_layout, 0, 16 },
 	{ REGION_GFX2, 0, &tiles8x8_layout, 0, 16 },
