@@ -158,15 +158,14 @@ Stephh's notes (based on the games Z80 code and some tests) :
 ***************************************************************************/
 
 #include "driver.h"
-#include "vidhrdw/generic.h"
 #include "sound/ay8910.h"
 #include "sound/discrete.h"
 
-extern unsigned char *wiz_videoram2;
-extern unsigned char *wiz_colorram2;
-extern unsigned char *wiz_attributesram;
-extern unsigned char *wiz_attributesram2;
-extern unsigned char *wiz_sprite_bank;
+extern UINT8 *wiz_videoram2;
+extern UINT8 *wiz_colorram2;
+extern UINT8 *wiz_attributesram;
+extern UINT8 *wiz_attributesram2;
+extern UINT8 *wiz_sprite_bank;
 
 WRITE8_HANDLER( wiz_char_bank_select_w );
 WRITE8_HANDLER( wiz_attributes_w );
@@ -584,7 +583,7 @@ INPUT_PORTS_END
 
 
 
-static struct GfxLayout charlayout =
+static const gfx_layout charlayout =
 {
 	8,8,	/* 8*8 characters */
 	256,	/* 256 characters */
@@ -596,7 +595,7 @@ static struct GfxLayout charlayout =
 };
 
 
-static struct GfxLayout spritelayout =
+static const gfx_layout spritelayout =
 {
 	16,16,	/* 16*16 sprites */
 	256,	/* 256 sprites */
@@ -610,7 +609,7 @@ static struct GfxLayout spritelayout =
 };
 
 
-static struct GfxDecodeInfo wiz_gfxdecodeinfo[] =
+static const gfx_decode wiz_gfxdecodeinfo[] =
 {
 	{ REGION_GFX1, 0x0000, &charlayout,   0, 32 },
 	{ REGION_GFX1, 0x0800, &charlayout,   0, 32 },
@@ -624,7 +623,7 @@ static struct GfxDecodeInfo wiz_gfxdecodeinfo[] =
 	{ -1 }	/* end of array */
 };
 
-static struct GfxDecodeInfo stinger_gfxdecodeinfo[] =
+static const gfx_decode stinger_gfxdecodeinfo[] =
 {
 	{ REGION_GFX1, 0x0000, &charlayout,   0, 32 },
 	{ REGION_GFX1, 0x0800, &charlayout,   0, 32 },
@@ -658,7 +657,6 @@ DISCRETE_SOUND_START(stinger_discrete_interface)
 
 #define STINGER_SHOT_OUT	NODE_90
 #define STINGER_BOOM_OUT	NODE_91
-#define STINGER_FINAL_GAIN	NODE_98
 #define STINGER_FINAL_MIX	NODE_99
 
 	/* triggers are interleaved to give each circuit sufficient time to reset */
@@ -700,8 +698,8 @@ DISCRETE_SOUND_START(stinger_discrete_interface)
 	/*--------------------------------------- */
 
 	DISCRETE_ADDER2	(STINGER_FINAL_MIX, 1, STINGER_SHOT_OUT, STINGER_BOOM_OUT)
-	DISCRETE_GAIN	(STINGER_FINAL_GAIN, STINGER_FINAL_MIX, 5.0)
-	DISCRETE_OUTPUT	(STINGER_FINAL_GAIN, 100)
+
+	DISCRETE_OUTPUT	(STINGER_FINAL_MIX, 5)
 
 DISCRETE_SOUND_END
 /** ANALOG SOUND ENDS */
@@ -908,7 +906,7 @@ ROM_START( wizt )
 ROM_END
 
 ROM_START( stinger )
-	ROM_REGION( 2*0x10000, REGION_CPU1, 0 )	/* 64k for code + 64k for decrypted opcodes */
+	ROM_REGION( 0x10000, REGION_CPU1, 0 )	/* 64k for code + 64k for decrypted opcodes */
 	ROM_LOAD( "1-5j.bin",     0x0000, 0x2000, CRC(1a2ca600) SHA1(473e89f2c49f6e6f38df5d6fc2267ffecf84c6c8) )	/* encrypted */
 	ROM_LOAD( "2-6j.bin",     0x2000, 0x2000, CRC(957cd39c) SHA1(38bb589b3bfd962415b31d1151adf4bdb661122f) )	/* encrypted */
 	ROM_LOAD( "3-8j.bin",     0x4000, 0x2000, CRC(404c932e) SHA1(c23eac49e06ff38564062c0e8c8cdadf877f1d6a) )	/* encrypted */
@@ -935,7 +933,7 @@ ROM_START( stinger )
 ROM_END
 
 ROM_START( stinger2 )
-	ROM_REGION( 2*0x10000, REGION_CPU1, 0 )	/* 64k for code + 64k for decrypted opcodes */
+	ROM_REGION( 0x10000, REGION_CPU1, 0 )	/* 64k for code + 64k for decrypted opcodes */
 	ROM_LOAD( "n1.bin",       0x0000, 0x2000, CRC(f2d2790c) SHA1(0e5e92ef45b5bc27b0818f83c89b3bda0e701403) )	/* encrypted */
 	ROM_LOAD( "n2.bin",       0x2000, 0x2000, CRC(8fd2d8d8) SHA1(d3318a81fddeb3fa50d01569c1e1145e26ce7277) )	/* encrypted */
 	ROM_LOAD( "n3.bin",       0x4000, 0x2000, CRC(f1794d36) SHA1(7954500f489c0bc58cda8e7ffc2e4474759fdc33) )	/* encrypted */
@@ -1020,31 +1018,31 @@ ROM_END
 
 static DRIVER_INIT( stinger )
 {
-	static const unsigned char swap_xor_table[4][4] =
+	static const UINT8 swap_xor_table[4][4] =
 	{
 		{ 7,3,5, 0xa0 },
 		{ 3,7,5, 0x88 },
 		{ 5,3,7, 0x80 },
 		{ 5,7,3, 0x28 }
 	};
-	unsigned char *rom = memory_region(REGION_CPU1);
-	int diff = memory_region_length(REGION_CPU1) / 2;
+	UINT8 *rom = memory_region(REGION_CPU1);
+	int size = memory_region_length(REGION_CPU1);
+	UINT8 *decrypt = auto_malloc(size);
 	int A;
-	const unsigned char *tbl;
+	const UINT8 *tbl;
 
-
-	memory_set_opcode_base(0,rom+diff);
+	memory_set_decrypted_region(0, 0x0000, 0xffff, decrypt);
 
 	for (A = 0x0000;A < 0x10000;A++)
 	{
 		int row;
-		unsigned char src;
+		UINT8 src;
 
 
 		if (A & 0x2040)
 		{
 			/* not encrypted */
-			rom[A+diff] = rom[A];
+			decrypt[A] = rom[A];
 		}
 		else
 		{
@@ -1055,7 +1053,7 @@ static DRIVER_INIT( stinger )
 
 			/* decode the opcodes */
 			tbl = swap_xor_table[row];
-			rom[A+diff] = BITSWAP8(src,tbl[0],6,tbl[1],4,tbl[2],2,1,0) ^ tbl[3];
+			decrypt[A] = BITSWAP8(src,tbl[0],6,tbl[1],4,tbl[2],2,1,0) ^ tbl[3];
 		}
 	}
 }
@@ -1073,11 +1071,11 @@ static DRIVER_INIT( wiz )
 }
 
 
-GAMEX(1983, stinger,  0,       stinger, stinger,  stinger, ROT90,  "Seibu Denshi", "Stinger", GAME_IMPERFECT_SOUND )
-GAMEX(1983, stinger2, stinger, stinger, stinger2, stinger, ROT90,  "Seibu Denshi", "Stinger (prototype?)", GAME_IMPERFECT_SOUND )
-GAMEX(1984, scion,    0,       scion,   scion,    scion,   ROT0,   "Seibu Denshi", "Scion", GAME_IMPERFECT_SOUND | GAME_IMPERFECT_COLORS )
-GAMEX(1984, scionc,   scion,   scion,   scion,    scion,   ROT0,   "Seibu Denshi (Cinematronics license)", "Scion (Cinematronics)", GAME_IMPERFECT_SOUND | GAME_IMPERFECT_COLORS )
-GAME( 1984, kungfut,  0,       kungfut, kungfut,  0,       ROT0,   "Seibu Kaihatsu Inc.", "Kung-Fu Taikun" )
-GAME( 1984, kungfuta, kungfut, kungfut, kungfut,  0,       ROT0,   "Seibu Kaihatsu Inc.", "Kung-Fu Taikun (alt)" ) /* board was a bootleg but set might still be original */
-GAME( 1985, wiz,      0,       wiz,     wiz,      wiz,     ROT270, "Seibu Kaihatsu Inc.", "Wiz" )
-GAME( 1985, wizt,     wiz,     wiz,     wiz,      wiz,     ROT270, "[Seibu] (Taito license)", "Wiz (Taito)" )
+GAME( 1983, stinger,  0,       stinger, stinger,  stinger, ROT90,  "Seibu Denshi", "Stinger", GAME_IMPERFECT_SOUND )
+GAME( 1983, stinger2, stinger, stinger, stinger2, stinger, ROT90,  "Seibu Denshi", "Stinger (prototype?)", GAME_IMPERFECT_SOUND )
+GAME( 1984, scion,    0,       scion,   scion,    scion,   ROT0,   "Seibu Denshi", "Scion", GAME_IMPERFECT_SOUND | GAME_IMPERFECT_COLORS )
+GAME( 1984, scionc,   scion,   scion,   scion,    scion,   ROT0,   "Seibu Denshi (Cinematronics license)", "Scion (Cinematronics)", GAME_IMPERFECT_SOUND | GAME_IMPERFECT_COLORS )
+GAME( 1984, kungfut,  0,       kungfut, kungfut,  0,       ROT0,   "Seibu Kaihatsu Inc.", "Kung-Fu Taikun", 0 )
+GAME( 1984, kungfuta, kungfut, kungfut, kungfut,  0,       ROT0,   "Seibu Kaihatsu Inc.", "Kung-Fu Taikun (alt)" , 0) /* board was a bootleg but set might still be original */
+GAME( 1985, wiz,      0,       wiz,     wiz,      wiz,     ROT270, "Seibu Kaihatsu Inc.", "Wiz", 0 )
+GAME( 1985, wizt,     wiz,     wiz,     wiz,      wiz,     ROT270, "[Seibu] (Taito license)", "Wiz (Taito)", 0 )
