@@ -38,7 +38,6 @@
 *******************************************************************************/
 
 #include "driver.h"
-#include "vidhrdw/generic.h"
 #include "cpu/m68000/m68000.h"
 #include "cpu/z80/z80.h"
 #include "wwfwfest.h"
@@ -324,7 +323,7 @@ INPUT_PORTS_END
 /*******************************************************************************
  Graphic Decoding
 *******************************************************************************/
-static gfx_layout tiles8x8_layout =
+static const gfx_layout tiles8x8_layout =
 {
 	8,8,
 	RGN_FRAC(1,1),
@@ -335,7 +334,7 @@ static gfx_layout tiles8x8_layout =
 	32*8
 };
 
-static gfx_layout tile_layout =
+static const gfx_layout tile_layout =
 {
 	16,16,	/* 16*16 tiles */
 	4096,	/* 8192 tiles */
@@ -348,7 +347,7 @@ static gfx_layout tile_layout =
 	64*8	/* every tile takes 64 consecutive bytes */
 };
 
-static gfx_layout sprite_layout = {
+static const gfx_layout sprite_layout = {
 	16,16,	/* 16*16 tiles */
 	RGN_FRAC(1,4),
 	4,	/* 4 bits per pixel */
@@ -360,7 +359,7 @@ static gfx_layout sprite_layout = {
 	32*8	/* every tile takes 32 consecutive bytes */
 };
 
-static gfx_decode gfxdecodeinfo[] =
+static const gfx_decode gfxdecodeinfo[] =
 {
 	{ REGION_GFX1, 0, &tiles8x8_layout, 0x0000, 16 },
 	{ REGION_GFX2, 0, &sprite_layout,   0x0400, 16 },
