@@ -23,7 +23,7 @@ TODO:
 #include "cpu/z80/z80.h"
 #include "sound/sn76496.h"
 
-data8_t *xyonix_vidram;
+UINT8 *xyonix_vidram;
 
 /* in vidhrdw/xyonix.c */
 PALETTE_INIT( xyonix );
@@ -42,12 +42,12 @@ static WRITE8_HANDLER( xyonix_irqack_w )
 
 static int e0_data,credits,coins;
 
-void handle_coins(int coin)
+static void handle_coins(int coin)
 {
-	int coinage_table[4][2] = {{2,3},{2,1},{1,2},{1,1}};
+	static const int coinage_table[4][2] = {{2,3},{2,1},{1,2},{1,1}};
 	int tmp = 0;
 
-/*  usrintf_showmessage("Coin %d",coin); */
+/*  ui_popup("Coin %d",coin); */
 
 	if (coin & 1)	/* Coin 2 ! */
 	{
@@ -135,7 +135,7 @@ READ8_HANDLER ( xyonix_io_r )
 	}
 
 /*  logerror ("xyonix_port_e0_r - PC = %04x - port = %02x\n", regPC, e0_data); */
-/*  usrintf_showmessage("%02x",e0_data); */
+/*  ui_popup("%02x",e0_data); */
 
 	return 0xff;
 }
@@ -223,7 +223,7 @@ INPUT_PORTS_END
 
 /* GFX Decode ****************************************************************/
 
-static struct GfxLayout charlayout =
+static const gfx_layout charlayout =
 {
 	4,8,
 	RGN_FRAC(1,2),
@@ -234,7 +234,7 @@ static struct GfxLayout charlayout =
 	4*16
 };
 
-static struct GfxDecodeInfo gfxdecodeinfo[] =
+static const gfx_decode gfxdecodeinfo[] =
 {
 	{ REGION_GFX1, 0, &charlayout, 0, 16 },
 	{ -1 }
@@ -249,7 +249,7 @@ static MACHINE_DRIVER_START( xyonix )
 	MDRV_CPU_PROGRAM_MAP(readmem,writemem)
 	MDRV_CPU_IO_MAP(port_readmem,port_writemem)
 	MDRV_CPU_VBLANK_INT(nmi_line_pulse,1)
-	MDRV_CPU_PERIODIC_INT(irq0_line_assert,4*60)	/* ?? controls music tempo */
+	MDRV_CPU_PERIODIC_INT(irq0_line_assert,TIME_IN_HZ(4*60))	/* ?? controls music tempo */
 
 	MDRV_FRAMES_PER_SECOND(60)
 	MDRV_VBLANK_DURATION(DEFAULT_60HZ_VBLANK_DURATION)
@@ -291,4 +291,4 @@ ROM_END
 
 /* GAME drivers **************************************************************/
 
-GAME( 1989, xyonix, 0, xyonix, xyonix, 0, ROT0, "Philko", "Xyonix" )
+GAME( 1989, xyonix, 0, xyonix, xyonix, 0, ROT0, "Philko", "Xyonix", 0 )
