@@ -13,8 +13,8 @@ Sound Chips  :  OKI M5205 + YM3812
 ---------------------------------------------------------------------------
 Year + Game         Board#
 ---------------------------------------------------------------------------
-95 Cannon Ball      ?
-95 Magix / Rock     ?
+95 Cannon Ball      YS-ROCK-970712
+95 Magix / Rock     YS-ROCK-970712
 ---------------------------------------------------------------------------
 
 Notes:
@@ -52,7 +52,7 @@ VIDEO_UPDATE( yunsung8 );
 
 
 
-MACHINE_INIT( yunsung8 )
+MACHINE_RESET( yunsung8 )
 {
 	unsigned char *RAM = memory_region(REGION_CPU1) + 0x24000;
 
@@ -378,7 +378,7 @@ INPUT_PORTS_END
 ***************************************************************************/
 
 /* 8x8x4 tiles in 2 roms */
-static gfx_layout layout_8x8x4 =
+static const gfx_layout layout_8x8x4 =
 {
 	8,8,
 	RGN_FRAC(1,2),
@@ -390,7 +390,7 @@ static gfx_layout layout_8x8x4 =
 };
 
 /* 8x8x8 tiles in 4 roms */
-static gfx_layout layout_8x8x8 =
+static const gfx_layout layout_8x8x8 =
 {
 	8,8,
 	RGN_FRAC(1,4),
@@ -402,7 +402,7 @@ static gfx_layout layout_8x8x8 =
 	8*8*8/4
 };
 
-static gfx_decode yunsung8_gfxdecodeinfo[] =
+static const gfx_decode yunsung8_gfxdecodeinfo[] =
 {
 	{ REGION_GFX1, 0, &layout_8x8x8, 0, 0x08 }, /* [0] Tiles (Background) */
 	{ REGION_GFX2, 0, &layout_8x8x4, 0,	0x40 }, /* [1] Tiles (Text) */
@@ -455,7 +455,7 @@ static MACHINE_DRIVER_START( yunsung8 )
 	MDRV_FRAMES_PER_SECOND(60)
 	MDRV_VBLANK_DURATION(DEFAULT_60HZ_VBLANK_DURATION)
 
-	MDRV_MACHINE_INIT(yunsung8)
+	MDRV_MACHINE_RESET(yunsung8)
 
 	/* video hardware */
 	MDRV_VIDEO_ATTRIBUTES(VIDEO_TYPE_RASTER)
