@@ -155,7 +155,6 @@ NMI causes a ROM/RAM test.
 
 
 #include "driver.h"
-#include "vidhrdw/generic.h"
 #include "machine/segacrpt.h"
 #include "sound/sn76496.h"
 #include "sound/samples.h"
@@ -1042,7 +1041,7 @@ gfx_layout zaxxon_charlayout2 =
 	8*8 /* every char takes 8 consecutive bytes */
 };
 
-static gfx_layout zaxxon_spritelayout =
+static const gfx_layout zaxxon_spritelayout =
 {
 	32,32,	/* 32*32 sprites */
 	64, /* 64 sprites */
@@ -1059,7 +1058,7 @@ static gfx_layout zaxxon_spritelayout =
 	128*8	/* every sprite takes 128 consecutive bytes */
 };
 
-static gfx_layout congo_spritelayout =
+static const gfx_layout congo_spritelayout =
 {
 	32,32,	/* 32*32 sprites */
 	128,	/* 128 sprites */
@@ -1078,7 +1077,7 @@ static gfx_layout congo_spritelayout =
 
 /* Graphics Decode Info */
 
-static gfx_decode gfxdecodeinfo[] =
+static const gfx_decode gfxdecodeinfo[] =
 {
 	{ REGION_GFX1, 0, &zaxxon_charlayout1,	 0, 32 },	/* characters */
 	{ REGION_GFX2, 0, &zaxxon_charlayout2,	 0, 32 },	/* background tiles */
@@ -1086,7 +1085,7 @@ static gfx_decode gfxdecodeinfo[] =
 	{ -1 } /* end of array */
 };
 
-static gfx_decode congo_gfxdecodeinfo[] =
+static const gfx_decode congo_gfxdecodeinfo[] =
 {
 	{ REGION_GFX1, 0, &zaxxon_charlayout1,	 0, 32 },	/* characters */
 	{ REGION_GFX2, 0, &zaxxon_charlayout2,	 0, 32 },	/* background tiles */
@@ -1124,10 +1123,10 @@ static const char *congo_sample_names[] =
 {
 	"*congo",
 	"gorilla.wav",
-	"bass.wav",
-	"congaa.wav",
-	"congab.wav",
 	"rim.wav",
+	"congah.wav",
+	"congal.wav",
+	"bass.wav",
 	0
 };
 
@@ -1150,17 +1149,17 @@ static INTERRUPT_GEN( zaxxon_interrupt )
 
 /* Machine Initialization */
 
-MACHINE_INIT( zaxxon )
+MACHINE_RESET( zaxxon )
 {
 	zaxxon_vid_type = 0;
 }
 
-MACHINE_INIT( congo )
+MACHINE_RESET( congo )
 {
 	zaxxon_vid_type = 1;
 }
 
-MACHINE_INIT( futspy )
+MACHINE_RESET( futspy )
 {
 	zaxxon_vid_type = 2;
 }
@@ -1176,7 +1175,7 @@ static MACHINE_DRIVER_START( root )
 	MDRV_FRAMES_PER_SECOND(60)
 	MDRV_VBLANK_DURATION(DEFAULT_60HZ_VBLANK_DURATION)
 
-	MDRV_MACHINE_INIT(zaxxon)
+	MDRV_MACHINE_RESET(zaxxon)
 
 	/* video hardware */
 	MDRV_VIDEO_ATTRIBUTES(VIDEO_TYPE_RASTER)
@@ -1232,7 +1231,7 @@ static MACHINE_DRIVER_START( congo )
 	MDRV_CPU_PROGRAM_MAP(congo_snd_readmem, congo_snd_writemem)
 	MDRV_CPU_VBLANK_INT(irq0_line_hold, 4)
 
-	MDRV_MACHINE_INIT(congo)
+	MDRV_MACHINE_RESET(congo)
 
 	MDRV_GFXDECODE(congo_gfxdecodeinfo)
 
@@ -1244,7 +1243,7 @@ static MACHINE_DRIVER_START( congo )
 	MDRV_SOUND_ADD(SN76496, 4000000)
 	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 1.0)
 
-	MDRV_SOUND_ADD(SN76496, 4000000)
+	MDRV_SOUND_ADD(SN76496, 4000000/4)
 	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 1.0)
 
 	MDRV_SOUND_ADD(SAMPLES, 0)
@@ -1258,7 +1257,7 @@ static MACHINE_DRIVER_START( futspy )
 	MDRV_CPU_MODIFY("main")
 	MDRV_CPU_PROGRAM_MAP(readmem, futspy_writemem)
 
-	MDRV_MACHINE_INIT(futspy)
+	MDRV_MACHINE_RESET(futspy)
 
 	MDRV_GFXDECODE(congo_gfxdecodeinfo)
 
@@ -1338,7 +1337,7 @@ ROM_START( zaxxon2 )
 ROM_END
 
 ROM_START( zaxxonb )
-	ROM_REGION( 2*0x10000, REGION_CPU1, 0 )	/* 64k for code + 64k for decrypted opcodes */
+	ROM_REGION( 0x10000, REGION_CPU1, 0 )	/* 64k for code + 64k for decrypted opcodes */
 	ROM_LOAD( "zaxxonb.3",    0x0000, 0x2000, CRC(125bca1c) SHA1(f4160966d42e5282736cde8a276204ba8910ca61) )
 	ROM_LOAD( "zaxxonb.2",    0x2000, 0x2000, CRC(c088df92) SHA1(c0c6cd8dcf6db65129980331fa9ecc3800b63436) )
 	ROM_LOAD( "zaxxonb.1",    0x4000, 0x1000, CRC(e7bdc417) SHA1(209f0d259f60b984c84229bb31af1ef939adc73e) )
@@ -1370,7 +1369,7 @@ ROM_START( zaxxonb )
 ROM_END
 
 ROM_START( szaxxon )
-	ROM_REGION( 2*0x10000, REGION_CPU1, 0 )	/* 64k for code + 64k for decrypted opcodes */
+	ROM_REGION( 0x10000, REGION_CPU1, 0 )	/* 64k for code + 64k for decrypted opcodes */
 	ROM_LOAD( "suzaxxon.3",   0x0000, 0x2000, CRC(af7221da) SHA1(b5d3beb296d52ed69b4ceacf329c20a72e3a1dce) )
 	ROM_LOAD( "suzaxxon.2",   0x2000, 0x2000, CRC(1b90fb2a) SHA1(afb2bd2ffee3f5e589064f59b6ac21ed915094df) )
 	ROM_LOAD( "suzaxxon.1",   0x4000, 0x1000, CRC(07258b4a) SHA1(91e3a0c0df6c9cf66980d1ffcc3830ffdbef8c2f) )
@@ -1402,7 +1401,7 @@ ROM_START( szaxxon )
 ROM_END
 
 ROM_START( razmataz )
-	ROM_REGION( 2*0x10000, REGION_CPU1, 0 )	/* 64k for code + 64k for decrypted opcodes */
+	ROM_REGION( 0x10000, REGION_CPU1, 0 )	/* 64k for code + 64k for decrypted opcodes */
 	ROM_LOAD( "u27",           0x0000, 0x2000, CRC(254f350f) SHA1(f8e84778b7ffc4da76e97992f01c742c212480cf) )
 	ROM_LOAD( "u28",           0x2000, 0x2000, CRC(3a1eaa99) SHA1(d1f2a61a8548135c9754097aa468672616244710) )
 	ROM_LOAD( "u29",           0x4000, 0x2000, CRC(0ee67e78) SHA1(c6c703000a4e0da8af65be53b2a6b2ef67860c30) )
@@ -1438,7 +1437,7 @@ ROM_START( razmataz )
 ROM_END
 
 ROM_START( ixion )
-	ROM_REGION( 2*0x10000, REGION_CPU1, 0 )	/* 64k for code + 64k for decrypted opcodes */
+	ROM_REGION( 0x10000, REGION_CPU1, 0 )	/* 64k for code + 64k for decrypted opcodes */
 	ROM_LOAD( "1937d.u27",           0x0000, 0x2000, CRC(f447aac5) SHA1(f6ec02f20482649ba1765254e0e67a8593075092) )
 	ROM_LOAD( "1938b.u28",           0x2000, 0x2000, CRC(17f48640) SHA1(d661e8ae0747c2c526360cb72e403deba7a98e71) )
 	ROM_LOAD( "1955b.u29",           0x4000, 0x1000, CRC(78636ec6) SHA1(afca6418221e700749031cb3fa738907d77c1566) )
@@ -1548,7 +1547,7 @@ ROM_START( tiptop )
 ROM_END
 
 ROM_START( futspy )
-	ROM_REGION( 2*0x10000, REGION_CPU1, 0 )	/* 64k for code + 64k for decrypted opcodes */
+	ROM_REGION( 0x10000, REGION_CPU1, 0 )	/* 64k for code + 64k for decrypted opcodes */
 	ROM_LOAD( "fs_snd.u27",   0x0000, 0x2000, CRC(7578fe7f) SHA1(ab42bdf74b07c1ba5337c3d34647d3ee16f9db05) )
 	ROM_LOAD( "fs_snd.u28",   0x2000, 0x2000, CRC(8ade203c) SHA1(f095f4019befff7af4203c886ef42357f79592a1) )
 	ROM_LOAD( "fs_snd.u29",   0x4000, 0x1000, CRC(734299c3) SHA1(12acf71d9d00e0e0df29c4d8c397ad407266b364) )
@@ -1627,9 +1626,10 @@ static DRIVER_INIT( zaxxonb )
 
 	int A;
 	UINT8 *rom = memory_region(REGION_CPU1);
-	int diff = memory_region_length(REGION_CPU1) / 2;
+	int size = memory_region_length(REGION_CPU1);
+	UINT8 *decrypt = auto_malloc(size);
 
-	memory_set_opcode_base(0, rom + diff);
+	memory_set_decrypted_region(0, 0x0000, 0x7fff, decrypt);
 
 	for (A = 0x0000; A < 0x8000; A++)
 	{
@@ -1652,7 +1652,7 @@ static DRIVER_INIT( zaxxonb )
 		/* now decode the opcodes */
 		/* pick the translation table from bits 0, 4, and 8 of the address */
 		i = ((A >> 0) & 1) + (((A >> 4) & 1) << 1) + (((A >> 8) & 1) << 2);
-		rom[A + diff] = src ^ opcode_xortable[i][j];
+		decrypt[A] = src ^ opcode_xortable[i][j];
 	}
 }
 
