@@ -27,7 +27,6 @@ TODO:
 
 ***************************************************************************/
 #include "driver.h"
-#include "vidhrdw/generic.h"
 #include "sound/okim6295.h"
 
 VIDEO_START( zerozone );
@@ -183,7 +182,7 @@ INPUT_PORTS_START( zerozone )
 INPUT_PORTS_END
 
 
-static gfx_layout charlayout =
+static const gfx_layout charlayout =
 {
 	8,8,	/* 8*8 characters */
 	RGN_FRAC(1,1),	/* 4096 characters */
@@ -195,7 +194,7 @@ static gfx_layout charlayout =
 };
 
 
-static gfx_decode gfxdecodeinfo[] =
+static const gfx_decode gfxdecodeinfo[] =
 {
 	{ REGION_GFX1, 0, &charlayout, 0, 256 },         /* sprites & playfield */
 	{ -1 } /* end of array */
