@@ -1,14 +1,24 @@
-/*  hiscore.c
-**  generalized high score save/restore support
-*/
+/***************************************************************************
+
+    hiscore.c
+
+    Manages the hiscore system.
+
+    Copyright (c) 1996-2006, Nicola Salmoria and the MAME Team.
+    Visit http://mamedev.org for licensing and usage restrictions.
+
+***************************************************************************/
 
 #include "driver.h"
 #include "hiscore.h"
+#include "cheat.h"
 
 #define MAX_CONFIG_LINE_SIZE 48
 
 #define VERBOSE 0
 
+static mame_timer *timer;
+
 #if VERBOSE
 #define LOG(x)	logerror x
 #else
@@ -17,17 +27,37 @@
 
 const char *db_filename = "hiscore.dat"; /* high score definition file */
 
+
+struct _memory_range
+{
+	UINT32 cpu, addr, num_bytes, start_value, end_value;
+	struct _memory_range *next;
+};
+typedef struct _memory_range memory_range;
+
+
 static struct
 {
 	int hiscores_have_been_loaded;
-
-	struct mem_range
-	{
-		UINT32 cpu, addr, num_bytes, start_value, end_value;
-		struct mem_range *next;
-	} *mem_range;
+	memory_range *mem_range;
 } state;
 
+
+static int is_highscore_enabled(void)
+{
+	/* disable high score when record/playback is on */
+	if (Machine->record_file != NULL || Machine->playback_file != NULL)
+		return FALSE;
+
+	/* disable high score when cheats are used */
+	if (he_did_cheat != 0)
+		return FALSE;
+
+	return TRUE;
+}
+
+
+
 /*****************************************************************************/
 
 static void copy_to_memory (int cpu, int addr, const UINT8 *source, int num_bytes)
@@ -131,7 +161,7 @@ static int matching_game_name (const char *pBuf, const char *name)
 /* safe_to_load checks the start and end values of each memory range */
 static int safe_to_load (void)
 {
-	struct mem_range *mem_range = state.mem_range;
+	memory_range *mem_range = state.mem_range;
 	while (mem_range)
 	{
 		if (cpunum_read_byte (mem_range->cpu, mem_range->addr) !=
@@ -149,84 +179,138 @@ static int safe_to_load (void)
 	return 1;
 }
 
-/* hs_free disposes of the mem_range linked list */
-static void hs_free (void)
+/* hiscore_free disposes of the mem_range linked list */
+static void hiscore_free (void)
 {
-	struct mem_range *mem_range = state.mem_range;
+	memory_range *mem_range = state.mem_range;
 	while (mem_range)
 	{
-		struct mem_range *next = mem_range->next;
+		memory_range *next = mem_range->next;
 		free (mem_range);
 		mem_range = next;
 	}
 	state.mem_range = NULL;
 }
 
-static void hs_load (void)
+static void hiscore_load (void)
 {
-	mame_file *f = mame_fopen (Machine->gamedrv->name, 0, FILETYPE_HIGHSCORE, 0);
-	state.hiscores_have_been_loaded = 1;
-	LOG(("hs_load\n"));
-	if (f)
+	if (is_highscore_enabled())
 	{
-		struct mem_range *mem_range = state.mem_range;
-		LOG(("loading...\n"));
-		while (mem_range)
+		mame_file *f = mame_fopen (Machine->gamedrv->name, 0, FILETYPE_HIGHSCORE, 0);
+		state.hiscores_have_been_loaded = 1;
+		LOG(("hiscore_load\n"));
+		if (f)
 		{
-			UINT8 *data = malloc (mem_range->num_bytes);
-			if (data)
+			memory_range *mem_range = state.mem_range;
+			LOG(("loading...\n"));
+			while (mem_range)
 			{
-				/*  this buffer will almost certainly be small
-                    enough to be dynamically allocated, but let's
-                    avoid memory trashing just in case
-                */
-				mame_fread (f, data, mem_range->num_bytes);
-				copy_to_memory (mem_range->cpu, mem_range->addr, data, mem_range->num_bytes);
-				free (data);
+				UINT8 *data = malloc (mem_range->num_bytes);
+				if (data)
+				{
+					/*  this buffer will almost certainly be small
+                        enough to be dynamically allocated, but let's
+                        avoid memory trashing just in case
+                    */
+					mame_fread (f, data, mem_range->num_bytes);
+					copy_to_memory (mem_range->cpu, mem_range->addr, data, mem_range->num_bytes);
+					free (data);
+				}
+				mem_range = mem_range->next;
 			}
-			mem_range = mem_range->next;
+			mame_fclose (f);
 		}
-		mame_fclose (f);
 	}
 }
 
-static void hs_save (void)
+static void hiscore_save (void)
 {
-	mame_file *f = mame_fopen (Machine->gamedrv->name, 0, FILETYPE_HIGHSCORE, 1);
-	LOG(("hs_save\n"));
-	if (f)
+	if (is_highscore_enabled())
 	{
-		struct mem_range *mem_range = state.mem_range;
-		LOG(("saving...\n"));
-		while (mem_range)
+		mame_file *f = mame_fopen (Machine->gamedrv->name, 0, FILETYPE_HIGHSCORE, 1);
+		LOG(("hiscore_save\n"));
+		if (f)
 		{
-			UINT8 *data = malloc (mem_range->num_bytes);
-			if (data)
+			memory_range *mem_range = state.mem_range;
+			LOG(("saving...\n"));
+			while (mem_range)
 			{
-				/*  this buffer will almost certainly be small
-                    enough to be dynamically allocated, but let's
-                    avoid memory trashing just in case
-                */
-				copy_from_memory (mem_range->cpu, mem_range->addr, data, mem_range->num_bytes);
-				mame_fwrite(f, data, mem_range->num_bytes);
+				UINT8 *data = malloc (mem_range->num_bytes);
+				if (data)
+				{
+					/*  this buffer will almost certainly be small
+                        enough to be dynamically allocated, but let's
+                        avoid memory trashing just in case
+                    */
+					copy_from_memory (mem_range->cpu, mem_range->addr, data, mem_range->num_bytes);
+					mame_fwrite(f, data, mem_range->num_bytes);
+					free (data);
+				}
+				mem_range = mem_range->next;
 			}
-			mem_range = mem_range->next;
+			mame_fclose(f);
 		}
-		mame_fclose(f);
 	}
 }
 
+
+/* call hiscore_update periodically (i.e. once per frame) */
+static void hiscore_periodic (int param)
+{
+	if (state.mem_range)
+	{
+		if (!state.hiscores_have_been_loaded)
+		{
+			if (safe_to_load())
+			{
+				hiscore_load();
+				timer_enable(timer, FALSE);
+			}
+		}
+	}
+}
+
+
+/* call hiscore_close when done playing game */
+void hiscore_close (void)
+{
+	if (state.hiscores_have_been_loaded) hiscore_save();
+	hiscore_free();
+}
+
+
 /*****************************************************************************/
 /* public API */
 
-/* call hs_open once after loading a game */
-void hs_open (const char *name)
+/* call hiscore_open once after loading a game */
+void hiscore_init (const char *name)
 {
-	mame_file *f = mame_fopen (NULL, db_filename, FILETYPE_HIGHSCORE_DB, 0);
+	memory_range *mem_range = state.mem_range;
+	mame_file *f;
+
+	state.hiscores_have_been_loaded = 0;
+
+	while (mem_range)
+	{
+		cpunum_write_byte(
+			mem_range->cpu,
+			mem_range->addr,
+			~mem_range->start_value
+		);
+
+		cpunum_write_byte(
+			mem_range->cpu,
+			mem_range->addr + mem_range->num_bytes-1,
+			~mem_range->end_value
+		);
+		mem_range = mem_range->next;
+	}
+
 	state.mem_range = NULL;
 
-	LOG(("hs_open: '%s'\n", name));
+	LOG(("hiscore_open: '%s'\n", name));
 
+	f = mame_fopen (NULL, db_filename, FILETYPE_HIGHSCORE_DB, 0);
 	if (f)
 	{
 		char buffer[MAX_CONFIG_LINE_SIZE];
@@ -246,7 +330,7 @@ void hs_open (const char *name)
 			else if (is_mem_range (buffer))
 			{
 				const char *pBuf = buffer;
-				struct mem_range *mem_range = malloc(sizeof(struct mem_range));
+				memory_range *mem_range = malloc(sizeof(memory_range));
 				if (mem_range)
 				{
 					mem_range->cpu = hexstr2num (&pBuf);
@@ -257,7 +341,7 @@ void hs_open (const char *name)
 
 					mem_range->next = NULL;
 					{
-						struct mem_range *last = state.mem_range;
+						memory_range *last = state.mem_range;
 						while (last && last->next) last = last->next;
 						if (last == NULL)
 						{
@@ -273,7 +357,7 @@ void hs_open (const char *name)
 				}
 				else
 				{
-					hs_free();
+					hiscore_free();
 					break;
 				}
 			}
@@ -285,46 +369,9 @@ void hs_open (const char *name)
 		}
 		mame_fclose (f);
 	}
-}
 
-/* call hs_init when emulation starts, and when the game is reset */
-void hs_init (void)
-{
-	struct mem_range *mem_range = state.mem_range;
-	state.hiscores_have_been_loaded = 0;
+	timer = timer_alloc(hiscore_periodic);
+	timer_adjust(timer, TIME_IN_HZ(60), 0, TIME_IN_HZ(60));
 
-	while (mem_range)
-	{
-		cpunum_write_byte(
-			mem_range->cpu,
-			mem_range->addr,
-			~mem_range->start_value
-		);
-
-		cpunum_write_byte(
-			mem_range->cpu,
-			mem_range->addr + mem_range->num_bytes-1,
-			~mem_range->end_value
-		);
-		mem_range = mem_range->next;
-	}
-}
-
-/* call hs_update periodically (i.e. once per frame) */
-void hs_update (void)
-{
-	if (state.mem_range)
-	{
-		if (!state.hiscores_have_been_loaded)
-		{
-			if (safe_to_load()) hs_load();
-		}
-	}
-}
-
-/* call hs_close when done playing game */
-void hs_close (void)
-{
-	if (state.hiscores_have_been_loaded) hs_save();
-	hs_free();
+	add_exit_callback(hiscore_close);
 }
