@@ -1,9 +1,12 @@
 #include "sound/custom.h"
 
-/* defined in machine/astrocde.c */
+/*----------- defined in drivers/astrocde.c -----------*/
+
+void astrocade_state_save_register_main(void);
+
+/*----------- defined in machine/astrocde.c -----------*/
 
 extern UINT8 *wow_protected_ram;
-extern size_t wow_protected_ram_size;
 
 READ8_HANDLER( seawolf2_controller1_r );
 READ8_HANDLER( seawolf2_controller2_r );
@@ -14,7 +17,6 @@ READ8_HANDLER( spacezap_io_r );
 WRITE8_HANDLER( wow_ramwrite_enable_w );
 READ8_HANDLER( wow_protected_ram_r );
 WRITE8_HANDLER( wow_protected_ram_w );
-NVRAM_HANDLER( robby_nvram );
 READ8_HANDLER( robby_nvram_r );
 WRITE8_HANDLER( robby_nvram_w );
 READ8_HANDLER( demndrgn_move_r );
@@ -25,12 +27,14 @@ READ8_HANDLER( demndrgn_io_r );
 READ8_HANDLER( demndrgn_nvram_r );
 WRITE8_HANDLER( demndrgn_nvram_w );
 WRITE8_HANDLER( profpac_banksw_w );
-WRITE8_HANDLER( profpac_page_select_w );
-WRITE8_HANDLER( profpac_screenram_ctrl_w );
 READ8_HANDLER( profpac_nvram_r );
 WRITE8_HANDLER( profpac_nvram_w );
+READ8_HANDLER( gorf_timer_r );
 
-/* defined in vidrhdw/astrocde.c */
+MACHINE_START( astrocde );
+MACHINE_START( profpac );
+
+/*----------- defined in vidhrdw/astrocde.c -----------*/
 
 extern UINT8 *wow_videoram;
 extern read8_handler astrocde_videoram_r;
@@ -38,7 +42,6 @@ extern read8_handler astrocde_videoram_r;
 PALETTE_INIT( astrocde );
 VIDEO_UPDATE( seawolf2 );
 READ8_HANDLER( wow_intercept_r );
-WRITE8_HANDLER( wow_videoram_w );
 WRITE8_HANDLER( astrocde_magic_expand_color_w );
 WRITE8_HANDLER( astrocde_magic_control_w );
 WRITE8_HANDLER( wow_magicram_w );
@@ -50,7 +53,6 @@ WRITE8_HANDLER( astrocde_interrupt_enable_w );
 WRITE8_HANDLER( astrocde_interrupt_w );
 INTERRUPT_GEN( wow_interrupt );
 INTERRUPT_GEN( gorf_interrupt );
-READ8_HANDLER( gorf_timer_r );
 READ8_HANDLER( gorf_io_1_r );
 READ8_HANDLER( gorf_io_2_r );
 VIDEO_START( astrocde );
@@ -67,26 +69,21 @@ READ8_HANDLER( profpac_intercept_r );
 VIDEO_START( profpac );
 READ8_HANDLER( profpac_io_1_r );
 READ8_HANDLER( profpac_io_2_r );
+READ8_HANDLER( wow_io_r );
+WRITE8_HANDLER( profpac_page_select_w );
+WRITE8_HANDLER( profpac_screenram_ctrl_w );
 
-/* defined in sndhrdw/wow.c */
+/*----------- defined in sndhrdw/wow.c -----------*/
 
 extern const char *wow_sample_names[];
 
-void *wow_sh_start(int clock, const struct CustomSound_interface *config);
 READ8_HANDLER( wow_speech_r );
 READ8_HANDLER( wow_port_2_r );
-READ8_HANDLER( wow_io_r );
 
-/* defined in sndhrdw/gorf.c */
+/*----------- defined in sndhrdw/gorf.c -----------*/
 
 extern const char *gorf_sample_names[];
 
-void *gorf_sh_start(int clock, const struct CustomSound_interface *config);
 READ8_HANDLER( gorf_speech_r );
 READ8_HANDLER( gorf_port_2_r );
-WRITE8_HANDLER( gorf_sound_control_a_w );
-
-
-
-
 
