@@ -6,8 +6,8 @@
 
 /*----------- defined in vidhrdw/beathead.c -----------*/
 
-extern data32_t *	beathead_vram_bulk_latch;
-extern data32_t *	beathead_palette_select;
+extern UINT32 *	beathead_vram_bulk_latch;
+extern UINT32 *	beathead_palette_select;
 
 VIDEO_START( beathead );
 VIDEO_UPDATE( beathead );
