@@ -1,9 +1,11 @@
 /*************************************************************************
 
-	Atari Canyon Bomber hardware
+    Atari Canyon Bomber hardware
 
 *************************************************************************/
 
+#include "sound/discrete.h"
+
 /* Discrete Sound Input Nodes */
 #define CANYON_MOTOR1_DATA		NODE_01
 #define CANYON_MOTOR2_DATA		NODE_02
@@ -26,4 +28,9 @@ extern struct discrete_sound_block canyon_discrete_interface[];
 
 /*----------- defined in vidhrdw/canyon.c -----------*/
 
+extern UINT8* canyon_videoram;
+
+VIDEO_START( canyon );
 VIDEO_UPDATE( canyon );
+
+WRITE8_HANDLER( canyon_videoram_w );
