@@ -1,9 +1,11 @@
 /*************************************************************************
 
-	Atari Drag Race hardware
+    Atari Drag Race hardware
 
 *************************************************************************/
 
+#include "sound/discrete.h"
+
 /* Discrete Sound Input Nodes */
 #define DRAGRACE_SCREECH1_EN	NODE_01
 #define DRAGRACE_SCREECH2_EN	NODE_02
@@ -23,3 +25,12 @@
 /*----------- defined in sndhrdw/dragrace.c -----------*/
 
 extern struct discrete_sound_block dragrace_discrete_interface[];
+
+/*----------- defined in vidhrdw/dragrace.c -----------*/
+
+VIDEO_START( dragrace );
+VIDEO_UPDATE( dragrace );
+
+extern UINT8* dragrace_playfield_ram;
+extern UINT8* dragrace_position_ram;
+
