@@ -10,20 +10,14 @@
 void itech32_update_interrupts(int vint, int xint, int qint);
 
 
-/*----------- defined in drivers/drivedge.c -----------*/
-
-void drivedge_update_interrupts(int vint, int xint, int qint);
-
-
 /*----------- defined in vidhrdw/itech32.c -----------*/
 
-extern data16_t *itech32_video;
-extern data32_t *drivedge_zbuf_control;
+extern UINT16 *itech32_video;
+extern UINT32 *drivedge_zbuf_control;
 extern UINT8 itech32_planes;
 extern UINT16 itech32_vram_height;
 
 VIDEO_START( itech32 );
-VIDEO_START( drivedge );
 
 WRITE16_HANDLER( timekill_colora_w );
 WRITE16_HANDLER( timekill_colorbc_w );
