@@ -1,10 +1,8 @@
-/* Variables defined in vidhrdw: */
+/*----------- defined in vidhrdw/paradise.c -----------*/
 
-extern data8_t *paradise_vram_0,*paradise_vram_1,*paradise_vram_2;
+extern UINT8 *paradise_vram_0,*paradise_vram_1,*paradise_vram_2;
 extern int paradise_sprite_inc;
 
-/* Functions defined in vidhrdw: */
-
 WRITE8_HANDLER( paradise_vram_0_w );
 WRITE8_HANDLER( paradise_vram_1_w );
 WRITE8_HANDLER( paradise_vram_2_w );
@@ -20,3 +18,4 @@ WRITE8_HANDLER( paradise_palbank_w );
 VIDEO_START( paradise );
 VIDEO_UPDATE( paradise );
 VIDEO_UPDATE( torus );
+VIDEO_UPDATE( madball );
