@@ -1,14 +1,16 @@
-/* defined in drivers/psikyosh.c */
+/*----------- defined in drivers/psikyosh.c -----------*/
+
 #define MASTER_CLOCK 57272700	/* main oscillator frequency */
 
-extern data32_t *psikyosh_bgram, *psikyosh_zoomram, *psikyosh_vidregs, *psh_ram;
+extern UINT32 *psikyosh_bgram, *psikyosh_zoomram, *psikyosh_vidregs, *psh_ram;
+
+/*----------- defined in vidhrdw/psikyosh.c -----------*/
 
-/* defined in vidhrdw/psiykosh.c */
 VIDEO_START( psikyosh );
 VIDEO_UPDATE( psikyosh );
 VIDEO_EOF( psikyosh );
 
-enum { EEPROM_0=0, EEPROM_DEFAULT=1, EEPROM_DARAKU, EEPROM_S1945III, EEPROM_DRAGNBLZ, EEPROM_GNBARICH };
+enum { EEPROM_0=0, EEPROM_DEFAULT=1, EEPROM_DARAKU, EEPROM_S1945III, EEPROM_DRAGNBLZ, EEPROM_GNBARICH, EEPROM_USER1 };
 
 /* Psikyo PS6406B */
 #define FLIPSCREEN (((psikyosh_vidregs[3] & 0x0000c000) == 0x0000c000) ? 1:0)
