@@ -1,3 +1,5 @@
+/*----------- defined in vidhrdw/realbrk.c -----------*/
+
 #ifndef REALBRK_H
 #define REALBRK_H
 
@@ -10,7 +12,7 @@ WRITE16_HANDLER( realbrk_vram_2_w );
 WRITE16_HANDLER( realbrk_vregs_w );
 WRITE16_HANDLER( realbrk_flipscreen_w );
 
-extern data16_t *realbrk_vram_0, *realbrk_vram_1, *realbrk_vram_2, *realbrk_vregs;
+extern UINT16 *realbrk_vram_0, *realbrk_vram_1, *realbrk_vram_2, *realbrk_vregs;
 
 #endif
 
