@@ -4,18 +4,20 @@
 
 ***************************************************************************/
 
-/* Variables and functions defined in drivers/seta.c */
+/*----------- defined in drivers/seta.c -----------*/
+
+#define	__uPD71054_TIMER	1
 
 void seta_coin_lockout_w(int data);
 
 
-/* Variables and functions defined in vidhrdw/seta.c */
+/*----------- defined in vidhrdw/seta.c -----------*/
 
-extern data16_t *seta_vram_0, *seta_vctrl_0;
-extern data16_t *seta_vram_2, *seta_vctrl_2;
-extern data16_t *seta_vregs;
+extern UINT16 *seta_vram_0, *seta_vctrl_0;
+extern UINT16 *seta_vram_2, *seta_vctrl_2;
+extern UINT16 *seta_vregs;
 
-extern data16_t *seta_workram; /* Needed for zombraid Crosshair hack */
+extern UINT16 *seta_workram; /* Needed for zombraid Crosshair hack */
 
 extern int seta_tiles_offset;
 
@@ -41,9 +43,9 @@ VIDEO_UPDATE( seta );
 VIDEO_UPDATE( seta_no_layers );
 
 
-/* Variables and functions defined in vidhrdw/seta2.c */
+/*----------- defined in vidhrdw/seta2.c -----------*/
 
-extern data16_t *seta2_vregs;
+extern UINT16 *seta2_vregs;
 
 WRITE16_HANDLER( seta2_vregs_w );
 
@@ -53,13 +55,9 @@ VIDEO_UPDATE( seta2 );
 VIDEO_EOF( seta2 );
 
 
-/* Variables and functions defined in sndhrdw/seta.c */
-#define	__uPD71054_TIMER	1
+/*----------- defined in vidhrdw/ssv.c -----------*/
 
-
-/* Variables and functions defined in vidhrdw/ssv.c */
-
-extern data16_t *ssv_scroll;
+extern UINT16 *ssv_scroll;
 
 extern int ssv_special;
 
@@ -68,10 +66,19 @@ extern int ssv_tile_code[16];
 extern int ssv_sprites_offsx, ssv_sprites_offsy;
 extern int ssv_tilemap_offsx, ssv_tilemap_offsy;
 
+extern UINT16 *eaglshot_gfxram, *gdfs_tmapram, *gdfs_tmapscroll;
+extern char eaglshot_dirty, *eaglshot_dirty_tile;
+
 READ16_HANDLER( ssv_vblank_r );
 WRITE16_HANDLER( ssv_scroll_w );
 WRITE16_HANDLER( paletteram16_xrgb_swap_word_w );
+WRITE16_HANDLER( gdfs_tmapram_w );
 void ssv_enable_video(int enable);
 
 VIDEO_START( ssv );
+VIDEO_START( eaglshot );
+VIDEO_START( gdfs );
+
 VIDEO_UPDATE( ssv );
+VIDEO_UPDATE( eaglshot );
+VIDEO_UPDATE( gdfs );
