@@ -11,5 +11,4 @@ extern UINT8 thunderj_alpha_tile_bank;
 VIDEO_START( thunderj );
 VIDEO_UPDATE( thunderj );
 
-void thunderj_mark_high_palette(struct mame_bitmap *bitmap, UINT16 *pf, UINT16 *mo, int x, int y);
-void thunderj_scanline_update(int scanline);
+void thunderj_mark_high_palette(mame_bitmap *bitmap, UINT16 *pf, UINT16 *mo, int x, int y);
