@@ -4,6 +4,9 @@
 
     Dumps the MAME internal data as an XML file.
 
+    Copyright (c) 1996-2006, Nicola Salmoria and the MAME Team.
+    Visit http://mamedev.org for licensing and usage restrictions.
+
 ***************************************************************************/
 
 #pragma once
@@ -11,7 +14,9 @@
 #ifndef __INFO_H__
 #define __INFO_H__
 
+#include "mamecore.h"
+
 /* Print the MAME database in XML format */
-void print_mame_xml(FILE* out, const game_driver* games[]);
+void print_mame_xml(FILE* out, const game_driver* const games[]);
 
 #endif	/* __INFO_H__ */
