@@ -4,9 +4,14 @@
 
     Handle input from the user.
 
+    Copyright (c) 1996-2006, Nicola Salmoria and the MAME Team.
+    Visit http://mamedev.org for licensing and usage restrictions.
+
 ***************************************************************************/
 
+#include "osdepend.h"
 #include "driver.h"
+#include "profiler.h"
 #include <time.h>
 #include <ctype.h>
 
@@ -31,6 +36,7 @@
  *
  *************************************/
 
+typedef struct _input_code_info input_code_info;
 struct _input_code_info
 {
 	UINT8						analogtype;				/* analog type */
@@ -39,7 +45,6 @@ struct _input_code_info
 	const os_code_info *		osinfo;					/* pointer to the OS code info */
 	char						token[MAX_TOKEN_LEN];	/* token string */
 };
-typedef struct _input_code_info input_code_info;
 
 
 
@@ -505,7 +510,7 @@ static input_code_info *code_map;
 static input_code code_count;
 
 /* Static information used in key/joy recording */
-static input_code record_seq[SEQ_MAX];		/* buffer for key recording */
+static input_code record_seq[SEQ_MAX];			/* buffer for key recording */
 static int record_count;						/* number of key/joy press recorded */
 static clock_t record_last;						/* time of last key/joy press */
 static UINT8 record_analog;						/* are we recording an analog sequence? */
@@ -535,9 +540,7 @@ int code_init(void)
 		}
 
 	/* allocate the table */
-	code_map = (input_code_info *)malloc((__code_max + extras) * sizeof(code_map[0]));
-	if (!code_map)
-		return -1;
+	code_map = (input_code_info *)auto_malloc((__code_max + extras) * sizeof(code_map[0]));
 	memset(code_map, 0, (__code_max + extras) * sizeof(code_map[0]));
 
 	/* now go through and match up the OS codes to the standard codes */
@@ -600,14 +603,6 @@ int code_init(void)
 }
 
 
-void code_exit(void)
-{
-	code_count = 0;
-	free(code_map);
-	code_map = NULL;
-}
-
-
 
 /*************************************
  *
@@ -838,13 +833,13 @@ input_code token_to_code(const char *token)
 	input_code code;
 
 	/* look for special cases */
-	if (!stricmp(token, "OR"))
+	if (!mame_stricmp(token, "OR"))
 		return CODE_OR;
-	if (!stricmp(token, "NOT"))
+	if (!mame_stricmp(token, "NOT"))
 		return CODE_NOT;
-	if (!stricmp(token, "NONE"))
+	if (!mame_stricmp(token, "NONE"))
 		return CODE_NONE;
-	if (!stricmp(token, "DEFAULT"))
+	if (!mame_stricmp(token, "DEFAULT"))
 		return CODE_DEFAULT;
 
 	/* look for a match against any of the codes in the table */
@@ -1326,7 +1321,8 @@ int seq_read_async(input_seq *seq, int first)
 		}
 	}
 
-	/* analog case: see if we have an analog change of sufficient amount (>25%) */
+	/* analog case: see if we have an analog change of sufficient amount */
+	/* Absolute > 25% --- Relative > 5% */
 	else
 	{
 		/* scan all the analog codes for change */
@@ -1339,7 +1335,7 @@ int seq_read_async(input_seq *seq, int first)
 					if (ANALOG_TYPE(newcode) == ANALOG_TYPE_ABSOLUTE)
 						diff = code_map[newcode].memory - diff;
 					if (diff < 0) diff = -diff;
-					if (diff > (ANALOG_VALUE_MAX - ANALOG_VALUE_MIN) / 4)
+					if (diff > (ANALOG_VALUE_MAX - ANALOG_VALUE_MIN) / ((ANALOG_TYPE(newcode) == ANALOG_TYPE_ABSOLUTE) ? 4 : 20))
 						break;
 				}
 			}
