@@ -7,11 +7,8 @@
 
 **********************************************************************/
 
-#include <string.h>
-#include <stdio.h>
 #include "driver.h"
 #include "6821pia.h"
-#include "state.h"
 
 #define VERBOSE 0
 
@@ -24,9 +21,10 @@
 
 /******************* internal PIA data structure *******************/
 
-struct pia6821
+typedef struct _pia6821 pia6821;
+struct _pia6821
 {
-	const struct pia6821_interface *intf;
+	const pia6821_interface *intf;
 	UINT8 addr;
 
 	UINT8 in_a;
@@ -87,139 +85,46 @@ struct pia6821
 
 /******************* static variables *******************/
 
-static struct pia6821 pia[MAX_PIA];
+static pia6821 pia[MAX_PIA];
 
 static const UINT8 swizzle_address[4] = { 0, 2, 1, 3 };
 
 
 
-/******************* stave state *******************/
-
-static void update_6821_interrupts(struct pia6821 *p);
-
-static void pia_postload(int which)
-{
-	struct pia6821 *p = pia + which;
-	update_6821_interrupts(p);
-	if (p->intf->out_a_func && p->ddr_a) p->intf->out_a_func(0, p->out_a & p->ddr_a);
-	if (p->intf->out_b_func && p->ddr_b) p->intf->out_b_func(0, p->out_b & p->ddr_b);
-	if (p->intf->out_ca2_func) p->intf->out_ca2_func(0, p->out_ca2);
-	if (p->intf->out_cb2_func) p->intf->out_cb2_func(0, p->out_cb2);
-}
-
-static void pia_postload_0(void)
-{
-	pia_postload(0);
-}
-
-static void pia_postload_1(void)
-{
-	pia_postload(1);
-}
-
-static void pia_postload_2(void)
-{
-	pia_postload(2);
-}
-
-static void pia_postload_3(void)
-{
-	pia_postload(3);
-}
-
-static void pia_postload_4(void)
-{
-	pia_postload(4);
-}
-
-static void pia_postload_5(void)
-{
-	pia_postload(5);
-}
-
-static void pia_postload_6(void)
-{
-	pia_postload(6);
-}
-
-static void pia_postload_7(void)
-{
-	pia_postload(7);
-}
-
-static void (*pia_postload_funcs[MAX_PIA])(void) =
-{
-	pia_postload_0,
-	pia_postload_1,
-	pia_postload_2,
-	pia_postload_3,
-	pia_postload_4,
-	pia_postload_5,
-	pia_postload_6,
-	pia_postload_7
-};
-
-void pia_init(int count)
-{
-	int i;
-	for (i = 0; i < count; i++)
-	{
-		state_save_register_UINT8("6821pia", i, "in_a",		&pia[i].in_a, 1);
-		state_save_register_UINT8("6821pia", i, "in_ca1",	&pia[i].in_ca1, 1);
-		state_save_register_UINT8("6821pia", i, "in_ca2",	&pia[i].in_ca2, 1);
-		state_save_register_UINT8("6821pia", i, "out_a",	&pia[i].out_a, 1);
-		state_save_register_UINT8("6821pia", i, "out_ca2",	&pia[i].out_ca2, 1);
-		state_save_register_UINT8("6821pia", i, "ddr_a",	&pia[i].ddr_a, 1);
-		state_save_register_UINT8("6821pia", i, "ctl_a",	&pia[i].ctl_a, 1);
-		state_save_register_UINT8("6821pia", i, "irq_a1",	&pia[i].irq_a1, 1);
-		state_save_register_UINT8("6821pia", i, "irq_a2",	&pia[i].irq_a2, 1);
-		state_save_register_UINT8("6821pia", i, "in_b",		&pia[i].in_b, 1);
-		state_save_register_UINT8("6821pia", i, "in_cb1",	&pia[i].in_cb1, 1);
-		state_save_register_UINT8("6821pia", i, "in_cb2",	&pia[i].in_cb2, 1);
-		state_save_register_UINT8("6821pia", i, "out_b",	&pia[i].out_b, 1);
-		state_save_register_UINT8("6821pia", i, "out_cb2",	&pia[i].out_cb2, 1);
-		state_save_register_UINT8("6821pia", i, "ddr_b",	&pia[i].ddr_b, 1);
-		state_save_register_UINT8("6821pia", i, "ctl_b",	&pia[i].ctl_b, 1);
-		state_save_register_UINT8("6821pia", i, "irq_b1",	&pia[i].irq_b1, 1);
-		state_save_register_UINT8("6821pia", i, "irq_b2",	&pia[i].irq_b2, 1);
-		state_save_register_UINT8("6821pia", i, "in_set",	&pia[i].in_set, 1);
-		state_save_register_func_postload(pia_postload_funcs[i]);
-	}
-}
-
-/******************* un-configuration *******************/
-
-void pia_unconfig(void)
-{
-	memset(&pia, 0, sizeof(pia));
-}
-
-
 /******************* configuration *******************/
 
-void pia_config(int which, int addressing, const struct pia6821_interface *intf)
+void pia_config(int which, int addressing, const pia6821_interface *intf)
 {
-	if (which >= MAX_PIA) return;
+	assert_always(mame_get_phase() == MAME_PHASE_INIT, "Can only call pia_config at init time!");
+	assert_always((which >= 0) && (which < MAX_PIA), "pia_config called on an invalid PIA!");
+	assert_always(intf, "pia_config called with an invalid interface!");
+
 	memset(&pia[which], 0, sizeof(pia[0]));
-	if (!intf) return;
+
 	pia[which].intf = intf;
 	pia[which].addr = addressing;
-	/* set default read values. */
-	/* Ports A,CA1,CA2 default to 1 */
-	/* Ports B,CB1,CB2 are three-state and undefined (set to 0) */
-	pia[which].in_a = pia[which].in_ca1 = pia[which].in_ca2 = 0xff;
-	if ((intf->in_a_func) && ((FPTR)(intf->in_a_func) <= 0x100))
-		{ pia[which].in_a = ((FPTR)(intf->in_a_func) - 1); pia[which].in_set |= PIA_IN_SET_A; }
-	if ((intf->in_b_func) && ((FPTR)(intf->in_b_func) <= 0x100))
-		{ pia[which].in_b = ((FPTR)(intf->in_b_func) - 1); pia[which].in_set |= PIA_IN_SET_B; }
-	if ((intf->in_ca1_func) && ((FPTR)(intf->in_ca1_func) <= 0x100))
-		{ pia[which].in_ca1 = ((FPTR)(intf->in_ca1_func) - 1); pia[which].in_set |= PIA_IN_SET_CA1; }
-	if ((intf->in_ca2_func) && ((FPTR)(intf->in_ca2_func) <= 0x100))
-		{ pia[which].in_ca2 = ((FPTR)(intf->in_ca2_func) - 1); pia[which].in_set |= PIA_IN_SET_CA2; }
-	if ((intf->in_cb1_func) && ((FPTR)(intf->in_cb1_func) <= 0x100))
-		{ pia[which].in_cb1 = ((FPTR)(intf->in_cb1_func) - 1); pia[which].in_set |= PIA_IN_SET_CB1; }
-	if ((intf->in_cb2_func) && ((FPTR)(intf->in_cb2_func) <= 0x100))
-		{ pia[which].in_cb2 = ((FPTR)(intf->in_cb2_func) - 1); pia[which].in_set |= PIA_IN_SET_CB2; }
+
+	state_save_register_item("6821pia", which, pia[which].in_a);
+	state_save_register_item("6821pia", which, pia[which].in_ca1);
+	state_save_register_item("6821pia", which, pia[which].in_ca2);
+	state_save_register_item("6821pia", which, pia[which].out_a);
+	state_save_register_item("6821pia", which, pia[which].out_ca2);
+	state_save_register_item("6821pia", which, pia[which].ddr_a);
+	state_save_register_item("6821pia", which, pia[which].ctl_a);
+	state_save_register_item("6821pia", which, pia[which].irq_a1);
+	state_save_register_item("6821pia", which, pia[which].irq_a2);
+	state_save_register_item("6821pia", which, pia[which].irq_a_state);
+	state_save_register_item("6821pia", which, pia[which].in_b);
+	state_save_register_item("6821pia", which, pia[which].in_cb1);
+	state_save_register_item("6821pia", which, pia[which].in_cb2);
+	state_save_register_item("6821pia", which, pia[which].out_b);
+	state_save_register_item("6821pia", which, pia[which].out_cb2);
+	state_save_register_item("6821pia", which, pia[which].ddr_b);
+	state_save_register_item("6821pia", which, pia[which].ctl_b);
+	state_save_register_item("6821pia", which, pia[which].irq_b1);
+	state_save_register_item("6821pia", which, pia[which].irq_b2);
+	state_save_register_item("6821pia", which, pia[which].irq_b_state);
+	state_save_register_item("6821pia", which, pia[which].in_set);
 }
 
 
@@ -230,7 +135,54 @@ void pia_reset(void)
 	int i;
 
 	/* zap each structure, preserving the interface and swizzle */
-	for (i = 0; i < MAX_PIA; i++) pia_config(i, pia[i].addr, pia[i].intf);
+	for (i = 0; i < MAX_PIA; i++)
+	{
+		const pia6821_interface *intf = pia[i].intf;
+		int addressing = pia[i].addr;
+
+		memset(&pia[i], 0, sizeof(pia[i]));
+
+		pia[i].intf = intf;
+		pia[i].addr = addressing;
+
+		/* set default read values. */
+		/* Ports A,CA1,CA2 default to 1 */
+		/* Ports B,CB1,CB2 are three-state and undefined (set to 0) */
+		pia[i].in_a = pia[i].in_ca1 = pia[i].in_ca2 = 0xff;
+		if (intf)
+		{
+			if ((intf->in_a_func) && ((FPTR)(intf->in_a_func) <= 0x100))
+			{
+				pia[i].in_a = ((FPTR)(intf->in_a_func) - 1);
+				pia[i].in_set |= PIA_IN_SET_A;
+			}
+			if ((intf->in_b_func) && ((FPTR)(intf->in_b_func) <= 0x100))
+			{
+				pia[i].in_b = ((FPTR)(intf->in_b_func) - 1);
+				pia[i].in_set |= PIA_IN_SET_B;
+			}
+			if ((intf->in_ca1_func) && ((FPTR)(intf->in_ca1_func) <= 0x100))
+			{
+				pia[i].in_ca1 = ((FPTR)(intf->in_ca1_func) - 1);
+				pia[i].in_set |= PIA_IN_SET_CA1;
+			}
+			if ((intf->in_ca2_func) && ((FPTR)(intf->in_ca2_func) <= 0x100))
+			{
+				pia[i].in_ca2 = ((FPTR)(intf->in_ca2_func) - 1);
+				pia[i].in_set |= PIA_IN_SET_CA2;
+			}
+			if ((intf->in_cb1_func) && ((FPTR)(intf->in_cb1_func) <= 0x100))
+			{
+				pia[i].in_cb1 = ((FPTR)(intf->in_cb1_func) - 1);
+				pia[i].in_set |= PIA_IN_SET_CB1;
+			}
+			if ((intf->in_cb2_func) && ((FPTR)(intf->in_cb2_func) <= 0x100))
+			{
+				pia[i].in_cb2 = ((FPTR)(intf->in_cb2_func) - 1);
+				pia[i].in_set |= PIA_IN_SET_CB2;
+			}
+		}
+	}
 }
 
 
@@ -266,7 +218,7 @@ static void update_shared_irq_handler(void (*irq_func)(int state))
 
 /******************* external interrupt check *******************/
 
-static void update_6821_interrupts(struct pia6821 *p)
+static void update_6821_interrupts(pia6821 *p)
 {
 	int new_state;
 
@@ -294,7 +246,7 @@ static void update_6821_interrupts(struct pia6821 *p)
 
 int pia_read(int which, int offset)
 {
-	struct pia6821 *p = pia + which;
+	pia6821 *p = pia + which;
 	int val = 0;
 
 	/* adjust offset for 16-bit and ordering */
@@ -474,7 +426,7 @@ int pia_read(int which, int offset)
 
 void pia_write(int which, int offset, int data)
 {
-	struct pia6821 *p = pia + which;
+	pia6821 *p = pia + which;
 
 	/* adjust offset for 16-bit and ordering */
 	offset &= 3;
@@ -648,7 +600,7 @@ void pia_write(int which, int offset, int data)
 
 void pia_set_input_a(int which, int data)
 {
-	struct pia6821 *p = pia + which;
+	pia6821 *p = pia + which;
 
 	/* set the input, what could be easier? */
 	p->in_a = data;
@@ -657,11 +609,21 @@ void pia_set_input_a(int which, int data)
 
 
 
+/******************* interface setting PIA port A input *******************/
+
+int pia_get_output_a(int which)
+{
+	pia6821 *p = pia + which;
+	return (p->out_a & p->ddr_a) + (p->in_a & ~p->ddr_a);
+}
+
+
+
 /******************* interface setting PIA port CA1 input *******************/
 
 void pia_set_input_ca1(int which, int data)
 {
-	struct pia6821 *p = pia + which;
+	pia6821 *p = pia + which;
 
 	/* limit the data to 0 or 1 */
 	data = data ? 1 : 0;
@@ -702,7 +664,7 @@ void pia_set_input_ca1(int which, int data)
 
 void pia_set_input_ca2(int which, int data)
 {
-	struct pia6821 *p = pia + which;
+	pia6821 *p = pia + which;
 
 	/* limit the data to 0 or 1 */
 	data = data ? 1 : 0;
@@ -736,7 +698,7 @@ void pia_set_input_ca2(int which, int data)
 
 void pia_set_input_b(int which, int data)
 {
-	struct pia6821 *p = pia + which;
+	pia6821 *p = pia + which;
 
 	/* set the input, what could be easier? */
 	p->in_b = data;
@@ -745,11 +707,21 @@ void pia_set_input_b(int which, int data)
 
 
 
+/******************* interface setting PIA port A input *******************/
+
+int pia_get_output_b(int which)
+{
+	pia6821 *p = pia + which;
+	return (p->out_b & p->ddr_b) + (p->in_b & ~p->ddr_b);
+}
+
+
+
 /******************* interface setting PIA port CB1 input *******************/
 
 void pia_set_input_cb1(int which, int data)
 {
-	struct pia6821 *p = pia + which;
+	pia6821 *p = pia + which;
 
 	/* limit the data to 0 or 1 */
 	data = data ? 1 : 0;
@@ -784,7 +756,7 @@ void pia_set_input_cb1(int which, int data)
 
 void pia_set_input_cb2(int which, int data)
 {
-	struct pia6821 *p = pia + which;
+	pia6821 *p = pia + which;
 
 	/* limit the data to 0 or 1 */
 	data = data ? 1 : 0;
@@ -814,11 +786,31 @@ void pia_set_input_cb2(int which, int data)
 
 
 
+/******************* interface retrieving PIA port CA2 output *******************/
+
+int pia_get_output_ca2(int which)
+{
+	pia6821 *p = pia + which;
+	return p->out_ca2;
+}
+
+
+
+/******************* interface retrieving PIA port CB2 output *******************/
+
+int pia_get_output_cb2(int which)
+{
+	pia6821 *p = pia + which;
+	return p->out_cb2;
+}
+
+
+
 /******************* interface retrieving DDR *******************/
 
 UINT8 pia_get_ddr_a(int which)
 {
-	struct pia6821 *p = pia + which;
+	pia6821 *p = pia + which;
 	return p->ddr_a;
 }
 
@@ -826,12 +818,31 @@ UINT8 pia_get_ddr_a(int which)
 
 UINT8 pia_get_ddr_b(int which)
 {
-	struct pia6821 *p = pia + which;
+	pia6821 *p = pia + which;
 	return p->ddr_b;
 }
 
 
 
+/******************* interface retrieving IRQ *******************/
+
+int pia_get_irq_a(int which)
+{
+	pia6821 *p = pia + which;
+	return p->irq_a_state;
+}
+
+
+
+int pia_get_irq_b(int which)
+{
+	pia6821 *p = pia + which;
+	return p->irq_b_state;
+}
+
+
+
+
 /******************* Standard 8-bit CPU interfaces, D0-D7 *******************/
 
 READ8_HANDLER( pia_0_r ) { return pia_read(0, offset); }
