@@ -13,7 +13,6 @@
 #include "sound/pokey.h"
 #ifdef MESS
 #include "image.h"
-#include "state.h"
 #endif
 
 #define VERBOSE_POKEY	0
@@ -21,14 +20,6 @@
 #define VERBOSE_TIMERS	0
 #define VERBOSE_CHKSUM	0
 
-#ifndef TRUE
-#define TRUE    1
-#endif
-
-#ifndef FALSE
-#define FALSE   0
-#endif
-
 /*#define LOG(x) if (errorlog) fprintf x */
 
 ATARI_PIA atari_pia;
@@ -50,10 +41,6 @@ typedef struct {
 
 static DRIVE drv[4] = {{0}, };
 
-extern void a800_serial_command(void);
-extern void a800_serial_write(void);
-extern void a800_serial_read(void);
-
 static int atari = 0;
 #define ATARI_5200	0
 #define ATARI_400	1
@@ -116,7 +103,7 @@ static void a800_setbank(int n)
 }
 #endif
 
-static void machine_init_atari_generic(int machine_type, int has_cart, int has_pia)
+static void machine_reset_atari_generic(int machine_type, int has_cart, int has_pia)
 {
 	atari = machine_type;
 
@@ -132,14 +119,14 @@ static void machine_init_atari_generic(int machine_type, int has_cart, int has_p
 #endif
 }
 
-MACHINE_INIT( a400 )
+MACHINE_RESET( a400 )
 {
-	machine_init_atari_generic(ATARI_400, TRUE, TRUE);
+	machine_reset_atari_generic(ATARI_400, TRUE, TRUE);
 }
 
-MACHINE_INIT( a800 )
+MACHINE_RESET( a800 )
 {
-	machine_init_atari_generic(ATARI_800, TRUE, TRUE);
+	machine_reset_atari_generic(ATARI_800, TRUE, TRUE);
 }
 
 #ifdef MESS
@@ -186,9 +173,9 @@ DEVICE_UNLOAD( a800_cart )
  * Atari 600XL (for MAME only)
  *
  **************************************************************/
-MACHINE_INIT(a600xl)
+MACHINE_RESET(a600xl)
 {
-	machine_init_atari_generic(ATARI_600XL, FALSE, TRUE);
+	machine_reset_atari_generic(ATARI_600XL, FALSE, TRUE);
 	a600xl_mmu(atari_pia.w.pbout, atari_pia.w.pbout);
 }
 
@@ -198,9 +185,9 @@ MACHINE_INIT(a600xl)
  *
  **************************************************************/
 
-MACHINE_INIT( a800xl)
+MACHINE_RESET( a800xl)
 {
-	machine_init_atari_generic(ATARI_800XL, FALSE, TRUE);
+	machine_reset_atari_generic(ATARI_800XL, FALSE, TRUE);
 	a800xl_mmu(atari_pia.w.pbout, atari_pia.w.pbout);
 }
 
@@ -246,9 +233,9 @@ DEVICE_LOAD( a800xl_cart )
  *
  **************************************************************/
 
-MACHINE_INIT( a5200 )
+MACHINE_RESET( a5200 )
 {
-	machine_init_atari_generic(ATARI_5200, FALSE, FALSE);
+	machine_reset_atari_generic(ATARI_5200, FALSE, FALSE);
 }
 
 #ifdef MESS
@@ -1112,11 +1099,13 @@ void a600xl_mmu(UINT8 old_mmu, UINT8 new_mmu)
 		else
 		{
 			logerror("%s MMU SELFTEST ROM\n", Machine->gamedrv->name);
-			rbank2 = MRA8_ROM;
+			rbank2 = MRA8_BANK2;
 			wbank2 = MWA8_ROM;
 		}
 		memory_install_read8_handler(0, ADDRESS_SPACE_PROGRAM, 0x5000, 0x57ff, 0, 0, rbank2);
 		memory_install_write8_handler(0, ADDRESS_SPACE_PROGRAM, 0x5000, 0x57ff, 0, 0, wbank2);
+		if (rbank2 == MRA8_BANK2)
+			memory_set_bankptr(2, memory_region(REGION_CPU1)+0x5000);
 	}
 }
 
@@ -1125,6 +1114,7 @@ void a800xl_mmu(UINT8 old_mmu, UINT8 new_mmu)
 	UINT8 changes = new_mmu ^ old_mmu;
 	read8_handler rbank1, rbank2, rbank3, rbank4;
 	write8_handler wbank1, wbank2, wbank3, wbank4;
+	UINT8 *base1, *base2, *base3, *base4;
 
 	if( changes == 0 )
 		return;
@@ -1139,25 +1129,27 @@ void a800xl_mmu(UINT8 old_mmu, UINT8 new_mmu)
 			logerror("%s MMU BIOS ROM\n", Machine->gamedrv->name);
 			rbank3 = MRA8_BANK3;
 			wbank3 = MWA8_ROM;
-			memory_set_bankptr(3, memory_region(REGION_CPU1)+0x14000);  /* 8K lo BIOS */
+			base3 = memory_region(REGION_CPU1)+0x14000;  /* 8K lo BIOS */
 			rbank4 = MRA8_BANK4;
 			wbank4 = MWA8_ROM;
-			memory_set_bankptr(4, memory_region(REGION_CPU1)+0x15800);  /* 4K FP ROM + 8K hi BIOS */
+			base4 = memory_region(REGION_CPU1)+0x15800;  /* 4K FP ROM + 8K hi BIOS */
 		}
 		else
 		{
 			logerror("%s MMU BIOS RAM\n", Machine->gamedrv->name);
-			rbank3 = MRA8_RAM;
-			wbank3 = MWA8_RAM;
-			memory_set_bankptr(3, memory_region(REGION_CPU1)+0x0c000);  /* 8K RAM */
-			rbank4 = MRA8_RAM;
-			wbank4 = MWA8_RAM;
-			memory_set_bankptr(4, memory_region(REGION_CPU1)+0x0d800);  /* 4K RAM + 8K RAM */
+			rbank3 = MRA8_BANK3;
+			wbank3 = MWA8_BANK3;
+			base3 = memory_region(REGION_CPU1)+0x0c000;  /* 8K RAM */
+			rbank4 = MRA8_BANK4;
+			wbank4 = MWA8_BANK4;
+			base4 = memory_region(REGION_CPU1)+0x0d800;  /* 4K RAM + 8K RAM */
 		}
 		memory_install_read8_handler(0, ADDRESS_SPACE_PROGRAM, 0xc000, 0xcfff, 0, 0, rbank3);
 		memory_install_write8_handler(0, ADDRESS_SPACE_PROGRAM, 0xc000, 0xcfff, 0, 0, wbank3);
 		memory_install_read8_handler(0, ADDRESS_SPACE_PROGRAM, 0xd800, 0xffff, 0, 0, rbank4);
 		memory_install_write8_handler(0, ADDRESS_SPACE_PROGRAM, 0xd800, 0xffff, 0, 0, wbank4);
+		memory_set_bankptr(3, base3);
+		memory_set_bankptr(4, base4);
 	}
 	/* check if BASIC changed */
 	if( changes & 0x02 )
@@ -1165,19 +1157,20 @@ void a800xl_mmu(UINT8 old_mmu, UINT8 new_mmu)
 		if( new_mmu & 0x02 )
 		{
 			logerror("%s MMU BASIC RAM\n", Machine->gamedrv->name);
-			rbank1 = MRA8_RAM;
-			wbank1 = MWA8_RAM;
-			memory_set_bankptr(1, memory_region(REGION_CPU1)+0x0a000);  /* 8K RAM */
+			rbank1 = MRA8_BANK1;
+			wbank1 = MWA8_BANK1;
+			base1 = memory_region(REGION_CPU1)+0x0a000;  /* 8K RAM */
 		}
 		else
 		{
 			logerror("%s MMU BASIC ROM\n", Machine->gamedrv->name);
-			rbank1 = MRA8_BANK2;
+			rbank1 = MRA8_BANK1;
 			wbank1 = MWA8_ROM;
-			memory_set_bankptr(1, memory_region(REGION_CPU1)+0x10000);  /* 8K BASIC */
+			base1 = memory_region(REGION_CPU1)+0x10000;  /* 8K BASIC */
 		}
 		memory_install_read8_handler(0, ADDRESS_SPACE_PROGRAM, 0xa000, 0xbfff, 0, 0, rbank1);
 		memory_install_write8_handler(0, ADDRESS_SPACE_PROGRAM, 0xa000, 0xbfff, 0, 0, wbank1);
+		memory_set_bankptr(1, base1);
 	}
 	/* check if self-test ROM changed */
 	if( changes & 0x80 )
@@ -1185,19 +1178,20 @@ void a800xl_mmu(UINT8 old_mmu, UINT8 new_mmu)
 		if( new_mmu & 0x80 )
 		{
 			logerror("%s MMU SELFTEST RAM\n", Machine->gamedrv->name);
-			rbank2 = MRA8_RAM;
-			wbank2 = MWA8_RAM;
-			memory_set_bankptr(2, memory_region(REGION_CPU1)+0x05000);  /* 0x0800 bytes */
+			rbank2 = MRA8_BANK2;
+			wbank2 = MWA8_BANK2;
+			base2 = memory_region(REGION_CPU1)+0x05000;  /* 0x0800 bytes */
 		}
 		else
 		{
 			logerror("%s MMU SELFTEST ROM\n", Machine->gamedrv->name);
-			rbank2 = MRA8_BANK1;
+			rbank2 = MRA8_BANK2;
 			wbank2 = MWA8_ROM;
-			memory_set_bankptr(2, memory_region(REGION_CPU1)+0x15000);  /* 0x0800 bytes */
+			base2 = memory_region(REGION_CPU1)+0x15000;  /* 0x0800 bytes */
 		}
 		memory_install_read8_handler(0, ADDRESS_SPACE_PROGRAM, 0x5000, 0x57ff, 0, 0, rbank2);
 		memory_install_write8_handler(0, ADDRESS_SPACE_PROGRAM, 0x5000, 0x57ff, 0, 0, wbank2);
+		memory_set_bankptr(2, base2);
 	}
 }
 
@@ -1609,8 +1603,18 @@ DRIVER_INIT( atari )
 	offs_t ram_top;
 	offs_t ram_size;
 
-	ram_size = !strcmp(Machine->gamedrv->name, "a400") || !strcmp(Machine->gamedrv->name, "a800")
-		? 0xA000 : 0x8000;
+	if (!strcmp(Machine->gamedrv->name, "a400")
+		|| !strcmp(Machine->gamedrv->name, "a400pal")
+		|| !strcmp(Machine->gamedrv->name, "a800")
+		|| !strcmp(Machine->gamedrv->name, "a800pal")
+		|| !strcmp(Machine->gamedrv->name, "a800xl"))
+	{
+		ram_size = 0xA000;
+	}
+	else
+	{
+		ram_size = 0x8000;
+	}
 
 	/* install RAM */
 	ram_top = MIN(mess_ram_size, ram_size) - 1;
@@ -1621,10 +1625,10 @@ DRIVER_INIT( atari )
 	memory_set_bankptr(2, mess_ram);
 
 	/* save states */
-	state_save_register_UINT8("atari", 0, "antic_r", (UINT8 *) &antic.r, sizeof(antic.r));
-	state_save_register_UINT8("atari", 0, "antic_w", (UINT8 *) &antic.w, sizeof(antic.w));
-	state_save_register_UINT8("atari", 0, "gtia_r", (UINT8 *) &gtia.r, sizeof(gtia.r));
-	state_save_register_UINT8("atari", 0, "gtia_w", (UINT8 *) &gtia.w, sizeof(gtia.w));
+	state_save_register_global_pointer(((UINT8 *) &antic.r), sizeof(antic.r));
+	state_save_register_global_pointer(((UINT8 *) &antic.w), sizeof(antic.w));
+	state_save_register_global_pointer(((UINT8 *) &gtia.r), sizeof(gtia.r));
+	state_save_register_global_pointer(((UINT8 *) &gtia.w), sizeof(gtia.w));
 }
 #endif
 
