@@ -9,8 +9,6 @@
 
 #include "driver.h"
 #include "cpu/z80/z80.h"
-#include "vidhrdw/generic.h"
-#include "machine/random.h"
 
 
 
@@ -23,7 +21,7 @@ WRITE8_HANDLER( bublbobl_bankswitch_w )
 	UINT8 *ROM = memory_region(REGION_CPU1);
 
 	/* bits 0-2 select ROM bank */
-	cpu_setbank(1,&ROM[0x10000 + 0x4000 * ((data ^ 4) & 7)]);
+	memory_set_bankptr(1,&ROM[0x10000 + 0x4000 * ((data ^ 4) & 7)]);
 
 	/* bit 3 n.c. */
 
@@ -45,7 +43,7 @@ WRITE8_HANDLER( tokio_bankswitch_w )
 	UINT8 *ROM = memory_region(REGION_CPU1);
 
 	/* bits 0-2 select ROM bank */
-	cpu_setbank(1,&ROM[0x10000 + 0x4000 * (data & 7)]);
+	memory_set_bankptr(1,&ROM[0x10000 + 0x4000 * (data & 7)]);
 
 	/* bits 3-7 unknown */
 }
@@ -64,7 +62,7 @@ WRITE8_HANDLER( bublbobl_nmitrigger_w )
 }
 
 
-static data8_t tokio_prot_data[] =
+static UINT8 tokio_prot_data[] =
 {
 	0x6c,
 	0x7f,0x5f,0x7f,0x6f,0x5f,0x77,0x5f,0x7f,0x5f,0x7f,0x5f,0x7f,0x5b,0x7f,0x5f,0x7f,
