@@ -5,18 +5,19 @@
 
 #include "driver.h"
 #include "cpu/z80/z80.h"
-#include "state.h"
 
 #define MCU_INITIAL_SEED	0x81
 
-static data8_t mcu_seed;
-static data8_t mcu_select;
-static data8_t mcu_result;
-static data8_t mcu_wait;
+UINT8 *chaknpop_ram;
+
+
+static UINT8 mcu_seed;
+static UINT8 mcu_select;
+static UINT8 mcu_result;
 
 /* mcu data that is extracted from the real board! */
 /* updated on 2st Jun 2003 */
-static data8_t mcu_data[256] = {
+static UINT8 mcu_data[256] = {
 	0x3a, 0xe6, 0x80, 0xc6, 0x0e, 0xdd, 0x77, 0xfd,
 	0x7e, 0xfe, 0x10, 0x38, 0x10, 0xdd, 0x7e, 0x03,
 	0xc6, 0x08, 0xdd, 0x77, 0x03, 0xdd, 0x7e, 0xff,
@@ -51,7 +52,7 @@ static data8_t mcu_data[256] = {
 	0x10, 0xfc, 0x3e, 0x01, 0x32, 0x5b, 0x81, 0xc9
 };
 
-static void mcu_update_seed(data8_t data)
+static void mcu_update_seed(UINT8 data)
 {
 	if (!(data & 0x80))
 	{
@@ -60,6 +61,7 @@ static void mcu_update_seed(data8_t data)
 	}
 
 	mcu_seed += 0x19;
+
 	/*logerror("New seed: 0x%02x\n", mcu_seed); */
 }
 
@@ -79,9 +81,6 @@ READ8_HANDLER( chaknpop_mcu_portB_r )
 {
 	/*logerror("%04x: MCU portB read\n", activecpu_get_pc()); */
 
-	if (--mcu_wait)
-		return 0x00;
-
 	return 0xff;
 }
 
@@ -93,8 +92,7 @@ READ8_HANDLER( chaknpop_mcu_portC_r )
 
 WRITE8_HANDLER( chaknpop_mcu_portA_w )
 {
-	data8_t *RAM = memory_region(REGION_CPU1);
-	data8_t mcu_command;
+	UINT8 mcu_command;
 
 	mcu_command = data + mcu_seed;
 	mcu_result = 0;
@@ -104,7 +102,7 @@ WRITE8_HANDLER( chaknpop_mcu_portA_w )
 		mcu_update_seed(data);
 
 		mcu_result = mcu_data[mcu_select * 8 + mcu_command];
-		mcu_result -=  mcu_seed;
+		mcu_result -= mcu_seed;
 
 		mcu_update_seed(mcu_result);
 
@@ -114,8 +112,8 @@ WRITE8_HANDLER( chaknpop_mcu_portA_w )
 	{
 		mcu_update_seed(data);
 
-		mcu_result = RAM[0x8380 + mcu_command];
-		mcu_result -=  mcu_seed;
+		mcu_result = chaknpop_ram[0x380 + mcu_command];
+		mcu_result -= mcu_seed;
 
 		mcu_update_seed(mcu_result);
 
@@ -157,14 +155,12 @@ WRITE8_HANDLER( chaknpop_mcu_portC_w )
 
 DRIVER_INIT( chaknpop )
 {
-	state_save_register_UINT8("chankpop", 0, "mcu_seed",    &mcu_seed,    1);
-	state_save_register_UINT8("chankpop", 0, "mcu_result",  &mcu_result,  1);
-	state_save_register_UINT8("chankpop", 0, "mcu_select",  &mcu_select,  1);
-	state_save_register_UINT8("chankpop", 0, "mcu_wait",    &mcu_wait,    1);
+	state_save_register_global(mcu_seed);
+	state_save_register_global(mcu_result);
+	state_save_register_global(mcu_select);
 }
 
-MACHINE_INIT( chaknpop )
+MACHINE_RESET( chaknpop )
 {
 	mcu_seed = MCU_INITIAL_SEED;
-	mcu_wait = 0;
 }
