@@ -8,10 +8,11 @@
 
 #include "driver.h"
 #include "machine/8255ppi.h"
+#include "includes/clayshoo.h"
 
 
-static data8_t input_port_select;
-static data8_t analog_port_val;
+static UINT8 input_port_select;
+static UINT8 analog_port_val;
 
 
 /*************************************
@@ -26,12 +27,12 @@ static WRITE8_HANDLER( input_port_select_w )
 }
 
 
-static data8_t difficulty_input_port_r(int bit)
+static UINT8 difficulty_input_port_r(int bit)
 {
-	data8_t ret = 0;
+	UINT8 ret = 0;
 
 	/* read fake port and remap the buttons to 2 bits */
-	data8_t	raw = readinputportbytag("FAKE");
+	UINT8	raw = readinputportbytag("FAKE");
 
 	if (raw & (1 << (bit + 1)))
 		ret = 0x03;		/* expert */
@@ -46,7 +47,7 @@ static data8_t difficulty_input_port_r(int bit)
 
 static READ8_HANDLER( input_port_r )
 {
-	data8_t ret = 0;
+	UINT8 ret = 0;
 
 
 	switch (input_port_select)
@@ -78,7 +79,7 @@ static ppi8255_interface ppi8255_intf =
 };
 
 
-MACHINE_INIT( clayshoo )
+MACHINE_RESET( clayshoo )
 {
 	ppi8255_init(&ppi8255_intf);
 }
