@@ -4,8 +4,9 @@
 
 ***************************************************************************/
 
+#include "driver.h"
 #include "idectrl.h"
-#include "state.h"
+#include "debugger.h"
 
 
 /*************************************
@@ -88,6 +89,10 @@
 #define IDE_COMMAND_SET_FEATURES		0xef
 #define IDE_COMMAND_SECURITY_UNLOCK		0xf2
 #define IDE_COMMAND_UNKNOWN_F9			0xf9
+#define IDE_COMMAND_VERIFY_MULTIPLE		0x40
+#define IDE_COMMAND_ATAPI_IDENTIFY		0xa1
+#define IDE_COMMAND_RECALIBRATE			0x10
+#define IDE_COMMAND_IDLE_IMMEDIATE		0xe1
 
 #define IDE_ERROR_NONE					0x00
 #define IDE_ERROR_DEFAULT				0x01
@@ -123,6 +128,7 @@ struct ide_state
 
 	UINT16	block_count;
 	UINT16	sectors_until_int;
+	UINT8	verify_only;
 
 	UINT8	dma_active;
 	UINT8	dma_cpu;
@@ -156,8 +162,8 @@ struct ide_state
 	void *	last_status_timer;
 	void *	reset_timer;
 
-	int	master_password_enable;
-	int	user_password_enable;
+	UINT8	master_password_enable;
+	UINT8	user_password_enable;
 	UINT8 *	master_password;
 	UINT8 *	user_password;
 };
@@ -268,11 +274,29 @@ INLINE void signal_delayed_interrupt(struct ide_state *ide, double time, int buf
  *
  *************************************/
 
+static void ide_controller_exit(void)
+{
+	int i;
+
+	/* close all open hard disks */
+	for (i = 0; i < MAX_IDE_CONTROLLERS; i++)
+		if (idestate[i].disk)
+		{
+			hard_disk_close(idestate[i].disk);
+			idestate[i].disk = NULL;
+		}
+}
+
+
 int ide_controller_init_custom(int which, struct ide_interface *intf, chd_file *diskhandle)
 {
 	struct ide_state *ide = &idestate[which];
 	const hard_disk_info *hdinfo;
 
+	/* must be called during init phase */
+	assert_always(mame_get_phase() == MAME_PHASE_INIT, "ide_controller_init can only be called at init time");
+	add_exit_callback(ide_controller_exit);
+
 	/* NULL interface is immediate failure */
 	if (!intf)
 		return 1;
@@ -307,50 +331,50 @@ int ide_controller_init_custom(int which, struct ide_interface *intf, chd_file *
 	ide->reset_timer = timer_alloc(reset_callback);
 
 	/* register ide status */
-	state_save_register_UINT8 ("ide", which, "adapter_control",        &ide->adapter_control,       1);
-	state_save_register_UINT8 ("ide", which, "status",                 &ide->status,                1);
-	state_save_register_UINT8 ("ide", which, "error",                  &ide->error,                 1);
-	state_save_register_UINT8 ("ide", which, "command",                &ide->command,               1);
-	state_save_register_UINT8 ("ide", which, "interrupt_pending",      &ide->interrupt_pending,     1);
-	state_save_register_UINT8 ("ide", which, "precomp_offset",         &ide->precomp_offset,        1);
+	state_save_register_item("ide", which, ide->adapter_control);
+	state_save_register_item("ide", which, ide->status);
+	state_save_register_item("ide", which, ide->error);
+	state_save_register_item("ide", which, ide->command);
+	state_save_register_item("ide", which, ide->interrupt_pending);
+	state_save_register_item("ide", which, ide->precomp_offset);
 
-	state_save_register_UINT8 ("ide", which, "buffer",                 ide->buffer,                 IDE_DISK_SECTOR_SIZE);
-	state_save_register_UINT8 ("ide", which, "features",               ide->features,               IDE_DISK_SECTOR_SIZE);
-	state_save_register_UINT16("ide", which, "buffer_offset",          &ide->buffer_offset,         1);
-	state_save_register_UINT16("ide", which, "sector_count",           &ide->sector_count,          1);
+	state_save_register_item_array("ide", which, ide->buffer);
+	state_save_register_item_array("ide", which, ide->features);
+	state_save_register_item("ide", which, ide->buffer_offset);
+	state_save_register_item("ide", which, ide->sector_count);
 
-	state_save_register_UINT16("ide", which, "block_count",            &ide->block_count,           1);
-	state_save_register_UINT16("ide", which, "sectors_until_int",      &ide->sectors_until_int,     1);
+	state_save_register_item("ide", which, ide->block_count);
+	state_save_register_item("ide", which, ide->sectors_until_int);
 
-	state_save_register_UINT8 ("ide", which, "dma_active",             &ide->dma_active,            1);
-	state_save_register_UINT8 ("ide", which, "dma_cpu",                &ide->dma_cpu,               1);
-	state_save_register_UINT8 ("ide", which, "dma_address_xor",        &ide->dma_address_xor,       1);
-	state_save_register_UINT8 ("ide", which, "dma_last_buffer",        &ide->dma_last_buffer,       1);
-	state_save_register_UINT32("ide", which, "dma_address",            &ide->dma_address,           1);
-	state_save_register_UINT32("ide", which, "dma_descriptor",         &ide->dma_descriptor,        1);
-	state_save_register_UINT32("ide", which, "dma_bytes_left",         &ide->dma_bytes_left,        1);
+	state_save_register_item("ide", which, ide->dma_active);
+	state_save_register_item("ide", which, ide->dma_cpu);
+	state_save_register_item("ide", which, ide->dma_address_xor);
+	state_save_register_item("ide", which, ide->dma_last_buffer);
+	state_save_register_item("ide", which, ide->dma_address);
+	state_save_register_item("ide", which, ide->dma_descriptor);
+	state_save_register_item("ide", which, ide->dma_bytes_left);
 
-	state_save_register_UINT8 ("ide", which, "bus_master_command",     &ide->bus_master_command,    1);
-	state_save_register_UINT8 ("ide", which, "bus_master_status",      &ide->bus_master_status,     1);
-	state_save_register_UINT32("ide", which, "bus_master_descriptor",  &ide->bus_master_descriptor, 1);
+	state_save_register_item("ide", which, ide->bus_master_command);
+	state_save_register_item("ide", which, ide->bus_master_status);
+	state_save_register_item("ide", which, ide->bus_master_descriptor);
 
-	state_save_register_UINT16("ide", which, "cur_cylinder",           &ide->cur_cylinder,          1);
-	state_save_register_UINT8 ("ide", which, "cur_sector",             &ide->cur_sector,            1);
-	state_save_register_UINT8 ("ide", which, "cur_head",               &ide->cur_head,              1);
-	state_save_register_UINT8 ("ide", which, "cur_head_reg",           &ide->cur_head_reg,          1);
+	state_save_register_item("ide", which, ide->cur_cylinder);
+	state_save_register_item("ide", which, ide->cur_sector);
+	state_save_register_item("ide", which, ide->cur_head);
+	state_save_register_item("ide", which, ide->cur_head_reg);
 
-	state_save_register_UINT32("ide", which, "cur_lba",                &ide->cur_lba,               1);
+	state_save_register_item("ide", which, ide->cur_lba);
 
-	state_save_register_UINT16("ide", which, "num_cylinders",          &ide->num_cylinders,         1);
-	state_save_register_UINT8 ("ide", which, "num_sectors",            &ide->num_sectors,           1);
-	state_save_register_UINT8 ("ide", which, "num_heads",              &ide->num_heads,             1);
+	state_save_register_item("ide", which, ide->num_cylinders);
+	state_save_register_item("ide", which, ide->num_sectors);
+	state_save_register_item("ide", which, ide->num_heads);
 
-	state_save_register_UINT8 ("ide", which, "config_unknown",         &ide->config_unknown,        1);
-	state_save_register_UINT8 ("ide", which, "config_register",        ide->config_register,        IDE_CONFIG_REGISTERS);
-	state_save_register_UINT8 ("ide", which, "config_register_num",    &ide->config_register_num,   1);
+	state_save_register_item("ide", which, ide->config_unknown);
+	state_save_register_item_array("ide", which, ide->config_register);
+	state_save_register_item("ide", which, ide->config_register_num);
 
-	state_save_register_int   ("ide", which, "master_password_enable", &ide->master_password_enable);
-	state_save_register_int   ("ide", which, "user_password_enable",   &ide->user_password_enable);
+	state_save_register_item("ide", which, ide->master_password_enable);
+	state_save_register_item("ide", which, ide->user_password_enable);
 
 	return 0;
 }
@@ -556,13 +580,13 @@ static void ide_build_features(struct ide_state *ide)
 	ide->features[ 2*2+0] = 0;							/*  2: reserved */
 	ide->features[ 2*2+1] = 0;
 	ide->features[ 3*2+0] = ide->num_heads & 0xff;		/*  3: logical heads */
-	ide->features[ 3*2+1] = ide->num_heads >> 8;
+	ide->features[ 3*2+1] = 0;/*ide->num_heads >> 8;*/
 	ide->features[ 4*2+0] = 0;							/*  4: vendor specific (obsolete) */
 	ide->features[ 4*2+1] = 0;
 	ide->features[ 5*2+0] = 0;							/*  5: vendor specific (obsolete) */
 	ide->features[ 5*2+1] = 0;
 	ide->features[ 6*2+0] = ide->num_sectors & 0xff;	/*  6: logical sectors per logical track */
-	ide->features[ 6*2+1] = ide->num_sectors >> 8;
+	ide->features[ 6*2+1] = 0;/*ide->num_sectors >> 8;*/
 	ide->features[ 7*2+0] = 0;							/*  7: vendor-specific */
 	ide->features[ 7*2+1] = 0;
 	ide->features[ 8*2+0] = 0;							/*  8: vendor-specific */
@@ -598,9 +622,9 @@ static void ide_build_features(struct ide_state *ide)
 	ide->features[54*2+0] = ide->num_cylinders & 0xff;	/* 54: number of current logical cylinders */
 	ide->features[54*2+1] = ide->num_cylinders >> 8;
 	ide->features[55*2+0] = ide->num_heads & 0xff;		/* 55: number of current logical heads */
-	ide->features[55*2+1] = ide->num_heads >> 8;
+	ide->features[55*2+1] = 0;/*ide->num_heads >> 8;*/
 	ide->features[56*2+0] = ide->num_sectors & 0xff;	/* 56: number of current logical sectors per track */
-	ide->features[56*2+1] = ide->num_sectors >> 8;
+	ide->features[56*2+1] = 0;/*ide->num_sectors >> 8;*/
 	ide->features[57*2+0] = sectors_per_track & 0xff;	/* 57-58: number of current logical sectors per track */
 	ide->features[57*2+1] = sectors_per_track >> 8;
 	ide->features[58*2+0] = sectors_per_track >> 16;
@@ -739,8 +763,9 @@ static void continue_read(struct ide_state *ide)
 	/* reset the totals */
 	ide->buffer_offset = 0;
 
-	/* clear the buffer ready flag */
+	/* clear the buffer ready and busy flag */
 	ide->status &= ~IDE_STATUS_BUFFER_READY;
+	ide->status &= ~IDE_STATUS_BUSY;
 
 	if (ide->master_password_enable || ide->user_password_enable)
 	{
@@ -823,10 +848,11 @@ static void read_sector_done(int which)
 		count = hard_disk_read(ide->disk, lba, 1, ide->buffer);
 
 	/* by default, mark the buffer ready and the seek complete */
-	ide->status |= IDE_STATUS_BUFFER_READY;
+	if (!ide->verify_only)
+		ide->status |= IDE_STATUS_BUFFER_READY;
 	ide->status |= IDE_STATUS_SEEK_COMPLETE;
 
-	/* and clear the busy adn error flags */
+	/* and clear the busy and error flags */
 	ide->status &= ~IDE_STATUS_ERROR;
 	ide->status &= ~IDE_STATUS_BUSY;
 
@@ -842,18 +868,21 @@ static void read_sector_done(int which)
 		ide->error = IDE_ERROR_NONE;
 
 		/* signal an interrupt */
-		if (--ide->sectors_until_int == 0 || ide->sector_count == 1)
+		if (!ide->verify_only)
+			ide->sectors_until_int--;
+		if (ide->sectors_until_int == 0 || ide->sector_count == 1)
 		{
 			ide->sectors_until_int = ((ide->command == IDE_COMMAND_READ_MULTIPLE_BLOCK) ? ide->block_count : 1);
 			signal_interrupt(ide);
 		}
 
-		/* keep going for DMA */
+		/* handle DMA */
 		if (ide->dma_active)
-		{
 			write_buffer_to_dma(ide);
+
+		/* if we're just verifying or if we DMA'ed the data, we can read the next sector */
+		if (ide->verify_only || ide->dma_active)
 			continue_read(ide);
-		}
 	}
 
 	/* if we got an error, we need to report it */
@@ -1091,6 +1120,7 @@ void handle_command(struct ide_state *ide, UINT8 command)
 			ide->buffer_offset = 0;
 			ide->sectors_until_int = 1;
 			ide->dma_active = 0;
+			ide->verify_only = 0;
 
 			/* start the read going */
 			read_first_sector(ide);
@@ -1104,6 +1134,21 @@ void handle_command(struct ide_state *ide, UINT8 command)
 			ide->buffer_offset = 0;
 			ide->sectors_until_int = 1;
 			ide->dma_active = 0;
+			ide->verify_only = 0;
+
+			/* start the read going */
+			read_first_sector(ide);
+			break;
+
+		case IDE_COMMAND_VERIFY_MULTIPLE:
+			LOGPRINT(("IDE Read verify multiple with retries: C=%d H=%d S=%d LBA=%d count=%d\n",
+				ide->cur_cylinder, ide->cur_head, ide->cur_sector, lba_address(ide), ide->sector_count));
+
+			/* reset the buffer */
+			ide->buffer_offset = 0;
+			ide->sectors_until_int = 1;
+			ide->dma_active = 0;
+			ide->verify_only = 1;
 
 			/* start the read going */
 			read_first_sector(ide);
@@ -1117,6 +1162,7 @@ void handle_command(struct ide_state *ide, UINT8 command)
 			ide->buffer_offset = 0;
 			ide->sectors_until_int = ide->sector_count;
 			ide->dma_active = 1;
+			ide->verify_only = 0;
 
 			/* start the read going */
 			if (ide->bus_master_command & 1)
@@ -1192,6 +1238,7 @@ void handle_command(struct ide_state *ide, UINT8 command)
 			/* indicate everything is ready */
 			ide->status |= IDE_STATUS_BUFFER_READY;
 			ide->status |= IDE_STATUS_SEEK_COMPLETE;
+			ide->status |= IDE_STATUS_DRIVE_READY;
 
 			/* and clear the busy adn error flags */
 			ide->status &= ~IDE_STATUS_ERROR;
@@ -1242,12 +1289,7 @@ void handle_command(struct ide_state *ide, UINT8 command)
 
 		default:
 			LOGPRINT(("IDE unknown command (%02X)\n", command));
-#ifdef MAME_DEBUG
-{
-	extern int debug_key_pressed;
-	debug_key_pressed = 1;
-}
-#endif
+			DEBUGGER_BREAK;
 			break;
 	}
 }
@@ -1265,7 +1307,7 @@ static UINT32 ide_controller_read(struct ide_state *ide, offs_t offset, int size
 	UINT32 result = 0;
 
 	/* logit */
-	if (offset != IDE_ADDR_DATA && offset != IDE_ADDR_STATUS_COMMAND && offset != IDE_ADDR_STATUS_CONTROL)
+/*  if (offset != IDE_ADDR_DATA && offset != IDE_ADDR_STATUS_COMMAND && offset != IDE_ADDR_STATUS_CONTROL) */
 		LOG(("%08X:IDE read at %03X, size=%d\n", activecpu_get_previouspc(), offset, size));
 
 	switch (offset)
@@ -1300,7 +1342,10 @@ static UINT32 ide_controller_read(struct ide_state *ide, offs_t offset, int size
 
 				/* if we're at the end of the buffer, handle it */
 				if (ide->buffer_offset >= IDE_DISK_SECTOR_SIZE)
+				{
+					LOG(("%08X:IDE completed PIO read\n", activecpu_get_previouspc()));
 					continue_read(ide);
+				}
 			}
 			break;
 
@@ -1409,6 +1454,7 @@ static void ide_controller_write(struct ide_state *ide, offs_t offset, int size,
 				/* if we're at the end of the buffer, handle it */
 				if (ide->buffer_offset >= IDE_DISK_SECTOR_SIZE)
 				{
+					LOG(("%08X:IDE completed PIO write\n", activecpu_get_previouspc()));
 					if (ide->command != IDE_COMMAND_SECURITY_UNLOCK)
 						continue_write(ide);
 					else
