@@ -24,7 +24,7 @@
     Fire Barrel                     ?       ? (same as R-Type Leo)
     In The Hunt                     Irem    D8000011A1 020
     Risky Challenge/Gussun Oyoyo            D8000019A1
-    Shisensho II                            D8000020A1 023 9320NK700
+    Match It II/Shisensho II        Irem    D8000020A1 023 9320NK700
     World PK Soccer                 Irem    D8000021A1
     Ninja Baseball Batman           ?       ?  (same as World PK Soccer)
     Perfect Soldiers                Irem    D8000022A1
@@ -37,6 +37,7 @@
 *****************************************************************************/
 
 #include "driver.h"
+#include "irem_cpu.h"
 
 /* CAVEATS: */
 /* 0x80 and 0x82 pre- opcodes can easily be confused. They perform exactly the same */
@@ -48,7 +49,7 @@
 
 #define xxxx 0xf1/* Unknown */
 
-const unsigned char gunforce_decryption_table[256] = {
+const UINT8 gunforce_decryption_table[256] = {
 	0xff,xxxx,xxxx,0x2c,xxxx,xxxx,0x43,0x88, xxxx,0x13,0x0a,0xbd,0xba,0x60,0xea,xxxx, /* 00 */
 	xxxx,xxxx,0xf2,0x29,0xb3,0x22,xxxx,0x0c, 0xa9,0x5f,0x9d,0x07,xxxx,xxxx,0x0b,0xbb, /* 10 */
 	0x8a,xxxx,xxxx,xxxx,0x3a,0x3c,0x5a,0x38, 0x99,xxxx,0xf8,0x89,xxxx,0x91,xxxx,0x55, /* 20 */
@@ -82,7 +83,7 @@ const unsigned char gunforce_decryption_table[256] = {
 
 /* 0x00 is NOT 0x20 (no context in bomberman) */
 
-const unsigned char bomberman_decryption_table[256] = {
+const UINT8 bomberman_decryption_table[256] = {
 	xxxx,xxxx,0x79,xxxx,0x9d,0x48,xxxx,xxxx, xxxx,xxxx,0x2e,xxxx,xxxx,0xa5,0x72,xxxx, /* 00 */
 	0x46,0x5b,0xb1,0x3a,0xc3,xxxx,0x35,xxxx, xxxx,0x23,xxxx,0x99,xxxx,0x05,xxxx,0x3c, /* 10 */
 	0x3b,0x76,0x11,xxxx,xxxx,0x4b,xxxx,0x92, xxxx,0x32,0x5d,xxxx,0xf7,0x5a,0x9c,xxxx, /* 20 */
@@ -102,7 +103,7 @@ const unsigned char bomberman_decryption_table[256] = {
 };
 
 
-const unsigned char lethalth_decryption_table[256] = {
+const UINT8 lethalth_decryption_table[256] = {
 	0x7f,0x26,0x5d,xxxx,0xba,xxxx,0x1e,0x5e, 0xb8,xxxx,0xbc,0xe8,0x01,xxxx,0x4a,0x25, /* 00 */
 	xxxx,0xbd,xxxx,0x22,0x10,xxxx,0x02,0x57, 0x70,xxxx,0x7c,xxxx,0xe7,0x52,xxxx,0xa9, /* 10 */
 /*                      ^^^^                 ^^^^ */
@@ -148,7 +149,7 @@ const unsigned char lethalth_decryption_table[256] = {
 /* 0xc5 (0x7a) completely in the dark (game start after car seelction) */
 
 
-const unsigned char dynablaster_decryption_table[256] = {
+const UINT8 dynablaster_decryption_table[256] = {
 	0x1f,0x51,0x84,xxxx,0x3d,0x09,0x0d,xxxx, xxxx,0x57,xxxx,xxxx,xxxx,0x32,0x11,xxxx, /* 00 */
 	xxxx,0x9c,xxxx,xxxx,0x4b,xxxx,xxxx,0x03, xxxx,xxxx,xxxx,0x89,0xb0,xxxx,xxxx,xxxx, /* 10 */
 	xxxx,0xbb,0x18,0xbe,0x53,0x21,0x55,0x7c, xxxx,xxxx,0x47,0x58,0xf6,xxxx,xxxx,0xb2, /* 20 */
@@ -182,7 +183,7 @@ const unsigned char dynablaster_decryption_table[256] = {
 /* NS010718  0xa0 was 0x00 (ADDB), verified to be 0x22 (ANDB) */
 
 
-const unsigned char mysticri_decryption_table[256] = {
+const UINT8 mysticri_decryption_table[256] = {
 	xxxx,0x57,xxxx,xxxx,xxxx,xxxx,xxxx,xxxx, 0xbf,0x43,xxxx,xxxx,xxxx,xxxx,0xfc,xxxx, /* 00 */
 	xxxx,xxxx,xxxx,xxxx,xxxx,0x52,0xa3,0x26, xxxx,0xc7,xxxx,0x0f,xxxx,0x0c,xxxx,xxxx, /* 10 */
 	xxxx,xxxx,0xff,xxxx,xxxx,0x02,xxxx,xxxx, 0x2e,xxxx,0x5f,xxxx,xxxx,xxxx,0x73,0x50, /* 20 */
@@ -204,7 +205,7 @@ const unsigned char mysticri_decryption_table[256] = {
 /* 0x4e (0x2b) not sure, could be 0x1b */
 
 
-const unsigned char majtitl2_decryption_table[256] = {
+const UINT8 majtitl2_decryption_table[256] = {
 	0x87,xxxx,0x78,0xaa,xxxx,xxxx,xxxx,0x2c, 0x32,0x0a,0x0f,xxxx,0x5e,xxxx,0xc6,0x8a, /* 00 */
 	0x33,xxxx,xxxx,xxxx,xxxx,0xea,xxxx,0x72, xxxx,xxxx,xxxx,xxxx,xxxx,xxxx,0x24,0x55, /* 10 */
 	xxxx,xxxx,xxxx,0x89,0xfb,xxxx,0x59,0x02, xxxx,xxxx,0x5d,xxxx,xxxx,xxxx,0x36,xxxx, /* 20 */
@@ -226,7 +227,7 @@ const unsigned char majtitl2_decryption_table[256] = {
 /* 0x70 (0x2b) not sure, could be 0x1b */
 
 
-const unsigned char hook_decryption_table[256] = {
+const UINT8 hook_decryption_table[256] = {
 	0xb6,0x20,0x22,xxxx,0x0f,0x57,0x59,0xc6, 0xeb,xxxx,0xb0,0xbb,0x3b,xxxx,xxxx,xxxx, /* 00 */
 	0x36,xxxx,xxxx,xxxx,xxxx,xxxx,xxxx,xxxx, xxxx,0xfe,xxxx,xxxx,xxxx,xxxx,xxxx,0xa0, /* 10 */
 	0x2e,xxxx,0x0b,xxxx,xxxx,0x58,xxxx,xxxx, xxxx,xxxx,xxxx,xxxx,xxxx,0x80,xxxx,xxxx, /* 20 */
@@ -248,7 +249,7 @@ const unsigned char hook_decryption_table[256] = {
 /* 0xbb (0x2b) not sure, could be 0x1b */
 
 
-const unsigned char rtypeleo_decryption_table[256] = {
+const UINT8 rtypeleo_decryption_table[256] = {
 	0x5d,xxxx,0xc6,xxxx,xxxx,xxxx,0x2a,0x3a, xxxx,xxxx,xxxx,0x86,xxxx,0x22,xxxx,0xf3, /* 00 */
 	xxxx,xxxx,xxxx,xxxx,xxxx,0x38,0x01,0x42, 0x04,xxxx,xxxx,0x1f,xxxx,xxxx,xxxx,0x58, /* 10 */
 /*                                ^^^^ */
@@ -274,7 +275,7 @@ const unsigned char rtypeleo_decryption_table[256] = {
 /* 0x16 (0x01) guess (wrong?) */
 
 
-const unsigned char inthunt_decryption_table[256] = {
+const UINT8 inthunt_decryption_table[256] = {
 	0x1f,xxxx,0xbb,0x50,xxxx,0x58,0x42,0x57, xxxx,xxxx,0xe9,xxxx,xxxx,xxxx,xxxx,0x0b, /* 00 */
 	xxxx,xxxx,0x9d,0x9c,xxxx,xxxx,0x1e,xxxx, xxxx,0xb4,0x5b,xxxx,xxxx,xxxx,xxxx,xxxx, /* 10 */
 	xxxx,xxxx,0x78,0xc7,xxxx,xxxx,0x83,xxxx, xxxx,0x0c,0xb0,0x04,xxxx,xxxx,xxxx,xxxx, /* 20 */
@@ -296,7 +297,7 @@ const unsigned char inthunt_decryption_table[256] = {
 /* 0xb8 (0x2b) not sure, could be 0x1b */
 
 
-const unsigned char gussun_decryption_table[256] = {
+const UINT8 gussun_decryption_table[256] = {
 	0x70,xxxx,xxxx,0x36,xxxx,0x52,0xb1,0x5b, 0x68,xxxx,xxxx,xxxx,xxxx,xxxx,xxxx,xxxx, /* 00 */
 /*  ????                                     ^^^^ ???? */
 	xxxx,xxxx,0x75,xxxx,xxxx,0x83,0x32,0xe9, xxxx,0x82,xxxx,xxxx,xxxx,xxxx,0xac,xxxx, /* 10 */
@@ -511,7 +512,7 @@ Unused: [1] fb  ei
 Unused: [1] fd  std
 */
 
-const unsigned char leagueman_decryption_table[256] = {
+const UINT8 leagueman_decryption_table[256] = {
 	xxxx,xxxx,xxxx,0x55,0xbb,xxxx,0x23,0x79, xxxx,xxxx,xxxx,xxxx,xxxx,xxxx,0x38,xxxx, /* 00 */
 	0x01,xxxx,xxxx,xxxx,xxxx,xxxx,xxxx,xxxx, 0x3d,xxxx,xxxx,xxxx,0xba,xxxx,0x1e,xxxx, /* 10 */
 	0x2c,0x46,xxxx,0xb5,xxxx,0x4b,xxxx,0xfe, xxxx,xxxx,0xfb,0x2e,xxxx,xxxx,0x36,0x04, /* 20 */
@@ -533,7 +534,7 @@ const unsigned char leagueman_decryption_table[256] = {
 /* 0x10 (0x01) guess (wrong?) */
 
 
-const unsigned char psoldier_decryption_table[256] = {
+const UINT8 psoldier_decryption_table[256] = {
 	xxxx,xxxx,xxxx,0x8a,xxxx,0xaa,xxxx,xxxx, xxxx,0x20,0x23,0x55,xxxx,0xb5,0x0a,xxxx, /* 00 */
 	xxxx,0x46,xxxx,0xb6,xxxx,0x74,0x8b,xxxx, xxxx,0xba,0x01,xxxx,xxxx,0x5a,0x86,0xfb, /* 10 */
 	0xb2,xxxx,0xb0,xxxx,0x42,0x06,0x1e,0x08, 0x22,0x9d,xxxx,xxxx,xxxx,xxxx,xxxx,0x73, /* 20 */
@@ -555,7 +556,7 @@ const unsigned char psoldier_decryption_table[256] = {
 /* 0x1a (0x01) guess (wrong?) */
 
 
-const unsigned char dsoccr94_decryption_table[256] = {
+const UINT8 dsoccr94_decryption_table[256] = {
 	xxxx,0xd1,xxxx,xxxx,xxxx,0x79,0x2e,xxxx, xxxx,xxxx,0x5a,0x0f,xxxx,xxxx,0x43,xxxx, /* 00 */
 	xxxx,xxxx,0xe8,0x50,xxxx,xxxx,xxxx,0xa0, 0x5d,0x22,xxxx,xxxx,0xb2,0x3a,xxxx,xxxx, /* 10 */
 	0xf6,0x8a,0x41,xxxx,xxxx,0x81,xxxx,xxxx, xxxx,xxxx,0x2b,0x58,xxxx,xxxx,xxxx,0xc6, /* 20 */
@@ -580,13 +581,13 @@ const unsigned char dsoccr94_decryption_table[256] = {
 
 
 /* preliminary table by Pierpaolo Prazzoli */
-const unsigned char shisen2_decryption_table[256] = {
+const UINT8 matchit2_decryption_table[256] = {
 	xxxx,0x86,0x0a,xxxx,0x32,0x01,0x81,0xbe, 0xea,xxxx,0xbb,xxxx,xxxx,xxxx,0xa5,0xf6, /* 00 */
-/*       new  new       new  new  new  new             new                 new  new */
+/*  new  new       new  new  new  new             new                 new  new */
 	0x5d,0x8c,0xf3,0xc4,0x42,0x5a,0x1c,0x26, xxxx,0x58,xxxx,xxxx,0x59,0x53,0x80,0x09, /* 10 */
 /*  new  new  new  new  !!!! new  ????            new            new  new  new  ???? */
 	xxxx,0x1e,0x48,0xe2,0x50,xxxx,0xc3,0x23, xxxx,xxxx,0xe9,xxxx,0x40,0x83,0xa3,0x46, /* 20 */
-/*       new  new  new  new       new  new             new       new  new  new */
+/*  new  new  new  new       new  new             new       new  new  new */
 	0x49,0xb4,0xa9,xxxx,0xd3,0x8b,0xe8,0xb8, 0xa0,xxxx,xxxx,xxxx,0x84,xxxx,xxxx,xxxx, /* 30 */
 /*  !!!! ???? new       !!!! new  new        new                 new */
 	xxxx,xxxx,xxxx,xxxx,0x14,xxxx,0x25,xxxx, xxxx,0x5e,xxxx,0x87,0x56,0xb9,xxxx,0x39, /* 40 */
@@ -643,7 +644,7 @@ the ones marked with "new" are checked against dynablst and bomberman tables
 
 
 
-const unsigned char test_decryption_table[256] = {
+const UINT8 test_decryption_table[256] = {
 	xxxx,xxxx,xxxx,xxxx,xxxx,xxxx,xxxx,xxxx, xxxx,xxxx,xxxx,xxxx,xxxx,xxxx,xxxx,xxxx, /* 00 */
 	xxxx,xxxx,xxxx,xxxx,xxxx,xxxx,xxxx,xxxx, xxxx,xxxx,xxxx,xxxx,xxxx,xxxx,xxxx,xxxx, /* 10 */
 	xxxx,xxxx,xxxx,xxxx,xxxx,xxxx,xxxx,xxxx, xxxx,xxxx,xxxx,xxxx,xxxx,xxxx,xxxx,xxxx, /* 20 */
@@ -662,7 +663,7 @@ const unsigned char test_decryption_table[256] = {
 	xxxx,xxxx,xxxx,xxxx,xxxx,xxxx,xxxx,xxxx, xxxx,xxxx,xxxx,xxxx,xxxx,xxxx,xxxx,xxxx, /* F0 */
 };
 
-static const unsigned char byte_count_table[256] = {
+static const UINT8 byte_count_table[256] = {
 	2,2,2,2,2,3,1,1, 2,2,2,2,2,3,1,0, /* 00 */
 	2,2,2,2,2,3,1,1, 2,2,2,2,2,3,1,1, /* 10 */
 	2,2,2,2,2,3,1,1, 2,2,2,2,2,3,1,1, /* 20 */
@@ -681,21 +682,24 @@ static const unsigned char byte_count_table[256] = {
 	0,0,0,0,0,0,0,0, 1,1,1,1,1,1,0,0, /* F0 */
 };
 
-void irem_cpu_decrypt(int cpu,const unsigned char *decryption_table)
+UINT8 *irem_cpu_decrypted;
+
+void irem_cpu_decrypt(int cpu,const UINT8 *decryption_table)
 {
-	int A,diff;
-	unsigned char *rom;
+	int A,size;
+	UINT8 *rom;
 /*  int t[256]; */
 #ifdef MAME_DEBUG
 /*    extern char *opmap1[]; */
 #endif
 
 	rom = memory_region(cpu+REGION_CPU1);
-	diff = memory_region_length(cpu+REGION_CPU1) / 2;
+	size = memory_region_length(cpu+REGION_CPU1);
+	irem_cpu_decrypted = auto_malloc(size);
 
-	memory_set_opcode_base(cpu,rom+diff);
-	for (A = 0;A < diff;A++)
-		rom[A + diff] = decryption_table[rom[A]];
+	memory_set_decrypted_region(cpu,0,size-1,irem_cpu_decrypted);
+	for (A = 0;A < size;A++)
+		irem_cpu_decrypted[A] = decryption_table[rom[A]];
 
 /*
     for (A=0; A<256; A++) {
