@@ -7,7 +7,7 @@
 ***************************************************************************/
 
 #include "driver.h"
-#include "machine/random.h"
+#include "includes/kaneko16.h"
 
 #include "kanekotb.h"	/* TOYBOX MCU trojaning results */
 
@@ -427,7 +427,7 @@ probably the MCU model string, so this one should be in internal MCU ROM (anothe
 TODO: look at this one since this remark is only driver-based.
 */
 
-void toybox_mcu_run(void);
+void (*toybox_mcu_run)(void);	/* One of the following */
 void bloodwar_mcu_run(void);
 void bonkadv_mcu_run(void);
 void gtmr_mcu_run(void);
@@ -457,41 +457,6 @@ TOYBOX_MCU_COM_W(1)
 TOYBOX_MCU_COM_W(2)
 TOYBOX_MCU_COM_W(3)
 
-extern const game_driver driver_bloodwar;
-extern const game_driver driver_bonkadv;
-extern const game_driver driver_gtmr;
-extern const game_driver driver_gtmre;
-extern const game_driver driver_gtmrusa;
-extern const game_driver driver_gtmr2;
-extern const game_driver driver_gtmr2u;
-extern const game_driver driver_gtmr2a;
-extern const game_driver driver_gtmra;
-
-void toybox_mcu_run(void)
-{
-	if ( (Machine->gamedrv == &driver_bloodwar) )
-	{
-		bloodwar_mcu_run();
-	}
-	else
-	if ( (Machine->gamedrv == &driver_bonkadv) )
-	{
-		bonkadv_mcu_run();
-	}
-	else
-	if ( (Machine->gamedrv == &driver_gtmr)    ||
-		 (Machine->gamedrv == &driver_gtmra)   ||
-		 (Machine->gamedrv == &driver_gtmre)   ||
-		 (Machine->gamedrv == &driver_gtmrusa) ||
-		 (Machine->gamedrv == &driver_gtmr2)   ||
-		 (Machine->gamedrv == &driver_gtmr2u)  ||
-		 (Machine->gamedrv == &driver_gtmr2a) )
-	{
-		gtmr_mcu_run();
-	}
-}
-
-
 /*
     bonkadv and bloodwar test bit 0
 */
@@ -796,8 +761,8 @@ void gtmr_mcu_run(void)
 
 		case 0x04:	/* TEST (2 versions) */
 		{
-			if ((Machine->gamedrv == &driver_gtmr) ||
-			    (Machine->gamedrv == &driver_gtmra))
+			if (strcmp(Machine->gamedrv->name, "gtmr") == 0 ||
+				strcmp(Machine->gamedrv->name, "gtmra") == 0)
 			{
 				/* MCU writes the string "MM0525-TOYBOX199" to shared ram */
 				mcu_ram[mcu_offset+0] = 0x4d4d;
@@ -809,12 +774,7 @@ void gtmr_mcu_run(void)
 				mcu_ram[mcu_offset+6] = 0x5831;
 				mcu_ram[mcu_offset+7] = 0x3939;
 			}
-			else if ( (Machine->gamedrv == &driver_gtmre)  ||
-					  (Machine->gamedrv == &driver_gtmrusa) ||
-					  (Machine->gamedrv == &driver_gtmr2) ||
-					  (Machine->gamedrv == &driver_gtmr2u) ||
-					  (Machine->gamedrv == &driver_gtmr2a) )
-
+			else
 			{
 				/* MCU writes the string "USMM0713-TB1994 " to shared ram */
 				mcu_ram[mcu_offset+0] = 0x5553;
