@@ -21,15 +21,14 @@ void K053247GP_set_SpriteOffset(int offsx, int offsy);
 void K053936GP_set_offset(int chip, int xoffs, int yoffs);
 void K053936GP_clip_enable(int chip, int status);
 void K053936GP_set_cliprect(int chip, int minx, int maxx, int miny, int maxy);
-void K053936GP_0_zoom_draw(struct mame_bitmap *bitmap, const struct rectangle *cliprect, struct tilemap *tilemap, int tilebpp, int blend);
-void K053936GP_1_zoom_draw(struct mame_bitmap *bitmap, const struct rectangle *cliprect, struct tilemap *tilemap, int tilebpp, int blend);
+void K053936GP_0_zoom_draw(mame_bitmap *bitmap, const rectangle *cliprect, tilemap *tmap, int tilebpp, int blend);
+void K053936GP_1_zoom_draw(mame_bitmap *bitmap, const rectangle *cliprect, tilemap *tmap, int tilebpp, int blend);
 
 
 
 /* 1st-Tier GX/MW Variables and Functions */
-extern int konamigx_cfgport;
-extern data8_t  konamigx_wrport1_0, konamigx_wrport1_1;
-extern data16_t konamigx_wrport2;
+extern UINT8  konamigx_wrport1_0, konamigx_wrport1_1;
+extern UINT16 konamigx_wrport2;
 
 
 /* Tile and Sprite Mixcode Decoders */
@@ -84,9 +83,9 @@ void konamigx_le2_sprite_callback(int *code, int *color, int *priority);
 #define GXSUB_5BPP 		0x05	/*  32 colors */
 #define GXSUB_8BPP 		0x08	/* 256 colors */
 
-void konamigx_mixer(struct mame_bitmap *bitmap, const struct rectangle *cliprect,
-					struct tilemap *sub1, int sub1flags,
-					struct tilemap *sub2, int sub2flags,
+void konamigx_mixer(mame_bitmap *bitmap, const rectangle *cliprect,
+					tilemap *sub1, int sub1flags,
+					tilemap *sub2, int sub2flags,
 					int mixerflags);
 
 int konamigx_mixer_init(int objdma);
