@@ -8,7 +8,7 @@
 
 #include "driver.h"
 
-extern void mb3773_set_ck( data8_t new_ck );
+extern void mb3773_set_ck( UINT8 new_ck );
 extern void mb3773_init( void );
 
 #endif
