@@ -5,6 +5,7 @@
 ***************************************************************************/
 
 #include "driver.h"
+#include "debugger.h"
 #include "midwayic.h"
 #include "machine/idectrl.h"
 #include "sndhrdw/cage.h"
@@ -77,6 +78,7 @@ struct ioasic_state
 	UINT8	irq_state;
 	UINT16	sound_irq_state;
 	UINT8	auto_ack;
+	UINT8	force_fifo_full;
 
 	UINT16	fifo[FIFO_SIZE];
 	UINT16	fifo_in;
@@ -194,7 +196,7 @@ UINT8 midway_serial_pic_status_r(void)
 
 UINT8 midway_serial_pic_r(void)
 {
-	logerror("%08X:security R = %04X\n", activecpu_get_pc(), serial.buffer);
+	logerror("%08X:security R = %04X\n", safe_activecpu_get_pc(), serial.buffer);
 	serial.status = 1;
 	return serial.buffer;
 }
@@ -202,7 +204,7 @@ UINT8 midway_serial_pic_r(void)
 
 void midway_serial_pic_w(UINT8 data)
 {
-	logerror("%08X:security W = %04X\n", activecpu_get_pc(), data);
+	logerror("%08X:security W = %04X\n", safe_activecpu_get_pc(), data);
 
 	/* status seems to reflect the clock bit */
 	serial.status = (data >> 4) & 1;
@@ -278,7 +280,7 @@ UINT8 midway_serial_pic2_status_r(void)
 		result = 1;
 	}
 
-	logerror("%06X:PIC status %d\n", activecpu_get_pc(), result);
+	logerror("%06X:PIC status %d\n", safe_activecpu_get_pc(), result);
 	return result;
 }
 
@@ -288,7 +290,7 @@ UINT8 midway_serial_pic2_r(void)
 	UINT8 result = 0;
 
 	/* PIC data register */
-	logerror("%06X:PIC data read (index=%d total=%d latch=%03X) =", activecpu_get_pc(), pic.index, pic.total, pic.latch);
+	logerror("%06X:PIC data read (index=%d total=%d latch=%03X) =", safe_activecpu_get_pc(), pic.index, pic.total, pic.latch);
 
 	/* return the current result */
 	if (pic.latch & 0xf00)
@@ -311,9 +313,9 @@ void midway_serial_pic2_w(UINT8 data)
 
 	/* PIC command register */
 	if (pic.state == 0)
-		logerror("%06X:PIC command %02X\n", activecpu_get_pc(), data);
+		logerror("%06X:PIC command %02X\n", safe_activecpu_get_pc(), data);
 	else
-		logerror("%06X:PIC data %02X\n", activecpu_get_pc(), data);
+		logerror("%06X:PIC data %02X\n", safe_activecpu_get_pc(), data);
 
 	/* store in the latch, along with a bit to indicate we have data */
 	pic.latch = (data & 0x00f) | 0x480;
@@ -339,12 +341,7 @@ void midway_serial_pic2_w(UINT8 data)
 					memcpy(pic.buffer, serial.data, 16);
 					pic.total = 16;
 					pic.index = 0;
-#ifdef MAME_DEBUG
-{
-	extern int debug_key_pressed;
-	debug_key_pressed = 1;
-}
-#endif
+					DEBUGGER_BREAK;
 				}
 				break;
 
@@ -537,7 +534,6 @@ enum
 
 static UINT16 ioasic_fifo_r(void);
 static UINT16 ioasic_fifo_status_r(void);
-static void ioasic_fifo_reset_w(int state);
 static void ioasic_input_empty(int state);
 static void ioasic_output_full(int state);
 static void update_ioasic_irq(void);
@@ -559,9 +555,13 @@ void midway_ioasic_init(int shuffle, int upper, int yearoffs, void (*irq_callbac
 	};
 
 	/* do we have a DCS2 sound chip connected? (most likely) */
-	ioasic.has_dcs = (mame_find_cpu_index("dcs2") != -1);
+	ioasic.has_dcs = (mame_find_cpu_index("dcs2") != -1 || mame_find_cpu_index("dsio") != -1 || mame_find_cpu_index("denver") != -1);
 	ioasic.has_cage = (mame_find_cpu_index("cage") != -1);
 	ioasic.dcs_cpu = mame_find_cpu_index("dcs2");
+	if (ioasic.dcs_cpu == (UINT8)-1)
+		ioasic.dcs_cpu = mame_find_cpu_index("dsio");
+	if (ioasic.dcs_cpu == (UINT8)-1)
+		ioasic.dcs_cpu = mame_find_cpu_index("denver");
 	ioasic.shuffle_type = shuffle;
 	ioasic.shuffle_map = &shuffle_maps[shuffle][0];
 	ioasic.auto_ack = 0;
@@ -580,7 +580,7 @@ void midway_ioasic_init(int shuffle, int upper, int yearoffs, void (*irq_callbac
 		dcs_set_fifo_callbacks(ioasic_fifo_r, ioasic_fifo_status_r);
 		dcs_set_io_callbacks(ioasic_output_full, ioasic_input_empty);
 	}
-	ioasic_fifo_reset_w(1);
+	midway_ioasic_fifo_reset_w(1);
 
 	/* configure the CAGE IRQ */
 	if (ioasic.has_cage)
@@ -606,7 +606,7 @@ void midway_ioasic_reset(void)
 	ioasic.sound_irq_state = 0x0080;
 	ioasic.reg[IOASIC_INTCTL] = 0;
 	if (ioasic.has_dcs)
-		ioasic_fifo_reset_w(1);
+		midway_ioasic_fifo_reset_w(1);
 	update_ioasic_irq();
 	midway_serial_pic_reset_w(1);
 }
@@ -700,7 +700,7 @@ static UINT16 ioasic_fifo_r(void)
 		/* main CPU is handling the I/O ASIC interrupt */
 		if (ioasic.fifo_bytes == 0 && ioasic.has_dcs)
 		{
-			ioasic.fifo_force_buffer_empty_pc = activecpu_get_pc();
+			ioasic.fifo_force_buffer_empty_pc = safe_activecpu_get_pc();
 			if (LOG_FIFO)
 				logerror("fifo_r(%04X): FIFO empty, PC = %04X\n", result, ioasic.fifo_force_buffer_empty_pc);
 		}
@@ -718,11 +718,11 @@ static UINT16 ioasic_fifo_status_r(void)
 {
 	UINT16 result = 0;
 
-	if (ioasic.fifo_bytes == 0)
+	if (ioasic.fifo_bytes == 0 && !ioasic.force_fifo_full)
 		result |= 0x08;
 	if (ioasic.fifo_bytes >= FIFO_SIZE/2)
 		result |= 0x10;
-	if (ioasic.fifo_bytes >= FIFO_SIZE)
+	if (ioasic.fifo_bytes >= FIFO_SIZE || ioasic.force_fifo_full)
 		result |= 0x20;
 
 	/* kludge alert: if we're reading this from the DCS CPU itself, and we recently cleared */
@@ -730,7 +730,7 @@ static UINT16 ioasic_fifo_status_r(void)
 	/* sure the FIFO clear bit is set */
 	if (ioasic.fifo_force_buffer_empty_pc && cpu_getactivecpu() == ioasic.dcs_cpu)
 	{
-		offs_t currpc = activecpu_get_pc();
+		offs_t currpc = safe_activecpu_get_pc();
 		if (currpc >= ioasic.fifo_force_buffer_empty_pc && currpc < ioasic.fifo_force_buffer_empty_pc + 0x10)
 		{
 			ioasic.fifo_force_buffer_empty_pc = 0;
@@ -744,7 +744,7 @@ static UINT16 ioasic_fifo_status_r(void)
 }
 
 
-static void ioasic_fifo_reset_w(int state)
+void midway_ioasic_fifo_reset_w(int state)
 {
 	/* on the high state, reset the FIFO data */
 	if (state)
@@ -752,10 +752,11 @@ static void ioasic_fifo_reset_w(int state)
 		ioasic.fifo_in = 0;
 		ioasic.fifo_out = 0;
 		ioasic.fifo_bytes = 0;
+		ioasic.force_fifo_full = 0;
 		update_ioasic_irq();
 	}
 	if (LOG_FIFO)
-		logerror("fifo_reset(%d)\n", state);
+		logerror("%08X:fifo_reset(%d)\n", safe_activecpu_get_pc(), state);
 }
 
 
@@ -779,6 +780,16 @@ void midway_ioasic_fifo_w(UINT16 data)
 }
 
 
+void midway_ioasic_fifo_full_w(UINT16 data)
+{
+	if (LOG_FIFO)
+		logerror("fifo_full_w(%04X)\n", data);
+	ioasic.force_fifo_full = 1;
+	update_ioasic_irq();
+	dcs_fifo_notify(ioasic.fifo_bytes, FIFO_SIZE);
+}
+
+
 
 /*************************************
  *
@@ -877,7 +888,7 @@ READ32_HANDLER( midway_ioasic_r )
 	}
 
 	if (LOG_IOASIC && offset != IOASIC_SOUNDSTAT && offset != IOASIC_SOUNDIN)
-		logerror("%06X:ioasic_r(%d) = %08X\n", activecpu_get_pc(), offset, result);
+		logerror("%06X:ioasic_r(%d) = %08X\n", safe_activecpu_get_pc(), offset, result);
 
 	return result;
 }
@@ -902,7 +913,7 @@ WRITE32_HANDLER( midway_ioasic_w )
 	newreg = ioasic.reg[offset];
 
 	if (LOG_IOASIC && offset != IOASIC_SOUNDOUT)
-		logerror("%06X:ioasic_w(%d) = %08X\n", activecpu_get_pc(), offset, data);
+		logerror("%06X:ioasic_w(%d) = %08X\n", safe_activecpu_get_pc(), offset, data);
 
 	switch (offset)
 	{
@@ -952,7 +963,7 @@ WRITE32_HANDLER( midway_ioasic_w )
 			}
 
 			/* FIFO reset? */
-			ioasic_fifo_reset_w(~newreg & 4);
+			midway_ioasic_fifo_reset_w(~newreg & 4);
 			break;
 
 		case IOASIC_SOUNDOUT:
