@@ -1,8 +1,5 @@
 #include "driver.h"
-#include "state.h"
-#include "vidhrdw/generic.h"
 #include "sound/ym2151.h"
-#include "machine/random.h"
 #include "sound/namco.h"
 
 #define NAMCOS1_MAX_BANK 0x400
@@ -10,13 +7,14 @@
 /* from vidhrdw */
 READ8_HANDLER( namcos1_videoram_r );
 WRITE8_HANDLER( namcos1_videoram_w );
-READ8_HANDLER( namcos1_paletteram_r );
 WRITE8_HANDLER( namcos1_paletteram_w );
 READ8_HANDLER( namcos1_spriteram_r );
 WRITE8_HANDLER( namcos1_spriteram_w );
 extern void namcos1_set_scroll_offsets( const int *bgx, const int *bgy, int negative, int optimize );
 extern void namcos1_set_sprite_offsets( int x, int y );
 
+UINT8 *namcos1_paletteram;
+
 static UINT8 *namcos1_triram;
 static UINT8 *s1ram;
 
@@ -668,7 +666,8 @@ static void set_bank(int banknum, bankhandler *handler)
 	int cpunum = (banknum >> 3) & 1;
 
 	/* for BANK handlers , memory direct and OP-code base */
-	memory_set_bankptr(banknum + 1, handler->bank_pointer);
+	if (handler->bank_pointer)
+		memory_set_bankptr(banknum + 1, handler->bank_pointer);
 
 	/* read handlers */
 	if (!handler->bank_handler_r)
@@ -802,7 +801,7 @@ static void namcos1_build_banks(read8_handler key_r,write8_handler key_w)
 	/* 3D glasses */
 	namcos1_install_bank(0x160,0x160,0,namcos1_3dcs_w,0,0);
 	/* RAM 6 banks - palette */
-	namcos1_install_bank(0x170,0x173,namcos1_paletteram_r,namcos1_paletteram_w,0,0);
+	namcos1_install_bank(0x170,0x173,0,namcos1_paletteram_w,0,namcos1_paletteram);
 	/* RAM 5 banks - videoram */
 	namcos1_install_bank(0x178,0x17b,namcos1_videoram_r,namcos1_videoram_w,0,0);
 	/* key chip bank */
@@ -833,7 +832,7 @@ static void namcos1_build_banks(read8_handler key_r,write8_handler key_w)
 	}
 }
 
-MACHINE_INIT( namcos1 )
+MACHINE_RESET( namcos1 )
 {
 	static bankhandler unknown_handler = { unknown_r, unknown_w, 0, NULL };
 	int bank;
@@ -970,10 +969,12 @@ static void namcos1_driver_init(const struct namcos1_specific *specific )
 	/* S1 RAM pointer set */
 	s1ram = auto_malloc(0x8000);
 	namcos1_triram = auto_malloc(0x800);
+	namcos1_paletteram = auto_malloc(0x8000);
 
 	/* Register volatile user memory for save state */
-	state_save_register_UINT8 ("memory", cpu_gettotalcpu(), "s1ram", s1ram, 0x8000);
-	state_save_register_UINT8 ("memory", cpu_gettotalcpu(), "triram", namcos1_triram, 0x800);
+	state_save_register_global_pointer(s1ram, 0x8000);
+	state_save_register_global_pointer(namcos1_triram, 0x800);
+	state_save_register_global_pointer(namcos1_paletteram, 0x8000);
 
 	/* Point mcu & sound shared RAM to destination */
 	memory_set_bankptr( 18, namcos1_triram );
