@@ -1,20 +1,22 @@
 /***************************************************************************
 
-	Atari Night Driver hardware
+    Atari Night Driver hardware
 
 ***************************************************************************/
 
 #include "driver.h"
-#include "vidhrdw/generic.h"
 #include "nitedrvr.h"
+#include "sound/discrete.h"
 
-static int nitedrvr_gear = 1;
-static int nitedrvr_track;
-static int nitedrvr_steering_buf;
-static int nitedrvr_steering_val;
-static int nitedrvr_crash_en;
-static int nitedrvr_crash_data = 0x0f;
-static int nitedrvr_crash_data_en;	/* IC D8 */
+static UINT8 nitedrvr_gear = 1;
+static UINT8 nitedrvr_track;
+static INT32 nitedrvr_steering_buf;
+static INT32 nitedrvr_steering_val;
+static UINT8 nitedrvr_crash_en;
+static UINT8 nitedrvr_crash_data = 0x0f;
+static UINT8 nitedrvr_crash_data_en;	/* IC D8 */
+static UINT8 ac_line;
+static INT32 last_steering_val;
 
 /***************************************************************************
 Steering
@@ -27,14 +29,13 @@ change in-between can affect the direction you move.
 ***************************************************************************/
 static int nitedrvr_steering(void)
 {
-	static int last_val=0;
 	int this_val;
 	int delta;
 
 	this_val = readinputport(5);
 
-	delta=this_val-last_val;
-	last_val=this_val;
+	delta=this_val-last_steering_val;
+	last_steering_val=this_val;
 	if (delta>128) delta-=256;
 	else if (delta<-128) delta+=256;
 	/* Divide by four to make our steering less sensitive */
@@ -77,26 +78,26 @@ WRITE8_HANDLER( nitedrvr_steering_reset_w )
 nitedrvr_in0_r
 
 Night Driver looks for the following:
-	A: $00
-		D4 - OPT1
-		D5 - OPT2
-		D6 - OPT3
-		D7 - OPT4
-	A: $01
-		D4 - TRACK SET
-		D5 - BONUS TIME ALLOWED
-		D6 - VBLANK
-		D7 - !TEST
-	A: $02
-		D4 - !GEAR 1
-		D5 - !GEAR 2
-		D6 - !GEAR 3
-		D7 - SPARE
-	A: $03
-		D4 - SPARE
-		D5 - DIFFICULT BONUS
-		D6 - STEER A
-		D7 - STEER B
+    A: $00
+        D4 - OPT1
+        D5 - OPT2
+        D6 - OPT3
+        D7 - OPT4
+    A: $01
+        D4 - TRACK SET
+        D5 - BONUS TIME ALLOWED
+        D6 - VBLANK
+        D7 - !TEST
+    A: $02
+        D4 - !GEAR 1
+        D5 - !GEAR 2
+        D6 - !GEAR 3
+        D7 - SPARE
+    A: $03
+        D4 - SPARE
+        D5 - DIFFICULT BONUS
+        D6 - STEER A
+        D7 - STEER B
 
 Fill in the steering and gear bits in a special way.
 ***************************************************************************/
@@ -133,37 +134,36 @@ READ8_HANDLER( nitedrvr_in0_r )
 nitedrvr_in1_r
 
 Night Driver looks for the following:
-	A: $00
-		D6 - SPARE
-		D7 - COIN 1
-	A: $01
-		D6 - SPARE
-		D7 - COIN 2
-	A: $02
-		D6 - SPARE
-		D7 - !START
-	A: $03
-		D6 - SPARE
-		D7 - !ACC
-	A: $04
-		D6 - SPARE
-		D7 - EXPERT
-	A: $05
-		D6 - SPARE
-		D7 - NOVICE
-	A: $06
-		D6 - SPARE
-		D7 - Special Alternating Signal
-	A: $07
-		D6 - SPARE
-		D7 - Ground
+    A: $00
+        D6 - SPARE
+        D7 - COIN 1
+    A: $01
+        D6 - SPARE
+        D7 - COIN 2
+    A: $02
+        D6 - SPARE
+        D7 - !START
+    A: $03
+        D6 - SPARE
+        D7 - !ACC
+    A: $04
+        D6 - SPARE
+        D7 - EXPERT
+    A: $05
+        D6 - SPARE
+        D7 - NOVICE
+    A: $06
+        D6 - SPARE
+        D7 - Special Alternating Signal
+    A: $07
+        D6 - SPARE
+        D7 - Ground
 
 Fill in the track difficulty switch and special signal in a special way.
 ***************************************************************************/
 
 READ8_HANDLER( nitedrvr_in1_r )
 {
-	static int ac_line=0x00;
 	int port;
 
 	ac_line=(ac_line+1) % 3;
@@ -268,3 +268,16 @@ void nitedrvr_crash_toggle(int dummy)
 		}
 	}
 }
+
+void nitedrvr_register_machine_vars(void)
+{/* save all the statics in this file. */
+	state_save_register_global(nitedrvr_gear);
+	state_save_register_global(nitedrvr_track);
+	state_save_register_global(nitedrvr_steering_buf);
+	state_save_register_global(nitedrvr_steering_val);
+	state_save_register_global(nitedrvr_crash_en);
+	state_save_register_global(nitedrvr_crash_data);
+	state_save_register_global(nitedrvr_crash_data_en);
+	state_save_register_global(ac_line);
+	state_save_register_global(last_steering_val);
+}
