@@ -6,8 +6,8 @@
 
 ***************************************************************************/
 
+#include <stdarg.h>
 #include "driver.h"
-#include "state.h"
 #include "cpu/mips/psx.h"
 #include "includes/psx.h"
 
@@ -33,10 +33,10 @@ INLINE void verboselog( int n_level, const char *s_fmt, ... )
 	}
 }
 
-data32_t *g_p_n_psxram;
+UINT32 *g_p_n_psxram;
 size_t g_n_psxramsize;
 
-INLINE void psxwriteword( data32_t n_address, data16_t n_data )
+INLINE void psxwriteword( UINT32 n_address, UINT16 n_data )
 {
 	*( (UINT16 *)( (UINT8 *)g_p_n_psxram + WORD_XOR_LE( n_address ) ) ) = n_data;
 }
@@ -46,7 +46,7 @@ INLINE UINT16 psxreadword( UINT32 n_address )
 	return *( (UINT16 *)( (UINT8 *)g_p_n_psxram + WORD_XOR_LE( n_address ) ) );
 }
 
-static data32_t psx_com_delay = 0;
+static UINT32 psx_com_delay = 0;
 
 WRITE32_HANDLER( psx_com_delay_w )
 {
@@ -210,7 +210,7 @@ void dma_finished( int n_channel )
 				if( n_address == 0xffffff )
 				{
 					m_p_n_dmabase[ n_channel ] = n_address;
-					dma_start_timer( n_channel, 26000 );
+					dma_start_timer( n_channel, 19000 );
 					return;
 				}
 				if( n_total > 65535 )
@@ -432,10 +432,10 @@ READ32_HANDLER( psx_dma_r )
 /* Root Counters */
 
 static void *m_p_timer_root[ 3 ];
-static data16_t m_p_n_root_count[ 3 ];
-static data16_t m_p_n_root_mode[ 3 ];
-static data16_t m_p_n_root_target[ 3 ];
-static data32_t m_p_n_root_start[ 3 ];
+static UINT16 m_p_n_root_count[ 3 ];
+static UINT16 m_p_n_root_mode[ 3 ];
+static UINT16 m_p_n_root_target[ 3 ];
+static UINT32 m_p_n_root_start[ 3 ];
 
 #define RC_STOP ( 0x01 )
 #define RC_RESET ( 0x04 ) /* guess */
@@ -470,7 +470,7 @@ static int root_divider( int n_counter )
 	return 1;
 }
 
-static data16_t root_current( int n_counter )
+static UINT16 root_current( int n_counter )
 {
 	if( ( m_p_n_root_mode[ n_counter ] & RC_STOP ) != 0 )
 	{
@@ -478,7 +478,7 @@ static data16_t root_current( int n_counter )
 	}
 	else
 	{
-		data32_t n_current;
+		UINT32 n_current;
 		n_current = psxcpu_gettotalcycles() - m_p_n_root_start[ n_counter ];
 		n_current /= root_divider( n_counter );
 		n_current += m_p_n_root_count[ n_counter ];
@@ -588,7 +588,7 @@ WRITE32_HANDLER( psx_counter_w )
 READ32_HANDLER( psx_counter_r )
 {
 	int n_counter;
-	data32_t data;
+	UINT32 data;
 
 	n_counter = offset / 4;
 
@@ -615,20 +615,20 @@ READ32_HANDLER( psx_counter_r )
 
 #define SIO_BUF_SIZE ( 8 )
 
-static data32_t m_p_n_sio_status[ 2 ];
-static data32_t m_p_n_sio_mode[ 2 ];
-static data32_t m_p_n_sio_control[ 2 ];
-static data32_t m_p_n_sio_baud[ 2 ];
-static data32_t m_p_n_sio_tx[ 2 ];
-static data32_t m_p_n_sio_rx[ 2 ];
-static data32_t m_p_n_sio_tx_prev[ 2 ];
-static data32_t m_p_n_sio_rx_prev[ 2 ];
-static data32_t m_p_n_sio_tx_data[ 2 ];
-static data32_t m_p_n_sio_rx_data[ 2 ];
-static data32_t m_p_n_sio_tx_shift[ 2 ];
-static data32_t m_p_n_sio_rx_shift[ 2 ];
-static data32_t m_p_n_sio_tx_bits[ 2 ];
-static data32_t m_p_n_sio_rx_bits[ 2 ];
+static UINT32 m_p_n_sio_status[ 2 ];
+static UINT32 m_p_n_sio_mode[ 2 ];
+static UINT32 m_p_n_sio_control[ 2 ];
+static UINT32 m_p_n_sio_baud[ 2 ];
+static UINT32 m_p_n_sio_tx[ 2 ];
+static UINT32 m_p_n_sio_rx[ 2 ];
+static UINT32 m_p_n_sio_tx_prev[ 2 ];
+static UINT32 m_p_n_sio_rx_prev[ 2 ];
+static UINT32 m_p_n_sio_tx_data[ 2 ];
+static UINT32 m_p_n_sio_rx_data[ 2 ];
+static UINT32 m_p_n_sio_tx_shift[ 2 ];
+static UINT32 m_p_n_sio_rx_shift[ 2 ];
+static UINT32 m_p_n_sio_tx_bits[ 2 ];
+static UINT32 m_p_n_sio_rx_bits[ 2 ];
 
 static void *m_p_timer_sio[ 2 ];
 static psx_sio_handler m_p_f_sio_handler[ 2 ];
@@ -873,7 +873,7 @@ WRITE32_HANDLER( psx_sio_w )
 
 READ32_HANDLER( psx_sio_r )
 {
-	data32_t data;
+	UINT32 data;
 	int n_port;
 
 	n_port = offset / 4;
@@ -934,6 +934,10 @@ void psx_sio_install_handler( int n_port, psx_sio_handler p_f_sio_handler )
 
 /* MDEC */
 
+static int mdec_decoded = 0;
+static int mdec_offset = 0;
+static UINT16 mdec_output[ 24 * 16 ];
+
 #define	DCTSIZE ( 8 )
 #define	DCTSIZE2 ( DCTSIZE * DCTSIZE )
 
@@ -1064,9 +1068,12 @@ static UINT32 mdec_unpack( UINT32 n_address )
 		}
 		n_packed = psxreadword( n_address );
 		n_address += 2;
+		if( n_packed == 0xfe00 )
+		{
+			break;
+		}
 
 		n_qscale = mdec_unpack_run( n_packed );
-
 		p_n_unpacked[ 0 ] = mdec_unpack_val( n_packed ) * p_n_q[ 0 ];
 
 		n_z = 0;
@@ -1127,18 +1134,20 @@ INLINE UINT16 mdec_clamp_b5( INT32 n_b )
 	return m_p_n_mdec_b5[ n_b + 128 + 256 ];
 }
 
-INLINE void mdec_makergb15( UINT32 n_address, INT32 n_r, INT32 n_g, INT32 n_b, INT32 *p_n_y, UINT32 n_stp )
+INLINE void mdec_makergb15( UINT32 n_address, INT32 n_r, INT32 n_g, INT32 n_b, INT32 *p_n_y, UINT16 n_stp )
 {
-	g_p_n_psxram[ n_address / 4 ] = n_stp |
+	mdec_output[ WORD_XOR_LE( n_address + 0 ) / 2 ] = n_stp |
 		mdec_clamp_r5( p_n_y[ 0 ] + n_r ) |
 		mdec_clamp_g5( p_n_y[ 0 ] + n_g ) |
-		mdec_clamp_b5( p_n_y[ 0 ] + n_b ) |
-		( mdec_clamp_r5( p_n_y[ 1 ] + n_r ) |
+		mdec_clamp_b5( p_n_y[ 0 ] + n_b );
+
+	mdec_output[ WORD_XOR_LE( n_address + 2 ) / 2 ] = n_stp |
+		mdec_clamp_r5( p_n_y[ 1 ] + n_r ) |
 		mdec_clamp_g5( p_n_y[ 1 ] + n_g ) |
-		mdec_clamp_b5( p_n_y[ 1 ] + n_b ) ) << 16;
+		mdec_clamp_b5( p_n_y[ 1 ] + n_b );
 }
 
-static void mdec_yuv2_to_rgb15( UINT32 n_address )
+static void mdec_yuv2_to_rgb15( void )
 {
 	INT32 n_r;
 	INT32 n_g;
@@ -1151,19 +1160,20 @@ static void mdec_yuv2_to_rgb15( UINT32 n_address )
 	UINT32 n_x;
 	UINT32 n_y;
 	UINT32 n_z;
-	UINT32 n_stp;
+	UINT16 n_stp;
+	int n_address = 0;
 
 	if( ( m_n_mdec0_command & ( 1L << 25 ) ) != 0 )
 	{
-		n_stp = 0x80008000;
+		n_stp = 0x8000;
 	}
 	else
 	{
-		n_stp = 0x00000000;
+		n_stp = 0x0000;
 	}
 
-	p_n_cb = &m_p_n_mdec_unpacked[ 0 ];
-	p_n_cr = &m_p_n_mdec_unpacked[ DCTSIZE2 ];
+	p_n_cr = &m_p_n_mdec_unpacked[ 0 ];
+	p_n_cb = &m_p_n_mdec_unpacked[ DCTSIZE2 ];
 	p_n_y = &m_p_n_mdec_unpacked[ DCTSIZE2 * 2 ];
 
 	for( n_z = 0; n_z < 2; n_z++ )
@@ -1202,6 +1212,7 @@ static void mdec_yuv2_to_rgb15( UINT32 n_address )
 		}
 		p_n_y += DCTSIZE2;
 	}
+	mdec_decoded = ( 16 * 16 ) / 2;
 }
 
 INLINE UINT16 mdec_clamp8( INT32 n_r )
@@ -1211,12 +1222,12 @@ INLINE UINT16 mdec_clamp8( INT32 n_r )
 
 INLINE void mdec_makergb24( UINT32 n_address, INT32 n_r, INT32 n_g, INT32 n_b, INT32 *p_n_y, UINT32 n_stp )
 {
-	psxwriteword( n_address + 0, ( mdec_clamp8( p_n_y[ 0 ] + n_g ) << 8 ) | mdec_clamp8( p_n_y[ 0 ] + n_r ) );
-	psxwriteword( n_address + 2, ( mdec_clamp8( p_n_y[ 1 ] + n_r ) << 8 ) | mdec_clamp8( p_n_y[ 0 ] + n_b ) );
-	psxwriteword( n_address + 4, ( mdec_clamp8( p_n_y[ 1 ] + n_b ) << 8 ) | mdec_clamp8( p_n_y[ 1 ] + n_g ) );
+	mdec_output[ WORD_XOR_LE( n_address + 0 ) / 2 ] = ( mdec_clamp8( p_n_y[ 0 ] + n_g ) << 8 ) | mdec_clamp8( p_n_y[ 0 ] + n_r );
+	mdec_output[ WORD_XOR_LE( n_address + 2 ) / 2 ] = ( mdec_clamp8( p_n_y[ 1 ] + n_r ) << 8 ) | mdec_clamp8( p_n_y[ 0 ] + n_b );
+	mdec_output[ WORD_XOR_LE( n_address + 4 ) / 2 ] = ( mdec_clamp8( p_n_y[ 1 ] + n_b ) << 8 ) | mdec_clamp8( p_n_y[ 1 ] + n_g );
 }
 
-static void mdec_yuv2_to_rgb24( UINT32 n_address )
+static void mdec_yuv2_to_rgb24( void )
 {
 	INT32 n_r;
 	INT32 n_g;
@@ -1230,6 +1241,7 @@ static void mdec_yuv2_to_rgb24( UINT32 n_address )
 	UINT32 n_y;
 	UINT32 n_z;
 	UINT32 n_stp;
+	int n_address = 0;
 
 	if( ( m_n_mdec0_command & ( 1L << 25 ) ) != 0 )
 	{
@@ -1240,8 +1252,8 @@ static void mdec_yuv2_to_rgb24( UINT32 n_address )
 		n_stp = 0x00000000;
 	}
 
-	p_n_cb = &m_p_n_mdec_unpacked[ 0 ];
-	p_n_cr = &m_p_n_mdec_unpacked[ DCTSIZE2 ];
+	p_n_cr = &m_p_n_mdec_unpacked[ 0 ];
+	p_n_cb = &m_p_n_mdec_unpacked[ DCTSIZE2 ];
 	p_n_y = &m_p_n_mdec_unpacked[ DCTSIZE2 * 2 ];
 
 	for( n_z = 0; n_z < 2; n_z++ )
@@ -1280,18 +1292,20 @@ static void mdec_yuv2_to_rgb24( UINT32 n_address )
 		}
 		p_n_y += DCTSIZE2;
 	}
+	mdec_decoded = ( 24 * 16 ) / 2;
 }
 
 static void mdec0_write( UINT32 n_address, INT32 n_size )
 {
 	int n_index;
 
+	verboselog( 2, "mdec0_write( %08x, %08x )\n", n_address, n_size );
 	switch( m_n_mdec0_command >> 28 )
 	{
 	case 0x3:
 		verboselog( 1, "mdec decode %08x %08x %08x\n", m_n_mdec0_command, n_address, n_size );
 		m_n_mdec0_address = n_address;
-		m_n_mdec0_size = n_size;
+		m_n_mdec0_size = n_size * 4;
 		m_n_mdec1_status |= ( 1L << 29 );
 		break;
 	case 0x4:
@@ -1339,29 +1353,60 @@ static void mdec0_write( UINT32 n_address, INT32 n_size )
 
 static void mdec1_read( UINT32 n_address, INT32 n_size )
 {
-	if( ( m_n_mdec0_command & ( 1L << 29 ) ) != 0 )
+	UINT32 n_this;
+	UINT32 n_nextaddress;
+
+	verboselog( 2, "mdec1_read( %08x, %08x )\n", n_address, n_size );
+	if( ( m_n_mdec0_command & ( 1L << 29 ) ) != 0 && m_n_mdec0_size != 0 )
 	{
-		if( ( m_n_mdec0_command & ( 1L << 27 ) ) != 0 )
+		while( n_size > 0 )
 		{
-			while( n_size > 0 )
+			if( mdec_decoded == 0 )
 			{
-				m_n_mdec0_address = mdec_unpack( m_n_mdec0_address );
-				mdec_yuv2_to_rgb15( n_address );
-				n_address += ( 16 * 16 ) * 2;
-				n_size -= ( 16 * 16 ) / 2;
+				if( (int)m_n_mdec0_size <= 0 )
+				{
+					printf( "ran out of data %08x\n", n_size );
+					m_n_mdec0_size = 0;
+					break;
+				}
+
+				n_nextaddress = mdec_unpack( m_n_mdec0_address );
+				m_n_mdec0_size -= n_nextaddress - m_n_mdec0_address;
+				m_n_mdec0_address = n_nextaddress;
+
+				if( ( m_n_mdec0_command & ( 1L << 27 ) ) != 0 )
+				{
+					mdec_yuv2_to_rgb15();
+				}
+				else
+				{
+					mdec_yuv2_to_rgb24();
+				}
+				mdec_offset = 0;
 			}
+
+			n_this = mdec_decoded;
+			if( n_this > n_size )
+			{
+				n_this = n_size;
+			}
+			mdec_decoded -= n_this;
+
+			memcpy( (UINT8 *)g_p_n_psxram + n_address, (UINT8 *)mdec_output + mdec_offset, n_this * 4 );
+			mdec_offset += n_this * 4;
+			n_address += n_this * 4;
+			n_size -= n_this;
 		}
-		else
+
+		if( m_n_mdec0_size < 0 )
 		{
-			while( n_size > 0 )
-			{
-				m_n_mdec0_address = mdec_unpack( m_n_mdec0_address );
-				mdec_yuv2_to_rgb24( n_address );
-				n_address += ( 24 * 16 ) * 2;
-				n_size -= ( 24 * 16 ) / 2;
-			}
+			printf( "ran out of data %d\n", m_n_mdec0_size );
 		}
 	}
+	else
+	{
+		printf( "mdec1_read no conversion :%08x:%08x:\n", m_n_mdec0_command, m_n_mdec0_size );
+	}
 	m_n_mdec1_status &= ~( 1L << 29 );
 }
 
@@ -1385,8 +1430,10 @@ READ32_HANDLER( psx_mdec_r )
 	switch( offset )
 	{
 	case 0:
+		verboselog( 2, "mdec 0 status %08x\n", 0 );
 		return 0;
 	case 1:
+		verboselog( 2, "mdec 1 status %08x\n", m_n_mdec1_status );
 		return m_n_mdec1_status;
 	}
 	return 0;
@@ -1498,16 +1545,16 @@ void psx_driver_init( void )
 		m_p_n_mdec_clamp8[ n + 512 ] = 255;
 
 		m_p_n_mdec_r5[ n ] = 0;
-		m_p_n_mdec_r5[ n + 256 ] = ( n >> 3 ) << 10;
-		m_p_n_mdec_r5[ n + 512 ] = ( 255 >> 3 ) << 10;
+		m_p_n_mdec_r5[ n + 256 ] = ( n >> 3 );
+		m_p_n_mdec_r5[ n + 512 ] = ( 255 >> 3 );
 
 		m_p_n_mdec_g5[ n ] = 0;
 		m_p_n_mdec_g5[ n + 256 ] = ( n >> 3 ) << 5;
 		m_p_n_mdec_g5[ n + 512 ] = ( 255 >> 3 ) << 5;
 
 		m_p_n_mdec_b5[ n ] = 0;
-		m_p_n_mdec_b5[ n + 256 ] = ( n >> 3 );
-		m_p_n_mdec_b5[ n + 512 ] = ( 255 >> 3 );
+		m_p_n_mdec_b5[ n + 256 ] = ( n >> 3 ) << 10;
+		m_p_n_mdec_b5[ n + 512 ] = ( 255 >> 3 ) << 10;
 	}
 
 	for( n = 0; n < 2; n++ )
@@ -1521,43 +1568,43 @@ void psx_driver_init( void )
 	psx_dma_install_write_handler( 0, mdec0_write );
 	psx_dma_install_write_handler( 2, gpu_write );
 
-	state_save_register_UINT32( "psx", 0, "m_n_irqdata", &m_n_irqdata, 1 );
-	state_save_register_UINT32( "psx", 0, "m_n_irqmask", &m_n_irqmask, 1 );
-	state_save_register_UINT32( "psx", 0, "m_p_n_dmabase", m_p_n_dmabase, 7 );
-	state_save_register_UINT32( "psx", 0, "m_p_n_dmablockcontrol", m_p_n_dmablockcontrol, 7 );
-	state_save_register_UINT32( "psx", 0, "m_p_n_dmachannelcontrol", m_p_n_dmachannelcontrol, 7 );
-	state_save_register_UINT32( "psx", 0, "m_p_n_dma_ticks", m_p_n_dma_ticks, 7 );
-	state_save_register_UINT32( "psx", 0, "m_p_b_dma_running", m_p_b_dma_running, 7 );
-	state_save_register_UINT32( "psx", 0, "m_n_dpcp", &m_n_dpcp, 1 );
-	state_save_register_UINT32( "psx", 0, "m_n_dicr", &m_n_dicr, 1 );
-	state_save_register_UINT16( "psx", 0, "m_p_n_root_count", m_p_n_root_count, 3 );
-	state_save_register_UINT16( "psx", 0, "m_p_n_root_mode", m_p_n_root_mode, 3 );
-	state_save_register_UINT16( "psx", 0, "m_p_n_root_target", m_p_n_root_target, 3 );
-	state_save_register_UINT32( "psx", 0, "m_p_n_root_start", m_p_n_root_start, 3 );
+	state_save_register_global( m_n_irqdata );
+	state_save_register_global( m_n_irqmask );
+	state_save_register_global_array( m_p_n_dmabase );
+	state_save_register_global_array( m_p_n_dmablockcontrol );
+	state_save_register_global_array( m_p_n_dmachannelcontrol );
+	state_save_register_global_array( m_p_n_dma_ticks );
+	state_save_register_global_array( m_p_b_dma_running );
+	state_save_register_global( m_n_dpcp );
+	state_save_register_global( m_n_dicr );
+	state_save_register_global_array( m_p_n_root_count );
+	state_save_register_global_array( m_p_n_root_mode );
+	state_save_register_global_array( m_p_n_root_target );
+	state_save_register_global_array( m_p_n_root_start );
 
-	state_save_register_UINT32( "psx", 0, "m_p_n_sio_status", m_p_n_sio_status, 2 );
-	state_save_register_UINT32( "psx", 0, "m_p_n_sio_mode", m_p_n_sio_mode, 2 );
-	state_save_register_UINT32( "psx", 0, "m_p_n_sio_control", m_p_n_sio_control, 2 );
-	state_save_register_UINT32( "psx", 0, "m_p_n_sio_baud", m_p_n_sio_baud, 2 );
-	state_save_register_UINT32( "psx", 0, "m_p_n_sio_tx", m_p_n_sio_tx, 2 );
-	state_save_register_UINT32( "psx", 0, "m_p_n_sio_rx", m_p_n_sio_rx, 2 );
-	state_save_register_UINT32( "psx", 0, "m_p_n_sio_tx_prev", m_p_n_sio_tx_prev, 2 );
-	state_save_register_UINT32( "psx", 0, "m_p_n_sio_rx_prev", m_p_n_sio_rx_prev, 2 );
-	state_save_register_UINT32( "psx", 0, "m_p_n_sio_rx_data", m_p_n_sio_rx_data, 2 );
-	state_save_register_UINT32( "psx", 0, "m_p_n_sio_tx_data", m_p_n_sio_tx_data, 2 );
-	state_save_register_UINT32( "psx", 0, "m_p_n_sio_rx_shift", m_p_n_sio_rx_shift, 2 );
-	state_save_register_UINT32( "psx", 0, "m_p_n_sio_tx_shift", m_p_n_sio_tx_shift, 2 );
-	state_save_register_UINT32( "psx", 0, "m_p_n_sio_rx_bits", m_p_n_sio_rx_bits, 2 );
-	state_save_register_UINT32( "psx", 0, "m_p_n_sio_tx_bits", m_p_n_sio_tx_bits, 2 );
+	state_save_register_global_array( m_p_n_sio_status );
+	state_save_register_global_array( m_p_n_sio_mode );
+	state_save_register_global_array( m_p_n_sio_control );
+	state_save_register_global_array( m_p_n_sio_baud );
+	state_save_register_global_array( m_p_n_sio_tx );
+	state_save_register_global_array( m_p_n_sio_rx );
+	state_save_register_global_array( m_p_n_sio_tx_prev );
+	state_save_register_global_array( m_p_n_sio_rx_prev );
+	state_save_register_global_array( m_p_n_sio_rx_data );
+	state_save_register_global_array( m_p_n_sio_tx_data );
+	state_save_register_global_array( m_p_n_sio_rx_shift );
+	state_save_register_global_array( m_p_n_sio_tx_shift );
+	state_save_register_global_array( m_p_n_sio_rx_bits );
+	state_save_register_global_array( m_p_n_sio_tx_bits );
 
-	state_save_register_UINT32( "psx", 0, "m_n_mdec0_command", &m_n_mdec0_command, 1 );
-	state_save_register_UINT32( "psx", 0, "m_n_mdec0_address", &m_n_mdec0_address, 1 );
-	state_save_register_UINT32( "psx", 0, "m_n_mdec0_size", &m_n_mdec0_size, 1 );
-	state_save_register_UINT32( "psx", 0, "m_n_mdec1_command", &m_n_mdec1_command, 1 );
-	state_save_register_UINT32( "psx", 0, "m_n_mdec1_status", &m_n_mdec1_status, 1 );
-	state_save_register_INT32( "psx", 0, "m_p_n_mdec_quantize_y", m_p_n_mdec_quantize_y, DCTSIZE2 );
-	state_save_register_INT32( "psx", 0, "m_p_n_mdec_quantize_uv", m_p_n_mdec_quantize_uv, DCTSIZE2 );
-	state_save_register_INT32( "psx", 0, "m_p_n_mdec_cos", m_p_n_mdec_cos, DCTSIZE2 );
+	state_save_register_global( m_n_mdec0_command );
+	state_save_register_global( m_n_mdec0_address );
+	state_save_register_global( m_n_mdec0_size );
+	state_save_register_global( m_n_mdec1_command );
+	state_save_register_global( m_n_mdec1_status );
+	state_save_register_global_array( m_p_n_mdec_quantize_y );
+	state_save_register_global_array( m_p_n_mdec_quantize_uv );
+	state_save_register_global_array( m_p_n_mdec_cos );
 
 	state_save_register_func_postload( psx_postload );
 }
