@@ -8,13 +8,11 @@
 ***************************************************************************/
 
 #include "driver.h"
+#include "cpu/z80/z80.h"
 #include "machine/7474.h"
 #include "machine/8255ppi.h"
-#include "galaxian.h"
-#include "state.h"
-
-
-void cclimber_decode(const unsigned char xortable[8][16]);
+#include "includes/galaxian.h"
+#include "includes/cclimber.h"
 
 
 
@@ -82,7 +80,7 @@ static void interrupt_timer(int param)
 }
 
 
-static void machine_init_common( int line )
+static void machine_reset_common( int line )
 {
 	irq_line = line;
 
@@ -101,19 +99,19 @@ static void machine_init_common( int line )
 	timer_adjust(int_timer, cpu_getscanlinetime(0), 0, 0);
 }
 
-MACHINE_INIT( galaxian )
+MACHINE_RESET( galaxian )
 {
-	machine_init_common(INPUT_LINE_NMI);
+	machine_reset_common(INPUT_LINE_NMI);
 }
 
-MACHINE_INIT( devilfsg )
+MACHINE_RESET( devilfsg )
 {
-	machine_init_common(0);
+	machine_reset_common(0);
 }
 
-MACHINE_INIT( scramble )
+MACHINE_RESET( scramble )
 {
-	machine_init_galaxian();
+	machine_reset_galaxian();
 
 	if (cpu_gettotalcpu() > 1)
 	{
@@ -121,19 +119,19 @@ MACHINE_INIT( scramble )
 	}
 }
 
-MACHINE_INIT( sfx )
+MACHINE_RESET( sfx )
 {
-	machine_init_scramble();
+	machine_reset_scramble();
 
 	sfx_sh_init();
 }
 
-MACHINE_INIT( explorer )
+MACHINE_RESET( explorer )
 {
 	UINT8 *RAM = memory_region(REGION_CPU1);
 	RAM[0x47ff] = 0; /* If not set, it doesn't reset after the 1st time */
 
-	machine_init_galaxian();
+	machine_reset_galaxian();
 }
 
 WRITE8_HANDLER( galaxian_coin_lockout_w )
@@ -384,6 +382,8 @@ DRIVER_INIT( zigzag )
 	UINT8 *RAM = memory_region(REGION_CPU1);
 	memory_configure_bank(1, 0, 2, &RAM[0x2000], 0x1000);
 	memory_configure_bank(2, 0, 2, &RAM[0x2000], 0x1000);
+	memory_set_bank(1, 0);
+	memory_set_bank(2, 1);
 }
 
 
@@ -765,13 +765,12 @@ DRIVER_INIT( moonqsr )
 {
 	offs_t i;
 	UINT8 *rom = memory_region(REGION_CPU1);
-	offs_t diff = memory_region_length(REGION_CPU1) / 2;
+	UINT8 *decrypt = auto_malloc(0x8000);
 
+	memory_set_decrypted_region(0, 0x0000, 0x7fff, decrypt);
 
-	memory_set_opcode_base(0,rom+diff);
-
-	for (i = 0;i < diff;i++)
-		rom[i + diff] = decode_mooncrst(rom[i],i);
+	for (i = 0;i < 0x8000;i++)
+		decrypt[i] = decode_mooncrst(rom[i],i);
 }
 
 DRIVER_INIT( checkman )
@@ -973,8 +972,9 @@ DRIVER_INIT( mariner )
 	init_scramble_ppi();
 
 	/* extra ROM */
-	memory_install_read8_handler(0, ADDRESS_SPACE_PROGRAM, 0x5800, 0x67ff, 0, 0, MRA8_ROM);
+	memory_install_read8_handler(0, ADDRESS_SPACE_PROGRAM, 0x5800, 0x67ff, 0, 0, MRA8_BANK1);
 	memory_install_write8_handler(0, ADDRESS_SPACE_PROGRAM, 0x5800, 0x67ff, 0, 0, MWA8_ROM);
+	memory_set_bankptr(1, memory_region(REGION_CPU1) + 0x5800);
 
 	memory_install_read8_handler(0, ADDRESS_SPACE_PROGRAM, 0x9008, 0x9008, 0, 0, mariner_protection_2_r);
 	memory_install_read8_handler(0, ADDRESS_SPACE_PROGRAM, 0xb401, 0xb401, 0, 0, mariner_protection_1_r);
@@ -1491,7 +1491,7 @@ DRIVER_INIT( gmgalax )
 static READ8_HANDLER( scorpion_prot_r )
 {
 	/* HACK! return register C */
-	return activecpu_get_reg(4) & 0xff;
+	return activecpu_get_reg(Z80_C) & 0xff;
 }
 
 static READ8_HANDLER( scorpion_sound_status_r )
@@ -1506,8 +1506,8 @@ DRIVER_INIT( scorpion )
 	ppi8255_set_portCread(1, scorpion_prot_r);
 
 	/* extra ROM */
-	memory_install_read8_handler(0, ADDRESS_SPACE_PROGRAM, 0x5800, 0x67ff, 0, 0, MRA8_ROM);
-	memory_install_write8_handler(0, ADDRESS_SPACE_PROGRAM, 0x5800, 0x67ff, 0, 0, MWA8_ROM);
+	memory_install_read8_handler(0, ADDRESS_SPACE_PROGRAM, 0x5800, 0x67ff, 0, 0, MRA8_BANK1);
+	memory_set_bankptr(1, memory_region(REGION_CPU1) + 0x5800);
 
 	/* no background related */
 	memory_install_write8_handler(0, ADDRESS_SPACE_PROGRAM, 0x6803, 0x6803, 0, 0, MWA8_NOP);
