@@ -23,7 +23,7 @@ extern unsigned char *getstar_e803;
 static unsigned char mcu_val;
 
 /* Perform basic machine initialisation */
-MACHINE_INIT( slapfight )
+MACHINE_RESET( slapfight )
 {
 	/* MAIN CPU */
 
@@ -89,21 +89,21 @@ WRITE8_HANDLER( slapfight_port_08_w )
 {
 	unsigned char *RAM = memory_region(REGION_CPU1);
 
-	cpu_setbank(1,&RAM[0x10000]);
+	memory_set_bankptr(1,&RAM[0x10000]);
 }
 
 WRITE8_HANDLER( slapfight_port_09_w )
 {
 	unsigned char *RAM = memory_region(REGION_CPU1);
 
-	cpu_setbank(1,&RAM[0x14000]);
+	memory_set_bankptr(1,&RAM[0x14000]);
 }
 
 
 /* Status register */
 READ8_HANDLER( slapfight_port_00_r )
 {
-	int states[3]={ 0xc7, 0x55, 0x00 };
+	static const int states[3]={ 0xc7, 0x55, 0x00 };
 
 	slapfight_status = states[slapfight_status_state];
 
@@ -123,7 +123,7 @@ READ8_HANDLER( slapfight_port_00_r )
 */
 READ8_HANDLER( getstar_e803_r )
 {
-unsigned char seq[] = { 0, 1, ((0+5)^0x56) };
+	static const unsigned char seq[] = { 0, 1, ((0+5)^0x56) };
 unsigned char val;
 
 	val = seq[getstar_sequence_index];
