@@ -558,7 +558,7 @@ VIDEO_UPDATE( slikshot )
 	int temp, i;
 
 	/* draw the normal video first */
-	video_update_itech8_2page(bitmap, cliprect);
+	video_update_itech8_2page(screen, bitmap, cliprect);
 
 	/* add the current X,Y positions to the list */
 	xbuffer[ybuffer_next % YBUFFER_COUNT] = readinputportbytag_safe("FAKEX", 0);
@@ -598,7 +598,7 @@ VIDEO_UPDATE( slikshot )
 		curx = temp;
 
 		compute_sensors();
-/*      usrintf_showmessage("V=%02x,%02x  X=%02x", curvx, curvy, curx); */
+/*      ui_popup("V=%02x,%02x  X=%02x", curvx, curvy, curx); */
 		crosshair_vis = 0;
 	}
 	last_ytotal = totaldy;
@@ -614,9 +614,9 @@ VIDEO_UPDATE( slikshot )
 	if (crosshair_vis)
 	{
 		if ((Machine->gamedrv->flags & ORIENTATION_MASK) == ROT90)
-			draw_crosshair(bitmap, 256 - 48, (crosshair_min + crosshair_max) / 2 - (curxpos * (crosshair_max - crosshair_min) / 0x100), cliprect);
+			draw_crosshair(bitmap, 256 - 48, (crosshair_min + crosshair_max) / 2 - (curxpos * (crosshair_max - crosshair_min) / 0x100), cliprect, 0);
 		else
-			draw_crosshair(bitmap, 48, (crosshair_min + crosshair_max) / 2 + (curxpos * (crosshair_max - crosshair_min) / 0x100), cliprect);
+			draw_crosshair(bitmap, 48, (crosshair_min + crosshair_max) / 2 + (curxpos * (crosshair_max - crosshair_min) / 0x100), cliprect, 0);
 	}
 }
 
