@@ -1,12 +1,13 @@
 #include "driver.h"
 #include "system16.h"
+#include "includes/system24.h"
 
 /* system24temp_ functions / variables are from shared rewrite files,
    once the rest of the rewrite is complete they can be removed, I
    just made a copy & renamed them for now to avoid any conflicts
 */
 
-data16_t *system24temp_sys16_shared_ram;
+UINT16 *system24temp_sys16_shared_ram;
 READ16_HANDLER( system24temp_sys16_shared_ram_r )
 {
 	return system24temp_sys16_shared_ram[offset];
