@@ -4,10 +4,10 @@
 #include "driver.h"
 
 /* Machine init */
-MACHINE_INIT( tmp68301 );
+MACHINE_RESET( tmp68301 );
 
 /* Hardware Registers */
-extern data16_t *tmp68301_regs;
+extern UINT16 *tmp68301_regs;
 WRITE16_HANDLER( tmp68301_regs_w );
 
 /* Interrupts */
