@@ -4,15 +4,14 @@
 /*                       VERY PRELIMINARY!                           */
 /*===================================================================*/
 
-#include <stdio.h>
 #include "driver.h"
-#include "machine/random.h"
 
-extern INT16 *AU_PTR;
-extern int inst_index;
+static INT16 AU_DATA;
+static INT16 *AU_PTR = &AU_DATA;
+static int inst_index;
 
 /* Internal registers and so forth */
-struct Regs
+static struct Regs
 {
       INT16 X;    /* Multiplicand and divisor */
       INT16 X1;   /* Previous X */
@@ -591,9 +590,9 @@ ST
 
 READ8_HANDLER(BB_AU_R)
 {
-data8_t *AU_instr = (data8_t *)memory_region(REGION_USER1);
-/*data8_t *AU_PROM1 = (data8_t *)memory_region(REGION_PROMS) + 0x1700; */
-/*data8_t *AU_PROM2 = (data8_t *)memory_region(REGION_PROMS) + 0x1900; */
+UINT8 *AU_instr = (UINT8 *)memory_region(REGION_USER1);
+/*UINT8 *AU_PROM1 = (UINT8 *)memory_region(REGION_PROMS) + 0x1700; */
+/*UINT8 *AU_PROM2 = (UINT8 *)memory_region(REGION_PROMS) + 0x1900; */
 
 INT8 value = 0;
 
@@ -640,8 +639,8 @@ INT8 value = 0;
 
 WRITE8_HANDLER(BB_AU_W)
 {
-/*data8_t *AU_PROM1 = (data8_t *)memory_region(REGION_PROMS) + 0x1700; */
-/*data8_t *AU_PROM2 = (data8_t *)memory_region(REGION_PROMS) + 0x1900; */
+/*UINT8 *AU_PROM1 = (UINT8 *)memory_region(REGION_PROMS) + 0x1700; */
+/*UINT8 *AU_PROM2 = (UINT8 *)memory_region(REGION_PROMS) + 0x1900; */
 
       switch (offset)
       {
