@@ -98,7 +98,7 @@ static int remap_colors( int num, int addr, int data )
 
 		#ifdef MAME_DEBUG
 		else
-			usrintf_showmessage( "Unmatched color %02x, at address %04x", data & 0x3f, addr );
+			ui_popup( "Unmatched color %02x, at address %04x", data & 0x3f, addr );
 		#endif
 	}
 
@@ -216,7 +216,7 @@ READ8_HANDLER( vsnes_in1_1_r )
  *
  *************************************/
 
-MACHINE_INIT( vsnes )
+MACHINE_RESET( vsnes )
 {
 	input_latch[0] = input_latch[1] = 0;
 	input_latch[2] = input_latch[3] = 0;
@@ -234,7 +234,7 @@ MACHINE_INIT( vsnes )
  *  Init machine
  *
  *************************************/
-MACHINE_INIT( vsdual )
+MACHINE_RESET( vsdual )
 {
 	input_latch[0] = input_latch[1] = 0;
 	input_latch[2] = input_latch[3] = 0;
@@ -1284,7 +1284,7 @@ DRIVER_INIT( vstennis )
 	memory_install_read8_handler(1, ADDRESS_SPACE_PROGRAM, 0x6000, 0x7fff, 0, 0, MRA8_BANK1 );
 	memory_install_write8_handler(1, ADDRESS_SPACE_PROGRAM, 0x6000, 0x7fff, 0, 0, MWA8_BANK1 );
 
-	cpu_setbank(1, &memory_region(REGION_CPU1)[0x6000]);
+	memory_set_bankptr(1, &memory_region(REGION_CPU1)[0x6000]);
 }
 
 /**********************************************************************/
