@@ -5,7 +5,6 @@
 ***************************************************************************/
 
 #include "driver.h"
-#include "vidhrdw/generic.h"
 #include "sndhrdw/williams.h"
 #include "cpu/m6800/m6800.h"
 #include "cpu/m6809/m6809.h"
@@ -16,6 +15,11 @@
 #include "sound/hc55516.h"
 
 
+/* timers */
+static mame_timer *scanline_timer;
+static mame_timer *scan240_timer;
+static mame_timer *scan254_timer;
+
 /* banking addresses set by the drivers */
 UINT8 *mayday_protection;
 
@@ -65,7 +69,7 @@ static WRITE8_HANDLER( joust2_pia_3_cb1_w );
  *************************************/
 
 /* Generic PIA 0, maps to input ports 0 and 1 */
-struct pia6821_interface williams_pia_0_intf =
+const pia6821_interface williams_pia_0_intf =
 {
 	/*inputs : A/B,CA/B1,CA/B2 */ input_port_0_r, input_port_1_r, 0, 0, 0, 0,
 	/*outputs: A/B,CA/B2       */ 0, 0, 0, 0,
@@ -73,7 +77,7 @@ struct pia6821_interface williams_pia_0_intf =
 };
 
 /* Generic muxing PIA 0, maps to input ports 0/3 and 1; port select is CB2 */
-struct pia6821_interface williams_muxed_pia_0_intf =
+const pia6821_interface williams_muxed_pia_0_intf =
 {
 	/*inputs : A/B,CA/B1,CA/B2 */ williams_input_port_0_3_r, input_port_1_r, 0, 0, 0, 0,
 	/*outputs: A/B,CA/B2       */ 0, 0, 0, williams_port_select_w,
@@ -81,7 +85,7 @@ struct pia6821_interface williams_muxed_pia_0_intf =
 };
 
 /* Generic dual muxing PIA 0, maps to input ports 0/3 and 1/4; port select is CB2 */
-struct pia6821_interface williams_dual_muxed_pia_0_intf =
+const pia6821_interface williams_dual_muxed_pia_0_intf =
 {
 	/*inputs : A/B,CA/B1,CA/B2 */ williams_input_port_0_3_r, williams_input_port_1_4_r, 0, 0, 0, 0,
 	/*outputs: A/B,CA/B2       */ 0, 0, 0, williams_port_select_w,
@@ -89,7 +93,7 @@ struct pia6821_interface williams_dual_muxed_pia_0_intf =
 };
 
 /* Generic 49-way joystick PIA 0 for Sinistar/Blaster */
-struct pia6821_interface williams_49way_pia_0_intf =
+const pia6821_interface williams_49way_pia_0_intf =
 {
 	/*inputs : A/B,CA/B1,CA/B2 */ williams_49way_port_0_r, input_port_1_r, 0, 0, 0, 0,
 	/*outputs: A/B,CA/B2       */ 0, 0, 0, 0,
@@ -97,7 +101,7 @@ struct pia6821_interface williams_49way_pia_0_intf =
 };
 
 /* Muxing 49-way joystick PIA 0 for Blaster kit */
-struct pia6821_interface williams_49way_muxed_pia_0_intf =
+const pia6821_interface williams_49way_muxed_pia_0_intf =
 {
 	/*inputs : A/B,CA/B1,CA/B2 */ williams_input_port_49way_0_5_r, input_port_1_r, 0, 0, 0, 0,
 	/*outputs: A/B,CA/B2       */ 0, 0, 0, williams_port_select_w,
@@ -105,7 +109,7 @@ struct pia6821_interface williams_49way_muxed_pia_0_intf =
 };
 
 /* Generic PIA 1, maps to input port 2, sound command out, and IRQs */
-struct pia6821_interface williams_pia_1_intf =
+const pia6821_interface williams_pia_1_intf =
 {
 	/*inputs : A/B,CA/B1,CA/B2 */ input_port_2_r, 0, 0, 0, 0, 0,
 	/*outputs: A/B,CA/B2       */ 0, williams_snd_cmd_w, 0, 0,
@@ -113,7 +117,7 @@ struct pia6821_interface williams_pia_1_intf =
 };
 
 /* Generic PIA 2, maps to DAC data in and sound IRQs */
-struct pia6821_interface williams_snd_pia_intf =
+const pia6821_interface williams_snd_pia_intf =
 {
 	/*inputs : A/B,CA/B1,CA/B2 */ 0, 0, 0, 0, 0, 0,
 	/*outputs: A/B,CA/B2       */ DAC_0_data_w, 0, 0, 0,
@@ -129,7 +133,7 @@ struct pia6821_interface williams_snd_pia_intf =
  *************************************/
 
 /* Special PIA 0 for Lotto Fun, to handle the controls and ticket dispenser */
-struct pia6821_interface lottofun_pia_0_intf =
+const pia6821_interface lottofun_pia_0_intf =
 {
 	/*inputs : A/B,CA/B1,CA/B2 */ lottofun_input_port_0_r, input_port_1_r, 0, 0, 0, 0,
 	/*outputs: A/B,CA/B2       */ 0, ticket_dispenser_w, 0, 0,
@@ -137,7 +141,7 @@ struct pia6821_interface lottofun_pia_0_intf =
 };
 
 /* Special PIA 2 for Sinistar, to handle the CVSD */
-struct pia6821_interface sinistar_snd_pia_intf =
+const pia6821_interface sinistar_snd_pia_intf =
 {
 	/*inputs : A/B,CA/B1,CA/B2 */ 0, 0, 0, 0, 0, 0,
 	/*outputs: A/B,CA/B2       */ DAC_0_data_w, 0, hc55516_0_digit_w, hc55516_0_clock_w,
@@ -145,7 +149,7 @@ struct pia6821_interface sinistar_snd_pia_intf =
 };
 
 /* Special PIA 1 for PlayBall, doesn't set the high bits on sound commands */
-struct pia6821_interface playball_pia_1_intf =
+const pia6821_interface playball_pia_1_intf =
 {
 	/*inputs : A/B,CA/B1,CA/B2 */ input_port_2_r, 0, 0, 0, 0, 0,
 	/*outputs: A/B,CA/B2       */ 0, playball_snd_cmd_w, 0, 0,
@@ -153,7 +157,7 @@ struct pia6821_interface playball_pia_1_intf =
 };
 
 /* extra PIA 3 for Speed Ball */
-struct pia6821_interface spdball_pia_3_intf =
+const pia6821_interface spdball_pia_3_intf =
 {
 	/*inputs : A/B,CA/B1,CA/B2 */ input_port_3_r, input_port_4_r, 0, 0, 0, 0,
 	/*outputs: A/B,CA/B2       */ 0, 0, 0, 0,
@@ -169,7 +173,7 @@ struct pia6821_interface spdball_pia_3_intf =
  *************************************/
 
 /* Generic muxing PIA 0, maps to input ports 0/3 and 1; port select is CA2 */
-struct pia6821_interface williams2_muxed_pia_0_intf =
+const pia6821_interface williams2_muxed_pia_0_intf =
 {
 	/*inputs : A/B,CA/B1,CA/B2 */ williams_input_port_0_3_r, input_port_1_r, 0, 0, 0, 0,
 	/*outputs: A/B,CA/B2       */ 0, 0, williams_port_select_w, 0,
@@ -177,7 +181,7 @@ struct pia6821_interface williams2_muxed_pia_0_intf =
 };
 
 /* Generic PIA 1, maps to input port 2, sound command out, and IRQs */
-struct pia6821_interface williams2_pia_1_intf =
+const pia6821_interface williams2_pia_1_intf =
 {
 	/*inputs : A/B,CA/B1,CA/B2 */ input_port_2_r, 0, 0, 0, 0, 0,
 	/*outputs: A/B,CA/B2       */ 0, williams2_snd_cmd_w, 0, pia_2_ca1_w,
@@ -185,7 +189,7 @@ struct pia6821_interface williams2_pia_1_intf =
 };
 
 /* Generic PIA 2, maps to DAC data in and sound IRQs */
-struct pia6821_interface williams2_snd_pia_intf =
+const pia6821_interface williams2_snd_pia_intf =
 {
 	/*inputs : A/B,CA/B1,CA/B2 */ 0, 0, 0, 0, 0, 0,
 	/*outputs: A/B,CA/B2       */ pia_1_portb_w, DAC_0_data_w, pia_1_cb1_w, 0,
@@ -201,7 +205,7 @@ struct pia6821_interface williams2_snd_pia_intf =
  *************************************/
 
 /* Mystic Marathon PIA 0 */
-struct pia6821_interface mysticm_pia_0_intf =
+const pia6821_interface mysticm_pia_0_intf =
 {
 	/*inputs : A/B,CA/B1,CA/B2 */ input_port_0_r, input_port_1_r, 0, 0, 0, 0,
 	/*outputs: A/B,CA/B2       */ 0, 0, 0, 0,
@@ -209,7 +213,7 @@ struct pia6821_interface mysticm_pia_0_intf =
 };
 
 /* Turkey Shoot PIA 0 */
-struct pia6821_interface tshoot_pia_0_intf =
+const pia6821_interface tshoot_pia_0_intf =
 {
 	/*inputs : A/B,CA/B1,CA/B2 */ tshoot_input_port_0_3_r, input_port_1_r, 0, 0, 0, 0,
 	/*outputs: A/B,CA/B2       */ 0, tshoot_lamp_w, williams_port_select_w, 0,
@@ -217,7 +221,7 @@ struct pia6821_interface tshoot_pia_0_intf =
 };
 
 /* Turkey Shoot PIA 2 */
-struct pia6821_interface tshoot_snd_pia_intf =
+const pia6821_interface tshoot_snd_pia_intf =
 {
 	/*inputs : A/B,CA/B1,CA/B2 */ 0, 0, 0, 0, 0, 0,
 	/*outputs: A/B,CA/B2       */ pia_1_portb_w, DAC_0_data_w, pia_1_cb1_w, tshoot_maxvol_w,
@@ -225,7 +229,7 @@ struct pia6821_interface tshoot_snd_pia_intf =
 };
 
 /* Joust 2 PIA 1 */
-struct pia6821_interface joust2_pia_1_intf =
+const pia6821_interface joust2_pia_1_intf =
 {
 	/*inputs : A/B,CA/B1,CA/B2 */ input_port_2_r, 0, 0, 0, 0, 0,
 	/*outputs: A/B,CA/B2       */ 0, joust2_snd_cmd_w, joust2_pia_3_cb1_w, pia_2_ca1_w,
@@ -251,7 +255,7 @@ static void williams_va11_callback(int scanline)
 	/* set a timer for the next update */
 	scanline += 8;
 	if (scanline >= 256) scanline = 0;
-	timer_set(cpu_getscanlinetime(scanline), scanline, williams_va11_callback);
+	timer_adjust(scanline_timer, cpu_getscanlinetime(scanline), scanline, 0);
 }
 
 
@@ -271,7 +275,7 @@ static void williams_count240_callback(int param)
 	timer_set(cpu_getscanlinetime(0), 0, williams_count240_off_callback);
 
 	/* set a timer for next frame */
-	timer_set(cpu_getscanlinetime(240), 0, williams_count240_callback);
+	timer_adjust(scan240_timer, cpu_getscanlinetime(240), 0, 0);
 }
 
 
@@ -303,7 +307,7 @@ static void williams_snd_irq(int state)
  *
  *************************************/
 
-MACHINE_INIT( williams )
+static void williams_common_init(void)
 {
 	/* reset the PIAs */
 	pia_reset();
@@ -312,10 +316,24 @@ MACHINE_INIT( williams )
 	ticket_dispenser_init(70, TICKET_MOTOR_ACTIVE_LOW, TICKET_STATUS_ACTIVE_HIGH);
 
 	/* set a timer to go off every 16 scanlines, to toggle the VA11 line and update the screen */
-	timer_set(cpu_getscanlinetime(0), 0, williams_va11_callback);
+	scanline_timer = timer_alloc(williams_va11_callback);
+	timer_adjust(scanline_timer, cpu_getscanlinetime(0), 0, 0);
 
 	/* also set a timer to go off on scanline 240 */
-	timer_set(cpu_getscanlinetime(240), 0, williams_count240_callback);
+	scan240_timer = timer_alloc(williams_count240_callback);
+	timer_adjust(scan240_timer, cpu_getscanlinetime(240), 0, 0);
+
+	state_save_register_global(vram_bank);
+}
+
+
+MACHINE_RESET( williams )
+{
+	williams_common_init();
+
+	/* configure the memory bank */
+	memory_configure_bank(1, 0, 1, williams_videoram, 0);
+	memory_configure_bank(1, 1, 1, memory_region(REGION_CPU1) + 0x10000, 0);
 }
 
 
@@ -338,7 +356,7 @@ static void williams2_va11_callback(int scanline)
 	/* set a timer for the next update */
 	scanline += 8;
 	if (scanline >= 256) scanline = 0;
-	timer_set(cpu_getscanlinetime(scanline), scanline, williams2_va11_callback);
+	timer_adjust(scanline_timer, cpu_getscanlinetime(scanline), scanline, 0);
 }
 
 
@@ -358,7 +376,7 @@ static void williams2_endscreen_callback(int param)
 	timer_set(cpu_getscanlinetime(8), 0, williams2_endscreen_off_callback);
 
 	/* set a timer for next frame */
-	timer_set(cpu_getscanlinetime(254), 0, williams2_endscreen_callback);
+	timer_adjust(scan254_timer, cpu_getscanlinetime(254), 0, 0);
 }
 
 
@@ -369,19 +387,34 @@ static void williams2_endscreen_callback(int param)
  *
  *************************************/
 
-MACHINE_INIT( williams2 )
+static void williams2_postload(void)
+{
+	williams2_bank_select_w(0, vram_bank);
+}
+
+
+MACHINE_RESET( williams2 )
 {
 	/* reset the PIAs */
 	pia_reset();
 
+	/* configure memory banks */
+	memory_configure_bank(1, 0, 1, williams_videoram, 0);
+	memory_configure_bank(1, 1, 4, memory_region(REGION_CPU1) + 0x10000, 0x10000);
+
 	/* make sure our banking is reset */
 	williams2_bank_select_w(0, 0);
 
 	/* set a timer to go off every 16 scanlines, to toggle the VA11 line and update the screen */
-	timer_set(cpu_getscanlinetime(0), 0, williams2_va11_callback);
+	scanline_timer = timer_alloc(williams2_va11_callback);
+	timer_adjust(scanline_timer, cpu_getscanlinetime(0), 0, 0);
 
 	/* also set a timer to go off on scanline 254 */
-	timer_set(cpu_getscanlinetime(254), 0, williams2_endscreen_callback);
+	scan254_timer = timer_alloc(williams2_endscreen_callback);
+	timer_adjust(scan254_timer, cpu_getscanlinetime(254), 0, 0);
+
+	state_save_register_global(vram_bank);
+	state_save_register_func_postload(williams2_postload);
 }
 
 
@@ -396,7 +429,7 @@ WRITE8_HANDLER( williams_vram_select_w )
 {
 	/* VRAM/ROM banking from bit 0 */
 	vram_bank = data & 0x01;
-	memory_set_bankptr(1, memory_region(REGION_CPU1) + 0x10000 * vram_bank);
+	memory_set_bank(1, vram_bank);
 
 	/* cocktail flip from bit 1 */
 	williams_cocktail = data & 0x02;
@@ -405,29 +438,33 @@ WRITE8_HANDLER( williams_vram_select_w )
 
 WRITE8_HANDLER( williams2_bank_select_w )
 {
+	vram_bank = data & 0x07;
+
 	/* the low two bits control the paging */
-	switch (data & 0x03)
+	switch (vram_bank & 0x03)
 	{
 		/* page 0 is video ram */
 		case 0:
 			memory_install_read8_handler(0, ADDRESS_SPACE_PROGRAM, 0x0000, 0x8fff, 0, 0, MRA8_BANK1);
-			memory_install_write8_handler(0, ADDRESS_SPACE_PROGRAM, 0x8000, 0x87ff, 0, 0, MWA8_RAM);
-			memory_set_bankptr(1, williams_videoram);
+			memory_install_write8_handler(0, ADDRESS_SPACE_PROGRAM, 0x8000, 0x87ff, 0, 0, MWA8_BANK4);
+			memory_set_bank(1, 0);
+			memory_set_bankptr(4, &williams_videoram[0x8000]);
 			break;
 
 		/* pages 1 and 2 are ROM */
 		case 1:
 		case 2:
 			memory_install_read8_handler(0, ADDRESS_SPACE_PROGRAM, 0x0000, 0x8fff, 0, 0, MRA8_BANK1);
-			memory_install_write8_handler(0, ADDRESS_SPACE_PROGRAM, 0x8000, 0x87ff, 0, 0, MWA8_RAM);
-			memory_set_bankptr(1, memory_region(REGION_CPU1) + 0x10000 + 0x10000 * ((data & 6) >> 1));
+			memory_install_write8_handler(0, ADDRESS_SPACE_PROGRAM, 0x8000, 0x87ff, 0, 0, MWA8_BANK4);
+			memory_set_bank(1, 1 + ((vram_bank & 6) >> 1));
+			memory_set_bankptr(4, &williams_videoram[0x8000]);
 			break;
 
 		/* page 3 accesses palette RAM; the remaining areas are as if page 1 ROM was selected */
 		case 3:
 			memory_install_read8_handler(0, ADDRESS_SPACE_PROGRAM, 0x8000, 0x87ff, 0, 0, williams2_paletteram_r);
 			memory_install_write8_handler(0, ADDRESS_SPACE_PROGRAM, 0x8000, 0x87ff, 0, 0, williams2_paletteram_w);
-			memory_set_bankptr(1, memory_region(REGION_CPU1) + 0x10000 + 0x10000 * ((data & 4) >> 1));
+			memory_set_bank(1, 1 + ((vram_bank & 4) >> 1));
 			break;
 	}
 }
@@ -627,13 +664,21 @@ WRITE8_HANDLER( williams2_7segment_w )
  *
  *************************************/
 
-MACHINE_INIT( defender )
+static void defender_postload(void)
 {
-	/* standard init */
-	machine_init_williams();
+	defender_bank_select_w(0, vram_bank);
+}
 
-	/* make sure the banking is reset to 0 */
+
+MACHINE_RESET( defender )
+{
+	williams_common_init();
+
+	/* configure the banking and make sure it is reset to 0 */
+	memory_configure_bank(1, 0, 9, &memory_region(REGION_CPU1)[0x10000], 0x1000);
 	defender_bank_select_w(0, 0);
+
+	state_save_register_func_postload(defender_postload);
 }
 
 
@@ -645,7 +690,7 @@ WRITE8_HANDLER( defender_video_control_w )
 
 WRITE8_HANDLER( defender_bank_select_w )
 {
-	data &= 0x0f;
+	vram_bank = data & 0x0f;
 
 	/* set bank address */
 	switch (data)
@@ -666,8 +711,8 @@ WRITE8_HANDLER( defender_bank_select_w )
 		case 8:
 		case 9:
 			memory_install_read8_handler(0, ADDRESS_SPACE_PROGRAM, 0xc000, 0xcfff, 0, 0, MRA8_BANK1);
-			memory_install_write8_handler(0, ADDRESS_SPACE_PROGRAM, 0xc000, 0xcfff, 0, 0, MWA8_ROM);
-			memory_set_bankptr(1, &memory_region(REGION_CPU1)[0x10000 + (data - 1) * 0x1000]);
+			memory_install_write8_handler(0, ADDRESS_SPACE_PROGRAM, 0xc000, 0xcfff, 0, 0, MWA8_UNMAP);
+			memory_set_bank(1, vram_bank - 1);
 			break;
 
 		/* pages A-F are not connected */
@@ -721,23 +766,25 @@ WRITE8_HANDLER( sinistar_vram_select_w )
  *
  *************************************/
 
+MACHINE_RESET( blaster )
+{
+	williams_common_init();
+
+	/* banking is different for blaster */
+	memory_configure_bank(1, 0, 1, williams_videoram, 0);
+	memory_configure_bank(1, 1, 16, memory_region(REGION_CPU1) + 0x18000, 0x4000);
+
+	memory_configure_bank(2, 0, 1, williams_videoram + 0x4000, 0);
+	memory_configure_bank(2, 1, 16, memory_region(REGION_CPU1) + 0x10000, 0x0000);
+
+	state_save_register_global(blaster_bank);
+}
+
+
 INLINE void update_blaster_banking(void)
 {
-	UINT8 *base = memory_region(REGION_CPU1);
-
-	/* if vram_bank is 1, we map in ROM areas based on the current bank select */
-	if (vram_bank)
-	{
-		memory_set_bankptr(1, base + 0x18000 + 0x4000 * blaster_bank);
-		memory_set_bankptr(2, base + 0x10000);
-	}
-
-	/* otherwise, we map standard video RAM */
-	else
-	{
-		memory_set_bankptr(1, base + 0x00000);
-		memory_set_bankptr(2, base + 0x04000);
-	}
+	memory_set_bank(1, vram_bank * (blaster_bank + 1));
+	memory_set_bank(2, vram_bank * (blaster_bank + 1));
 }
 
 
@@ -832,14 +879,19 @@ static WRITE8_HANDLER( tshoot_lamp_w )
  *
  *************************************/
 
-MACHINE_INIT( joust2 )
+MACHINE_START( joust2 )
+{
+	williams_cvsd_init(3);
+	return 0;
+}
+
+
+MACHINE_RESET( joust2 )
 {
 	/* standard init */
-	machine_init_williams2();
-
-	/* make sure sound board starts out in the reset state */
-	williams_cvsd_init(2, 3);
-	pia_reset();
+	machine_reset_williams2();
+	pia_set_input_ca1(3, 1);
+	state_save_register_global(joust2_current_sound_data);
 }
 
 
