@@ -8,6 +8,8 @@
 ***************************************************************************/
 
 #include "driver.h"
+#include "sound/samples.h"
+#include "includes/galaga.h"
 
 /***************************************************************************
 
