@@ -4,6 +4,9 @@
 
     Functions which handle the CPU memory accesses.
 
+    Copyright (c) 1996-2006, Nicola Salmoria and the MAME Team.
+    Visit http://mamedev.org for licensing and usage restrictions.
+
 ***************************************************************************/
 
 #pragma once
@@ -12,8 +15,6 @@
 #define __MEMORY_H__
 
 #include "mamecore.h"
-#include <stddef.h>
-#include <stdio.h>
 
 
 
@@ -200,10 +201,9 @@ typedef struct _data_accessors data_accessors;
 #define STATIC_BANK30			30						/* banked memory #30 */
 #define STATIC_BANK31			31						/* banked memory #31 */
 #define STATIC_BANK32			32						/* banked memory #32 */
-/* entries 33-66 are reserved for dynamically allocated internal banks */
-#define STATIC_RAM				67						/* RAM - standard reads/writes */
-#define STATIC_ROM				68						/* ROM - standard reads, no writes */
-#define STATIC_RAMROM			69						/* RAMROM - use for access in encrypted 8-bit systems */
+/* entries 33-67 are reserved for dynamically allocated internal banks */
+#define STATIC_RAM				68						/* RAM - standard reads/writes */
+#define STATIC_ROM				69						/* ROM - standard reads, no writes */
 #define STATIC_NOP				70						/* unmapped - all unmapped memory goes here */
 #define STATIC_UNMAP			71						/* unmapped - all unmapped memory goes here */
 #define STATIC_COUNT			72						/* total number of static handlers */
@@ -260,9 +260,10 @@ typedef struct _data_accessors data_accessors;
 #define MRA8_BANK30				((read8_handler)STATIC_BANK30)
 #define MRA8_BANK31				((read8_handler)STATIC_BANK31)
 #define MRA8_BANK32				((read8_handler)STATIC_BANK32)
-#define MRA8_NOP				((read8_handler)STATIC_NOP)
 #define MRA8_RAM				((read8_handler)STATIC_RAM)
 #define MRA8_ROM				((read8_handler)STATIC_ROM)
+#define MRA8_NOP				((read8_handler)STATIC_NOP)
+#define MRA8_UNMAP				((read8_handler)STATIC_UNMAP)
 
 /* 8-bit writes */
 #define MWA8_BANK1				((write8_handler)STATIC_BANK1)
@@ -297,10 +298,10 @@ typedef struct _data_accessors data_accessors;
 #define MWA8_BANK30				((write8_handler)STATIC_BANK30)
 #define MWA8_BANK31				((write8_handler)STATIC_BANK31)
 #define MWA8_BANK32				((write8_handler)STATIC_BANK32)
-#define MWA8_NOP				((write8_handler)STATIC_NOP)
 #define MWA8_RAM				((write8_handler)STATIC_RAM)
 #define MWA8_ROM				((write8_handler)STATIC_ROM)
-#define MWA8_RAMROM				((write8_handler)STATIC_RAMROM)
+#define MWA8_NOP				((write8_handler)STATIC_NOP)
+#define MWA8_UNMAP				((write8_handler)STATIC_UNMAP)
 
 /* 16-bit reads */
 #define MRA16_BANK1				((read16_handler)STATIC_BANK1)
@@ -335,9 +336,10 @@ typedef struct _data_accessors data_accessors;
 #define MRA16_BANK30			((read16_handler)STATIC_BANK30)
 #define MRA16_BANK31			((read16_handler)STATIC_BANK31)
 #define MRA16_BANK32			((read16_handler)STATIC_BANK32)
-#define MRA16_NOP				((read16_handler)STATIC_NOP)
 #define MRA16_RAM				((read16_handler)STATIC_RAM)
 #define MRA16_ROM				((read16_handler)STATIC_ROM)
+#define MRA16_NOP				((read16_handler)STATIC_NOP)
+#define MRA16_UNMAP				((read16_handler)STATIC_UNMAP)
 
 /* 16-bit writes */
 #define MWA16_BANK1				((write16_handler)STATIC_BANK1)
@@ -372,9 +374,10 @@ typedef struct _data_accessors data_accessors;
 #define MWA16_BANK30			((write16_handler)STATIC_BANK30)
 #define MWA16_BANK31			((write16_handler)STATIC_BANK31)
 #define MWA16_BANK32			((write16_handler)STATIC_BANK32)
-#define MWA16_NOP				((write16_handler)STATIC_NOP)
 #define MWA16_RAM				((write16_handler)STATIC_RAM)
 #define MWA16_ROM				((write16_handler)STATIC_ROM)
+#define MWA16_NOP				((write16_handler)STATIC_NOP)
+#define MWA16_UNMAP				((write16_handler)STATIC_UNMAP)
 
 /* 32-bit reads */
 #define MRA32_BANK1				((read32_handler)STATIC_BANK1)
@@ -409,9 +412,10 @@ typedef struct _data_accessors data_accessors;
 #define MRA32_BANK30			((read32_handler)STATIC_BANK30)
 #define MRA32_BANK31			((read32_handler)STATIC_BANK31)
 #define MRA32_BANK32			((read32_handler)STATIC_BANK32)
-#define MRA32_NOP				((read32_handler)STATIC_NOP)
 #define MRA32_RAM				((read32_handler)STATIC_RAM)
 #define MRA32_ROM				((read32_handler)STATIC_ROM)
+#define MRA32_NOP				((read32_handler)STATIC_NOP)
+#define MRA32_UNMAP				((read32_handler)STATIC_UNMAP)
 
 /* 32-bit writes */
 #define MWA32_BANK1				((write32_handler)STATIC_BANK1)
@@ -446,9 +450,10 @@ typedef struct _data_accessors data_accessors;
 #define MWA32_BANK30			((write32_handler)STATIC_BANK30)
 #define MWA32_BANK31			((write32_handler)STATIC_BANK31)
 #define MWA32_BANK32			((write32_handler)STATIC_BANK32)
-#define MWA32_NOP				((write32_handler)STATIC_NOP)
 #define MWA32_RAM				((write32_handler)STATIC_RAM)
 #define MWA32_ROM				((write32_handler)STATIC_ROM)
+#define MWA32_NOP				((write32_handler)STATIC_NOP)
+#define MWA32_UNMAP				((write32_handler)STATIC_UNMAP)
 
 /* 64-bit reads */
 #define MRA64_BANK1				((read64_handler)STATIC_BANK1)
@@ -483,9 +488,10 @@ typedef struct _data_accessors data_accessors;
 #define MRA64_BANK30			((read64_handler)STATIC_BANK30)
 #define MRA64_BANK31			((read64_handler)STATIC_BANK31)
 #define MRA64_BANK32			((read64_handler)STATIC_BANK32)
-#define MRA64_NOP				((read64_handler)STATIC_NOP)
 #define MRA64_RAM				((read64_handler)STATIC_RAM)
 #define MRA64_ROM				((read64_handler)STATIC_ROM)
+#define MRA64_NOP				((read64_handler)STATIC_NOP)
+#define MRA64_UNMAP				((read64_handler)STATIC_UNMAP)
 
 /* 64-bit writes */
 #define MWA64_BANK1				((write64_handler)STATIC_BANK1)
@@ -520,9 +526,10 @@ typedef struct _data_accessors data_accessors;
 #define MWA64_BANK30			((write64_handler)STATIC_BANK30)
 #define MWA64_BANK31			((write64_handler)STATIC_BANK31)
 #define MWA64_BANK32			((write64_handler)STATIC_BANK32)
-#define MWA64_NOP				((write64_handler)STATIC_NOP)
 #define MWA64_RAM				((write64_handler)STATIC_RAM)
 #define MWA64_ROM				((write64_handler)STATIC_ROM)
+#define MWA64_NOP				((write64_handler)STATIC_NOP)
+#define MWA64_UNMAP				((write64_handler)STATIC_UNMAP)
 
 
 
@@ -574,11 +581,15 @@ struct _address_map
 	offs_t				mirror;				/* mirror bits */
 	offs_t				mask;				/* mask bits */
 	read_handlers 		read;				/* read handler callback */
+	const char *		read_name;			/* read handler callback name */
 	write_handlers 		write;				/* write handler callback */
+	const char *		write_name;			/* write handler callback name */
 	void *				memory;				/* pointer to memory backing this entry */
 	UINT32				share;				/* index of a shared memory block */
 	void **				base;				/* receives pointer to memory (optional) */
 	size_t *			size;				/* receives size of area in bytes (optional) */
+	UINT32				region;				/* region containing the memory backing this entry */
+	offs_t				region_offs;		/* offset within the region */
 };
 typedef struct _address_map address_map;
 
@@ -607,11 +618,11 @@ typedef address_map *(*construct_map_t)(address_map *map);
 
 /* use this to declare external references to a machine driver */
 #define ADDRESS_MAP_EXTERN(_name)										\
-address_map *construct_map_##_name(address_map *map)	\
+address_map *construct_map_##_name(address_map *map)					\
 
 /* ----- macros for starting, ending, and setting map flags ----- */
 #define ADDRESS_MAP_START(_name,_space,_bits)							\
-address_map *construct_map_##_name(address_map *map)	\
+address_map *construct_map_##_name(address_map *map)					\
 {																		\
 	typedef read##_bits##_handler _rh_t;								\
 	typedef write##_bits##_handler _wh_t;								\
@@ -656,12 +667,15 @@ address_map *construct_map_##_name(address_map *map)	\
 
 #define AM_READ(_handler)												\
 	map->read.handler = (genf *)(read = _handler);						\
+	map->read_name = #_handler;											\
 
 #define AM_WRITE(_handler)												\
 	map->write.handler = (genf *)(write = _handler);					\
+	map->write_name = #_handler;										\
 
 #define AM_REGION(_region, _offs)										\
-	map->memory = memory_region(_region) + _offs;						\
+	map->region = (_region);											\
+	map->region_offs = (_offs);											\
 
 #define AM_SHARE(_index)												\
 	map->share = _index;												\
@@ -676,6 +690,7 @@ address_map *construct_map_##_name(address_map *map)	\
 #define AM_READWRITE(_read,_write)			AM_READ(_read) AM_WRITE(_write)
 #define AM_ROM								AM_READ((_rh_t)STATIC_ROM)
 #define AM_RAM								AM_READWRITE((_rh_t)STATIC_RAM, (_wh_t)STATIC_RAM)
+#define AM_UNMAP							AM_READWRITE((_rh_t)STATIC_UNMAP, (_wh_t)STATIC_UNMAP)
 #define AM_ROMBANK(_bank)					AM_READ((_rh_t)(STATIC_BANK1 + (_bank) - 1))
 #define AM_RAMBANK(_bank)					AM_READWRITE((_rh_t)(STATIC_BANK1 + (_bank) - 1), (_wh_t)(STATIC_BANK1 + (_bank) - 1))
 #define AM_NOP								AM_READWRITE((_rh_t)STATIC_NOP, (_wh_t)STATIC_NOP)
@@ -713,6 +728,8 @@ address_map *construct_map_##_name(address_map *map)	\
 #define ADDRESS_SPACE_DATA		1						/* data address space */
 #define ADDRESS_SPACE_IO		2						/* I/O address space */
 
+extern const char *address_space_names[ADDRESS_SPACES];
+
 /* ----- address map lookup table definitions ----- */
 #define SUBTABLE_COUNT			64						/* number of slots reserved for subtables */
 #define SUBTABLE_BASE			(256-SUBTABLE_COUNT)	/* first index of a subtable */
@@ -909,43 +926,52 @@ const address_map *memory_get_map(int cpunum, int spacenum);
 opbase_handler memory_set_opbase_handler(int cpunum, opbase_handler function);
 void		memory_set_opbase(offs_t offset);
 
-/* ----- separate opcode/data encryption helpers ---- */
-void		memory_set_opcode_base(int cpunum, void *base);
+/* ----- separate opcode/data encryption helper ---- */
+void 		memory_set_decrypted_region(int cpunum, offs_t start, offs_t end, void *base);
 
 /* ----- return a base pointer to memory ---- */
 void *		memory_get_read_ptr(int cpunum, int spacenum, offs_t offset);
 void *		memory_get_write_ptr(int cpunum, int spacenum, offs_t offset);
-void *		memory_get_op_ptr(int cpunum, offs_t offset);
+void *		memory_get_op_ptr(int cpunum, offs_t offset, int arg);
 
 /* ----- memory banking ----- */
 void		memory_configure_bank(int banknum, int startentry, int numentries, void *base, offs_t stride);
+void		memory_configure_bank_decrypted(int banknum, int startentry, int numentries, void *base, offs_t stride);
 void		memory_set_bank(int banknum, int entrynum);
 void		memory_set_bankptr(int banknum, void *base);
 
-/* ----- dynamic address space mapping ----- */
+/* ----- debugging ----- */
 void		memory_set_debugger_access(int debugger);
+void		memory_set_log_unmap(int spacenum, int log);
+int			memory_get_log_unmap(int spacenum);
 
 /* ----- dynamic address space mapping ----- */
-UINT8 *		memory_install_read8_handler  (int cpunum, int spacenum, offs_t start, offs_t end, offs_t mask, offs_t mirror, read8_handler handler);
-UINT16 *	memory_install_read16_handler (int cpunum, int spacenum, offs_t start, offs_t end, offs_t mask, offs_t mirror, read16_handler handler);
-UINT32 *	memory_install_read32_handler (int cpunum, int spacenum, offs_t start, offs_t end, offs_t mask, offs_t mirror, read32_handler handler);
-UINT64 *	memory_install_read64_handler (int cpunum, int spacenum, offs_t start, offs_t end, offs_t mask, offs_t mirror, read64_handler handler);
-UINT8 *		memory_install_write8_handler (int cpunum, int spacenum, offs_t start, offs_t end, offs_t mask, offs_t mirror, write8_handler handler);
-UINT16 *	memory_install_write16_handler(int cpunum, int spacenum, offs_t start, offs_t end, offs_t mask, offs_t mirror, write16_handler handler);
-UINT32 *	memory_install_write32_handler(int cpunum, int spacenum, offs_t start, offs_t end, offs_t mask, offs_t mirror, write32_handler handler);
-UINT64 *	memory_install_write64_handler(int cpunum, int spacenum, offs_t start, offs_t end, offs_t mask, offs_t mirror, write64_handler handler);
+void *		_memory_install_read_handler   (int cpunum, int spacenum, offs_t start, offs_t end, offs_t mask, offs_t mirror, int handler, const char *handler_name);
+UINT8 *		_memory_install_read8_handler  (int cpunum, int spacenum, offs_t start, offs_t end, offs_t mask, offs_t mirror, read8_handler handler, const char *handler_name);
+UINT16 *	_memory_install_read16_handler (int cpunum, int spacenum, offs_t start, offs_t end, offs_t mask, offs_t mirror, read16_handler handler, const char *handler_name);
+UINT32 *	_memory_install_read32_handler (int cpunum, int spacenum, offs_t start, offs_t end, offs_t mask, offs_t mirror, read32_handler handler, const char *handler_name);
+UINT64 *	_memory_install_read64_handler (int cpunum, int spacenum, offs_t start, offs_t end, offs_t mask, offs_t mirror, read64_handler handler, const char *handler_name);
+void *		_memory_install_write_handler  (int cpunum, int spacenum, offs_t start, offs_t end, offs_t mask, offs_t mirror, int handler, const char *handler_name);
+UINT8 *		_memory_install_write8_handler (int cpunum, int spacenum, offs_t start, offs_t end, offs_t mask, offs_t mirror, write8_handler handler, const char *handler_name);
+UINT16 *	_memory_install_write16_handler(int cpunum, int spacenum, offs_t start, offs_t end, offs_t mask, offs_t mirror, write16_handler handler, const char *handler_name);
+UINT32 *	_memory_install_write32_handler(int cpunum, int spacenum, offs_t start, offs_t end, offs_t mask, offs_t mirror, write32_handler handler, const char *handler_name);
+UINT64 *	_memory_install_write64_handler(int cpunum, int spacenum, offs_t start, offs_t end, offs_t mask, offs_t mirror, write64_handler handler, const char *handler_name);
 
-UINT8 *		memory_install_read8_matchmask_handler  (int cpunum, int spacenum, offs_t matchval, offs_t maskval, offs_t mask, offs_t mirror, read8_handler handler);
-UINT16 *	memory_install_read16_matchmask_handler (int cpunum, int spacenum, offs_t matchval, offs_t maskval, offs_t mask, offs_t mirror, read16_handler handler);
-UINT32 *	memory_install_read32_matchmask_handler (int cpunum, int spacenum, offs_t matchval, offs_t maskval, offs_t mask, offs_t mirror, read32_handler handler);
-UINT64 *	memory_install_read64_matchmask_handler (int cpunum, int spacenum, offs_t matchval, offs_t maskval, offs_t mask, offs_t mirror, read64_handler handler);
-UINT8 *		memory_install_write8_matchmask_handler (int cpunum, int spacenum, offs_t matchval, offs_t maskval, offs_t mask, offs_t mirror, write8_handler handler);
-UINT16 *	memory_install_write16_matchmask_handler(int cpunum, int spacenum, offs_t matchval, offs_t maskval, offs_t mask, offs_t mirror, write16_handler handler);
-UINT32 *	memory_install_write32_matchmask_handler(int cpunum, int spacenum, offs_t matchval, offs_t maskval, offs_t mask, offs_t mirror, write32_handler handler);
-UINT64 *	memory_install_write64_matchmask_handler(int cpunum, int spacenum, offs_t matchval, offs_t maskval, offs_t mask, offs_t mirror, write64_handler handler);
+void *		_memory_install_read_matchmask_handler   (int cpunum, int spacenum, offs_t matchval, offs_t maskval, offs_t mask, offs_t mirror, int handler, const char *handler_name);
+UINT8 *		_memory_install_read8_matchmask_handler  (int cpunum, int spacenum, offs_t matchval, offs_t maskval, offs_t mask, offs_t mirror, read8_handler handler, const char *handler_name);
+UINT16 *	_memory_install_read16_matchmask_handler (int cpunum, int spacenum, offs_t matchval, offs_t maskval, offs_t mask, offs_t mirror, read16_handler handler, const char *handler_name);
+UINT32 *	_memory_install_read32_matchmask_handler (int cpunum, int spacenum, offs_t matchval, offs_t maskval, offs_t mask, offs_t mirror, read32_handler handler, const char *handler_name);
+UINT64 *	_memory_install_read64_matchmask_handler (int cpunum, int spacenum, offs_t matchval, offs_t maskval, offs_t mask, offs_t mirror, read64_handler handler, const char *handler_name);
+void *		_memory_install_write_matchmask_handler  (int cpunum, int spacenum, offs_t matchval, offs_t maskval, offs_t mask, offs_t mirror, int handler, const char *handler_name);
+UINT8 *		_memory_install_write8_matchmask_handler (int cpunum, int spacenum, offs_t matchval, offs_t maskval, offs_t mask, offs_t mirror, write8_handler handler, const char *handler_name);
+UINT16 *	_memory_install_write16_matchmask_handler(int cpunum, int spacenum, offs_t matchval, offs_t maskval, offs_t mask, offs_t mirror, write16_handler handler, const char *handler_name);
+UINT32 *	_memory_install_write32_matchmask_handler(int cpunum, int spacenum, offs_t matchval, offs_t maskval, offs_t mask, offs_t mirror, write32_handler handler, const char *handler_name);
+UINT64 *	_memory_install_write64_matchmask_handler(int cpunum, int spacenum, offs_t matchval, offs_t maskval, offs_t mask, offs_t mirror, write64_handler handler, const char *handler_name);
 
 /* ----- memory debugging ----- */
-void memory_dump(FILE *file);
+void 		memory_dump(FILE *file);
+const char *memory_get_handler_string(int read0_or_write1, int cpunum, int spacenum, offs_t offset);
+
 
 
 /***************************************************************************
@@ -997,6 +1023,51 @@ extern address_map *	construct_map_0(address_map *map);
 #error Must set either CPUREADOP_SAFETY_NONE, CPUREADOP_SAFETY_PARTIAL or CPUREADOP_SAFETY_FULL
 #endif
 
+/* ----- dynamic memory installation ----- */
+#define memory_install_read_handler(cpu, space, start, end, mask, mirror, handler)				\
+	_memory_install_read_handler(cpu, space, start, end, mask, mirror, handler, #handler)
+#define memory_install_read8_handler(cpu, space, start, end, mask, mirror, handler)				\
+	_memory_install_read8_handler(cpu, space, start, end, mask, mirror, handler, #handler)
+#define memory_install_read16_handler(cpu, space, start, end, mask, mirror, handler)			\
+	_memory_install_read16_handler(cpu, space, start, end, mask, mirror, handler, #handler)
+#define memory_install_read32_handler(cpu, space, start, end, mask, mirror, handler)			\
+	_memory_install_read32_handler(cpu, space, start, end, mask, mirror, handler, #handler)
+#define memory_install_read64_handler(cpu, space, start, end, mask, mirror, handler)			\
+	_memory_install_read64_handler(cpu, space, start, end, mask, mirror, handler, #handler)
+
+#define memory_install_write_handler(cpu, space, start, end, mask, mirror, handler)			\
+	_memory_install_write_handler(cpu, space, start, end, mask, mirror, handler, #handler)
+#define memory_install_write8_handler(cpu, space, start, end, mask, mirror, handler)			\
+	_memory_install_write8_handler(cpu, space, start, end, mask, mirror, handler, #handler)
+#define memory_install_write16_handler(cpu, space, start, end, mask, mirror, handler)			\
+	_memory_install_write16_handler(cpu, space, start, end, mask, mirror, handler, #handler)
+#define memory_install_write32_handler(cpu, space, start, end, mask, mirror, handler)			\
+	_memory_install_write32_handler(cpu, space, start, end, mask, mirror, handler, #handler)
+#define memory_install_write64_handler(cpu, space, start, end, mask, mirror, handler)			\
+	_memory_install_write64_handler(cpu, space, start, end, mask, mirror, handler, #handler)
+
+#define memory_install_read_matchmask_handler(cpu, space, start, end, mask, mirror, handler)			\
+	_memory_install_read_matchmask_handler(cpu, space, start, end, mask, mirror, handler, #handler)
+#define memory_install_read8_matchmask_handler(cpu, space, start, end, mask, mirror, handler)			\
+	_memory_install_read8_matchmask_handler(cpu, space, start, end, mask, mirror, handler, #handler)
+#define memory_install_read16_matchmask_handler(cpu, space, start, end, mask, mirror, handler)			\
+	_memory_install_read16_matchmask_handler(cpu, space, start, end, mask, mirror, handler, #handler)
+#define memory_install_read32_matchmask_handler(cpu, space, start, end, mask, mirror, handler)			\
+	_memory_install_read32_matchmask_handler(cpu, space, start, end, mask, mirror, handler, #handler)
+#define memory_install_read64_matchmask_handler(cpu, space, start, end, mask, mirror, handler)			\
+	_memory_install_read64_matchmask_handler(cpu, space, start, end, mask, mirror, handler, #handler)
+
+#define memory_install_write_matchmask_handler(cpu, space, start, end, mask, mirror, handler)			\
+	_memory_install_write_matchmask_handler(cpu, space, start, end, mask, mirror, handler, #handler)
+#define memory_install_write8_matchmask_handler(cpu, space, start, end, mask, mirror, handler)			\
+	_memory_install_write8_matchmask_handler(cpu, space, start, end, mask, mirror, handler, #handler)
+#define memory_install_write16_matchmask_handler(cpu, space, start, end, mask, mirror, handler)			\
+	_memory_install_write16_matchmask_handler(cpu, space, start, end, mask, mirror, handler, #handler)
+#define memory_install_write32_matchmask_handler(cpu, space, start, end, mask, mirror, handler)			\
+	_memory_install_write32_matchmask_handler(cpu, space, start, end, mask, mirror, handler, #handler)
+#define memory_install_write64_matchmask_handler(cpu, space, start, end, mask, mirror, handler)			\
+	_memory_install_write64_matchmask_handler(cpu, space, start, end, mask, mirror, handler, #handler)
+
 /* ----- generic memory access ----- */
 INLINE UINT8  program_read_byte (offs_t offset) { return (*active_address_space[ADDRESS_SPACE_PROGRAM].accessors->read_byte)(offset); }
 INLINE UINT16 program_read_word (offs_t offset) { return (*active_address_space[ADDRESS_SPACE_PROGRAM].accessors->read_word)(offset); }
@@ -1050,7 +1121,7 @@ UINT64	cpu_readop_arg64_safe(offs_t offset);
 #define cpu_readop_arg64_unsafe(A)	(*(UINT64 *)&opcode_arg_base[(A) & opcode_mask])
 
 /* ----- opcode and opcode argument reading ----- */
-INLINE void *   cpu_opptr(offs_t A)			{ if (address_is_unsafe(A)) { memory_set_opbase(A); } return cpu_opptr_unsafe(A); }
+INLINE void * cpu_opptr(offs_t A)			{ if (address_is_unsafe(A)) { memory_set_opbase(A); } return cpu_opptr_unsafe(A); }
 INLINE UINT8  cpu_readop(offs_t A)			{ if (address_is_unsafe(A)) { memory_set_opbase(A); } return cpu_readop_unsafe(A); }
 INLINE UINT16 cpu_readop16(offs_t A)		{ if (address_is_unsafe(A)) { memory_set_opbase(A); } return cpu_readop16_unsafe(A); }
 INLINE UINT32 cpu_readop32(offs_t A)		{ if (address_is_unsafe(A)) { memory_set_opbase(A); } return cpu_readop32_unsafe(A); }
