@@ -1,27 +1,23 @@
-#ifndef OSDEPEND_H
-#define OSDEPEND_H
+/***************************************************************************
 
-#include "osd_cpu.h"
-#include "inptport.h"
+    osdepend.h
 
-#ifdef __cplusplus
-extern "C" {
-#endif
+    OS-dependent code interface.
 
-/* The Win32 port requires this constant for variable arg routines. */
-#ifndef CLIB_DECL
-#define CLIB_DECL
-#endif
+    Copyright (c) 1996-2006, Nicola Salmoria and the MAME Team.
+    Visit http://mamedev.org for licensing and usage restrictions.
 
-#ifdef __LP64__
-#define FPTR unsigned long   /* 64bit: sizeof(void *) is sizeof(long)  */
-#else
-#define FPTR unsigned int
-#endif
+***************************************************************************/
 
+#pragma once
+
+#ifndef __OSDEPEND_H__
+#define __OSDEPEND_H__
+
+#include "mamecore.h"
+#include <stdarg.h>
 
 int osd_init(void);
-void osd_exit(void);
 
 #ifdef NEW_DEBUGGER
 void osd_wait_for_debugger(void);
@@ -34,17 +30,9 @@ void osd_wait_for_debugger(void);
 
 ******************************************************************************/
 
-/* mame_bitmap used to be declared here, but has moved to common.c */
-/* sadly, the include order requires that at least this forward declaration is here */
-struct mame_bitmap;
-struct mame_display;
-struct performance_info;
-struct rectangle;
-struct rom_load_data;
-
-
 /* these are the parameters passed into osd_create_display */
-struct osd_create_params
+/* In mamecore.h: typedef struct _osd_create_params osd_create_params; */
+struct _osd_create_params
 {
 	int width, height;			/* width and height */
 	int aspect_x, aspect_y;		/* aspect ratio X:Y */
@@ -80,7 +68,7 @@ struct osd_create_params
 
   Returns 0 on success.
 */
-int osd_create_display(const struct osd_create_params *params, UINT32 *rgb_components);
+int osd_create_display(const osd_create_params *params, UINT32 *rgb_components);
 void osd_close_display(void);
 
 
@@ -110,7 +98,7 @@ int osd_skip_this_frame(void);
   simulated using the keyboard LEDs, or in other ways e.g. by placing graphics
   on the window title bar.
 */
-void osd_update_video_and_audio(struct mame_display *display);
+void osd_update_video_and_audio(struct _mame_display *display);
 
 
 /*
@@ -118,14 +106,14 @@ void osd_update_video_and_audio(struct mame_display *display);
   snapshot.  This function will either return a new bitmap, for which the
   caller is responsible for freeing.
 */
-struct mame_bitmap *osd_override_snapshot(struct mame_bitmap *bitmap, struct rectangle *bounds);
+mame_bitmap *osd_override_snapshot(mame_bitmap *bitmap, rectangle *bounds);
 
 /*
   Returns a pointer to the text to display when the FPS display is toggled.
   This normally includes information about the frameskip, FPS, and percentage
   of full game speed.
 */
-const char *osd_get_fps_text(const struct performance_info *performance);
+const char *osd_get_fps_text(const performance_info *performance);
 
 
 
@@ -179,17 +167,27 @@ void osd_sound_enable(int enable);
 
 ******************************************************************************/
 
+typedef UINT32 os_code;
+
+typedef struct _os_code_info os_code_info;
+struct _os_code_info
+{
+	char *			name;			/* OS dependant name; 0 terminates the list */
+	os_code		oscode;			/* OS dependant code */
+	input_code	inputcode;		/* CODE_xxx equivalent from input.h, or one of CODE_OTHER_* if n/a */
+};
+
 /*
   return a list of all available inputs (see input.h)
 */
-const struct OSCodeInfo *osd_get_code_list(void);
+const os_code_info *osd_get_code_list(void);
 
 /*
   return the value of the specified input. digital inputs return 0 or 1. analog
   inputs should return a value between -65536 and +65536. oscode is the OS dependent
   code specified in the list returned by osd_get_code_list().
 */
-INT32 osd_get_code_value(os_code_t oscode);
+INT32 osd_get_code_value(os_code oscode);
 
 /*
   Return the Unicode value of the most recently pressed key. This
@@ -211,7 +209,7 @@ int osd_readkey_unicode(int flush);
   This function is called on startup, before reading the configuration from disk.
   Scan the list, and change the keys/joysticks you want.
 */
-void osd_customize_inputport_list(struct InputPortDefinition *defaults);
+void osd_customize_inputport_list(input_port_default_entry *defaults);
 
 
 /* Joystick calibration routines BW 19981216 */
@@ -236,15 +234,13 @@ void osd_joystick_end_calibration(void);
 ******************************************************************************/
 
 /* inp header */
-typedef struct
+typedef struct _inp_header inp_header;
+struct _inp_header
 {
 	char name[9];      /* 8 bytes for game->name + NUL */
 	char version[3];   /* byte[0] = 0, byte[1] = version byte[2] = beta_version */
 	char reserved[20]; /* for future use, possible store game options? */
-} INP_HEADER;
-
-
-typedef struct _osd_file osd_file;
+};
 
 
 /* These values are returned by osd_get_path_info */
@@ -255,6 +251,19 @@ enum
 	PATH_IS_DIRECTORY
 };
 
+/* These values are returned as error codes by osd_fopen() */
+enum _osd_file_error
+{
+	FILEERR_SUCCESS,
+	FILEERR_FAILURE,
+	FILEERR_OUT_OF_MEMORY,
+	FILEERR_NOT_FOUND,
+	FILEERR_ACCESS_DENIED,
+	FILEERR_ALREADY_OPEN,
+	FILEERR_TOO_MANY_FILES
+};
+
+typedef struct _osd_file osd_file;
 
 /* Return the number of paths for a given type */
 int osd_get_path_count(int pathtype);
@@ -262,8 +271,11 @@ int osd_get_path_count(int pathtype);
 /* Get information on the existence of a file */
 int osd_get_path_info(int pathtype, int pathindex, const char *filename);
 
+/* Create a directory if it doesn't already exist */
+int osd_create_directory(int pathtype, int pathindex, const char *dirname);
+
 /* Attempt to open a file with the given name and mode using the specified path type */
-osd_file *osd_fopen(int pathtype, int pathindex, const char *filename, const char *mode);
+osd_file *osd_fopen(int pathtype, int pathindex, const char *filename, const char *mode, osd_file_error *error);
 
 /* Seek within a file */
 int osd_fseek(osd_file *file, INT64 offset, int whence);
@@ -319,28 +331,11 @@ void osd_free_executable(void *ptr);
 /* called while loading ROMs. It is called a last time with name == 0 to signal */
 /* that the ROM loading process is finished. */
 /* return non-zero to abort loading */
-int osd_display_loading_rom_message(const char *name,struct rom_load_data *romdata);
-
-/* called when the game is paused/unpaused, so the OS dependent code can do special */
-/* things like changing the title bar or darkening the display. */
-/* Note that the OS dependent code must NOT stop processing input, since the user */
-/* interface is still active while the game is paused. */
-void osd_pause(int paused);
+int osd_display_loading_rom_message(const char *name,rom_load_data *romdata);
 
 /* checks to see if a pointer is bad */
 int osd_is_bad_read_ptr(const void *ptr, size_t size);
 
-/* aborts the program in some unexpected fatal way */
-#ifdef __GNUC__
-void CLIB_DECL osd_die(const char *text,...)
-#if (__GNUC__ > 2) || (__GNUC__ == 2 && __GNUC_MINOR__ >= 5)
-	__attribute__((noreturn))
-#endif
-	__attribute__ ((format (printf, 1, 2)));
-#else
-void CLIB_DECL osd_die(const char *text,...);
-#endif
-
 
 
 #ifdef MESS
@@ -348,15 +343,4 @@ void CLIB_DECL osd_die(const char *text,...);
 #include "osd_mess.h"
 #endif
 
-#ifdef __GNUC__
-void CLIB_DECL logerror(const char *text,...)
-      __attribute__ ((format (printf, 1, 2)));
-#else
-void CLIB_DECL logerror(const char *text,...);
-#endif
-
-#ifdef __cplusplus
-}
-#endif
-
-#endif
+#endif	/* __OSDEPEND_H__ */
