@@ -4,11 +4,16 @@
 
     Palette handling functions.
 
+    Copyright (c) 1996-2006, Nicola Salmoria and the MAME Team.
+    Visit http://mamedev.org for licensing and usage restrictions.
+
 ******************************************************************************/
 
 #include "driver.h"
-#include "state.h"
 #include <math.h>
+#if defined(MAME_DEBUG) && !defined(NEW_DEBUGGER)
+#include "debug/mamedbg.h"
+#endif
 
 #define VERBOSE 0
 
@@ -35,19 +40,13 @@ enum
 UINT32 direct_rgb_components[3];
 UINT16 *palette_shadow_table;
 
-UINT8 *paletteram;
-UINT8 *paletteram_2;	/* use when palette RAM is split in two parts */
-UINT16 *paletteram16;
-UINT16 *paletteram16_2;
-UINT32 *paletteram32;
-
 
 
 /*-------------------------------------------------
     LOCAL VARIABLES
 -------------------------------------------------*/
 
-static rgb_t *game_palette;			/* RGB palette as set by the driver */
+rgb_t *game_palette;				/* RGB palette as set by the driver */
 static rgb_t *adjusted_palette;		/* actual RGB palette after brightness/gamma adjustments */
 static UINT32 *dirty_palette;
 static UINT16 *pen_brightness;
@@ -188,8 +187,8 @@ int palette_start(void)
 		return 1;
 
 	/* set up save/restore of the palette */
-	state_save_register_UINT32("palette", 0, "colors", game_palette, total_colors);
-	state_save_register_UINT16("palette", 0, "brightness", pen_brightness, Machine->drv->total_colors);
+	state_save_register_global_pointer(game_palette, total_colors);
+	state_save_register_global_pointer(pen_brightness, Machine->drv->total_colors);
 	state_save_register_func_postload(palette_reset);
 
 	return 0;
@@ -511,54 +510,49 @@ static int palette_alloc(void)
 
 	/* allocate memory for the raw game palette */
 	game_palette = auto_malloc(max_total_colors * sizeof(game_palette[0]));
-	if (!game_palette)
-		return 1;
 	for (i = 0; i < max_total_colors; i++)
 		game_palette[i] = MAKE_RGB((i & 1) * 0xff, ((i >> 1) & 1) * 0xff, ((i >> 2) & 1) * 0xff);
 
 	/* allocate memory for the adjusted game palette */
 	adjusted_palette = auto_malloc(max_total_colors * sizeof(adjusted_palette[0]));
-	if (!adjusted_palette)
-		return 1;
 	for (i = 0; i < max_total_colors; i++)
 		adjusted_palette[i] = game_palette[i];
 
 	/* allocate memory for the dirty palette array */
 	dirty_palette = auto_malloc((max_total_colors + 31) / 32 * sizeof(dirty_palette[0]));
-	if (!dirty_palette)
-		return 1;
 	dirty_palette[(max_total_colors - 1) / 32] = 0; /* initialize all the bits of the last dirty entry */
 	for (i = 0; i < max_total_colors; i++)
 		mark_pen_dirty(i);
 
 	/* allocate memory for the pen table */
-	Machine->pens = auto_malloc(total_colors * sizeof(Machine->pens[0]));
-	if (!Machine->pens)
-		return 1;
-	for (i = 0; i < total_colors; i++)
-		Machine->pens[i] = i;
+	if (total_colors > 0)
+	{
+		Machine->pens = auto_malloc(total_colors * sizeof(Machine->pens[0]));
+		for (i = 0; i < total_colors; i++)
+			Machine->pens[i] = i;
 
-	/* allocate memory for the per-entry brightness table */
-	pen_brightness = auto_malloc(Machine->drv->total_colors * sizeof(pen_brightness[0]));
-	if (!pen_brightness)
-		return 1;
-	for (i = 0; i < Machine->drv->total_colors; i++)
-		pen_brightness[i] = 1 << PEN_BRIGHTNESS_BITS;
+		/* allocate memory for the per-entry brightness table */
+		pen_brightness = auto_malloc(Machine->drv->total_colors * sizeof(pen_brightness[0]));
+		for (i = 0; i < Machine->drv->total_colors; i++)
+			pen_brightness[i] = 1 << PEN_BRIGHTNESS_BITS;
+	}
+	else
+	{
+		/* this driver does not use a palette */
+		Machine->pens = NULL;
+		pen_brightness = NULL;
+	}
 
 	/* allocate memory for the colortables, if needed */
 	if (Machine->drv->color_table_len)
 	{
 		/* first for the raw colortable */
 		Machine->game_colortable = auto_malloc(Machine->drv->color_table_len * sizeof(Machine->game_colortable[0]));
-		if (!Machine->game_colortable)
-			return 1;
 		for (i = 0; i < Machine->drv->color_table_len; i++)
 			Machine->game_colortable[i] = i % total_colors;
 
 		/* then for the remapped colortable */
 		Machine->remapped_colortable = auto_malloc(Machine->drv->color_table_len * sizeof(Machine->remapped_colortable[0]));
-		if (!Machine->remapped_colortable)
-			return 1;
 	}
 
 	/* otherwise, keep the game_colortable NULL and point the remapped_colortable to the pens */
@@ -568,22 +562,20 @@ static int palette_alloc(void)
 		Machine->remapped_colortable = Machine->pens;	/* straight 1:1 mapping from palette to colortable */
 	}
 
+#if defined(MAME_DEBUG) && !defined(NEW_DEBUGGER)
 	/* allocate memory for the debugger pens */
 	Machine->debug_pens = auto_malloc(DEBUGGER_TOTAL_COLORS * sizeof(Machine->debug_pens[0]));
-	if (!Machine->debug_pens)
-		return 1;
 	for (i = 0; i < DEBUGGER_TOTAL_COLORS; i++)
 		Machine->debug_pens[i] = i;
 
 	/* allocate memory for the debugger colortable */
 	Machine->debug_remapped_colortable = auto_malloc(2 * DEBUGGER_TOTAL_COLORS * DEBUGGER_TOTAL_COLORS * sizeof(Machine->debug_remapped_colortable[0]));
-	if (!Machine->debug_remapped_colortable)
-		return 1;
 	for (i = 0; i < DEBUGGER_TOTAL_COLORS * DEBUGGER_TOTAL_COLORS; i++)
 	{
 		Machine->debug_remapped_colortable[2*i+0] = i / DEBUGGER_TOTAL_COLORS;
 		Machine->debug_remapped_colortable[2*i+1] = i % DEBUGGER_TOTAL_COLORS;
 	}
+#endif
 
 #if 0 /** for reference, do not remove */
 	/* allocate the shadow lookup table for 16bpp modes */
@@ -594,8 +586,6 @@ static int palette_alloc(void)
          * bugs should the tilemap contains pens >= total_colors
          */
 		palette_shadow_table = auto_malloc(65536 * sizeof(palette_shadow_table[0]));
-		if (!palette_shadow_table)
-			return 1;
 
 		/* map entries up to the total_colors so they point to the next block of colors */
 		for (i = 0; i < 65536; i++)
@@ -618,7 +608,7 @@ static int palette_alloc(void)
 		{
 			if (Machine->drv->video_attributes & VIDEO_HAS_SHADOWS)
 			{
-				if (!(table_ptr16 = auto_malloc(65536 * sizeof(UINT16)))) return 1;
+				table_ptr16 = auto_malloc(65536 * sizeof(UINT16));
 
 				shadow_table_base[0] = shadow_table_base[2] = (UINT32*)table_ptr16;
 
@@ -630,7 +620,7 @@ static int palette_alloc(void)
 
 			if (Machine->drv->video_attributes & VIDEO_HAS_HIGHLIGHTS)
 			{
-				if (!(table_ptr16 = auto_malloc(65536 * sizeof(UINT16)))) return 1;
+				table_ptr16 = auto_malloc(65536 * sizeof(UINT16));
 
 				shadow_table_base[1] = shadow_table_base[3] = (UINT32*)table_ptr16;
 
@@ -644,7 +634,7 @@ static int palette_alloc(void)
 		{
 			if (Machine->drv->video_attributes & VIDEO_HAS_SHADOWS)
 			{
-				if (!(table_ptr32 = auto_malloc(65536 * sizeof(UINT32)))) return 1;
+				table_ptr32 = auto_malloc(65536 * sizeof(UINT32));
 
 				shadow_table_base[0] = table_ptr32;
 				shadow_table_base[2] = table_ptr32 + 32768;
@@ -654,7 +644,7 @@ static int palette_alloc(void)
 
 			if (Machine->drv->video_attributes & VIDEO_HAS_HIGHLIGHTS)
 			{
-				if (!(table_ptr32 = auto_malloc(65536 * sizeof(UINT32)))) return 1;
+				table_ptr32 = auto_malloc(65536 * sizeof(UINT32));
 
 				shadow_table_base[1] = table_ptr32;
 				shadow_table_base[3] = table_ptr32 + 32768;
@@ -747,11 +737,8 @@ int palette_init(void)
 		pen_t color = Machine->game_colortable[i];
 
 		/* check for invalid colors set by Machine->drv->init_palette */
-		if (color < total_colors)
-			Machine->remapped_colortable[i] = Machine->pens[color];
-		else
-			ui_popup("colortable[%d] (=%d) out of range (total_colors = %d)",
-					i,color,total_colors);
+		assert(color < total_colors);
+		Machine->remapped_colortable[i] = Machine->pens[color];
 	}
 
 	/* all done */
@@ -1224,765 +1211,3 @@ pen_t get_white_pen(void)
 {
 	return white_pen;
 }
-
-
-
-
-/******************************************************************************
-
- Commonly used palette RAM handling functions
-
-******************************************************************************/
-
-READ8_HANDLER( paletteram_r )
-{
-	return paletteram[offset];
-}
-
-READ8_HANDLER( paletteram_2_r )
-{
-	return paletteram_2[offset];
-}
-
-READ16_HANDLER( paletteram16_word_r )
-{
-	return paletteram16[offset];
-}
-
-READ16_HANDLER( paletteram16_2_word_r )
-{
-	return paletteram16_2[offset];
-}
-
-READ32_HANDLER( paletteram32_r )
-{
-	return paletteram32[offset];
-}
-
-WRITE8_HANDLER( paletteram_RRRGGGBB_w )
-{
-	int r,g,b;
-	int bit0,bit1,bit2;
-
-
-	paletteram[offset] = data;
-
-	/* red component */
-	bit0 = (data >> 5) & 0x01;
-	bit1 = (data >> 6) & 0x01;
-	bit2 = (data >> 7) & 0x01;
-	r = 0x21 * bit0 + 0x47 * bit1 + 0x97 * bit2;
-	/* green component */
-	bit0 = (data >> 2) & 0x01;
-	bit1 = (data >> 3) & 0x01;
-	bit2 = (data >> 4) & 0x01;
-	g = 0x21 * bit0 + 0x47 * bit1 + 0x97 * bit2;
-	/* blue component */
-	bit0 = 0;
-	bit1 = (data >> 0) & 0x01;
-	bit2 = (data >> 1) & 0x01;
-	b = 0x21 * bit0 + 0x47 * bit1 + 0x97 * bit2;
-
-	palette_set_color(offset,r,g,b);
-}
-
-WRITE8_HANDLER( paletteram_BBBGGGRR_w )
-{
-	int r,g,b;
-	int bit0,bit1,bit2;
-
-	paletteram[offset] = data;
-
-	/* blue component */
-	bit0 = (data >> 5) & 0x01;
-	bit1 = (data >> 6) & 0x01;
-	bit2 = (data >> 7) & 0x01;
-	b = 0x21 * bit0 + 0x47 * bit1 + 0x97 * bit2;
-	/* green component */
-	bit0 = (data >> 2) & 0x01;
-	bit1 = (data >> 3) & 0x01;
-	bit2 = (data >> 4) & 0x01;
-	g = 0x21 * bit0 + 0x47 * bit1 + 0x97 * bit2;
-	/* blue component */
-	bit0 = (data >> 0) & 0x01;
-	bit1 = (data >> 1) & 0x01;
-	r = 0x55 * bit0 + 0xaa * bit1;
-
-	palette_set_color(offset,r,g,b);
-}
-
-WRITE8_HANDLER( paletteram_BBGGGRRR_w )
-{
-	int r,g,b;
-	int bit0,bit1,bit2;
-
-
-	paletteram[offset] = data;
-
-	/* red component */
-	bit0 = (data >> 0) & 0x01;
-	bit1 = (data >> 1) & 0x01;
-	bit2 = (data >> 2) & 0x01;
-	r = 0x21 * bit0 + 0x47 * bit1 + 0x97 * bit2;
-	/* green component */
-	bit0 = (data >> 3) & 0x01;
-	bit1 = (data >> 4) & 0x01;
-	bit2 = (data >> 5) & 0x01;
-	g = 0x21 * bit0 + 0x47 * bit1 + 0x97 * bit2;
-	/* blue component */
-	bit0 = 0;
-	bit1 = (data >> 6) & 0x01;
-	bit2 = (data >> 7) & 0x01;
-	b = 0x21 * bit0 + 0x47 * bit1 + 0x97 * bit2;
-
-	palette_set_color(offset,r,g,b);
-}
-
-
-WRITE8_HANDLER( paletteram_IIBBGGRR_w )
-{
-	int r,g,b,i;
-
-
-	paletteram[offset] = data;
-
-	i = (data >> 6) & 0x03;
-	/* red component */
-	r = (data << 2) & 0x0c;
-	if (r) r |= i;
-	r *= 0x11;
-	/* green component */
-	g = (data >> 0) & 0x0c;
-	if (g) g |= i;
-	g *= 0x11;
-	/* blue component */
-	b = (data >> 2) & 0x0c;
-	if (b) b |= i;
-	b *= 0x11;
-
-	palette_set_color(offset,r,g,b);
-}
-
-
-WRITE8_HANDLER( paletteram_BBGGRRII_w )
-{
-	int r,g,b,i;
-
-
-	paletteram[offset] = data;
-
-	i = (data >> 0) & 0x03;
-	/* red component */
-	r = (((data >> 0) & 0x0c) | i) * 0x11;
-	/* green component */
-	g = (((data >> 2) & 0x0c) | i) * 0x11;
-	/* blue component */
-	b = (((data >> 4) & 0x0c) | i) * 0x11;
-
-	palette_set_color(offset,r,g,b);
-}
-
-
-INLINE void changecolor_xxxxBBBBGGGGRRRR(pen_t color,int data)
-{
-	int r,g,b;
-
-
-	r = (data >> 0) & 0x0f;
-	g = (data >> 4) & 0x0f;
-	b = (data >> 8) & 0x0f;
-
-	r = (r << 4) | r;
-	g = (g << 4) | g;
-	b = (b << 4) | b;
-
-	palette_set_color(color,r,g,b);
-}
-
-WRITE8_HANDLER( paletteram_xxxxBBBBGGGGRRRR_w )
-{
-	paletteram[offset] = data;
-	changecolor_xxxxBBBBGGGGRRRR(offset / 2,paletteram[offset & ~1] | (paletteram[offset | 1] << 8));
-}
-
-WRITE8_HANDLER( paletteram_xxxxBBBBGGGGRRRR_swap_w )
-{
-	paletteram[offset] = data;
-	changecolor_xxxxBBBBGGGGRRRR(offset / 2,paletteram[offset | 1] | (paletteram[offset & ~1] << 8));
-}
-
-WRITE8_HANDLER( paletteram_xxxxBBBBGGGGRRRR_split1_w )
-{
-	paletteram[offset] = data;
-	changecolor_xxxxBBBBGGGGRRRR(offset,paletteram[offset] | (paletteram_2[offset] << 8));
-}
-
-WRITE8_HANDLER( paletteram_xxxxBBBBGGGGRRRR_split2_w )
-{
-	paletteram_2[offset] = data;
-	changecolor_xxxxBBBBGGGGRRRR(offset,paletteram[offset] | (paletteram_2[offset] << 8));
-}
-
-WRITE16_HANDLER( paletteram16_xxxxBBBBGGGGRRRR_word_w )
-{
-	COMBINE_DATA(&paletteram16[offset]);
-	changecolor_xxxxBBBBGGGGRRRR(offset,paletteram16[offset]);
-}
-
-
-INLINE void changecolor_xxxxBBBBRRRRGGGG(pen_t color,int data)
-{
-	int r,g,b;
-
-
-	r = (data >> 4) & 0x0f;
-	g = (data >> 0) & 0x0f;
-	b = (data >> 8) & 0x0f;
-
-	r = (r << 4) | r;
-	g = (g << 4) | g;
-	b = (b << 4) | b;
-
-	palette_set_color(color,r,g,b);
-}
-
-WRITE8_HANDLER( paletteram_xxxxBBBBRRRRGGGG_w )
-{
-	paletteram[offset] = data;
-	changecolor_xxxxBBBBRRRRGGGG(offset / 2,paletteram[offset & ~1] | (paletteram[offset | 1] << 8));
-}
-
-WRITE8_HANDLER( paletteram_xxxxBBBBRRRRGGGG_swap_w )
-{
-	paletteram[offset] = data;
-	changecolor_xxxxBBBBRRRRGGGG(offset / 2,paletteram[offset | 1] | (paletteram[offset & ~1] << 8));
-}
-
-WRITE8_HANDLER( paletteram_xxxxBBBBRRRRGGGG_split1_w )
-{
-	paletteram[offset] = data;
-	changecolor_xxxxBBBBRRRRGGGG(offset,paletteram[offset] | (paletteram_2[offset] << 8));
-}
-
-WRITE8_HANDLER( paletteram_xxxxBBBBRRRRGGGG_split2_w )
-{
-	paletteram_2[offset] = data;
-	changecolor_xxxxBBBBRRRRGGGG(offset,paletteram[offset] | (paletteram_2[offset] << 8));
-}
-
-WRITE16_HANDLER( paletteram16_xxxxBBBBRRRRGGGG_word_w )
-{
-	COMBINE_DATA(&paletteram16[offset]);
-	changecolor_xxxxBBBBRRRRGGGG(offset,paletteram16[offset]);
-}
-
-
-INLINE void changecolor_xxxxRRRRBBBBGGGG(pen_t color,int data)
-{
-	int r,g,b;
-
-
-	r = (data >> 8) & 0x0f;
-	g = (data >> 0) & 0x0f;
-	b = (data >> 4) & 0x0f;
-
-	r = (r << 4) | r;
-	g = (g << 4) | g;
-	b = (b << 4) | b;
-
-	palette_set_color(color,r,g,b);
-}
-
-WRITE8_HANDLER( paletteram_xxxxRRRRBBBBGGGG_split1_w )
-{
-	paletteram[offset] = data;
-	changecolor_xxxxRRRRBBBBGGGG(offset,paletteram[offset] | (paletteram_2[offset] << 8));
-}
-
-WRITE8_HANDLER( paletteram_xxxxRRRRBBBBGGGG_split2_w )
-{
-	paletteram_2[offset] = data;
-	changecolor_xxxxRRRRBBBBGGGG(offset,paletteram[offset] | (paletteram_2[offset] << 8));
-}
-
-
-INLINE void changecolor_xxxxRRRRGGGGBBBB(pen_t color,int data)
-{
-	int r,g,b;
-
-
-	r = (data >> 8) & 0x0f;
-	g = (data >> 4) & 0x0f;
-	b = (data >> 0) & 0x0f;
-
-	r = (r << 4) | r;
-	g = (g << 4) | g;
-	b = (b << 4) | b;
-
-	palette_set_color(color,r,g,b);
-}
-
-WRITE8_HANDLER( paletteram_xxxxRRRRGGGGBBBB_w )
-{
-	paletteram[offset] = data;
-	changecolor_xxxxRRRRGGGGBBBB(offset / 2,paletteram[offset & ~1] | (paletteram[offset | 1] << 8));
-}
-
-WRITE8_HANDLER( paletteram_xxxxRRRRGGGGBBBB_swap_w )
-{
-	paletteram[offset] = data;
-	changecolor_xxxxRRRRGGGGBBBB(offset / 2,paletteram[offset | 1] | (paletteram[offset & ~1] << 8));
-}
-
-WRITE16_HANDLER( paletteram16_xxxxRRRRGGGGBBBB_word_w )
-{
-	COMBINE_DATA(&paletteram16[offset]);
-	changecolor_xxxxRRRRGGGGBBBB(offset,paletteram16[offset]);
-}
-
-
-INLINE void changecolor_RRRRGGGGBBBBxxxx(pen_t color,int data)
-{
-	int r,g,b;
-
-
-	r = (data >> 12) & 0x0f;
-	g = (data >>  8) & 0x0f;
-	b = (data >>  4) & 0x0f;
-
-	r = (r << 4) | r;
-	g = (g << 4) | g;
-	b = (b << 4) | b;
-
-	palette_set_color(color,r,g,b);
-}
-
-WRITE8_HANDLER( paletteram_RRRRGGGGBBBBxxxx_swap_w )
-{
-	paletteram[offset] = data;
-	changecolor_RRRRGGGGBBBBxxxx(offset / 2,paletteram[offset | 1] | (paletteram[offset & ~1] << 8));
-}
-
-WRITE8_HANDLER( paletteram_RRRRGGGGBBBBxxxx_split1_w )
-{
-	paletteram[offset] = data;
-	changecolor_RRRRGGGGBBBBxxxx(offset,paletteram[offset] | (paletteram_2[offset] << 8));
-}
-
-WRITE8_HANDLER( paletteram_RRRRGGGGBBBBxxxx_split2_w )
-{
-	paletteram_2[offset] = data;
-	changecolor_RRRRGGGGBBBBxxxx(offset,paletteram[offset] | (paletteram_2[offset] << 8));
-}
-
-WRITE16_HANDLER( paletteram16_RRRRGGGGBBBBxxxx_word_w )
-{
-	COMBINE_DATA(&paletteram16[offset]);
-	changecolor_RRRRGGGGBBBBxxxx(offset,paletteram16[offset]);
-}
-
-
-INLINE void changecolor_BBBBGGGGRRRRxxxx(pen_t color,int data)
-{
-	int r,g,b;
-
-
-	r = (data >>  4) & 0x0f;
-	g = (data >>  8) & 0x0f;
-	b = (data >> 12) & 0x0f;
-
-	r = (r << 4) | r;
-	g = (g << 4) | g;
-	b = (b << 4) | b;
-
-	palette_set_color(color,r,g,b);
-}
-
-WRITE8_HANDLER( paletteram_BBBBGGGGRRRRxxxx_swap_w )
-{
-	paletteram[offset] = data;
-	changecolor_BBBBGGGGRRRRxxxx(offset / 2,paletteram[offset | 1] | (paletteram[offset & ~1] << 8));
-}
-
-WRITE8_HANDLER( paletteram_BBBBGGGGRRRRxxxx_split1_w )
-{
-	paletteram[offset] = data;
-	changecolor_BBBBGGGGRRRRxxxx(offset,paletteram[offset] | (paletteram_2[offset] << 8));
-}
-
-WRITE8_HANDLER( paletteram_BBBBGGGGRRRRxxxx_split2_w )
-{
-	paletteram_2[offset] = data;
-	changecolor_BBBBGGGGRRRRxxxx(offset,paletteram[offset] | (paletteram_2[offset] << 8));
-}
-
-WRITE16_HANDLER( paletteram16_BBBBGGGGRRRRxxxx_word_w )
-{
-	COMBINE_DATA(&paletteram16[offset]);
-	changecolor_BBBBGGGGRRRRxxxx(offset,paletteram16[offset]);
-}
-
-
-INLINE void changecolor_xBBBBBGGGGGRRRRR(pen_t color,int data)
-{
-	int r,g,b;
-
-
-	r = (data >>  0) & 0x1f;
-	g = (data >>  5) & 0x1f;
-	b = (data >> 10) & 0x1f;
-
-	r = (r << 3) | (r >> 2);
-	g = (g << 3) | (g >> 2);
-	b = (b << 3) | (b >> 2);
-
-	palette_set_color(color,r,g,b);
-}
-
-WRITE8_HANDLER( paletteram_xBBBBBGGGGGRRRRR_w )
-{
-	paletteram[offset] = data;
-	changecolor_xBBBBBGGGGGRRRRR(offset / 2,paletteram[offset & ~1] | (paletteram[offset | 1] << 8));
-}
-
-WRITE8_HANDLER( paletteram_xBBBBBGGGGGRRRRR_swap_w )
-{
-	paletteram[offset] = data;
-	changecolor_xBBBBBGGGGGRRRRR(offset / 2,paletteram[offset | 1] | (paletteram[offset & ~1] << 8));
-}
-
-WRITE8_HANDLER( paletteram_xBBBBBGGGGGRRRRR_split1_w )
-{
-	paletteram[offset] = data;
-	changecolor_xBBBBBGGGGGRRRRR(offset,paletteram[offset] | (paletteram_2[offset] << 8));
-}
-
-WRITE8_HANDLER( paletteram_xBBBBBGGGGGRRRRR_split2_w )
-{
-	paletteram_2[offset] = data;
-	changecolor_xBBBBBGGGGGRRRRR(offset,paletteram[offset] | (paletteram_2[offset] << 8));
-}
-
-WRITE16_HANDLER( paletteram16_xBBBBBGGGGGRRRRR_word_w )
-{
-	COMBINE_DATA(&paletteram16[offset]);
-	changecolor_xBBBBBGGGGGRRRRR(offset,paletteram16[offset]);
-}
-
-
-INLINE void changecolor_xBBBBBRRRRRGGGGG(pen_t color,int data)
-{
-	int r,g,b;
-
-
-	r = (data >>  5) & 0x1f;
-	g = (data >>  0) & 0x1f;
-	b = (data >> 10) & 0x1f;
-
-	r = (r << 3) | (r >> 2);
-	g = (g << 3) | (g >> 2);
-	b = (b << 3) | (b >> 2);
-
-	palette_set_color(color,r,g,b);
-}
-
-WRITE8_HANDLER( paletteram_xBBBBBRRRRRGGGGG_split1_w )
-{
-	paletteram[offset] = data;
-	changecolor_xBBBBBRRRRRGGGGG(offset,paletteram[offset] | (paletteram_2[offset] << 8));
-}
-
-WRITE8_HANDLER( paletteram_xBBBBBRRRRRGGGGG_split2_w )
-{
-	paletteram_2[offset] = data;
-	changecolor_xBBBBBRRRRRGGGGG(offset,paletteram[offset] | (paletteram_2[offset] << 8));
-}
-
-
-INLINE void changecolor_xRRRRRGGGGGBBBBB(pen_t color,int data)
-{
-	int r,g,b;
-
-
-	r = (data >> 10) & 0x1f;
-	g = (data >>  5) & 0x1f;
-	b = (data >>  0) & 0x1f;
-
-	r = (r << 3) | (r >> 2);
-	g = (g << 3) | (g >> 2);
-	b = (b << 3) | (b >> 2);
-
-	palette_set_color(color,r,g,b);
-}
-
-WRITE8_HANDLER( paletteram_xRRRRRGGGGGBBBBB_w )
-{
-	paletteram[offset] = data;
-	changecolor_xRRRRRGGGGGBBBBB(offset / 2,paletteram[offset & ~1] | (paletteram[offset | 1] << 8));
-}
-
-WRITE16_HANDLER( paletteram16_xRRRRRGGGGGBBBBB_word_w )
-{
-	COMBINE_DATA(&paletteram16[offset]);
-	changecolor_xRRRRRGGGGGBBBBB(offset,paletteram16[offset]);
-}
-
-
-INLINE void changecolor_xGGGGGRRRRRBBBBB(pen_t color,int data)
-{
-	int r,g,b;
-
-
-	r = (data >>  5) & 0x1f;
-	g = (data >> 10) & 0x1f;
-	b = (data >>  0) & 0x1f;
-
-	r = (r << 3) | (r >> 2);
-	g = (g << 3) | (g >> 2);
-	b = (b << 3) | (b >> 2);
-
-	palette_set_color(color,r,g,b);
-}
-
-WRITE16_HANDLER( paletteram16_xGGGGGRRRRRBBBBB_word_w )
-{
-	COMBINE_DATA(&paletteram16[offset]);
-	changecolor_xGGGGGRRRRRBBBBB(offset,paletteram16[offset]);
-}
-
-
-INLINE void changecolor_xGGGGGBBBBBRRRRR(pen_t color,int data)
-{
-	int r,g,b;
-
-
-	r = (data >>  0) & 0x1f;
-	g = (data >> 10) & 0x1f;
-	b = (data >>  5) & 0x1f;
-
-	r = (r << 3) | (r >> 2);
-	g = (g << 3) | (g >> 2);
-	b = (b << 3) | (b >> 2);
-
-	palette_set_color(color,r,g,b);
-}
-
-WRITE16_HANDLER( paletteram16_xGGGGGBBBBBRRRRR_word_w )
-{
-	COMBINE_DATA(&paletteram16[offset]);
-	changecolor_xGGGGGBBBBBRRRRR(offset,paletteram16[offset]);
-}
-
-
-INLINE void changecolor_RRRRRGGGGGBBBBBx(pen_t color,int data)
-{
-	int r,g,b;
-
-
-	r = (data >> 11) & 0x1f;
-	g = (data >>  6) & 0x1f;
-	b = (data >>  1) & 0x1f;
-
-	r = (r << 3) | (r >> 2);
-	g = (g << 3) | (g >> 2);
-	b = (b << 3) | (b >> 2);
-
-	palette_set_color(color,r,g,b);
-}
-
-WRITE8_HANDLER( paletteram_RRRRRGGGGGBBBBBx_w )
-{
-	paletteram[offset] = data;
-	changecolor_RRRRRGGGGGBBBBBx(offset / 2,paletteram[offset & ~1] | (paletteram[offset | 1] << 8));
-}
-
-WRITE16_HANDLER( paletteram16_RRRRRGGGGGBBBBBx_word_w )
-{
-	COMBINE_DATA(&paletteram16[offset]);
-	changecolor_RRRRRGGGGGBBBBBx(offset,paletteram16[offset]);
-}
-
-
-INLINE void changecolor_IIIIRRRRGGGGBBBB(pen_t color,int data)
-{
-	int i,r,g,b;
-
-
-	static const int ztable[16] =
-		{ 0x0, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0x10, 0x11 };
-
-	i = ztable[(data >> 12) & 15];
-	r = ((data >> 8) & 15) * i;
-	g = ((data >> 4) & 15) * i;
-	b = ((data >> 0) & 15) * i;
-
-	palette_set_color(color,r,g,b);
-
-	if (!(Machine->drv->video_attributes & VIDEO_NEEDS_6BITS_PER_GUN))
-		ui_popup("driver should use VIDEO_NEEDS_6BITS_PER_GUN flag");
-}
-
-WRITE16_HANDLER( paletteram16_IIIIRRRRGGGGBBBB_word_w )
-{
-	COMBINE_DATA(&paletteram16[offset]);
-	changecolor_IIIIRRRRGGGGBBBB(offset,paletteram16[offset]);
-}
-
-
-INLINE void changecolor_RRRRGGGGBBBBIIII(pen_t color,int data)
-{
-	int i,r,g,b;
-
-
-	static const int ztable[16] =
-		{ 0x0, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0x10, 0x11 };
-
-	i = ztable[(data >> 0) & 15];
-	r = ((data >> 12) & 15) * i;
-	g = ((data >>  8) & 15) * i;
-	b = ((data >>  4) & 15) * i;
-
-	palette_set_color(color,r,g,b);
-
-	if (!(Machine->drv->video_attributes & VIDEO_NEEDS_6BITS_PER_GUN))
-		ui_popup("driver should use VIDEO_NEEDS_6BITS_PER_GUN flag");
-}
-
-WRITE16_HANDLER( paletteram16_RRRRGGGGBBBBIIII_word_w )
-{
-	COMBINE_DATA(&paletteram16[offset]);
-	changecolor_RRRRGGGGBBBBIIII(offset,paletteram16[offset]);
-}
-
-
-WRITE16_HANDLER( paletteram16_xrgb_word_w )
-{
-	int r, g, b;
-	UINT16 data0, data1;
-
-	COMBINE_DATA(paletteram16 + offset);
-
-	offset &= ~1;
-
-	data0 = paletteram16[offset];
-	data1 = paletteram16[offset + 1];
-
-	r = data0 & 0xff;
-	g = data1 >> 8;
-	b = data1 & 0xff;
-
-	palette_set_color(offset>>1, r, g, b);
-
-	if (!(Machine->drv->video_attributes & VIDEO_NEEDS_6BITS_PER_GUN))
-		ui_popup("driver should use VIDEO_NEEDS_6BITS_PER_GUN flag");
-}
-
-
-WRITE16_HANDLER( paletteram16_xbgr_word_w )
-{
-	int r, g, b;
-	UINT16 data0, data1;
-
-	COMBINE_DATA(paletteram16 + offset);
-
-	offset &= ~1;
-
-	data0 = paletteram16[offset];
-	data1 = paletteram16[offset + 1];
-
-	b = data0 & 0xff;
-	g = data1 >> 8;
-	r = data1 & 0xff;
-
-	palette_set_color(offset>>1, r, g, b);
-
-	if (!(Machine->drv->video_attributes & VIDEO_NEEDS_6BITS_PER_GUN))
-		ui_popup("driver should use VIDEO_NEEDS_6BITS_PER_GUN flag");
-}
-
-
-INLINE void changecolor_RRRRGGGGBBBBRGBx(pen_t color,int data)
-{
-	int r,g,b;
-
-	r = ((data >> 11) & 0x1e) | ((data>>3) & 0x01);
-	g = ((data >>  7) & 0x1e) | ((data>>2) & 0x01);
-	b = ((data >>  3) & 0x1e) | ((data>>1) & 0x01);
-	r = (r<<3) | (r>>2);
-	g = (g<<3) | (g>>2);
-	b = (b<<3) | (b>>2);
-
-	palette_set_color(color,r,g,b);
-}
-
-WRITE16_HANDLER( paletteram16_RRRRGGGGBBBBRGBx_word_w )
-{
-	COMBINE_DATA(&paletteram16[offset]);
-	changecolor_RRRRGGGGBBBBRGBx(offset,paletteram16[offset]);
-}
-
-
-
-/******************************************************************************
-
- Commonly used color PROM handling functions
-
-******************************************************************************/
-
-
-/***************************************************************************
-
-    Standard black and white palette.
-    Color 0 is pure black, color 1 is pure white.
-
-***************************************************************************/
-
-PALETTE_INIT( black_and_white )
-{
-	palette_set_color(0,0x00,0x00,0x00); /* black */
-	palette_set_color(1,0xff,0xff,0xff); /* white */
-}
-
-
-/***************************************************************************
-
-  This assumes the commonly used resistor values:
-
-  bit 3 -- 220 ohm resistor  -- RED/GREEN/BLUE
-        -- 470 ohm resistor  -- RED/GREEN/BLUE
-        -- 1  kohm resistor  -- RED/GREEN/BLUE
-  bit 0 -- 2.2kohm resistor  -- RED/GREEN/BLUE
-
-***************************************************************************/
-
-PALETTE_INIT( RRRR_GGGG_BBBB )
-{
-	int i;
-
-
-	for (i = 0;i < Machine->drv->total_colors;i++)
-	{
-		int bit0,bit1,bit2,bit3,r,g,b;
-
-		/* red component */
-		bit0 = (color_prom[i] >> 0) & 0x01;
-		bit1 = (color_prom[i] >> 1) & 0x01;
-		bit2 = (color_prom[i] >> 2) & 0x01;
-		bit3 = (color_prom[i] >> 3) & 0x01;
-		r = 0x0e * bit0 + 0x1f * bit1 + 0x43 * bit2 + 0x8f * bit3;
-		/* green component */
-		bit0 = (color_prom[i + Machine->drv->total_colors] >> 0) & 0x01;
-		bit1 = (color_prom[i + Machine->drv->total_colors] >> 1) & 0x01;
-		bit2 = (color_prom[i + Machine->drv->total_colors] >> 2) & 0x01;
-		bit3 = (color_prom[i + Machine->drv->total_colors] >> 3) & 0x01;
-		g = 0x0e * bit0 + 0x1f * bit1 + 0x43 * bit2 + 0x8f * bit3;
-		/* blue component */
-		bit0 = (color_prom[i + 2*Machine->drv->total_colors] >> 0) & 0x01;
-		bit1 = (color_prom[i + 2*Machine->drv->total_colors] >> 1) & 0x01;
-		bit2 = (color_prom[i + 2*Machine->drv->total_colors] >> 2) & 0x01;
-		bit3 = (color_prom[i + 2*Machine->drv->total_colors] >> 3) & 0x01;
-		b = 0x0e * bit0 + 0x1f * bit1 + 0x43 * bit2 + 0x8f * bit3;
-
-		palette_set_color(i,r,g,b);
-	}
-}
