@@ -1,22 +1,25 @@
 /*********************************************************************
 
-  png.c
+    png.c
 
-  PNG reading functions.
+    PNG reading functions.
 
-  07/15/1998 Created by Mathis Rosenhauer
-  10/02/1998 Code clean up and abstraction by Mike Balfour
-             and Mathis Rosenhauer
-  10/15/1998 Image filtering. MLR
-  11/09/1998 Bit depths 1-8 MLR
-  11/10/1998 Some additional PNG chunks recognized MLR
-  05/14/1999 Color type 2 and PNG save functions added
-  05/15/1999 Handle RGB555 while saving, use mame_fxxx
-             functions for writing MSH
-  04/27/2001 Simple MNG support MLR
+    Copyright (c) 1996-2006, Nicola Salmoria and the MAME Team.
+    Visit http://mamedev.org for licensing and usage restrictions.
 
-  TODO : Fully comply with the "Recommendations for Decoders"
-         of the W3C
+    07/15/1998 Created by Mathis Rosenhauer
+    10/02/1998 Code clean up and abstraction by Mike Balfour
+            and Mathis Rosenhauer
+    10/15/1998 Image filtering. MLR
+    11/09/1998 Bit depths 1-8 MLR
+    11/10/1998 Some additional PNG chunks recognized MLR
+    05/14/1999 Color type 2 and PNG save functions added
+    05/15/1999 Handle RGB555 while saving, use mame_fxxx
+            functions for writing MSH
+    04/27/2001 Simple MNG support MLR
+
+    TODO : Fully comply with the "Recommendations for Decoders"
+        of the W3C
 
 *********************************************************************/
 
@@ -25,7 +28,6 @@
 #include "driver.h"
 #include "png.h"
 
-
 /* convert_uint is here so we don't have to deal with byte-ordering issues */
 static UINT32 convert_from_network_order (UINT8 *v)
 {
@@ -35,7 +37,7 @@ static UINT32 convert_from_network_order (UINT8 *v)
 	return i;
 }
 
-int png_unfilter(struct png_info *p)
+int png_unfilter(png_info *p)
 {
 	int i, j, bpp, filter;
 	INT32 prediction, pA, pB, pC, dA, dB, dC;
@@ -119,7 +121,7 @@ int png_verify_signature (mame_file *fp)
 	return 1;
 }
 
-int png_inflate_image (struct png_info *p)
+int png_inflate_image (png_info *p)
 {
 	unsigned long fbuff_size;
 
@@ -142,10 +144,10 @@ int png_inflate_image (struct png_info *p)
 	return 1;
 }
 
-int png_read_file(mame_file *fp, struct png_info *p)
+int png_read_file(mame_file *fp, png_info *p)
 {
 	/* translates color_type to bytes per pixel */
-	const int samples[] = {1, 0, 3, 1, 2, 0, 4};
+	static const int samples[] = {1, 0, 3, 1, 2, 0, 4};
 
 	UINT32 chunk_length, chunk_type=0, chunk_crc, crc;
 	UINT8 *chunk_data, *temp;
@@ -331,6 +333,7 @@ int png_read_file(mame_file *fp, struct png_info *p)
 		ihead = pidat->next;
 		free (pidat);
 	}
+	free(ihead);
 	p->bpp = (samples[p->color_type] * p->bit_depth) / 8;
 	p->rowbytes = ceil((p->width * p->bit_depth * samples[p->color_type]) / 8.0);
 
@@ -343,7 +346,7 @@ int png_read_file(mame_file *fp, struct png_info *p)
 	return 1;
 }
 
-int png_read_info(mame_file *fp, struct png_info *p)
+int png_read_info(mame_file *fp, png_info *p)
 {
 	UINT32 chunk_length, chunk_type=0, chunk_crc, crc;
 	UINT8 *chunk_data;
@@ -453,7 +456,7 @@ int png_read_info(mame_file *fp, struct png_info *p)
 }
 
 /*  Expands a p->image from p->bit_depth to 8 bit */
-int png_expand_buffer_8bit (struct png_info *p)
+int png_expand_buffer_8bit (png_info *p)
 {
 	int i,j, k;
 	UINT8 *inp, *outp, *outbuf;
@@ -490,7 +493,7 @@ int png_expand_buffer_8bit (struct png_info *p)
 	return 1;
 }
 
-void png_delete_unused_colors (struct png_info *p)
+void png_delete_unused_colors (png_info *p)
 {
 	int i, tab[256], pen=0, trns=0;
 	UINT8 ptemp[3*256], ttemp[256];
@@ -535,14 +538,15 @@ void png_delete_unused_colors (struct png_info *p)
 
 ********************************************************************************/
 
-struct png_text
+struct _png_text
 {
 	char *data;
 	int length;
-	struct png_text *next;
+	struct _png_text *next;
 };
+typedef struct _png_text png_text;
 
-static struct png_text *png_text_list = 0;
+static png_text *png_text_list = 0;
 
 static void convert_to_network_order (UINT32 i, UINT8 *v)
 {
@@ -554,9 +558,9 @@ static void convert_to_network_order (UINT32 i, UINT8 *v)
 
 int png_add_text (const char *keyword, const char *text)
 {
-	struct png_text *pt;
+	png_text *pt;
 
-	pt = malloc (sizeof(struct png_text));
+	pt = malloc (sizeof(png_text));
 	if (pt == 0)
 		return 0;
 
@@ -619,10 +623,10 @@ int png_write_sig(mame_file *fp)
 	return 1;
 }
 
-int png_write_datastream(mame_file *fp, struct png_info *p)
+int png_write_datastream(mame_file *fp, png_info *p)
 {
 	UINT8 ihdr[13];
-	struct png_text *pt;
+	png_text *pt;
 
 	/* IHDR */
 	convert_to_network_order(p->width, ihdr);
@@ -664,7 +668,7 @@ int png_write_datastream(mame_file *fp, struct png_info *p)
 	return 1;
 }
 
-int png_filter(struct png_info *p)
+int png_filter(png_info *p)
 {
 	int i;
 	UINT8 *src, *dst;
@@ -688,7 +692,7 @@ int png_filter(struct png_info *p)
 	return 1;
 }
 
-int png_deflate_image(struct png_info *p)
+int png_deflate_image(png_info *p)
 {
 	unsigned long zbuff_size;
 
@@ -710,7 +714,7 @@ int png_deflate_image(struct png_info *p)
 	return 1;
 }
 
-static int png_pack_buffer (struct png_info *p)
+static int png_pack_buffer (png_info *p)
 {
 	UINT8 *outp, *inp;
 	int i,j,k;
@@ -749,15 +753,15 @@ static int png_pack_buffer (struct png_info *p)
 
  *********************************************************************/
 
-static int png_create_datastream(void *fp, struct mame_bitmap *bitmap)
+static int png_create_datastream(void *fp, mame_bitmap *bitmap)
 {
 	int i, j;
 	int r, g, b;
 	UINT32 color;
 	UINT8 *ip;
-	struct png_info p;
+	png_info p;
 
-	memset (&p, 0, sizeof (struct png_info));
+	memset (&p, 0, sizeof (png_info));
 	p.xscale = p.yscale = p.source_gamma = 0.0;
 	p.palette = p.trans = p.image = p.zimage = p.fimage = NULL;
 	p.width = bitmap->width;
@@ -869,7 +873,7 @@ static int png_create_datastream(void *fp, struct mame_bitmap *bitmap)
 	return 1;
 }
 
-int png_write_bitmap(mame_file *fp, struct mame_bitmap *bitmap)
+int png_write_bitmap(mame_file *fp, mame_bitmap *bitmap)
 {
 	char text[1024];
 
@@ -893,12 +897,16 @@ int png_write_bitmap(mame_file *fp, struct mame_bitmap *bitmap)
 
 ********************************************************************************/
 
-static int mng_status;
 
-int mng_capture_start(mame_file *fp, struct mame_bitmap *bitmap)
+int mng_capture_start(mame_file *fp, mame_bitmap *bitmap)
 {
 	UINT8 mhdr[28];
-/*  UINT8 term; */
+	char text[1024];
+
+	sprintf (text, APPNAME " %s", build_version);
+	png_add_text("Software", text);
+	sprintf (text, "%s %s", Machine->gamedrv->manufacturer, Machine->gamedrv->description);
+	png_add_text("System", text);
 
 	if (mame_fwrite(fp, MNG_Signature, 8) != 8)
 	{
@@ -916,27 +924,15 @@ int mng_capture_start(mame_file *fp, struct mame_bitmap *bitmap)
 	if (write_chunk(fp, MNG_CN_MHDR, mhdr, 28)==0)
 		return 0;
 
-/*  term = 0x03;    loop sequence    */
-/*  if (write_chunk(fp, MNG_CN_TERM, &term, 1)==0) */
-/*      return 0; */
-
-	mng_status = 1;
 	return 1;
 }
 
-int mng_capture_frame(mame_file *fp, struct mame_bitmap *bitmap)
+int mng_capture_frame(mame_file *fp, mame_bitmap *bitmap)
 {
-	if (mng_status)
-	{
-		if(png_create_datastream(fp, bitmap) == 0)
-			return 0;
-		return 1;
-	}
-	else
-	{
-		logerror("MNG recording not running\n");
+	if(png_create_datastream(fp, bitmap) == 0)
 		return 0;
-	}
+
+	return 1;
 }
 
 int mng_capture_stop(mame_file *fp)
@@ -944,12 +940,6 @@ int mng_capture_stop(mame_file *fp)
 	if (write_chunk(fp, MNG_CN_MEND, NULL, 0)==0)
 		return 0;
 
-	mng_status = 0;
 	return 1;
 }
 
-int mng_capture_status(void)
-{
-	return mng_status;
-}
-
