@@ -1,11 +1,21 @@
+/***************************************************************************
+
+    profiler.c
+
+    Functions to manage profiling of MAME execution.
+
+    Copyright (c) 1996-2006, Nicola Salmoria and the MAME Team.
+    Visit http://mamedev.org for licensing and usage restrictions.
+
+***************************************************************************/
+
+#include "osdepend.h"
 #include "driver.h"
 #include "osinline.h"
+#include "profiler.h"
 
 
 /* in usrintf.c */
-extern int uirotcharwidth, uirotcharheight;
-
-
 static int use_profiler;
 
 
@@ -22,13 +32,14 @@ static int use_profiler;
 
 #define MEMORY 6
 
-struct profile_data
+struct _profile_data
 {
 	UINT64 count[MEMORY][PROFILER_TOTAL];
 	unsigned int cpu_context_switches[MEMORY];
 };
+typedef struct _profile_data profile_data;
 
-static struct profile_data profile;
+static profile_data profile;
 static int memory;
 
 
@@ -47,7 +58,7 @@ void profiler_stop(void)
 	use_profiler = 0;
 }
 
-void profiler__mark(int type)
+void profiler_mark(int type)
 {
 	cycles_t curr_cycles;
 
@@ -98,13 +109,11 @@ logerror("Profiler error: FILO buffer underflow\n");
 	}
 }
 
-void profiler_show(struct mame_bitmap *bitmap)
+const char *profiler_get_text(void)
 {
 	int i,j;
 	UINT64 total,normalize;
 	UINT64 computed;
-	int line;
-	char buf[30];
 	static const char *names[PROFILER_TOTAL] =
 	{
 		"CPU 1  ",
@@ -130,6 +139,8 @@ void profiler_show(struct mame_bitmap *bitmap)
 		"Callbck",
 		"Hiscore",
 		"Input  ",
+		"Movie  ",
+		"Logerr ",
 		"Extra  ",
 		"User1  ",
 		"User2  ",
@@ -139,9 +150,11 @@ void profiler_show(struct mame_bitmap *bitmap)
 		"Idle   ",
 	};
 	static int showdelay[PROFILER_TOTAL];
+	static char buf[30*20];
+	char *bufptr = buf;
 
 
-	if (!use_profiler) return;
+	if (!use_profiler) return "";
 
 	profiler_mark(PROFILER_PROFILER);
 
@@ -162,9 +175,8 @@ void profiler_show(struct mame_bitmap *bitmap)
 	}
 	total = computed;
 
-	if (total == 0 || normalize == 0) return;	/* we have been just reset */
+	if (total == 0 || normalize == 0) return "";	/* we have been just reset */
 
-	line = 0;
 	for (i = 0;i < PROFILER_TOTAL;i++)
 	{
 		computed = 0;
@@ -178,21 +190,19 @@ void profiler_show(struct mame_bitmap *bitmap)
 			showdelay[i]--;
 
 			if (i < PROFILER_PROFILER)
-				sprintf(buf,"%s%3d%%%3d%%",names[i],
+				bufptr += sprintf(bufptr,"%s%3d%%%3d%%\n",names[i],
 						(int)((computed * 100 + total/2) / total),
 						(int)((computed * 100 + normalize/2) / normalize));
 			else
-				sprintf(buf,"%s%3d%%",names[i],
+				bufptr += sprintf(bufptr,"%s%3d%%\n",names[i],
 						(int)((computed * 100 + total/2) / total));
-			ui_text(bitmap,buf,0,(line++)*uirotcharheight);
 		}
 	}
 
 	i = 0;
 	for (j = 0;j < MEMORY;j++)
 		i += profile.cpu_context_switches[j];
-	sprintf(buf,"CPU switches%4d",i / MEMORY);
-	ui_text(bitmap,buf,0,(line++)*uirotcharheight);
+	bufptr += sprintf(bufptr,"CPU switches%4d\n",i / MEMORY);
 
 	/* reset the counters */
 	memory = (memory + 1) % MEMORY;
@@ -201,4 +211,6 @@ void profiler_show(struct mame_bitmap *bitmap)
 		profile.count[memory][i] = 0;
 
 	profiler_mark(PROFILER_END);
+
+	return buf;
 }
