@@ -1,8 +1,22 @@
-#ifndef PROFILER_H
-#define PROFILER_H
+/***************************************************************************
+
+    profiler.h
+
+    Functions to manage profiling of MAME execution.
+
+    Copyright (c) 1996-2006, Nicola Salmoria and the MAME Team.
+    Visit http://mamedev.org for licensing and usage restrictions.
+
+***************************************************************************/
+
+#pragma once
+
+#ifndef __PROFILER_H__
+#define __PROFILER_H__
 
 /* profiling */
-enum {
+enum
+{
 	PROFILER_END = -1,
 	PROFILER_CPU1 = 0,
 	PROFILER_CPU2,
@@ -27,6 +41,8 @@ enum {
 	PROFILER_TIMER_CALLBACK,
 	PROFILER_HISCORE,	/* high score load can slow things down if incorrectly written */
 	PROFILER_INPUT,		/* input.c and inptport.c */
+	PROFILER_MOVIE_REC,	/* movie recording */
+	PROFILER_LOGERROR,	/* logerror */
 	PROFILER_EXTRA,		/* everything else */
 
 	/* the USER types are available to driver writers to profile */
@@ -53,16 +69,19 @@ the profiler handles a FILO list so calls may be nested.
 */
 
 #ifdef MAME_DEBUG
-#define profiler_mark(type) profiler__mark(type)
-#else
-#define profiler_mark(type)
-#endif
-
-void profiler__mark(int type);
+void profiler_mark(int type);
 
 /* functions called by usrintf.c */
 void profiler_start(void);
 void profiler_stop(void);
-void profiler_show(struct mame_bitmap *bitmap);
+const char *profiler_get_text(void);
+#else
+#define profiler_mark(type)
 
-#endif	/* PROFILER_H */
+#define profiler_start()
+#define profiler_stop()
+#define profiler_get_text() ""
+#endif
+
+
+#endif	/* __PROFILER_H__ */
