@@ -2,31 +2,33 @@
 
 Battlezone sound info, courtesy of Al Kossow:
 
-D7	motor enable			this enables the engine sound
-D6	start LED
-D5	sound enable			this enables ALL sound outputs
-							including the POKEY output
-D4	engine rev en			this controls the engine speed
-							the engine sound is an integrated square
-							wave (saw tooth) that is frequency modulated
-							by engine rev.
-D3	shell loud, soft/		explosion volume
-D2	shell enable
-D1	explosion loud, soft/	explosion volume
-D0	explosion enable		gates a noise generator
+D7  motor enable            this enables the engine sound
+D6  start LED
+D5  sound enable            this enables ALL sound outputs
+                            including the POKEY output
+D4  engine rev en           this controls the engine speed
+                            the engine sound is an integrated square
+                            wave (saw tooth) that is frequency modulated
+                            by engine rev.
+D3  shell loud, soft/       explosion volume
+D2  shell enable
+D1  explosion loud, soft/   explosion volume
+D0  explosion enable        gates a noise generator
 
 */
 
 #include <math.h>
 #include "driver.h"
+#include "streams.h"
 #include "bzone.h"
+#include "sound/custom.h"
 
 
 /* Statics */
 static INT16 *discharge = NULL;
 #define EXP(charge,n) (charge ? 0x7fff - discharge[0x7fff-n] : discharge[n])
 
-static int channel;
+static sound_stream *channel;
 static int latch;
 static int poly_counter;
 static int poly_shift;
@@ -60,11 +62,12 @@ WRITE8_HANDLER( bzone_sounds_w )
 	stream_update(channel, 0);
     latch = data;
 
-    mixer_sound_enable_global_w(latch & 0x20);
+    sound_global_enable(latch & 0x20);
 }
 
-static void bzone_sound_update(int param, INT16 *buffer, int length)
+static void bzone_sound_update(void *param, stream_sample_t **inputs, stream_sample_t **outputs, int length)
 {
+	stream_sample_t *buffer = outputs[0];
 	while( length-- )
 	{
 		static int last_val = 0;
@@ -113,10 +116,10 @@ static void bzone_sound_update(int param, INT16 *buffer, int length)
 			if( explosion_amp > 0 )
 			{
 				/*
-				 * discharge C14 through R17 + R16
-				 * time constant is 10e-6 * 23000 = 0.23 seconds
-				 * (samples were decaying much slower: 1/4th rate? )
-				 */
+                 * discharge C14 through R17 + R16
+                 * time constant is 10e-6 * 23000 = 0.23 seconds
+                 * (samples were decaying much slower: 1/4th rate? )
+                 */
 				explosion_amp_counter -= (int)(32767 / (0.23*4));
 				if( explosion_amp_counter < 0 )
 				{
@@ -127,9 +130,9 @@ static void bzone_sound_update(int param, INT16 *buffer, int length)
 				}
 			}
 			/*
-			 * I don't know the amplification of the op-amp
-			 * and feedback, so the loud/soft values are arbitrary
-			 */
+             * I don't know the amplification of the op-amp
+             * and feedback, so the loud/soft values are arbitrary
+             */
 			if( latch & 0x02 )	/* explosion loud ? */
 				sum += EXP(0,explosion_amp)/3;
 			else
@@ -146,10 +149,10 @@ static void bzone_sound_update(int param, INT16 *buffer, int length)
 			if( shell_amp > 0 )
 			{
 				/*
-				 * discharge C9 through R14 + R15
-				 * time constant is 4.7e-6 * 23000 = 0.1081 seconds
-				 * (samples were decaying much slower: 1/4th rate? )
-				 */
+                 * discharge C9 through R14 + R15
+                 * time constant is 4.7e-6 * 23000 = 0.1081 seconds
+                 * (samples were decaying much slower: 1/4th rate? )
+                 */
 				shell_amp_counter -= (int)(32767 / (0.1081*4));
 				if( shell_amp_counter < 0 )
 				{
@@ -160,9 +163,9 @@ static void bzone_sound_update(int param, INT16 *buffer, int length)
 				}
 			}
 			/*
-			 * I don't know the amplification of the op-amp
-			 * and feedback, so the loud/soft values are arbitrary
-			 */
+             * I don't know the amplification of the op-amp
+             * and feedback, so the loud/soft values are arbitrary
+             */
 			if( latch & 0x08 )	/* shell loud ? */
 				sum += EXP(0,shell_amp)/3;
 			else
@@ -174,14 +177,14 @@ static void bzone_sound_update(int param, INT16 *buffer, int length)
 			static double r0 = 1.0/1e12, r1 = 1.0/1e12;
 
 			/* NE5555 timer
-			 * C = 0.018u, Ra = 100k, Rb = 125k
-			 * charge time = 0.693 * (Ra + Rb) * C = 3870us
-			 * discharge time = 0.693 * Rb * C = 1559.25us
-			 * freq approx. 184 Hz
-			 * I have no idea what frequencies are coming from the NE555
-			 * with "MOTOR REV EN" being high or low. I took 240Hz as
-			 * higher rate and sweep up or down to the new rate in 0.25s
-			 */
+             * C = 0.018u, Ra = 100k, Rb = 125k
+             * charge time = 0.693 * (Ra + Rb) * C = 3870us
+             * discharge time = 0.693 * Rb * C = 1559.25us
+             * freq approx. 184 Hz
+             * I have no idea what frequencies are coming from the NE555
+             * with "MOTOR REV EN" being high or low. I took 240Hz as
+             * higher rate and sweep up or down to the new rate in 0.25s
+             */
 			motor_rate_new = (latch & 0x10) ? 240 : 184;
 			if( motor_rate != motor_rate_new )
 			{
@@ -266,31 +269,15 @@ static void bzone_sound_update(int param, INT16 *buffer, int length)
 	}
 }
 
-int bzone_sh_start(const struct MachineSound *msound)
+void *bzone_sh_start(int clock, const struct CustomSound_interface *config)
 {
     int i;
 
 	discharge = (INT16 *)auto_malloc(32768 * sizeof(INT16));
-	if( !discharge )
-        return 1;
-
     for( i = 0; i < 0x8000; i++ )
 		discharge[0x7fff-i] = (INT16) (0x7fff/exp(1.0*i/4096));
 
-	channel = stream_init("Custom", 50, Machine->sample_rate, 0, bzone_sound_update);
-    if( channel == -1 )
-        return 1;
+	channel = stream_create(0, 1, Machine->sample_rate, 0, bzone_sound_update);
 
-    return 0;
+    return auto_malloc(1);
 }
-
-void bzone_sh_stop(void)
-{
-}
-
-void bzone_sh_update(void)
-{
-	stream_update(channel, 0);
-}
-
-
