@@ -1,9 +1,10 @@
 /*
- *	Depth Charge sound routines
+ *  Depth Charge sound routines
  */
 
 #include "driver.h"
-
+#include "sound/samples.h"
+#include "includes/vicdual.h"
 
 /* output port 0x01 definitions - sound effect drive outputs */
 #define OUT_PORT_1_LONGEXPL     0x01
