@@ -78,6 +78,7 @@
 ***************************************************************************/
 
 #include "driver.h"
+#include "streams.h"
 #include "cpu/i86/i186intf.h"
 #include "cpu/z80/z80.h"
 #include "leland.h"
@@ -135,10 +136,6 @@ void *leland_sh_start(int clock, const struct CustomSound_interface *config)
 	dac_bufin[0]  = dac_bufin[1]  = 0;
 	dac_bufout[0] = dac_bufout[1] = 0;
 
-	/* skip if no sound */
-	if (Machine->sample_rate == 0)
-		return auto_malloc(1);
-
 	/* allocate the stream */
 	dac_stream = stream_create(0, 1, 256*60, NULL, leland_update);
 
@@ -184,7 +181,6 @@ void leland_dac_update(int dacnum, UINT8 sample)
 #define LOG_DAC				0
 #define LOG_EXTERN			0
 #define LOG_PIT				0
-#define LOG_OPTIMIZATION	0
 
 
 /* according to the Intel manual, external interrupts are not latched */
@@ -192,7 +188,6 @@ void leland_dac_update(int dacnum, UINT8 sample)
 #define LATCH_INTS	1
 
 #define DAC_VOLUME_SCALE	4
-#define CPU_RESUME_TRIGGER	7123
 
 
 static sound_stream * dma_stream;
@@ -215,9 +210,6 @@ static UINT32 ext_stop;
 static UINT8 ext_active;
 static UINT8 *ext_base;
 
-static UINT8 *active_mask;
-static int total_reads;
-
 struct mem_state
 {
 	UINT16	lower;
@@ -361,11 +353,7 @@ static void leland_i186_dac_update(void *param, stream_sample_t **inputs, stream
 
 		/* update the clock status */
 		if (count < d->buftarget)
-		{
-			if (LOG_OPTIMIZATION) logerror("  - trigger due to clock active in update\n");
-			cpu_trigger(CPU_RESUME_TRIGGER);
 			clock_active |= 1 << i;
-		}
 	}
 }
 
@@ -386,6 +374,7 @@ static void leland_i186_dma_update(void *param, stream_sample_t **inputs, stream
 	memset(buffer, 0, length * sizeof(*buffer));
 
 	/* loop over DMA buffers */
+	cpuintrf_push_context(2);
 	for (i = 0; i < 2; i++)
 	{
 		struct dma_state *d = &i186.dma[i];
@@ -410,7 +399,6 @@ static void leland_i186_dma_update(void *param, stream_sample_t **inputs, stream
 			/* otherwise, we're ready for liftoff */
 			else
 			{
-				UINT8 *base = memory_region(REGION_CPU3);
 				int source = d->source;
 				int count = d->count;
 				int which, frac, step, volume;
@@ -428,7 +416,7 @@ static void leland_i186_dma_update(void *param, stream_sample_t **inputs, stream
 				/* sample-rate convert to the output frequency */
 				for (j = 0; j < length && count > 0; j++)
 				{
-					buffer[j] += ((int)base[source] - 0x80) * volume;
+					buffer[j] += ((int)program_read_byte(source) - 0x80) * volume;
 					frac += step;
 					source += frac >> 24;
 					count -= frac >> 24;
@@ -456,6 +444,7 @@ static void leland_i186_dma_update(void *param, stream_sample_t **inputs, stream
 			}
 		}
 	}
+	cpuintrf_pop_context();
 }
 
 
@@ -514,10 +503,6 @@ void *leland_i186_sh_start(int clock, const struct CustomSound_interface *config
 {
 	int i;
 
-	/* bail if nothing to play */
-	if (Machine->sample_rate == 0)
-		return auto_malloc(1);
-
 	/* determine which sound hardware is installed */
 	has_ym2151 = 0;
 	for (i = 0; i < MAX_SOUND; i++)
@@ -597,11 +582,6 @@ static void leland_i186_reset(void)
 	memset(&counter, 0, sizeof(counter));
 	for (i = 0; i < 9; i++)
 		counter[i].timer = counter_timer[i];
-
-	/* send a trigger in case we're suspended */
-	if (LOG_OPTIMIZATION) logerror("  - trigger due to reset\n");
-	cpu_trigger(CPU_RESUME_TRIGGER);
-	total_reads = 0;
 }
 
 
@@ -743,8 +723,6 @@ generate_int:
 	if (!i186.intr.pending)
 		cpunum_set_input_line(2, 0, ASSERT_LINE);
 	i186.intr.pending = 1;
-	cpu_trigger(CPU_RESUME_TRIGGER);
-	if (LOG_OPTIMIZATION) logerror("  - trigger due to interrupt pending\n");
 	if (LOG_INTERRUPTS) logerror("(%f) **** Requesting interrupt vector %02X\n", timer_get_time(), new_vector);
 }
 
@@ -1453,7 +1431,7 @@ static WRITE8_HANDLER( i186_internal_port_w )
 			/* we need to do this at a time when the I86 context is swapped in */
 			/* this register is generally set once at startup and never again, so it's a good */
 			/* time to set it up */
-			activecpu_set_info_fct(CPUINFO_PTR_IRQ_CALLBACK, (genf *)int_callback);
+			cpunum_set_irq_callback(cpu_getactivecpu(), int_callback);
 			break;
 
 		case 0xc0:
@@ -1805,15 +1783,9 @@ READ8_HANDLER( leland_i86_response_r )
 {
 	if (LOG_COMM) logerror("%04X:Read sound response latch = %02X\n", activecpu_get_previouspc(), sound_response);
 
-	/* if sound is disabled, toggle between FF and 00 */
-	if (Machine->sample_rate == 0)
-		return sound_response ^= 0xff;
-	else
-	{
-		/* synchronize the response */
-		timer_set(TIME_NOW, activecpu_get_previouspc() + 2, delayed_response_r);
-		return sound_response;
-	}
+	/* synchronize the response */
+	timer_set(TIME_NOW, activecpu_get_previouspc() + 2, delayed_response_r);
+	return sound_response;
 }
 
 
@@ -1849,11 +1821,7 @@ static void set_dac_frequency(int which, int frequency)
 	if (count > d->buftarget)
 		clock_active &= ~(1 << which);
 	else if (count < d->buftarget)
-	{
-		if (LOG_OPTIMIZATION) logerror("  - trigger due to clock active in set_dac_frequency\n");
-		cpu_trigger(CPU_RESUME_TRIGGER);
 		clock_active |= 1 << which;
-	}
 
 	if (LOG_DAC) logerror("DAC %d frequency = %d, step = %08X\n", which, d->frequency, d->step);
 }
@@ -2066,17 +2034,6 @@ static READ8_HANDLER( peripheral_r )
 				else
 					result = ((clock_active << 1) & 0x7e);
 
-				if (!i186.intr.pending && active_mask && (*active_mask & result) == 0 && ++total_reads > 100)
-				{
-					if (LOG_OPTIMIZATION) logerror("Suspended CPU: active_mask = %02X, result = %02X\n", *active_mask, result);
-					cpu_spinuntil_trigger(CPU_RESUME_TRIGGER);
-				}
-				else if (LOG_OPTIMIZATION)
-				{
-					if (i186.intr.pending) logerror("(can't suspend - interrupt pending)\n");
-					else if (active_mask && (*active_mask & result) != 0) logerror("(can't suspend: mask=%02X result=%02X\n", *active_mask, result);
-				}
-
 				return result;
 			}
 
@@ -2150,22 +2107,6 @@ static WRITE8_HANDLER( peripheral_w )
 
 
 
-/*************************************
- *
- *  Optimizations
- *
- *************************************/
-
-void leland_i86_optimize_address(offs_t offset)
-{
-	if (offset)
-		active_mask = memory_region(REGION_CPU3) + offset;
-	else
-		active_mask = NULL;
-}
-
-
-
 /*************************************
  *
  *  Game-specific handlers
