@@ -1,11 +1,12 @@
 /*************************************************************************
 
-	Sega Z80-3D system
+    Sega Z80-3D system
 
 *************************************************************************/
 
 #include "driver.h"
 #include "turbo.h"
+#include "sound/samples.h"
 
 
 #define DISCRETE_TEST (0)
@@ -73,11 +74,11 @@ DISCRETE_SOUND_START(turbo_sound_interface)
 	/* 5-5-5 counter provides the input clock */
 	DISCRETE_555_ASTABLE(NODE_50,1,470,120,0.1e-6,&turbo_alarm_555)
 	/* which clocks a 74393 dual 4-bit counter, clocked on the falling edge */
-	DISCRETE_COUNTER(NODE_51,1,0,NODE_50,15,1,0,0)
+	DISCRETE_COUNTER(NODE_51,1,0,NODE_50,15,1,0,DISC_CLK_ON_F_EDGE)
 	/* the high bit of this counter */
 	DISCRETE_TRANSFORM2(NODE_52,1,NODE_51,8,"01/")
 	/* clocks the other half of the 74393 */
-	DISCRETE_COUNTER(NODE_53,1,0,NODE_52,15,1,0,0)
+	DISCRETE_COUNTER(NODE_53,1,0,NODE_52,15,1,0,DISC_CLK_ON_F_EDGE)
 
 	/* trig1 triggers a LS123 retriggerable multivibrator */
 	DISCRETE_ONESHOT(NODE_60,TURBO_TRIG1_INV,5.0,(0.33e-9)*47*1e6, DISC_ONESHOT_FEDGE|DISC_ONESHOT_RETRIG|DISC_OUT_ACTIVE_HIGH)
@@ -110,30 +111,30 @@ DISCRETE_SOUND_START(turbo_sound_interface)
 
 /*
 
-	the rest of the circuit looks like this:
+    the rest of the circuit looks like this:
 
-	                  +5V            +12V                                +---+
-	                   ^              ^   +--------+               1K    v   |
-	                   |              |   | |\     |           +---NNN--NNN--+
-	                   Z 1K       10K Z   | | \    |           | |\     20K  |   +--|(----> ALARM_M
-	                   Z              Z   +-|- \   |           | | \         |   |  4.7u
-	                   |              |     |   >--+---NNNN----+-|- \        |   +--|(----> ALARM_F
-	                   +--NNNN--|(----+-----|+ /        22K      |   >-------+---+  4.7u
-	+-\                |  5.1K  4.7u  |     | /             +6V--|+ /            +--|(----> ALARM_R
-	|  >o---(NODE_62)--+              Z     |/                   | /             |  4.7u
-	+-/                |          10K Z                          |/              +--|(----> ALARM_L
+                      +5V            +12V                                +---+
+                       ^              ^   +--------+               1K    v   |
+                       |              |   | |\     |           +---NNN--NNN--+
+                       Z 1K       10K Z   | | \    |           | |\     20K  |   +--|(----> ALARM_M
+                       Z              Z   +-|- \   |           | | \         |   |  4.7u
+                       |              |     |   >--+---NNNN----+-|- \        |   +--|(----> ALARM_F
+                       +--NNNN--|(----+-----|+ /        22K      |   >-------+---+  4.7u
+    +-\                |  5.1K  4.7u  |     | /             +6V--|+ /            +--|(----> ALARM_R
+    |  >o---(NODE_62)--+              Z     |/                   | /             |  4.7u
+    +-/                |          10K Z                          |/              +--|(----> ALARM_L
                        |              |                                             4.7u
-	+-\                |              v
-	|  >o---(NODE_66)--+             GND
-	+-/                |
+    +-\                |              v
+    |  >o---(NODE_66)--+             GND
+    +-/                |
                        |
-	+-\                |
-	|  >o---(NODE_72)--+
-	+-/                |
+    +-\                |
+    |  >o---(NODE_72)--+
+    +-/                |
                        |
-	+-\                |
-	|  >o---(NODE_77)--+
-	+-/
+    +-\                |
+    |  >o---(NODE_77)--+
+    +-/
 
 
 */
@@ -141,8 +142,8 @@ DISCRETE_SOUND_START(turbo_sound_interface)
 	/************************************************/
 	/* Combine all 7 sound sources.                 */
 	/************************************************/
-	DISCRETE_GAIN(NODE_81,NODE_80,16000)
-	DISCRETE_OUTPUT(NODE_81, 100)
+
+	DISCRETE_OUTPUT(NODE_80, 16000)
 DISCRETE_SOUND_END
 
 #endif
@@ -151,7 +152,7 @@ DISCRETE_SOUND_END
 
 /*******************************************
 
-	Sample handling
+    Sample handling
 
 *******************************************/
 
@@ -185,7 +186,7 @@ static void buckrog_update_samples(void)
 
 /*******************************************
 
-	Turbo sound handling
+    Turbo sound handling
 
 *******************************************/
 
@@ -208,8 +209,8 @@ if (!((data >> 2) & 1)) printf("/TRIG2\n");
 if (!((data >> 3) & 1)) printf("/TRIG3\n");
 if (!((data >> 4) & 1)) printf("/TRIG4\n");
 
-/*	osel = (osel & 6) | ((data >> 5) & 1); */
-/*	turbo_update_samples(); */
+/*  osel = (osel & 6) | ((data >> 5) & 1); */
+/*  turbo_update_samples(); */
 }
 #endif
 
@@ -217,15 +218,15 @@ if (!((data >> 4) & 1)) printf("/TRIG4\n");
 WRITE8_HANDLER( turbo_sound_A_w )
 {
 	/*
-		2PA0 = /CRASH
-		2PA1 = /TRIG1
-		2PA2 = /TRIG2
-		2PA3 = /TRIG3
-		2PA4 = /TRIG4
-		2PA5 = OSEL0
-		2PA6 = /SLIP
-		2PA7 = /CRASHL
-	*/
+        2PA0 = /CRASH
+        2PA1 = /TRIG1
+        2PA2 = /TRIG2
+        2PA3 = /TRIG3
+        2PA4 = /TRIG4
+        2PA5 = OSEL0
+        2PA6 = /SLIP
+        2PA7 = /CRASHL
+    */
 #if (DISCRETE_TEST)
 	if (((data ^ last_sound_A) & 0x1e) && (last_sound_A & 0x1e) != 0x1e)
 		timer_set(TIME_IN_HZ(20000), data, update_sound_A);
@@ -250,15 +251,15 @@ WRITE8_HANDLER( turbo_sound_A_w )
 WRITE8_HANDLER( turbo_sound_B_w )
 {
 	/*
-		2PB0 = ACC0
-		2PB1 = ACC1
-		2PB2 = ACC2
-		2PB3 = ACC3
-		2PB4 = ACC4
-		2PB5 = ACC5
-		2PB6 = /AMBU
-		2PB7 = /SPIN
-	*/
+        2PB0 = ACC0
+        2PB1 = ACC1
+        2PB2 = ACC2
+        2PB3 = ACC3
+        2PB4 = ACC4
+        2PB5 = ACC5
+        2PB6 = /AMBU
+        2PB7 = /SPIN
+    */
 	turbo_accel = data & 0x3f;
 	turbo_update_samples();
 	if (!(data & 0x40))
@@ -277,15 +278,15 @@ WRITE8_HANDLER( turbo_sound_B_w )
 WRITE8_HANDLER( turbo_sound_C_w )
 {
 	/*
-		2PC0 = OSEL1
-		2PC1 = OSEL2
-		2PC2 = BSEL0
-		2PC3 = BSEL1
-		2PC4 = SPEED0
-		2PC5 = SPEED1
-		2PC6 = SPEED2
-		2PC7 = SPEED3
-	*/
+        2PC0 = OSEL1
+        2PC1 = OSEL2
+        2PC2 = BSEL0
+        2PC3 = BSEL1
+        2PC4 = SPEED0
+        2PC5 = SPEED1
+        2PC6 = SPEED2
+        2PC7 = SPEED3
+    */
 	turbo_speed = (data >> 4) & 0x0f;
 	bsel = (data >> 2) & 3;
 	osel = (osel & 1) | ((data & 3) << 1);
@@ -297,7 +298,7 @@ WRITE8_HANDLER( turbo_sound_C_w )
 
 /*******************************************
 
-	Subroc3D 8255 PPI handling
+    Subroc3D 8255 PPI handling
 
 *******************************************/
 
@@ -314,7 +315,7 @@ WRITE8_HANDLER( subroc3d_sound_B_w )
 {
 	static UINT8 last = 0;
 
-	int volume = 16 * (15 - subroc3d_volume);
+	float volume = (15 - subroc3d_volume) / 15.0;
 
 	if ((data & 1) && !(last & 1))
 		sample_set_volume(0, volume);
@@ -342,18 +343,18 @@ WRITE8_HANDLER( subroc3d_sound_C_w )
 	if ((data & 0x10) && !(last & 0x10))
 		sample_start(5, (data & 0x20) ? 10 : 9, 0);
 
-	sample_set_volume(7, (data & 0x40) ? 0 : 255);
+	sample_set_volume(7, (data & 0x40) ? 0 : 1.0);
 
 	last = data;
 
-	mixer_sound_enable_global_w(!(data & 0x80));
+	sound_global_enable(!(data & 0x80));
 }
 
 
 
 /*******************************************
 
-	Buck Rogers 8255 PPI handling
+    Buck Rogers 8255 PPI handling
 
 *******************************************/
 
@@ -401,7 +402,7 @@ WRITE8_HANDLER( buckrog_sound_B_w )
 	if (!(data & 0x40) && sample_playing(0))
 		sample_stop(0);
 
-	mixer_sound_enable_global_w(data & 0x80);
+	sound_global_enable(data & 0x80);
 
 	last = data;
 }
